#include "py/mpconfig.h"
#include "py/objint.h"
#include "py/objstr.h"
#include "py/emitglue.h"

#if MICROPY_OPT_CACHE_MAP_LOOKUP_IN_BYTECODE != 0
#error "incompatible MICROPY_OPT_CACHE_MAP_LOOKUP_IN_BYTECODE"
#endif

#if MICROPY_LONGINT_IMPL != 2
#error "incompatible MICROPY_LONGINT_IMPL"
#endif

#if MPZ_DIG_SIZE != 16
#error "incompatible MPZ_DIG_SIZE"
#endif

#if MICROPY_PY_BUILTINS_FLOAT
typedef struct _mp_obj_float_t {
    mp_obj_base_t base;
    mp_float_t value;
} mp_obj_float_t;
#endif

#if MICROPY_PY_BUILTINS_COMPLEX
typedef struct _mp_obj_complex_t {
    mp_obj_base_t base;
    mp_float_t real;
    mp_float_t imag;
} mp_obj_complex_t;
#endif

enum {
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py = MP_QSTRnumber_of,
    MP_QSTR_HCI_READ_PACKET_SIZE,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci,
    MP_QSTR_OCF_DISCONNECT,
    MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST,
    MP_QSTR_OCF_LE_CLEAR_WHITE_LIST,
    MP_QSTR_OCF_LE_CREATE_CONN,
    MP_QSTR_OCF_LE_CREATE_CONN_CANCEL,
    MP_QSTR_OCF_LE_ENCRYPT,
    MP_QSTR_OCF_LE_LTK_NEG_REPLY,
    MP_QSTR_OCF_LE_LTK_REPLY,
    MP_QSTR_OCF_LE_RAND,
    MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER,
    MP_QSTR_OCF_LE_READ_BUFFER_SIZE,
    MP_QSTR_OCF_LE_READ_CHANNEL_MAP,
    MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES,
    MP_QSTR_OCF_LE_READ_SUPPORTED_STATES,
    MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE,
    MP_QSTR_OCF_LE_RECEIVER_TEST,
    MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST,
    MP_QSTR_OCF_LE_SET_ADV_DATA,
    MP_QSTR_OCF_LE_SET_ADV_PARAMETERS,
    MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE,
    MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS,
    MP_QSTR_OCF_LE_SET_SCAN_ENABLE,
    MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS,
    MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA,
    MP_QSTR_OCF_LE_TEST_END,
    MP_QSTR_OCF_LE_TRANSMITTER_TEST,
    MP_QSTR_OCF_READ_BD_ADDR,
    MP_QSTR_OCF_READ_LOCAL_VERSION,
    MP_QSTR_OCF_READ_RSSI,
    MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL,
    MP_QSTR_OCF_RESET,
    MP_QSTR_OGF_HOST_CTL,
    MP_QSTR_OGF_INFO_PARAM,
    MP_QSTR_OGF_LE_CTL,
    MP_QSTR_OGF_LINK_CTL,
    MP_QSTR_OGF_STATUS_PARAM,
    MP_QSTR_HCI_COMMAND,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_cmd,
    MP_QSTR_HardwareException,
    MP_QSTR_BaseHCI,
    MP_QSTR_self,
    MP_QSTR_message,
    MP_QSTR_hci_send_cmd,
    MP_QSTR_hci_reset,
    MP_QSTR_hci_disconnect,
    MP_QSTR_hci_le_read_local_version,
    MP_QSTR_hci_le_read_buffer_size,
    MP_QSTR_hci_le_set_advertising_parameters,
    MP_QSTR_hci_le_set_advertising_data,
    MP_QSTR_hci_le_set_advertise_enable,
    MP_QSTR_hci_le_set_scan_parameters,
    MP_QSTR_hci_le_set_scan_enable,
    MP_QSTR_hci_le_rand,
    MP_QSTR_hci_le_set_scan_resp_data,
    MP_QSTR_hci_le_read_advertising_channel_tx_power,
    MP_QSTR_hci_le_set_random_address,
    MP_QSTR_hci_read_bd_addr,
    MP_QSTR_hci_le_create_connection,
    MP_QSTR_hci_le_create_connection_cancel,
    MP_QSTR_hci_le_encrypt,
    MP_QSTR_hci_le_ltk_request_reply,
    MP_QSTR_hci_le_ltk_request_neg_reply,
    MP_QSTR_hci_le_read_white_list_size,
    MP_QSTR_hci_le_clear_white_list,
    MP_QSTR_hci_le_add_device_to_white_list,
    MP_QSTR_hci_le_remove_device_from_white_list,
    MP_QSTR_hci_read_transmit_power_level,
    MP_QSTR_hci_read_rssi,
    MP_QSTR_hci_le_read_local_supported_features,
    MP_QSTR_hci_le_read_channel_map,
    MP_QSTR_hci_le_read_supported_states,
    MP_QSTR_hci_le_receiver_test,
    MP_QSTR_hci_le_transmitter_test,
    MP_QSTR_hci_le_test_end,
    MP_QSTR_cmd,
    MP_QSTR_is_async,
    MP_QSTR_retry,
    MP_QSTR_ogf,
    MP_QSTR_ocf,
    MP_QSTR__lt_HB,
    MP_QSTR_handle,
    MP_QSTR_reason,
    MP_QSTR__lt_HHBBB6sBB,
    MP_QSTR_min_interval,
    MP_QSTR_max_interval,
    MP_QSTR_advtype,
    MP_QSTR_own_bdaddr_type,
    MP_QSTR_direct_bdaddr_type,
    MP_QSTR_direct_bdaddr,
    MP_QSTR_chan_map,
    MP_QSTR_filter_,
    MP_QSTR__lt_B_brace_open__colon_d_brace_close_s,
    MP_QSTR_length,
    MP_QSTR__lt_B,
    MP_QSTR__lt_BHHBB,
    MP_QSTR_type_,
    MP_QSTR_interval,
    MP_QSTR_window,
    MP_QSTR__lt_BB,
    MP_QSTR_filter_dup,
    MP_QSTR__lt_6s,
    MP_QSTR_bdaddr,
    MP_QSTR_initiator_filter,
    MP_QSTR_peer_bdaddr_type,
    MP_QSTR_peer_bdaddr,
    MP_QSTR_latency,
    MP_QSTR_supervision_timeout,
    MP_QSTR_min_ce_length,
    MP_QSTR_max_ce_length,
    MP_QSTR__lt_16s16s,
    MP_QSTR_plaintext_data,
    MP_QSTR__lt_H16s,
    MP_QSTR__lt_H,
    MP_QSTR__lt_B6s,
    MP_QSTR_bdaddr_type,
    MP_QSTR_frequency,
    MP_QSTR__lt_BBB,
    MP_QSTR_payload,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py,
    MP_QSTR_bluetooth_low_energy_dot_modules_dot_base_hci,
    MP_QSTR_HCI_COMMAND_PKT,
    MP_QSTR_HCI_EVENT_HDR_SIZE,
    MP_QSTR_HCI_EVENT_PKT,
    MP_QSTR_HCI_COMMANDS,
    MP_QSTR_OGF_VENDOR_CMD,
    MP_QSTR_EVT_CMD_COMPLETE,
    MP_QSTR_EVT_CMD_STATUS,
    MP_QSTR_EVT_HARDWARE_ERROR,
    MP_QSTR_EVT_LE_META_EVENT,
    MP_QSTR_EVT_VENDOR,
    MP_QSTR_HCI_EVENT,
    MP_QSTR_HCI_EVENTS,
    MP_QSTR_HCI_VENDOR_EVENTS,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_event,
    MP_QSTR_BLE_STATUS_SUCCESS,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_status,
    MP_QSTR_HCI_UART,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_uart,
    MP_QSTR_HCI_VENDOR_COMMANDS,
    MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ,
    MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ,
    MP_QSTR_OCF_ATT_FIND_INFO_REQ,
    MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ,
    MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ,
    MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ,
    MP_QSTR_OCF_GAP_ALLOW_REBOND_DB,
    MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE,
    MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB,
    MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST,
    MP_QSTR_OCF_GAP_CREATE_CONNECTION,
    MP_QSTR_OCF_GAP_DELETE_AD_TYPE,
    MP_QSTR_OCF_GAP_GET_BONDED_DEVICES,
    MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL,
    MP_QSTR_OCF_GAP_INIT,
    MP_QSTR_OCF_GAP_IS_DEVICE_BONDED,
    MP_QSTR_OCF_GAP_PASSKEY_RESPONSE,
    MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS,
    MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST,
    MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT,
    MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT,
    MP_QSTR_OCF_GAP_SET_BROADCAST_MODE,
    MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE,
    MP_QSTR_OCF_GAP_SET_DISCOVERABLE,
    MP_QSTR_OCF_GAP_SET_IO_CAPABILITY,
    MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE,
    MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE,
    MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE,
    MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE,
    MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST,
    MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC,
    MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE,
    MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC,
    MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC,
    MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC,
    MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC,
    MP_QSTR_OCF_GAP_START_OBSERVATION_PROC,
    MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC,
    MP_QSTR_OCF_GAP_TERMINATE,
    MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE,
    MP_QSTR_OCF_GAP_UPDATE_ADV_DATA,
    MP_QSTR_OCF_GATT_ADD_CHAR,
    MP_QSTR_OCF_GATT_ADD_CHAR_DESC,
    MP_QSTR_OCF_GATT_ADD_SERV,
    MP_QSTR_OCF_GATT_ALLOW_READ,
    MP_QSTR_OCF_GATT_CONFIRM_INDICATION,
    MP_QSTR_OCF_GATT_DEL_CHAR,
    MP_QSTR_OCF_GATT_DEL_INC_SERV,
    MP_QSTR_OCF_GATT_DEL_SERV,
    MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS,
    MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV,
    MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES,
    MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID,
    MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID,
    MP_QSTR_OCF_GATT_EXCHANGE_CONFIG,
    MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES,
    MP_QSTR_OCF_GATT_INCLUDE_SERV,
    MP_QSTR_OCF_GATT_INIT,
    MP_QSTR_OCF_GATT_READ_CHAR_DESC,
    MP_QSTR_OCF_GATT_READ_CHARAC_VAL,
    MP_QSTR_OCF_GATT_READ_HANDLE_VALUE,
    MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET,
    MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC,
    MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL,
    MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL,
    MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID,
    MP_QSTR_OCF_GATT_SET_DESC_VAL,
    MP_QSTR_OCF_GATT_SET_EVT_MASK,
    MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION,
    MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE,
    MP_QSTR_OCF_GATT_UPD_CHAR_VAL,
    MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT,
    MP_QSTR_OCF_GATT_WRITE_CHAR_DESC,
    MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE,
    MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE,
    MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC,
    MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL,
    MP_QSTR_OCF_GATT_WRITE_RESPONSE,
    MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE,
    MP_QSTR_OCF_GET_UPDATER_BUFSIZE,
    MP_QSTR_OCF_GET_UPDATER_VERSION,
    MP_QSTR_OCF_HAL_DEVICE_STANDBY,
    MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD,
    MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER,
    MP_QSTR_OCF_HAL_GET_LINK_STATUS,
    MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER,
    MP_QSTR_OCF_HAL_READ_CONFIG_DATA,
    MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL,
    MP_QSTR_OCF_HAL_TONE_START,
    MP_QSTR_OCF_HAL_TONE_STOP,
    MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA,
    MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ,
    MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP,
    MP_QSTR_OCF_UPDATER_CALC_CRC,
    MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG,
    MP_QSTR_OCF_UPDATER_ERASE_SECTOR,
    MP_QSTR_OCF_UPDATER_HW_VERSION,
    MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK,
    MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK,
    MP_QSTR_OCF_UPDATER_REBOOT,
    MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG,
    MP_QSTR_OCF_UPDATER_START,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_cmd,
    MP_QSTR_UUID_TYPE_16,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_constant,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_event,
    MP_QSTR_ST_HCI_VENDOR_EVENTS,
    MP_QSTR_HCI_PCK_TYPE_OFFSET,
    MP_QSTR_EVENT_PARAMETER_TOT_LEN_OFFSET,
    MP_QSTR_CSContext,
    MP_QSTR_BlueNRG_MS,
    MP_QSTR__pin,
    MP_QSTR_exc_type,
    MP_QSTR_exc_value,
    MP_QSTR_traceback,
    MP_QSTR_x,
    MP_QSTR_Y3,
    MP_QSTR_Y4,
    MP_QSTR_Y5,
    MP_QSTR_set_spi_irq_as_output,
    MP_QSTR_set_spi_irq_as_input,
    MP_QSTR_hw_bootloader,
    MP_QSTR_run,
    MP_QSTR___start__,
    MP_QSTR___stop__,
    MP_QSTR___process__,
    MP_QSTR_hci_verify,
    MP_QSTR_hci_wait_event,
    MP_QSTR_hci_send,
    MP_QSTR_get_version,
    MP_QSTR_aci_gap_init_IDB04A1,
    MP_QSTR_aci_gap_init_IDB05A1,
    MP_QSTR_aci_gap_set_non_discoverable,
    MP_QSTR_aci_gap_set_limited_discoverable,
    MP_QSTR_aci_gap_set_discoverable,
    MP_QSTR_aci_gap_set_direct_connectable_IDB05A1,
    MP_QSTR_aci_gap_set_direct_connectable_IDB04A1,
    MP_QSTR_aci_gap_set_io_capability,
    MP_QSTR_aci_gap_set_auth_requirement,
    MP_QSTR_aci_gap_set_author_requirement,
    MP_QSTR_aci_gap_pass_key_response,
    MP_QSTR_aci_gap_authorization_response,
    MP_QSTR_aci_gap_set_non_connectable_IDB05A1,
    MP_QSTR_aci_gap_set_non_connectable_IDB04A1,
    MP_QSTR_aci_gap_set_undirected_connectable,
    MP_QSTR_aci_gap_slave_security_request,
    MP_QSTR_aci_gap_update_adv_data,
    MP_QSTR_aci_gap_delete_ad_type,
    MP_QSTR_aci_gap_get_security_level,
    MP_QSTR_aci_gap_configure_whitelist,
    MP_QSTR_aci_gap_terminate,
    MP_QSTR_aci_gap_clear_security_database,
    MP_QSTR_aci_gap_allow_rebond_IDB05A1,
    MP_QSTR_aci_gap_allow_rebond_IDB04A1,
    MP_QSTR_aci_gap_start_limited_discovery_proc,
    MP_QSTR_aci_gap_start_general_discovery_proc,
    MP_QSTR_aci_gap_start_name_discovery_proc,
    MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB05A1,
    MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB04A1,
    MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB05A1,
    MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB04A1,
    MP_QSTR_aci_gap_start_selective_conn_establish_proc,
    MP_QSTR_aci_gap_create_connection,
    MP_QSTR_aci_gap_terminate_gap_procedure,
    MP_QSTR_aci_gap_start_connection_update,
    MP_QSTR_aci_gap_send_pairing_request,
    MP_QSTR_aci_gap_resolve_private_address_IDB05A1,
    MP_QSTR_aci_gap_resolve_private_address_IDB04A1,
    MP_QSTR_aci_gap_set_broadcast_mode,
    MP_QSTR_aci_gap_start_observation_procedure,
    MP_QSTR_aci_gap_is_device_bonded,
    MP_QSTR_aci_gap_get_bonded_devices,
    MP_QSTR_aci_gatt_init,
    MP_QSTR_aci_gatt_add_serv,
    MP_QSTR_aci_gatt_include_service,
    MP_QSTR_aci_gatt_add_char,
    MP_QSTR_aci_gatt_add_char_desc,
    MP_QSTR_aci_gatt_update_char_value,
    MP_QSTR_aci_gatt_del_char,
    MP_QSTR_aci_gatt_del_service,
    MP_QSTR_aci_gatt_del_include_service,
    MP_QSTR_aci_gatt_set_event_mask,
    MP_QSTR_aci_gatt_exchange_configuration,
    MP_QSTR_aci_att_find_information_req,
    MP_QSTR_aci_att_find_by_type_value_req,
    MP_QSTR_aci_att_read_by_type_req,
    MP_QSTR_aci_att_read_by_group_type_req,
    MP_QSTR_aci_att_prepare_write_req,
    MP_QSTR_aci_att_execute_write_req,
    MP_QSTR_aci_gatt_disc_all_prim_services,
    MP_QSTR_aci_gatt_disc_prim_service_by_uuid,
    MP_QSTR_aci_gatt_find_included_services,
    MP_QSTR_aci_gatt_disc_all_charac_of_serv,
    MP_QSTR_aci_gatt_disc_charac_by_uuid,
    MP_QSTR_aci_gatt_disc_all_charac_descriptors,
    MP_QSTR_aci_gatt_read_charac_val,
    MP_QSTR_aci_gatt_read_using_charac_uuid,
    MP_QSTR_aci_gatt_read_long_charac_val,
    MP_QSTR_aci_gatt_read_multiple_charac_val,
    MP_QSTR_aci_gatt_write_charac_value,
    MP_QSTR_aci_gatt_write_long_charac_val,
    MP_QSTR_aci_gatt_write_charac_reliable,
    MP_QSTR_aci_gatt_write_long_charac_desc,
    MP_QSTR_aci_gatt_read_long_charac_desc,
    MP_QSTR_aci_gatt_write_charac_descriptor,
    MP_QSTR_aci_gatt_read_charac_desc,
    MP_QSTR_aci_gatt_write_without_response,
    MP_QSTR_aci_gatt_signed_write_without_resp,
    MP_QSTR_aci_gatt_confirm_indication,
    MP_QSTR_aci_gatt_write_response,
    MP_QSTR_aci_gatt_allow_read,
    MP_QSTR_aci_gatt_set_security_permission,
    MP_QSTR_aci_gatt_set_desc_value,
    MP_QSTR_aci_gatt_read_handle_value,
    MP_QSTR_aci_gatt_read_handle_value_offset_IDB05A1,
    MP_QSTR_aci_gatt_update_char_value_ext_IDB05A1,
    MP_QSTR_aci_hal_get_fw_build_number,
    MP_QSTR_aci_hal_write_config_data,
    MP_QSTR_aci_hal_read_config_data,
    MP_QSTR_aci_hal_set_tx_power_level,
    MP_QSTR_aci_hal_le_tx_test_packet_number,
    MP_QSTR_aci_hal_device_standby,
    MP_QSTR_aci_hal_tone_start,
    MP_QSTR_aci_hal_tone_stop,
    MP_QSTR_aci_hal_get_link_status,
    MP_QSTR_aci_hal_get_anchor_period,
    MP_QSTR_aci_l2cap_connection_parameter_update_request,
    MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB05A1,
    MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB04A1,
    MP_QSTR_aci_updater_start,
    MP_QSTR_aci_updater_reboot,
    MP_QSTR_aci_get_updater_version,
    MP_QSTR_aci_get_updater_buffer_size,
    MP_QSTR_aci_erase_blue_flag,
    MP_QSTR_aci_reset_blue_flag,
    MP_QSTR_aci_updater_erase_sector,
    MP_QSTR_aci_updater_program_data_block,
    MP_QSTR_aci_updater_read_data_block,
    MP_QSTR_aci_updater_calc_crc,
    MP_QSTR_aci_updater_hw_version,
    MP_QSTR__spi_bus,
    MP_QSTR__irq_pin,
    MP_QSTR__rst_pin,
    MP_QSTR__nss_pin,
    MP_QSTR_spi_bus,
    MP_QSTR_irq_pin,
    MP_QSTR_rst_pin,
    MP_QSTR_nss_pin,
    MP_QSTR_callback_time,
    MP_QSTR_event,
    MP_QSTR_size,
    MP_QSTR_header,
    MP_QSTR_param,
    MP_QSTR_hci_pckt,
    MP_QSTR_from_buffer,
    MP_QSTR_pkt_type,
    MP_QSTR_evtcode,
    MP_QSTR_subevtcode,
    MP_QSTR_to_buffer,
    MP_QSTR__struct_size,
    MP_QSTR__lt_B3s,
    MP_QSTR_opcode,
    MP_QSTR_status,
    MP_QSTR_struct_size,
    MP_QSTR_response_data,
    MP_QSTR_response_struct,
    MP_QSTR_hci_revision,
    MP_QSTR_lmp_pal_subversion,
    MP_QSTR_dev,
    MP_QSTR__dot_,
    MP_QSTR_role,
    MP_QSTR_privacy_enabled,
    MP_QSTR_device_name_char_len,
    MP_QSTR_adv_type,
    MP_QSTR_adv_interv_min,
    MP_QSTR_adv_interv_max,
    MP_QSTR_own_addr_type,
    MP_QSTR_adv_filter_policy,
    MP_QSTR_local_name_len,
    MP_QSTR_local_name,
    MP_QSTR_service_uuid_len,
    MP_QSTR_service_uuid_list,
    MP_QSTR_slave_conn_interv_min,
    MP_QSTR_slave_conn_interv_max,
    MP_QSTR__lt_BBB6sHH,
    MP_QSTR_directed_adv_type,
    MP_QSTR_initiator_addr_type,
    MP_QSTR_initiator_addr,
    MP_QSTR__lt_BB6s,
    MP_QSTR_io_capability,
    MP_QSTR_mitm_mode,
    MP_QSTR_oob_enable,
    MP_QSTR_oob_data,
    MP_QSTR_min_encryption_key_size,
    MP_QSTR_max_encryption_key_size,
    MP_QSTR_use_fixed_pin,
    MP_QSTR_fixed_pin,
    MP_QSTR_bonding_mode,
    MP_QSTR_conn_handle,
    MP_QSTR_authorization_enable,
    MP_QSTR__lt_HI,
    MP_QSTR_passkey,
    MP_QSTR_authorize,
    MP_QSTR_own_address_type,
    MP_QSTR__lt_HBB,
    MP_QSTR_bonding,
    MP_QSTR_mitm_protection,
    MP_QSTR_adv_len,
    MP_QSTR_adv_data,
    MP_QSTR_ad_type,
    MP_QSTR__lt_HHBB,
    MP_QSTR_scan_interval,
    MP_QSTR_scan_window,
    MP_QSTR_filter_duplicates,
    MP_QSTR_conn_min_interval,
    MP_QSTR_conn_max_interval,
    MP_QSTR_conn_latency,
    MP_QSTR_min_conn_length,
    MP_QSTR_max_conn_length,
    MP_QSTR_num_whitelist_entries,
    MP_QSTR_addr_array,
    MP_QSTR_use_reconn_addr,
    MP_QSTR_reconn_addr,
    MP_QSTR_scan_type,
    MP_QSTR__lt_BHHBB6s,
    MP_QSTR_procedure_code,
    MP_QSTR__lt_HHHHHHH,
    MP_QSTR_force_rebond,
    MP_QSTR_private_address,
    MP_QSTR_adv_data_length,
    MP_QSTR__lt_HHBBB,
    MP_QSTR_peer_address_type,
    MP_QSTR_peer_address,
    MP_QSTR__lt_B_brace_open__colon_d_brace_close_sBB,
    MP_QSTR_service_uuid_type,
    MP_QSTR_service_uuid,
    MP_QSTR_service_type,
    MP_QSTR_max_attr_records,
    MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s,
    MP_QSTR_service_handle,
    MP_QSTR_included_start_handle,
    MP_QSTR_included_end_handle,
    MP_QSTR_included_uuid_type,
    MP_QSTR_included_uuid,
    MP_QSTR_char_uuid_type,
    MP_QSTR_char_uuid,
    MP_QSTR_char_value_len,
    MP_QSTR_char_properties,
    MP_QSTR_sec_permissions,
    MP_QSTR_gatt_evt_mask,
    MP_QSTR_encry_key_size,
    MP_QSTR_is_variable,
    MP_QSTR_char_handle,
    MP_QSTR_desc_uuid_type,
    MP_QSTR_uuid,
    MP_QSTR_desc_value_max_len,
    MP_QSTR_desc_value_len,
    MP_QSTR_desc_value,
    MP_QSTR_acc_permissions,
    MP_QSTR__lt_HHBB_brace_open__colon_d_brace_close_s,
    MP_QSTR_serv_handle,
    MP_QSTR_char_val_offset,
    MP_QSTR_char_value,
    MP_QSTR__lt_HH,
    MP_QSTR_include_serv_handle,
    MP_QSTR__lt_I,
    MP_QSTR_event_mask,
    MP_QSTR__lt_HHH,
    MP_QSTR_start_handle,
    MP_QSTR_end_handle,
    MP_QSTR_attr_val_len,
    MP_QSTR_attr_val,
    MP_QSTR_uuid_type,
    MP_QSTR_attr_handle,
    MP_QSTR_value_offset,
    MP_QSTR_execute,
    MP_QSTR__lt_HB_brace_open__colon_d_brace_close_s,
    MP_QSTR_start_attr_handle,
    MP_QSTR_end_attr_handle,
    MP_QSTR_char_val_handle,
    MP_QSTR_char_end_handle,
    MP_QSTR_val_offset,
    MP_QSTR_num_handles,
    MP_QSTR_set_of_handles,
    MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s,
    MP_QSTR_val_len,
    MP_QSTR_attr_value,
    MP_QSTR_write_status,
    MP_QSTR_err_code,
    MP_QSTR_att_val_len,
    MP_QSTR_att_val,
    MP_QSTR__lt_HHB,
    MP_QSTR_security_permission,
    MP_QSTR_char_desc_handle,
    MP_QSTR_char_desc_val_offset,
    MP_QSTR_char_desc_value_len,
    MP_QSTR_char_desc_value,
    MP_QSTR_offset,
    MP_QSTR_update_type,
    MP_QSTR_char_length,
    MP_QSTR_value_length,
    MP_QSTR__lt_BB_brace_open__colon_d_brace_close_s,
    MP_QSTR_en_high_power,
    MP_QSTR_pa_level,
    MP_QSTR_rf_channel,
    MP_QSTR__lt_HHHHH,
    MP_QSTR_interval_min,
    MP_QSTR_interval_max,
    MP_QSTR_slave_latency,
    MP_QSTR_timeout_multiplier,
    MP_QSTR__lt_HHHHHHHBB,
    MP_QSTR_id_,
    MP_QSTR__lt_HHHHHBB,
    MP_QSTR_address,
    MP_QSTR__lt_IH_brace_open__colon_d_brace_close_s,
    MP_QSTR_data_len,
    MP_QSTR__lt_IH,
    MP_QSTR_num_sectors,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py,
    MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_bluenrg_ms,
    MP_QSTR_SPBTLE_RF,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_central_dot_py,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_delegate_dot_py,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_constants,
    MP_QSTR_UUID,
    MP_QSTR___all__,
    MP_QSTR___properties__,
    MP_QSTR__hyphen_,
    MP_QSTR_UUID_16_BIT,
    MP_QSTR_UUID_128_BIT,
    MP_QSTR_ascii,
    MP_QSTR_other,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py,
    MP_QSTR_Descriptor,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_descriptor,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid,
    MP_QSTR_Characteristic,
    MP_QSTR_PROP_READ,
    MP_QSTR_PROP_WRITE,
    MP_QSTR_PERM_NONE,
    MP_QSTR_MASK_DONT_NOTIFY_EVENTS,
    MP_QSTR_add_descriptor,
    MP_QSTR_get_descriptors,
    MP_QSTR___write_proprerties__,
    MP_QSTR___read_proprerties__,
    MP_QSTR_props,
    MP_QSTR_perms,
    MP_QSTR_mask,
    MP_QSTR_descriptors,
    MP_QSTR_st_constant,
    MP_QSTR_MAX_ENCRY_KEY_SIZE,
    MP_QSTR__brace_open__bang_s_brace_close__brace_open__colon_s_brace_close_,
    MP_QSTR__comma__space_,
    MP_QSTR_descriptor,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_characteristic,
    MP_QSTR_compute_attributes_record,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_util,
    MP_QSTR_Service,
    MP_QSTR_SERVICE_PRIMARY,
    MP_QSTR_add_characteristic,
    MP_QSTR_get_characteristic,
    MP_QSTR_get_characteristics,
    MP_QSTR_characteristics,
    MP_QSTR_characteristic,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_constants_dot_py,
    MP_QSTR_constant,
    MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms,
    MP_QSTR_st_event,
    MP_QSTR_ADDR_TYPE_PUBLIC,
    MP_QSTR_ADDR_TYPE_RANDOM_STATIC,
    MP_QSTR_PRIMARY_SERVICE,
    MP_QSTR_SECONDARY_SERVICE,
    MP_QSTR_SERVICE_SECONDARY,
    MP_QSTR_UUID_TYPE_128,
    MP_QSTR_EVT_LE_CONN_COMPLETE,
    MP_QSTR_EVT_GAP_CONNECTED,
    MP_QSTR_EVT_DISCONN_COMPLETE,
    MP_QSTR_EVT_GAP_DISCONNECTED,
    MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED,
    MP_QSTR_EVT_GATTS_WRITE,
    MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ,
    MP_QSTR_EVT_GATTS_READ_PERMIT_REQ,
    MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ,
    MP_QSTR_EVT_GATTS_WRITE_PERMIT_REQ,
    MP_QSTR_CHAR_PROP_BROADCAST,
    MP_QSTR_PROP_BROADCAST,
    MP_QSTR_CHAR_PROP_READ,
    MP_QSTR_CHAR_PROP_WRITE_WITHOUT_RESP,
    MP_QSTR_PROP_WRITE_WO_RESP,
    MP_QSTR_CHAR_PROP_WRITE,
    MP_QSTR_CHAR_PROP_NOTIFY,
    MP_QSTR_PROP_NOTIFY,
    MP_QSTR_CHAR_PROP_INDICATE,
    MP_QSTR_PROP_INDICATE,
    MP_QSTR_CHAR_PROP_SIGNED_WRITE,
    MP_QSTR_PROP_AUTH_SIGNED_WR,
    MP_QSTR_ATTR_PERMISSION_NONE,
    MP_QSTR_ATTR_PERMISSION_AUTHEN_READ,
    MP_QSTR_PERM_AUTHEN_READ,
    MP_QSTR_ATTR_PERMISSION_AUTHOR_READ,
    MP_QSTR_PERM_AUTHOR_READ,
    MP_QSTR_ATTR_PERMISSION_ENCRY_READ,
    MP_QSTR_PERM_ENCRY_READ,
    MP_QSTR_ATTR_PERMISSION_AUTHEN_WRITE,
    MP_QSTR_PERM_AUTHEN_WRITE,
    MP_QSTR_ATTR_PERMISSION_AUTHOR_WRITE,
    MP_QSTR_PERM_AUTHOR_WRITE,
    MP_QSTR_ATTR_PERMISSION_ENCRY_WRITE,
    MP_QSTR_PERM_ENCRY_WRITE,
    MP_QSTR_ATTR_NO_ACCESS,
    MP_QSTR_ACC_NO_ACCESS,
    MP_QSTR_ATTR_ACCESS_READ_ONLY,
    MP_QSTR_ACC_READ_ONLY,
    MP_QSTR_ATTR_ACCESS_WRITE_REQ_ONLY,
    MP_QSTR_ACC_WRITE_REQ_ONLY,
    MP_QSTR_ATTR_ACCESS_READ_WRITE,
    MP_QSTR_ACC_READ_WRITE,
    MP_QSTR_ATTR_ACCESS_WRITE_WITHOUT_RESPONSE,
    MP_QSTR_ACC_WRITE_WITHOUT_RESPONSE,
    MP_QSTR_ATTR_ACCESS_SIGNED_WRITE_ALLOWED,
    MP_QSTR_ACC_SIGNED_WRITE_ALLOWED,
    MP_QSTR_GATT_DONT_NOTIFY_EVENTS,
    MP_QSTR_GATT_NOTIFY_ATTRIBUTE_WRITE,
    MP_QSTR_MASK_NOTIFY_ATTRIBUTE_WRITE,
    MP_QSTR_GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP,
    MP_QSTR_MASK_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP,
    MP_QSTR_GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP,
    MP_QSTR_MASK_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py,
    MP_QSTR_ScanEntry,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_scan_entry,
    MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_spbtle_rf,
    MP_QSTR_uart,
    MP_QSTR_Scanner,
    MP_QSTR_response,
    MP_QSTR_EVT_BLUE_HAL_INITIALIZED,
    MP_QSTR_reason_code,
    MP_QSTR_RESET_NORMAL,
    MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET,
    MP_QSTR_CONFIG_DATA_PUBADDR_LEN,
    MP_QSTR_CONFIG_DATA_MODE_OFFSET,
    MP_QSTR_CONFIG_DATA_MODE_LEN,
    MP_QSTR_GAP_CENTRAL_ROLE_IDB05A1,
    MP_QSTR_PRIVACY_DISABLED,
    MP_QSTR_EVT_LE_ADVERTISING_REPORT,
    MP_QSTR_evt_type,
    MP_QSTR_ADV_IND,
    MP_QSTR_ADV_SCAN_IND,
    MP_QSTR_data_length,
    MP_QSTR_data_RSSI,
    MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE,
    MP_QSTR_GAP_GENERAL_DISCOVERY_PROC,
    MP_QSTR_evt,
    MP_QSTR_PUBLIC_ADDR,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py,
    MP_QSTR_bluetooth_low_energy_dot_api_dot_service,
    MP_QSTR_Peripheral,
    MP_QSTR_set_discoverable,
    MP_QSTR_add_service,
    MP_QSTR_set_event_handler,
    MP_QSTR_write_uuid,
    MP_QSTR_read_uuid,
    MP_QSTR_uuid_from_handle,
    MP_QSTR_address_type,
    MP_QSTR_connectable,
    MP_QSTR_services,
    MP_QSTR_event_handler,
    MP_QSTR_connection_handle,
    MP_QSTR_dev_name_char_handle,
    MP_QSTR_appearance_char_handle,
    MP_QSTR_GAP_PERIPHERAL_ROLE_IDB05A1,
    MP_QSTR_MITM_PROTECTION_REQUIRED,
    MP_QSTR_OOB_AUTH_DATA_ABSENT,
    MP_QSTR_MIN_ENCRY_KEY_SIZE,
    MP_QSTR_USE_FIXED_PIN_FOR_PAIRING,
    MP_QSTR_BONDING,
    MP_QSTR_att_data,
    MP_QSTR_data_buffer,
    MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME,
    MP_QSTR_MAX_ADV_DATA_LEN,
    MP_QSTR_NO_WHITE_LIST_USE,
    MP_QSTR__service,
    MP_QSTR_uuid_value,
    MP_QSTR_value_len,
    MP_QSTR_bluetooth_low_energy_slash_api_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py,
    MP_QSTR_acc,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py,
    MP_QSTR_format_advertisement,
    MP_QSTR_CHAR_PROP_EXT,
    MP_QSTR_service,
    MP_QSTR_FLAGS,
    MP_QSTR_AD_TYPE_FLAGS,
    MP_QSTR_AD_TYPE_16_BIT_SERV_UUID,
    MP_QSTR_AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST,
    MP_QSTR_AD_TYPE_32_BIT_SERV_UUID,
    MP_QSTR_AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST,
    MP_QSTR_AD_TYPE_128_BIT_SERV_UUID,
    MP_QSTR_AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST,
    MP_QSTR_AD_TYPE_SHORTENED_LOCAL_NAME,
    MP_QSTR_AD_TYPE_TX_POWER_LEVEL,
    MP_QSTR_AD_TYPE_CLASS_OF_DEVICE,
    MP_QSTR_AD_TYPE_SEC_MGR_TK_VALUE,
    MP_QSTR_AD_TYPE_SEC_MGR_OOB_FLAGS,
    MP_QSTR_AD_TYPE_SLAVE_CONN_INTERVAL,
    MP_QSTR_AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST,
    MP_QSTR_AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST,
    MP_QSTR_AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST,
    MP_QSTR_AD_TYPE_SERVICE_DATA,
    MP_QSTR_AD_TYPE_MANUFACTURER_SPECIFIC_DATA,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py,
    MP_QSTR_get_data,
    MP_QSTR_rssi,
    MP_QSTR_bluetooth_low_energy_slash___init___dot_py,
    MP_QSTR_0_dot_1_hyphen_pre,
    MP_QSTR___version__,
    MP_QSTR_2_dot_0_dot_2,
    MP_QSTR___version_bluenrg_dk__,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_at_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_status_dot_py,
    MP_QSTR_BLE_STATUS_FAILED,
    MP_QSTR_BLE_STATUS_INVALID_PARAMS,
    MP_QSTR_BLE_STATUS_NOT_ALLOWED,
    MP_QSTR_BLE_STATUS_ERROR,
    MP_QSTR_BLE_STATUS_ADDR_NOT_RESOLVED,
    MP_QSTR_FLASH_READ_FAILED,
    MP_QSTR_FLASH_WRITE_FAILED,
    MP_QSTR_FLASH_ERASE_FAILED,
    MP_QSTR_BLE_STATUS_INVALID_CID,
    MP_QSTR_TIMER_NOT_VALID_LAYER,
    MP_QSTR_TIMER_INSUFFICIENT_RESOURCES,
    MP_QSTR_BLE_STATUS_CSRK_NOT_FOUND,
    MP_QSTR_BLE_STATUS_IRK_NOT_FOUND,
    MP_QSTR_BLE_STATUS_DEV_NOT_FOUND_IN_DB,
    MP_QSTR_BLE_STATUS_SEC_DB_FULL,
    MP_QSTR_BLE_STATUS_DEV_NOT_BONDED,
    MP_QSTR_BLE_STATUS_DEV_IN_BLACKLIST,
    MP_QSTR_BLE_STATUS_INVALID_HANDLE,
    MP_QSTR_BLE_STATUS_INVALID_PARAMETER,
    MP_QSTR_BLE_STATUS_OUT_OF_HANDLE,
    MP_QSTR_BLE_STATUS_INVALID_OPERATION,
    MP_QSTR_BLE_STATUS_INSUFFICIENT_RESOURCES,
    MP_QSTR_BLE_INSUFFICIENT_ENC_KEYSIZE,
    MP_QSTR_BLE_STATUS_CHARAC_ALREADY_EXISTS,
    MP_QSTR_BLE_STATUS_NO_VALID_SLOT,
    MP_QSTR_BLE_STATUS_SCAN_WINDOW_SHORT,
    MP_QSTR_BLE_STATUS_NEW_INTERVAL_FAILED,
    MP_QSTR_BLE_STATUS_INTERVAL_TOO_LARGE,
    MP_QSTR_BLE_STATUS_LENGTH_FAILED,
    MP_QSTR_BLE_STATUS_TIMEOUT,
    MP_QSTR_BLE_STATUS_PROFILE_ALREADY_INITIALIZED,
    MP_QSTR_BLE_STATUS_NULL_PARAM,
    MP_QSTR_SPI_FRAMING_ERROR,
    MP_QSTR_RADIO_STATE_ERROR,
    MP_QSTR_TIMER_OVERRUN_ERROR,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_event_dot_py,
    MP_QSTR_HCI_MAX_PAYLOAD_SIZE,
    MP_QSTR_EVT_BLUE_HAL_EVENTS_LOST_IDB05A1,
    MP_QSTR_EVT_BLUE_HAL_CRASH_INFO_IDB05A1,
    MP_QSTR_EVT_BLUE_GAP_LIMITED_DISCOVERABLE,
    MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT,
    MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST,
    MP_QSTR_EVT_BLUE_GAP_SLAVE_SECURITY_INITIATED,
    MP_QSTR_EVT_BLUE_GAP_BOND_LOST,
    MP_QSTR_EVT_BLUE_GAP_DEVICE_FOUND,
    MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_IDB05A1,
    MP_QSTR_EVT_BLUE_GAP_RECONNECTION_ADDRESS_IDB04A1,
    MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST,
    MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_RESP,
    MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT,
    MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_REQ,
    MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT,
    MP_QSTR_EVT_BLUE_ATT_EXCHANGE_MTU_RESP,
    MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP,
    MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP,
    MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP,
    MP_QSTR_EVT_BLUE_ATT_READ_RESP,
    MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP,
    MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP,
    MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_TYPE_RESP,
    MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP,
    MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP,
    MP_QSTR_EVT_BLUE_GATT_INDICATION,
    MP_QSTR_EVT_BLUE_GATT_NOTIFICATION,
    MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE,
    MP_QSTR_EVT_BLUE_GATT_ERROR_RESP,
    MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHAR_BY_UUID_RESP,
    MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ,
    MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE,
    MP_QSTR_EVT_BLUE_GATT_SERVER_CONFIRMATION_EVENT,
    MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ,
    MP_QSTR_EVT_DISCONN_COMPLETE_BIT,
    MP_QSTR_EVT_ENCRYPT_CHANGE_BIT,
    MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE_BIT,
    MP_QSTR_EVT_CMD_COMPLETE_BIT,
    MP_QSTR_EVT_CMD_STATUS_BIT,
    MP_QSTR_EVT_HARDWARE_ERROR_BIT,
    MP_QSTR_EVT_NUM_COMP_PKTS_BIT,
    MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_BIT,
    MP_QSTR_EVT_BLUE_HAL_INITIALIZED_BIT,
    MP_QSTR_EVT_BLUE_GAP_SET_LIMITED_DISCOVERABLE_BIT,
    MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT_BIT,
    MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST_BIT,
    MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST_BIT,
    MP_QSTR_EVT_BLUE_GAP_SECURITY_REQ_INITIATED_BIT,
    MP_QSTR_EVT_BLUE_GAP_BOND_LOST_BIT,
    MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE_BIT,
    MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_BIT,
    MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_RESP_BIT,
    MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT_BIT,
    MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_REQ_BIT,
    MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED_BIT,
    MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT_BIT,
    MP_QSTR_EVT_BLUE_EXCHANGE_MTU_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_READ_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_WRITE_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP_BIT,
    MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP_BIT,
    MP_QSTR_EVT_BLUE_GATT_INDICATION_BIT,
    MP_QSTR_EVT_BLUE_GATT_NOTIFICATION_BIT,
    MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE_BIT,
    MP_QSTR_EVT_BLUE_GATT_ERROR_RESP_BIT,
    MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHARAC_BY_UUID_RESP_BIT,
    MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ_BIT,
    MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ_BIT,
    MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ_BIT,
    MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE_BIT,
    MP_QSTR_EVT_BLUE_GATT_SERVER_RX_CONFIRMATION_BIT,
    MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ_BIT,
    MP_QSTR_EVT_LL_CONNECTION_COMPLETE_BIT,
    MP_QSTR_EVT_LL_ADVERTISING_REPORT_BIT,
    MP_QSTR_EVT_LL_CONNECTION_UPDATE_COMPLETE_BIT,
    MP_QSTR_EVT_LL_READ_REMOTE_USED_FEATURES_BIT,
    MP_QSTR_EVT_LL_LTK_REQUEST_BIT,
    MP_QSTR_crash_type,
    MP_QSTR_sp,
    MP_QSTR_sp1,
    MP_QSTR_r0,
    MP_QSTR_r1,
    MP_QSTR_r2,
    MP_QSTR_r3,
    MP_QSTR_r12,
    MP_QSTR_lr,
    MP_QSTR_pc,
    MP_QSTR_xpsr,
    MP_QSTR_debug_data,
    MP_QSTR_data_rssi,
    MP_QSTR_identifier,
    MP_QSTR_result,
    MP_QSTR_IDB05A1,
    MP_QSTR_IDB04A1,
    MP_QSTR_error_code,
    MP_QSTR_req_opcode,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_cmd_dot_py,
    MP_QSTR_OCF_GAP_SET_EVT_MASK,
    MP_QSTR_VENDOR_CMD,
    MP_QSTR_GAP_INIT,
    MP_QSTR_evt_mask,
    MP_QSTR_dv_type,
    MP_QSTR_num_addr,
    MP_QSTR_dev_list,
    MP_QSTR_GATT_INIT,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_constant_dot_py,
    MP_QSTR_RESET_UPDATER_ACI,
    MP_QSTR_RESET_UPDATER_BAD_FLAG,
    MP_QSTR_RESET_UPDATER_PIN,
    MP_QSTR_RESET_WATCHDOG,
    MP_QSTR_RESET_LOCKUP,
    MP_QSTR_RESET_BROWNOUT,
    MP_QSTR_RESET_CRASH,
    MP_QSTR_RESET_ECC_ERR,
    MP_QSTR_CONFIG_DATA_DIV_OFFSET,
    MP_QSTR_CONFIG_DATA_ER_OFFSET,
    MP_QSTR_CONFIG_DATA_IR_OFFSET,
    MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST,
    MP_QSTR_CONFIG_DATA_RANDOM_ADDRESS,
    MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE,
    MP_QSTR_CONFIG_DATA_DIV_LEN,
    MP_QSTR_CONFIG_DATA_ER_LEN,
    MP_QSTR_CONFIG_DATA_IR_LEN,
    MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST_LEN,
    MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE_LEN,
    MP_QSTR_STATUS_IDLE,
    MP_QSTR_STATUS_ADVERTISING,
    MP_QSTR_STATUS_CONNECTED_AS_SLAVE,
    MP_QSTR_STATUS_SCANNING,
    MP_QSTR_STATUS_CONNECTED_AS_MASTER,
    MP_QSTR_STATUS_TX_TEST,
    MP_QSTR_STATUS_RX_TEST,
    MP_QSTR_GAP_SERVICE_UUID,
    MP_QSTR_DEVICE_NAME_UUID,
    MP_QSTR_APPEARANCE_UUID,
    MP_QSTR_PERIPHERAL_PRIVACY_FLAG_UUID,
    MP_QSTR_RECONNECTION_ADDR_UUID,
    MP_QSTR_PERIPHERAL_PREFERRED_CONN_PARAMS_UUID,
    MP_QSTR_DEVICE_NAME_CHARACTERISTIC_LEN,
    MP_QSTR_APPEARANCE_CHARACTERISTIC_LEN,
    MP_QSTR_PERIPHERAL_PRIVACY_CHARACTERISTIC_LEN,
    MP_QSTR_RECONNECTION_ADDR_CHARACTERISTIC_LEN,
    MP_QSTR_PERIPHERAL_PREF_CONN_PARAMS_CHARACTERISTIC_LEN,
    MP_QSTR_FLAG_BIT_LE_LIMITED_DISCOVERABLE_MODE,
    MP_QSTR_FLAG_BIT_LE_GENERAL_DISCOVERABLE_MODE,
    MP_QSTR_FLAG_BIT_BR_EDR_NOT_SUPPORTED,
    MP_QSTR_FLAG_BIT_LE_BR_EDR_CONTROLLER,
    MP_QSTR_FLAG_BIT_LE_BR_EDR_HOST,
    MP_QSTR_DEVICE_NAME_LEN,
    MP_QSTR_BD_ADDR_SIZE,
    MP_QSTR_PRIVACY_ENABLED,
    MP_QSTR_DIR_CONN_ADV_INT_MIN,
    MP_QSTR_DIR_CONN_ADV_INT_MAX,
    MP_QSTR_UNDIR_CONN_ADV_INT_MIN,
    MP_QSTR_UNDIR_CONN_ADV_INT_MAX,
    MP_QSTR_LIM_DISC_ADV_INT_MIN,
    MP_QSTR_LIM_DISC_ADV_INT_MAX,
    MP_QSTR_GEN_DISC_ADV_INT_MIN,
    MP_QSTR_GEN_DISC_ADV_INT_MAX,
    MP_QSTR_LIM_DISC_MODE_TIMEOUT,
    MP_QSTR_PRIVATE_ADDR_INT_TIMEOUT,
    MP_QSTR_GAP_BROADCASTER_ROLE_IDB05A1,
    MP_QSTR_GAP_OBSERVER_ROLE_IDB05A1,
    MP_QSTR_GAP_PERIPHERAL_ROLE_IDB04A1,
    MP_QSTR_GAP_BROADCASTER_ROLE_IDB04A1,
    MP_QSTR_GAP_CENTRAL_ROLE_IDB04A1,
    MP_QSTR_GAP_OBSERVER_ROLE_IDB04A1,
    MP_QSTR_GAP_LIMITED_DISCOVERY_PROC,
    MP_QSTR_GAP_NAME_DISCOVERY_PROC,
    MP_QSTR_GAP_AUTO_CONNECTION_ESTABLISHMENT_PROC,
    MP_QSTR_GAP_GENERAL_CONNECTION_ESTABLISHMENT_PROC,
    MP_QSTR_GAP_SELECTIVE_CONNECTION_ESTABLISHMENT_PROC,
    MP_QSTR_GAP_DIRECT_CONNECTION_ESTABLISHMENT_PROC,
    MP_QSTR_GAP_OBSERVATION_PROC_IDB05A1,
    MP_QSTR_WHITE_LIST_FOR_ONLY_SCAN,
    MP_QSTR_WHITE_LIST_FOR_ONLY_CONN,
    MP_QSTR_WHITE_LIST_FOR_ALL,
    MP_QSTR_RANDOM_ADDR,
    MP_QSTR_STATIC_RANDOM_ADDR,
    MP_QSTR_RESOLVABLE_PRIVATE_ADDR,
    MP_QSTR_NON_RESOLVABLE_PRIVATE_ADDR,
    MP_QSTR_HIGH_DUTY_CYCLE_DIRECTED_ADV,
    MP_QSTR_LOW_DUTY_CYCLE_DIRECTED_ADV,
    MP_QSTR_ADV_DIRECT_IND,
    MP_QSTR_ADV_NONCONN_IND,
    MP_QSTR_SCAN_RSP,
    MP_QSTR_ADV_INTERVAL_LOWEST_CONN,
    MP_QSTR_ADV_INTERVAL_HIGHEST,
    MP_QSTR_ADV_INTERVAL_LOWEST_NONCONN,
    MP_QSTR_ADV_CH_37,
    MP_QSTR_ADV_CH_38,
    MP_QSTR_ADV_CH_39,
    MP_QSTR_PASSIVE_SCAN,
    MP_QSTR_ACTIVE_SCAN,
    MP_QSTR_PRIMARY_SERVICE_UUID,
    MP_QSTR_SECONDARY_SERVICE_UUID,
    MP_QSTR_INCLUDE_SERVICE_UUID,
    MP_QSTR_CHARACTERISTIC_UUID,
    MP_QSTR_CHAR_EXTENDED_PROP_DESC_UUID,
    MP_QSTR_CHAR_USER_DESC_UUID,
    MP_QSTR_CHAR_CLIENT_CONFIG_DESC_UUID,
    MP_QSTR_CHAR_SERVER_CONFIG_DESC_UUID,
    MP_QSTR_CHAR_FORMAT_DESC_UUID,
    MP_QSTR_CHAR_AGGR_FMT_DESC_UUID,
    MP_QSTR_GATT_SERVICE_UUID,
    MP_QSTR_SERVICE_CHANGED_UUID,
    MP_QSTR_ATTR_ACCESS_WRITE_ANY,
    MP_QSTR_CHAR_VALUE_LEN_CONSTANT,
    MP_QSTR_CHAR_VALUE_LEN_VARIABLE,
    MP_QSTR_FORMAT_UINT8,
    MP_QSTR_FORMAT_UINT16,
    MP_QSTR_FORMAT_SINT16,
    MP_QSTR_FORMAT_SINT24,
    MP_QSTR_UNIT_UNITLESS,
    MP_QSTR_UNIT_TEMP_CELSIUS,
    MP_QSTR_UNIT_PRESSURE_BAR,
    MP_QSTR_ATT_MTU,
    MP_QSTR_NOTIFICATION,
    MP_QSTR_INDICATION,
    MP_QSTR_O_CAP_DISPLAY_ONLY,
    MP_QSTR_O_CAP_DISPLAY_YES_NO,
    MP_QSTR_O_CAP_KEYBOARD_ONLY,
    MP_QSTR_O_CAP_NO_INPUT_NO_OUTPUT,
    MP_QSTR_O_CAP_KEYBOARD_DISPLAY,
    MP_QSTR_NO_BONDING,
    MP_QSTR_MITM_PROTECTION_NOT_REQUIRED,
    MP_QSTR_OOB_AUTH_DATA_PRESENT,
    MP_QSTR_AUTHORIZATION_NOT_REQUIRED,
    MP_QSTR_AUTHORIZATION_REQUIRED,
    MP_QSTR_CONNECTION_AUTHORIZED,
    MP_QSTR_CONNECTION_REJECTED,
    MP_QSTR_DONOT_USE_FIXED_PIN_FOR_PAIRING,
    MP_QSTR_SM_LINK_AUTHENTICATED,
    MP_QSTR_SM_LINK_AUTHORIZED,
    MP_QSTR_SM_LINK_ENCRYPTED,
    MP_QSTR_PASSKEY_ENTRY_FAILED,
    MP_QSTR_OOB_NOT_AVAILABLE,
    MP_QSTR_AUTH_REQ_CANNOT_BE_MET,
    MP_QSTR_CONFIRM_VALUE_FAILED,
    MP_QSTR_PAIRING_NOT_SUPPORTED,
    MP_QSTR_INSUFF_ENCRYPTION_KEY_SIZE,
    MP_QSTR_CMD_NOT_SUPPORTED,
    MP_QSTR_UNSPECIFIED_REASON,
    MP_QSTR_VERY_EARLY_NEXT_ATTEMPT,
    MP_QSTR_SM_INVALID_PARAMS,
    MP_QSTR_SM_PAIRING_SUCCESS,
    MP_QSTR_SM_PAIRING_TIMEOUT,
    MP_QSTR_SM_PAIRING_FAILED,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash___init___dot_py,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py,
    MP_QSTR_pb,
    MP_QSTR_bc,
    MP_QSTR_HCI_ACL_STRUCT,
    MP_QSTR_ACL_PB_START_NON_AUTO_L2CAP_PDU,
    MP_QSTR_ACL_PB_CONT_FRAG_MSG,
    MP_QSTR_ACL_PB_START_AUTO_L2CAP_PDU,
    MP_QSTR_ACL_PB_COMPLETE_L2CAP_PDU,
    MP_QSTR_PB_FLAGS,
    MP_QSTR_HCI_ACL,
    MP_QSTR__struct_format,
    MP_QSTR__handle,
    MP_QSTR__pb,
    MP_QSTR__pb_name,
    MP_QSTR__bc,
    MP_QSTR__tobytes,
    MP_QSTR__data,
    MP_QSTR_pb_name,
    MP_QSTR_tobytes,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py,
    MP_QSTR_PAIRING_REQUEST,
    MP_QSTR_PAIRING_RESPONSE,
    MP_QSTR_PAIRING_CONFIRM,
    MP_QSTR_PAIRING_RANDOM,
    MP_QSTR_PAIRING_FAILED,
    MP_QSTR_ENCRYPTION_INFORMATION,
    MP_QSTR_MASTER_IDENTIFICATION,
    MP_QSTR_IDENTITY_INFORMATION,
    MP_QSTR_IDENTITY_ADDRESS_INFORMATION,
    MP_QSTR_SIGNING_INFORMATION,
    MP_QSTR_SECURITY_REQUEST,
    MP_QSTR_SMP_PDUS,
    MP_QSTR_SMP,
    MP_QSTR__code,
    MP_QSTR__code_name,
    MP_QSTR_code_name,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py,
    MP_QSTR_HCI_ACLDATA_PKT,
    MP_QSTR_HCI_SCODATA_PKT,
    MP_QSTR_HCI_VENDOR_PKT,
    MP_QSTR_COMMAND,
    MP_QSTR_ACLDATA,
    MP_QSTR_SCODATA,
    MP_QSTR_EVENT,
    MP_QSTR_VENDOR,
    MP_QSTR_HCI_UART_PKT_TYPES,
    MP_QSTR__struct_format_size,
    MP_QSTR__pkt_type,
    MP_QSTR__pkt_type_name,
    MP_QSTR_pkt_type_name,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_status_dot_py,
    MP_QSTR_ERR_CMD_SUCCESS,
    MP_QSTR_ERR_UNKNOWN_HCI_COMMAND,
    MP_QSTR_ERR_UNKNOWN_CONN_IDENTIFIER,
    MP_QSTR_ERR_AUTH_FAILURE,
    MP_QSTR_ERR_PIN_OR_KEY_MISSING,
    MP_QSTR_ERR_MEM_CAPACITY_EXCEEDED,
    MP_QSTR_ERR_CONNECTION_TIMEOUT,
    MP_QSTR_ERR_COMMAND_DISALLOWED,
    MP_QSTR_ERR_UNSUPPORTED_FEATURE,
    MP_QSTR_ERR_INVALID_HCI_CMD_PARAMS,
    MP_QSTR_ERR_RMT_USR_TERM_CONN,
    MP_QSTR_ERR_RMT_DEV_TERM_CONN_LOW_RESRCES,
    MP_QSTR_ERR_RMT_DEV_TERM_CONN_POWER_OFF,
    MP_QSTR_ERR_LOCAL_HOST_TERM_CONN,
    MP_QSTR_ERR_UNSUPP_RMT_FEATURE,
    MP_QSTR_ERR_INVALID_LMP_PARAM,
    MP_QSTR_ERR_UNSPECIFIED_ERROR,
    MP_QSTR_ERR_LL_RESP_TIMEOUT,
    MP_QSTR_ERR_LMP_PDU_NOT_ALLOWED,
    MP_QSTR_ERR_INSTANT_PASSED,
    MP_QSTR_ERR_PAIR_UNIT_KEY_NOT_SUPP,
    MP_QSTR_ERR_CONTROLLER_BUSY,
    MP_QSTR_ERR_DIRECTED_ADV_TIMEOUT,
    MP_QSTR_ERR_CONN_END_WITH_MIC_FAILURE,
    MP_QSTR_ERR_CONN_FAILED_TO_ESTABLISH,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py,
    MP_QSTR_L2CAP_CID_NUL,
    MP_QSTR_L2CAP_CID_SCH,
    MP_QSTR_L2CAP_CID_ATT,
    MP_QSTR_L2CAP_CID_LE_SCH,
    MP_QSTR_L2CAP_CID_SMP,
    MP_QSTR_NUL,
    MP_QSTR_SCH,
    MP_QSTR_ATT,
    MP_QSTR_LE_SCH,
    MP_QSTR_L2CAP_CHANNEL_IDS,
    MP_QSTR_L2CAP,
    MP_QSTR_SCH_COMMAND_REJECT,
    MP_QSTR_SCH_CONNECTION_REQUEST,
    MP_QSTR_SCH_CONNECTION_RESPONSE,
    MP_QSTR_SCH_CONFIGURE_REQUEST,
    MP_QSTR_SCH_CONFIGURE_RESPONSE,
    MP_QSTR_SCH_DISCONNECTION_REQUEST,
    MP_QSTR_SCH_DISCONNECTION_RESPONSE,
    MP_QSTR_SCH_ECHO_REQUEST,
    MP_QSTR_SCH_ECHO_RESPONSE,
    MP_QSTR_SCH_INFORMATION_REQUEST,
    MP_QSTR_SCH_INFORMATION_RESPONSE,
    MP_QSTR_SCH_CREATE_CHANNEL_REQUEST,
    MP_QSTR_SCH_CREATE_CHANNEL_RESPONSE,
    MP_QSTR_SCH_MOVE_CHANNEL_REQUEST,
    MP_QSTR_SCH_MOVE_CHANNEL_RESPONSE,
    MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION,
    MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION_RESPONSE,
    MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_REQUEST,
    MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_RESPONSE,
    MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_REQUEST,
    MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_RESPONSE,
    MP_QSTR_LE_SCH_LE_FLOW_CONTROL_CREDIT,
    MP_QSTR_L2CAP_SCH_PDUS,
    MP_QSTR_L2CAP_SCH,
    MP_QSTR__cid,
    MP_QSTR__cid_name,
    MP_QSTR_cid,
    MP_QSTR_cid_name,
    MP_QSTR__lt_BBH,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py,
    MP_QSTR_EVT_LE_CONN_UPDATE_COMPLETE,
    MP_QSTR_EVT_LE_READ_REMOTE_USED_FEATURES_COMPLETE,
    MP_QSTR_EVT_LE_LTK_REQUEST,
    MP_QSTR_features,
    MP_QSTR_ediv,
    MP_QSTR_HCI_LE_META_EVENTS,
    MP_QSTR_EVT_CONN_COMPLETE,
    MP_QSTR_EVT_ENCRYPT_CHANGE,
    MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE,
    MP_QSTR_EVT_NUM_COMP_PKTS,
    MP_QSTR_EVT_DATA_BUFFER_OVERFLOW,
    MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_COMPLETE,
    MP_QSTR_link_type,
    MP_QSTR_encr_mode,
    MP_QSTR_encrypt,
    MP_QSTR_subversion,
    MP_QSTR_ncmd,
    MP_QSTR_CMD_STATUS,
    MP_QSTR_num_hndl,
    MP_QSTR_hndl,
    MP_QSTR_subevent,
    MP_QSTR__evtcode,
    MP_QSTR__evtname,
    MP_QSTR__subevtcode,
    MP_QSTR__subevtname,
    MP_QSTR__struct,
    MP_QSTR__module,
    MP_QSTR_evtname,
    MP_QSTR_subevtname,
    MP_QSTR__space_,
    MP_QSTR_B,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py,
    MP_QSTR_OCF_SET_CONTROLLER_TO_HOST_FC,
    MP_QSTR_OCF_HOST_NUM_COMP_PKTS,
    MP_QSTR_OCF_READ_LOCAL_COMMANDS,
    MP_QSTR_OCF_READ_LOCAL_FEATURES,
    MP_QSTR_OCF_LE_SET_EVENT_MASK,
    MP_QSTR_OCF_LE_CONN_UPDATE,
    MP_QSTR_OCF_LE_SET_HOST_CHANNEL_CLASSIFICATION,
    MP_QSTR_OCF_LE_READ_REMOTE_USED_FEATURES,
    MP_QSTR_OCF_LE_START_ENCRYPTION,
    MP_QSTR_LINK_CTL,
    MP_QSTR_DISCONNECT,
    MP_QSTR_HOST_CTL,
    MP_QSTR_RESET,
    MP_QSTR_level,
    MP_QSTR_INFO_PARAM,
    MP_QSTR_READ_RSSI,
    MP_QSTR_LE_CTL,
    MP_QSTR_pkt_len,
    MP_QSTR_max_pkt,
    MP_QSTR_LE_ENCRYPT,
    MP_QSTR_plaintext,
    MP_QSTR_encdata,
    MP_QSTR_LE_RAND,
    MP_QSTR_states,
    MP_QSTR_num_pkts,
    MP_QSTR_OPCODE,
    MP_QSTR__opcode,
    MP_QSTR__ogf,
    MP_QSTR__ogf_name,
    MP_QSTR__ocf,
    MP_QSTR__ocf_name,
    MP_QSTR__request_struct,
    MP_QSTR__request_data,
    MP_QSTR__response_struct,
    MP_QSTR__response_data,
    MP_QSTR_ogf_name,
    MP_QSTR_ocf_name,
    MP_QSTR_request_struct,
    MP_QSTR_request_data,
    MP_QSTR_request_length,
    MP_QSTR_response_length,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py,
    MP_QSTR_ATT_PDUS,
    MP_QSTR_a,
    MP_QSTR_c,
    MP_QSTR_ATT_STRUCT,
    MP_QSTR__opcode_name,
    MP_QSTR_opcode_name,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py,
    MP_QSTR_ps,
    MP_QSTR_xx,
    MP_QSTR_HCI_SCO_STRUCT,
    MP_QSTR_HCI_SCO,
    MP_QSTR__ps,
    MP_QSTR__xx,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash___init___dot_py,
    MP_QSTR_logging_dot_py,
    MP_QSTR__stream,
    MP_QSTR_CRITICAL,
    MP_QSTR_ERROR,
    MP_QSTR_WARNING,
    MP_QSTR_INFO,
    MP_QSTR_NOTSET,
    MP_QSTR_CRIT,
    MP_QSTR_WARN,
    MP_QSTR__level_dict,
    MP_QSTR_Logger,
    MP_QSTR__level,
    MP_QSTR__loggers,
    MP_QSTR_getLogger,
    MP_QSTR_basicConfig,
    MP_QSTR__level_str,
    MP_QSTR_warning,
    MP_QSTR_error,
    MP_QSTR_critical,
    MP_QSTR_root,
    MP_QSTR_LVL,
    MP_QSTR__colon_,
    MP_QSTR_msg,
    MP_QSTR_filename,
    MP_QSTR_stream,
    MP_QSTR_collections_slash___init___dot_py,
    MP_QSTR_deque,
    MP_QSTR_defaultdict,
    MP_QSTR_collections_slash_defaultdict_dot_py,
    MP_QSTR___missing__,
    MP_QSTR_d,
    MP_QSTR_cls,
    MP_QSTR_default_factory,
    MP_QSTR_v,
    MP_QSTR_collections_slash_deque_dot_py,
    MP_QSTR_popleft,
    MP_QSTR_popright,
    MP_QSTR_appendleft,
    MP_QSTR_extendleft,
    MP_QSTR_maxlen,
    MP_QSTR_q,
};

extern const qstr_pool_t mp_qstr_const_pool;
const qstr_pool_t mp_qstr_frozen_const_pool = {
    (qstr_pool_t*)&mp_qstr_const_pool, // previous pool
    MP_QSTRnumber_of, // previous pool size
    1308, // allocated entries
    1308, // used entries
    {
        (const byte*)"\xa3\x73\x28" "bluetooth_low_energy/modules/base_hci.py",
        (const byte*)"\x87\x18\x14" "HCI_READ_PACKET_SIZE",
        (const byte*)"\x42\xbb\x22" "bluetooth_low_energy.protocols.hci",
        (const byte*)"\x50\xf6\x0e" "OCF_DISCONNECT",
        (const byte*)"\x81\x67\x1f" "OCF_LE_ADD_DEVICE_TO_WHITE_LIST",
        (const byte*)"\xda\x07\x17" "OCF_LE_CLEAR_WHITE_LIST",
        (const byte*)"\x71\x58\x12" "OCF_LE_CREATE_CONN",
        (const byte*)"\x08\x41\x19" "OCF_LE_CREATE_CONN_CANCEL",
        (const byte*)"\x41\x14\x0e" "OCF_LE_ENCRYPT",
        (const byte*)"\xcb\x08\x14" "OCF_LE_LTK_NEG_REPLY",
        (const byte*)"\x18\x72\x10" "OCF_LE_LTK_REPLY",
        (const byte*)"\x1f\xb5\x0b" "OCF_LE_RAND",
        (const byte*)"\x77\x65\x20" "OCF_LE_READ_ADV_CHANNEL_TX_POWER",
        (const byte*)"\x11\x27\x17" "OCF_LE_READ_BUFFER_SIZE",
        (const byte*)"\xab\x24\x17" "OCF_LE_READ_CHANNEL_MAP",
        (const byte*)"\x6f\xbb\x24" "OCF_LE_READ_LOCAL_SUPPORTED_FEATURES",
        (const byte*)"\xde\xc2\x1c" "OCF_LE_READ_SUPPORTED_STATES",
        (const byte*)"\x2b\x8c\x1b" "OCF_LE_READ_WHITE_LIST_SIZE",
        (const byte*)"\x36\x71\x14" "OCF_LE_RECEIVER_TEST",
        (const byte*)"\xcb\x9c\x24" "OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST",
        (const byte*)"\x47\xfa\x13" "OCF_LE_SET_ADV_DATA",
        (const byte*)"\xad\xc7\x19" "OCF_LE_SET_ADV_PARAMETERS",
        (const byte*)"\x4a\x8a\x1b" "OCF_LE_SET_ADVERTISE_ENABLE",
        (const byte*)"\xc9\xd2\x19" "OCF_LE_SET_RANDOM_ADDRESS",
        (const byte*)"\x7a\xc2\x16" "OCF_LE_SET_SCAN_ENABLE",
        (const byte*)"\x01\xa0\x1a" "OCF_LE_SET_SCAN_PARAMETERS",
        (const byte*)"\x97\xb4\x1d" "OCF_LE_SET_SCAN_RESPONSE_DATA",
        (const byte*)"\x40\x00\x0f" "OCF_LE_TEST_END",
        (const byte*)"\xc6\x35\x17" "OCF_LE_TRANSMITTER_TEST",
        (const byte*)"\x57\xa0\x10" "OCF_READ_BD_ADDR",
        (const byte*)"\xf5\xcc\x16" "OCF_READ_LOCAL_VERSION",
        (const byte*)"\xa6\x71\x0d" "OCF_READ_RSSI",
        (const byte*)"\x3e\x41\x1d" "OCF_READ_TRANSMIT_POWER_LEVEL",
        (const byte*)"\x65\xbe\x09" "OCF_RESET",
        (const byte*)"\x30\xff\x0c" "OGF_HOST_CTL",
        (const byte*)"\x2a\x47\x0e" "OGF_INFO_PARAM",
        (const byte*)"\x19\xd7\x0a" "OGF_LE_CTL",
        (const byte*)"\x50\xcb\x0c" "OGF_LINK_CTL",
        (const byte*)"\x30\x0d\x10" "OGF_STATUS_PARAM",
        (const byte*)"\xbf\x52\x0b" "HCI_COMMAND",
        (const byte*)"\xe6\x2b\x26" "bluetooth_low_energy.protocols.hci.cmd",
        (const byte*)"\xac\x59\x11" "HardwareException",
        (const byte*)"\x72\x32\x07" "BaseHCI",
        (const byte*)"\x79\x77\x04" "self",
        (const byte*)"\x6e\xbc\x07" "message",
        (const byte*)"\x91\x21\x0c" "hci_send_cmd",
        (const byte*)"\x6d\x2a\x09" "hci_reset",
        (const byte*)"\x38\x1e\x0e" "hci_disconnect",
        (const byte*)"\x6b\xd1\x19" "hci_le_read_local_version",
        (const byte*)"\xb9\xbc\x17" "hci_le_read_buffer_size",
        (const byte*)"\x3c\xb2\x21" "hci_le_set_advertising_parameters",
        (const byte*)"\x56\x83\x1b" "hci_le_set_advertising_data",
        (const byte*)"\x62\x42\x1b" "hci_le_set_advertise_enable",
        (const byte*)"\xc9\xaf\x1a" "hci_le_set_scan_parameters",
        (const byte*)"\xb2\xf9\x16" "hci_le_set_scan_enable",
        (const byte*)"\xb7\xb8\x0b" "hci_le_rand",
        (const byte*)"\x28\xfd\x19" "hci_le_set_scan_resp_data",
        (const byte*)"\x86\x19\x28" "hci_le_read_advertising_channel_tx_power",
        (const byte*)"\xe1\xa8\x19" "hci_le_set_random_address",
        (const byte*)"\xff\x34\x10" "hci_read_bd_addr",
        (const byte*)"\xc3\x97\x18" "hci_le_create_connection",
        (const byte*)"\x7a\x52\x1f" "hci_le_create_connection_cancel",
        (const byte*)"\x89\x5c\x0e" "hci_le_encrypt",
        (const byte*)"\x9e\xd7\x18" "hci_le_ltk_request_reply",
        (const byte*)"\x6d\x98\x1c" "hci_le_ltk_request_neg_reply",
        (const byte*)"\xe3\x46\x1b" "hci_le_read_white_list_size",
        (const byte*)"\x72\x19\x17" "hci_le_clear_white_list",
        (const byte*)"\x69\xc5\x1f" "hci_le_add_device_to_white_list",
        (const byte*)"\xc3\x56\x24" "hci_le_remove_device_from_white_list",
        (const byte*)"\xd6\x6a\x1d" "hci_read_transmit_power_level",
        (const byte*)"\x0e\x38\x0d" "hci_read_rssi",
        (const byte*)"\x07\x66\x24" "hci_le_read_local_supported_features",
        (const byte*)"\x83\x01\x17" "hci_le_read_channel_map",
        (const byte*)"\xd6\xbd\x1c" "hci_le_read_supported_states",
        (const byte*)"\x5e\x45\x14" "hci_le_receiver_test",
        (const byte*)"\xce\xbf\x17" "hci_le_transmitter_test",
        (const byte*)"\x08\xa1\x0f" "hci_le_test_end",
        (const byte*)"\x2f\x4c\x03" "cmd",
        (const byte*)"\xc6\xea\x08" "is_async",
        (const byte*)"\xad\x02\x05" "retry",
        (const byte*)"\x6b\x5d\x03" "ogf",
        (const byte*)"\xef\x5c\x03" "ocf",
        (const byte*)"\x53\x87\x03" "<HB",
        (const byte*)"\xcf\xe3\x06" "handle",
        (const byte*)"\xc1\xe7\x06" "reason",
        (const byte*)"\xfe\x70\x0a" "<HHBBB6sBB",
        (const byte*)"\x4f\xd9\x0c" "min_interval",
        (const byte*)"\x91\xd0\x0c" "max_interval",
        (const byte*)"\xce\x0e\x07" "advtype",
        (const byte*)"\x1e\x59\x0f" "own_bdaddr_type",
        (const byte*)"\xc5\x8f\x12" "direct_bdaddr_type",
        (const byte*)"\xc2\x8c\x0d" "direct_bdaddr",
        (const byte*)"\x22\x5a\x08" "chan_map",
        (const byte*)"\x9a\x82\x07" "filter_",
        (const byte*)"\x90\xc6\x07" "<B{:d}s",
        (const byte*)"\x59\x87\x06" "length",
        (const byte*)"\xfb\x68\x02" "<B",
        (const byte*)"\xbb\x0c\x06" "<BHHBB",
        (const byte*)"\x62\x73\x05" "type_",
        (const byte*)"\x1a\x0e\x08" "interval",
        (const byte*)"\x89\xc3\x06" "window",
        (const byte*)"\x19\x88\x03" "<BB",
        (const byte*)"\x1b\x2e\x0a" "filter_dup",
        (const byte*)"\x1c\x7a\x03" "<6s",
        (const byte*)"\x70\xc5\x06" "bdaddr",
        (const byte*)"\x61\x36\x10" "initiator_filter",
        (const byte*)"\x0a\x65\x10" "peer_bdaddr_type",
        (const byte*)"\x2d\xc4\x0b" "peer_bdaddr",
        (const byte*)"\xad\x17\x07" "latency",
        (const byte*)"\x64\x9a\x13" "supervision_timeout",
        (const byte*)"\xb5\xdc\x0d" "min_ce_length",
        (const byte*)"\xab\x49\x0d" "max_ce_length",
        (const byte*)"\x19\xeb\x07" "<16s16s",
        (const byte*)"\xad\x54\x0e" "plaintext_data",
        (const byte*)"\xa5\xcd\x05" "<H16s",
        (const byte*)"\xf1\x68\x02" "<H",
        (const byte*)"\x7e\x96\x04" "<B6s",
        (const byte*)"\xb7\xae\x0b" "bdaddr_type",
        (const byte*)"\xa1\xce\x09" "frequency",
        (const byte*)"\x7b\x8b\x04" "<BBB",
        (const byte*)"\x4b\x05\x07" "payload",
        (const byte*)"\x93\x21\x3e" "bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py",
        (const byte*)"\x84\x41\x25" "bluetooth_low_energy.modules.base_hci",
        (const byte*)"\x6f\xf0\x0f" "HCI_COMMAND_PKT",
        (const byte*)"\x8f\x1b\x12" "HCI_EVENT_HDR_SIZE",
        (const byte*)"\x24\x45\x0d" "HCI_EVENT_PKT",
        (const byte*)"\xcc\xaa\x0c" "HCI_COMMANDS",
        (const byte*)"\x05\x3e\x0e" "OGF_VENDOR_CMD",
        (const byte*)"\x01\x18\x10" "EVT_CMD_COMPLETE",
        (const byte*)"\xfc\x31\x0e" "EVT_CMD_STATUS",
        (const byte*)"\x84\x48\x12" "EVT_HARDWARE_ERROR",
        (const byte*)"\x25\x74\x11" "EVT_LE_META_EVENT",
        (const byte*)"\x59\xa0\x0a" "EVT_VENDOR",
        (const byte*)"\xf4\x17\x09" "HCI_EVENT",
        (const byte*)"\x27\x16\x0a" "HCI_EVENTS",
        (const byte*)"\x5c\x15\x11" "HCI_VENDOR_EVENTS",
        (const byte*)"\x40\xcf\x28" "bluetooth_low_energy.protocols.hci.event",
        (const byte*)"\x19\x7f\x12" "BLE_STATUS_SUCCESS",
        (const byte*)"\xd8\x61\x29" "bluetooth_low_energy.protocols.hci.status",
        (const byte*)"\xca\x38\x08" "HCI_UART",
        (const byte*)"\xde\x34\x27" "bluetooth_low_energy.protocols.hci.uart",
        (const byte*)"\xf7\xcd\x13" "HCI_VENDOR_COMMANDS",
        (const byte*)"\xca\x3a\x19" "OCF_ATT_EXECUTE_WRITE_REQ",
        (const byte*)"\xe5\xff\x1e" "OCF_ATT_FIND_BY_TYPE_VALUE_REQ",
        (const byte*)"\x43\xc5\x15" "OCF_ATT_FIND_INFO_REQ",
        (const byte*)"\x74\xc6\x19" "OCF_ATT_PREPARE_WRITE_REQ",
        (const byte*)"\x26\x9e\x1e" "OCF_ATT_READ_BY_GROUP_TYPE_REQ",
        (const byte*)"\x66\xba\x18" "OCF_ATT_READ_BY_TYPE_REQ",
        (const byte*)"\x36\xa2\x17" "OCF_GAP_ALLOW_REBOND_DB",
        (const byte*)"\x5e\x51\x1e" "OCF_GAP_AUTHORIZATION_RESPONSE",
        (const byte*)"\x30\xbf\x19" "OCF_GAP_CLEAR_SECURITY_DB",
        (const byte*)"\xeb\xdf\x1b" "OCF_GAP_CONFIGURE_WHITELIST",
        (const byte*)"\xd4\x8c\x19" "OCF_GAP_CREATE_CONNECTION",
        (const byte*)"\x7d\x87\x16" "OCF_GAP_DELETE_AD_TYPE",
        (const byte*)"\x82\x7c\x1a" "OCF_GAP_GET_BONDED_DEVICES",
        (const byte*)"\x4f\xa4\x1a" "OCF_GAP_GET_SECURITY_LEVEL",
        (const byte*)"\x83\x53\x0c" "OCF_GAP_INIT",
        (const byte*)"\x9d\x53\x18" "OCF_GAP_IS_DEVICE_BONDED",
        (const byte*)"\x43\x7e\x18" "OCF_GAP_PASSKEY_RESPONSE",
        (const byte*)"\x16\x9a\x1f" "OCF_GAP_RESOLVE_PRIVATE_ADDRESS",
        (const byte*)"\xfe\x3f\x1c" "OCF_GAP_SEND_PAIRING_REQUEST",
        (const byte*)"\x0c\xec\x1c" "OCF_GAP_SET_AUTH_REQUIREMENT",
        (const byte*)"\x71\xc6\x1e" "OCF_GAP_SET_AUTHOR_REQUIREMENT",
        (const byte*)"\x07\x59\x1a" "OCF_GAP_SET_BROADCAST_MODE",
        (const byte*)"\x02\x0a\x1e" "OCF_GAP_SET_DIRECT_CONNECTABLE",
        (const byte*)"\xfd\xd0\x18" "OCF_GAP_SET_DISCOVERABLE",
        (const byte*)"\xad\x7f\x19" "OCF_GAP_SET_IO_CAPABILITY",
        (const byte*)"\xd6\x38\x20" "OCF_GAP_SET_LIMITED_DISCOVERABLE",
        (const byte*)"\x40\x67\x1b" "OCF_GAP_SET_NON_CONNECTABLE",
        (const byte*)"\xad\x01\x1c" "OCF_GAP_SET_NON_DISCOVERABLE",
        (const byte*)"\x58\x94\x22" "OCF_GAP_SET_UNDIRECTED_CONNECTABLE",
        (const byte*)"\x33\x56\x1e" "OCF_GAP_SLAVE_SECURITY_REQUEST",
        (const byte*)"\x8b\x07\x26" "OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC",
        (const byte*)"\x5e\xea\x1f" "OCF_GAP_START_CONNECTION_UPDATE",
        (const byte*)"\x12\x5b\x29" "OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC",
        (const byte*)"\xd4\x5b\x24" "OCF_GAP_START_GENERAL_DISCOVERY_PROC",
        (const byte*)"\x96\xcb\x24" "OCF_GAP_START_LIMITED_DISCOVERY_PROC",
        (const byte*)"\xe5\xa0\x21" "OCF_GAP_START_NAME_DISCOVERY_PROC",
        (const byte*)"\xf5\x57\x1e" "OCF_GAP_START_OBSERVATION_PROC",
        (const byte*)"\x76\xb4\x2b" "OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC",
        (const byte*)"\x60\x80\x11" "OCF_GAP_TERMINATE",
        (const byte*)"\xfb\x28\x1f" "OCF_GAP_TERMINATE_GAP_PROCEDURE",
        (const byte*)"\x8b\x2c\x17" "OCF_GAP_UPDATE_ADV_DATA",
        (const byte*)"\x6f\xaf\x11" "OCF_GATT_ADD_CHAR",
        (const byte*)"\x61\xd8\x16" "OCF_GATT_ADD_CHAR_DESC",
        (const byte*)"\xc5\xbc\x11" "OCF_GATT_ADD_SERV",
        (const byte*)"\xfd\x14\x13" "OCF_GATT_ALLOW_READ",
        (const byte*)"\x90\x86\x1b" "OCF_GATT_CONFIRM_INDICATION",
        (const byte*)"\x03\xe4\x11" "OCF_GATT_DEL_CHAR",
        (const byte*)"\xb2\xbc\x15" "OCF_GATT_DEL_INC_SERV",
        (const byte*)"\x69\x68\x11" "OCF_GATT_DEL_SERV",
        (const byte*)"\xf0\xeb\x24" "OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS",
        (const byte*)"\x74\xa9\x20" "OCF_GATT_DISC_ALL_CHARAC_OF_SERV",
        (const byte*)"\x22\x5c\x1f" "OCF_GATT_DISC_ALL_PRIM_SERVICES",
        (const byte*)"\x87\x51\x1c" "OCF_GATT_DISC_CHARAC_BY_UUID",
        (const byte*)"\xf9\xc6\x22" "OCF_GATT_DISC_PRIM_SERVICE_BY_UUID",
        (const byte*)"\x47\x27\x18" "OCF_GATT_EXCHANGE_CONFIG",
        (const byte*)"\x1a\xd1\x1f" "OCF_GATT_FIND_INCLUDED_SERVICES",
        (const byte*)"\x38\xa3\x15" "OCF_GATT_INCLUDE_SERV",
        (const byte*)"\x13\x76\x0d" "OCF_GATT_INIT",
        (const byte*)"\x72\xea\x17" "OCF_GATT_READ_CHAR_DESC",
        (const byte*)"\xba\xb2\x18" "OCF_GATT_READ_CHARAC_VAL",
        (const byte*)"\xfa\x2b\x1a" "OCF_GATT_READ_HANDLE_VALUE",
        (const byte*)"\xa8\x2e\x21" "OCF_GATT_READ_HANDLE_VALUE_OFFSET",
        (const byte*)"\x25\xb5\x1e" "OCF_GATT_READ_LONG_CHARAC_DESC",
        (const byte*)"\x2f\x54\x1d" "OCF_GATT_READ_LONG_CHARAC_VAL",
        (const byte*)"\x75\x52\x21" "OCF_GATT_READ_MULTIPLE_CHARAC_VAL",
        (const byte*)"\x35\x96\x1f" "OCF_GATT_READ_USING_CHARAC_UUID",
        (const byte*)"\x41\xef\x15" "OCF_GATT_SET_DESC_VAL",
        (const byte*)"\x58\xf7\x15" "OCF_GATT_SET_EVT_MASK",
        (const byte*)"\x16\xff\x20" "OCF_GATT_SET_SECURITY_PERMISSION",
        (const byte*)"\xd6\xba\x26" "OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE",
        (const byte*)"\xeb\x53\x15" "OCF_GATT_UPD_CHAR_VAL",
        (const byte*)"\x9d\x22\x19" "OCF_GATT_UPD_CHAR_VAL_EXT",
        (const byte*)"\xfd\x62\x18" "OCF_GATT_WRITE_CHAR_DESC",
        (const byte*)"\x07\x0e\x19" "OCF_GATT_WRITE_CHAR_VALUE",
        (const byte*)"\xd6\x52\x1e" "OCF_GATT_WRITE_CHARAC_RELIABLE",
        (const byte*)"\xca\x6d\x1f" "OCF_GATT_WRITE_LONG_CHARAC_DESC",
        (const byte*)"\xe0\x03\x1e" "OCF_GATT_WRITE_LONG_CHARAC_VAL",
        (const byte*)"\x88\x4e\x17" "OCF_GATT_WRITE_RESPONSE",
        (const byte*)"\x9b\x36\x1f" "OCF_GATT_WRITE_WITHOUT_RESPONSE",
        (const byte*)"\x11\x34\x17" "OCF_GET_UPDATER_BUFSIZE",
        (const byte*)"\xbf\x67\x17" "OCF_GET_UPDATER_VERSION",
        (const byte*)"\xfa\x6e\x16" "OCF_HAL_DEVICE_STANDBY",
        (const byte*)"\x40\xd5\x19" "OCF_HAL_GET_ANCHOR_PERIOD",
        (const byte*)"\xe7\xef\x1b" "OCF_HAL_GET_FW_BUILD_NUMBER",
        (const byte*)"\x48\x65\x17" "OCF_HAL_GET_LINK_STATUS",
        (const byte*)"\x52\xec\x20" "OCF_HAL_LE_TX_TEST_PACKET_NUMBER",
        (const byte*)"\x62\xeb\x18" "OCF_HAL_READ_CONFIG_DATA",
        (const byte*)"\xd2\xef\x1a" "OCF_HAL_SET_TX_POWER_LEVEL",
        (const byte*)"\x85\xf3\x12" "OCF_HAL_TONE_START",
        (const byte*)"\x7d\x3f\x11" "OCF_HAL_TONE_STOP",
        (const byte*)"\xcd\xc6\x19" "OCF_HAL_WRITE_CONFIG_DATA",
        (const byte*)"\x68\x05\x1f" "OCF_L2CAP_CONN_PARAM_UPDATE_REQ",
        (const byte*)"\xfa\xb2\x20" "OCF_L2CAP_CONN_PARAM_UPDATE_RESP",
        (const byte*)"\x8c\xe4\x14" "OCF_UPDATER_CALC_CRC",
        (const byte*)"\x9e\xa7\x1b" "OCF_UPDATER_ERASE_BLUE_FLAG",
        (const byte*)"\x4f\xfd\x18" "OCF_UPDATER_ERASE_SECTOR",
        (const byte*)"\x16\x4b\x16" "OCF_UPDATER_HW_VERSION",
        (const byte*)"\x3f\x49\x1b" "OCF_UPDATER_PROG_DATA_BLOCK",
        (const byte*)"\x27\xb6\x1b" "OCF_UPDATER_READ_DATA_BLOCK",
        (const byte*)"\xed\x43\x12" "OCF_UPDATER_REBOOT",
        (const byte*)"\x6b\x3a\x1b" "OCF_UPDATER_RESET_BLUE_FLAG",
        (const byte*)"\x0c\x2e\x11" "OCF_UPDATER_START",
        (const byte*)"\xb7\x25\x56" "bluetooth_low_energy.protocols.hci.vendor_specifics.st_microelectronics.bluenrg_ms.cmd",
        (const byte*)"\xd7\xce\x0c" "UUID_TYPE_16",
        (const byte*)"\x63\x74\x5b" "bluetooth_low_energy.protocols.hci.vendor_specifics.st_microelectronics.bluenrg_ms.constant",
        (const byte*)"\x51\xfd\x58" "bluetooth_low_energy.protocols.hci.vendor_specifics.st_microelectronics.bluenrg_ms.event",
        (const byte*)"\xa4\xa9\x14" "ST_HCI_VENDOR_EVENTS",
        (const byte*)"\xb5\xe3\x13" "HCI_PCK_TYPE_OFFSET",
        (const byte*)"\xe5\x03\x1e" "EVENT_PARAMETER_TOT_LEN_OFFSET",
        (const byte*)"\xea\x38\x09" "CSContext",
        (const byte*)"\x41\x2a\x0a" "BlueNRG_MS",
        (const byte*)"\x2d\xfb\x04" "_pin",
        (const byte*)"\xfc\xcb\x08" "exc_type",
        (const byte*)"\x0f\x8a\x09" "exc_value",
        (const byte*)"\xcf\xb2\x09" "traceback",
        (const byte*)"\xdd\xb5\x01" "x",
        (const byte*)"\x4f\x75\x02" "Y3",
        (const byte*)"\x48\x75\x02" "Y4",
        (const byte*)"\x49\x75\x02" "Y5",
        (const byte*)"\xea\x45\x15" "set_spi_irq_as_output",
        (const byte*)"\x03\x03\x14" "set_spi_irq_as_input",
        (const byte*)"\xe2\x6c\x0d" "hw_bootloader",
        (const byte*)"\x6c\x89\x03" "run",
        (const byte*)"\x85\x33\x09" "__start__",
        (const byte*)"\x5d\xd0\x08" "__stop__",
        (const byte*)"\x4e\xc3\x0b" "__process__",
        (const byte*)"\x8f\xaa\x0a" "hci_verify",
        (const byte*)"\x80\x2c\x0e" "hci_wait_event",
        (const byte*)"\x24\x8c\x08" "hci_send",
        (const byte*)"\x56\xd9\x0b" "get_version",
        (const byte*)"\x06\x88\x14" "aci_gap_init_IDB04A1",
        (const byte*)"\x07\x8c\x14" "aci_gap_init_IDB05A1",
        (const byte*)"\xcc\x39\x1c" "aci_gap_set_non_discoverable",
        (const byte*)"\xf7\x2c\x20" "aci_gap_set_limited_discoverable",
        (const byte*)"\x7c\x07\x18" "aci_gap_set_discoverable",
        (const byte*)"\x86\xf3\x26" "aci_gap_set_direct_connectable_IDB05A1",
        (const byte*)"\x87\xf7\x26" "aci_gap_set_direct_connectable_IDB04A1",
        (const byte*)"\xcc\xa4\x19" "aci_gap_set_io_capability",
        (const byte*)"\xed\x15\x1c" "aci_gap_set_auth_requirement",
        (const byte*)"\x50\xae\x1e" "aci_gap_set_author_requirement",
        (const byte*)"\xbd\x10\x19" "aci_gap_pass_key_response",
        (const byte*)"\x1f\x58\x1e" "aci_gap_authorization_response",
        (const byte*)"\xc4\xda\x23" "aci_gap_set_non_connectable_IDB05A1",
        (const byte*)"\xc5\xde\x23" "aci_gap_set_non_connectable_IDB04A1",
        (const byte*)"\x39\x25\x22" "aci_gap_set_undirected_connectable",
        (const byte*)"\xd2\xb9\x1e" "aci_gap_slave_security_request",
        (const byte*)"\xea\xe7\x17" "aci_gap_update_adv_data",
        (const byte*)"\xdc\x3c\x16" "aci_gap_delete_ad_type",
        (const byte*)"\x2e\x8d\x1a" "aci_gap_get_security_level",
        (const byte*)"\xea\x35\x1b" "aci_gap_configure_whitelist",
        (const byte*)"\xc1\x6a\x11" "aci_gap_terminate",
        (const byte*)"\x72\xcc\x1f" "aci_gap_clear_security_database",
        (const byte*)"\x6b\xc9\x1c" "aci_gap_allow_rebond_IDB05A1",
        (const byte*)"\xea\xd5\x1c" "aci_gap_allow_rebond_IDB04A1",
        (const byte*)"\x17\x5a\x24" "aci_gap_start_limited_discovery_proc",
        (const byte*)"\x95\xc2\x24" "aci_gap_start_general_discovery_proc",
        (const byte*)"\x24\x4e\x21" "aci_gap_start_name_discovery_proc",
        (const byte*)"\x0f\x12\x2e" "aci_gap_start_auto_conn_establish_proc_IDB05A1",
        (const byte*)"\x0e\x0e\x2e" "aci_gap_start_auto_conn_establish_proc_IDB04A1",
        (const byte*)"\x16\x92\x31" "aci_gap_start_general_conn_establish_proc_IDB05A1",
        (const byte*)"\x17\x96\x31" "aci_gap_start_general_conn_establish_proc_IDB04A1",
        (const byte*)"\xd7\x96\x2b" "aci_gap_start_selective_conn_establish_proc",
        (const byte*)"\xd5\x86\x19" "aci_gap_create_connection",
        (const byte*)"\xda\x1a\x1f" "aci_gap_terminate_gap_procedure",
        (const byte*)"\x3f\x33\x1f" "aci_gap_start_connection_update",
        (const byte*)"\x1f\x85\x1c" "aci_gap_send_pairing_request",
        (const byte*)"\x52\x7a\x27" "aci_gap_resolve_private_address_IDB05A1",
        (const byte*)"\x53\x7e\x27" "aci_gap_resolve_private_address_IDB04A1",
        (const byte*)"\x26\x71\x1a" "aci_gap_set_broadcast_mode",
        (const byte*)"\x77\x43\x23" "aci_gap_start_observation_procedure",
        (const byte*)"\xfc\xb6\x18" "aci_gap_is_device_bonded",
        (const byte*)"\xe3\x2d\x1a" "aci_gap_get_bonded_devices",
        (const byte*)"\x72\xed\x0d" "aci_gatt_init",
        (const byte*)"\xc4\xbb\x11" "aci_gatt_add_serv",
        (const byte*)"\x56\x32\x18" "aci_gatt_include_service",
        (const byte*)"\x2e\xae\x11" "aci_gatt_add_char",
        (const byte*)"\xc0\xee\x16" "aci_gatt_add_char_desc",
        (const byte*)"\xea\x8e\x1a" "aci_gatt_update_char_value",
        (const byte*)"\x82\xfd\x11" "aci_gatt_del_char",
        (const byte*)"\x27\x9d\x14" "aci_gatt_del_service",
        (const byte*)"\xe4\x26\x1c" "aci_gatt_del_include_service",
        (const byte*)"\x92\xc2\x17" "aci_gatt_set_event_mask",
        (const byte*)"\x1c\x21\x1f" "aci_gatt_exchange_configuration",
        (const byte*)"\xe0\xe2\x1c" "aci_att_find_information_req",
        (const byte*)"\x44\xf4\x1e" "aci_att_find_by_type_value_req",
        (const byte*)"\x27\x78\x18" "aci_att_read_by_type_req",
        (const byte*)"\x87\x08\x1e" "aci_att_read_by_group_type_req",
        (const byte*)"\x55\x01\x19" "aci_att_prepare_write_req",
        (const byte*)"\x2b\x54\x19" "aci_att_execute_write_req",
        (const byte*)"\x63\xca\x1f" "aci_gatt_disc_all_prim_services",
        (const byte*)"\x98\x41\x22" "aci_gatt_disc_prim_service_by_uuid",
        (const byte*)"\xfb\x9b\x1f" "aci_gatt_find_included_services",
        (const byte*)"\x15\xee\x20" "aci_gatt_disc_all_charac_of_serv",
        (const byte*)"\x46\xf7\x1c" "aci_gatt_disc_charac_by_uuid",
        (const byte*)"\x31\x30\x24" "aci_gatt_disc_all_charac_descriptors",
        (const byte*)"\x9b\xb8\x18" "aci_gatt_read_charac_val",
        (const byte*)"\x74\xae\x1f" "aci_gatt_read_using_charac_uuid",
        (const byte*)"\x2e\xfb\x1d" "aci_gatt_read_long_charac_val",
        (const byte*)"\xf4\x37\x21" "aci_gatt_read_multiple_charac_val",
        (const byte*)"\x04\x17\x1b" "aci_gatt_write_charac_value",
        (const byte*)"\x21\x5d\x1e" "aci_gatt_write_long_charac_val",
        (const byte*)"\x77\x69\x1e" "aci_gatt_write_charac_reliable",
        (const byte*)"\xcb\xee\x1f" "aci_gatt_write_long_charac_desc",
        (const byte*)"\xe4\x3c\x1e" "aci_gatt_read_long_charac_desc",
        (const byte*)"\x5c\xb4\x20" "aci_gatt_write_charac_descriptor",
        (const byte*)"\x31\xfe\x19" "aci_gatt_read_charac_desc",
        (const byte*)"\xba\xa4\x1f" "aci_gatt_write_without_response",
        (const byte*)"\x00\x70\x22" "aci_gatt_signed_write_without_resp",
        (const byte*)"\x91\x6e\x1b" "aci_gatt_confirm_indication",
        (const byte*)"\x49\x7e\x17" "aci_gatt_write_response",
        (const byte*)"\xbc\x73\x13" "aci_gatt_allow_read",
        (const byte*)"\xb7\x4b\x20" "aci_gatt_set_security_permission",
        (const byte*)"\x90\xf6\x17" "aci_gatt_set_desc_value",
        (const byte*)"\xdb\xe0\x1a" "aci_gatt_read_handle_value",
        (const byte*)"\x8c\xfc\x29" "aci_gatt_read_handle_value_offset_IDB05A1",
        (const byte*)"\x99\x48\x26" "aci_gatt_update_char_value_ext_IDB05A1",
        (const byte*)"\x26\xf0\x1b" "aci_hal_get_fw_build_number",
        (const byte*)"\xec\xf7\x19" "aci_hal_write_config_data",
        (const byte*)"\xc3\x67\x18" "aci_hal_read_config_data",
        (const byte*)"\x93\x4c\x1a" "aci_hal_set_tx_power_level",
        (const byte*)"\x33\xb7\x20" "aci_hal_le_tx_test_packet_number",
        (const byte*)"\xfb\xd2\x16" "aci_hal_device_standby",
        (const byte*)"\x04\xf9\x12" "aci_hal_tone_start",
        (const byte*)"\x3c\x8c\x11" "aci_hal_tone_stop",
        (const byte*)"\x29\x0b\x17" "aci_hal_get_link_status",
        (const byte*)"\xe1\x66\x19" "aci_hal_get_anchor_period",
        (const byte*)"\x42\x08\x2d" "aci_l2cap_connection_parameter_update_request",
        (const byte*)"\xb5\x34\x36" "aci_l2cap_connection_parameter_update_response_IDB05A1",
        (const byte*)"\x34\x41\x36" "aci_l2cap_connection_parameter_update_response_IDB04A1",
        (const byte*)"\xad\x21\x11" "aci_updater_start",
        (const byte*)"\xcc\xc3\x12" "aci_updater_reboot",
        (const byte*)"\x7e\xcc\x17" "aci_get_updater_version",
        (const byte*)"\x3e\xee\x1b" "aci_get_updater_buffer_size",
        (const byte*)"\x23\xd8\x13" "aci_erase_blue_flag",
        (const byte*)"\xd6\xe5\x13" "aci_reset_blue_flag",
        (const byte*)"\x8e\x43\x18" "aci_updater_erase_sector",
        (const byte*)"\x20\xe8\x1e" "aci_updater_program_data_block",
        (const byte*)"\xc6\x8c\x1b" "aci_updater_read_data_block",
        (const byte*)"\x4d\xc1\x14" "aci_updater_calc_crc",
        (const byte*)"\x57\x6f\x16" "aci_updater_hw_version",
        (const byte*)"\x2b\xc9\x08" "_spi_bus",
        (const byte*)"\xf8\xba\x08" "_irq_pin",
        (const byte*)"\xc7\x02\x08" "_rst_pin",
        (const byte*)"\x1c\x3e\x08" "_nss_pin",
        (const byte*)"\xf4\xec\x07" "spi_bus",
        (const byte*)"\x27\xbb\x07" "irq_pin",
        (const byte*)"\x58\xf4\x07" "rst_pin",
        (const byte*)"\x03\xb8\x07" "nss_pin",
        (const byte*)"\x66\xd2\x0d" "callback_time",
        (const byte*)"\xc9\x69\x05" "event",
        (const byte*)"\x20\xa5\x04" "size",
        (const byte*)"\x9a\x98\x06" "header",
        (const byte*)"\xca\xc8\x05" "param",
        (const byte*)"\x34\xd7\x08" "hci_pckt",
        (const byte*)"\x6c\x7f\x0b" "from_buffer",
        (const byte*)"\x2d\x93\x08" "pkt_type",
        (const byte*)"\xaf\xde\x07" "evtcode",
        (const byte*)"\x0b\x4c\x0a" "subevtcode",
        (const byte*)"\xe1\xfd\x09" "to_buffer",
        (const byte*)"\xb7\x7a\x0c" "_struct_size",
        (const byte*)"\x1b\x95\x04" "<B3s",
        (const byte*)"\x17\xf2\x06" "opcode",
        (const byte*)"\x71\x09\x06" "status",
        (const byte*)"\x28\x24\x0b" "struct_size",
        (const byte*)"\xe9\xe1\x0d" "response_data",
        (const byte*)"\xee\x46\x0f" "response_struct",
        (const byte*)"\x8b\x7e\x0c" "hci_revision",
        (const byte*)"\x17\x5f\x12" "lmp_pal_subversion",
        (const byte*)"\x72\x1e\x03" "dev",
        (const byte*)"\x8b\xb5\x01" ".",
        (const byte*)"\x51\x02\x04" "role",
        (const byte*)"\x19\x51\x0f" "privacy_enabled",
        (const byte*)"\x7a\xbe\x14" "device_name_char_len",
        (const byte*)"\xd1\x68\x08" "adv_type",
        (const byte*)"\x4e\x5e\x0e" "adv_interv_min",
        (const byte*)"\x50\x5f\x0e" "adv_interv_max",
        (const byte*)"\x18\x44\x0d" "own_addr_type",
        (const byte*)"\xf6\x06\x11" "adv_filter_policy",
        (const byte*)"\xc8\xbd\x0e" "local_name_len",
        (const byte*)"\x30\x48\x0a" "local_name",
        (const byte*)"\xf2\xe0\x10" "service_uuid_len",
        (const byte*)"\xb7\xcb\x11" "service_uuid_list",
        (const byte*)"\x83\x23\x15" "slave_conn_interv_min",
        (const byte*)"\x9d\x22\x15" "slave_conn_interv_max",
        (const byte*)"\xfe\x97\x08" "<BBB6sHH",
        (const byte*)"\xa2\xfe\x11" "directed_adv_type",
        (const byte*)"\xf5\x2d\x13" "initiator_addr_type",
        (const byte*)"\xf2\xe3\x0e" "initiator_addr",
        (const byte*)"\x9c\xec\x05" "<BB6s",
        (const byte*)"\xac\x6c\x0d" "io_capability",
        (const byte*)"\x84\x0a\x09" "mitm_mode",
        (const byte*)"\x19\xf2\x0a" "oob_enable",
        (const byte*)"\x08\xf8\x08" "oob_data",
        (const byte*)"\x6d\xa6\x17" "min_encryption_key_size",
        (const byte*)"\xf3\xdd\x17" "max_encryption_key_size",
        (const byte*)"\x47\xab\x0d" "use_fixed_pin",
        (const byte*)"\xfb\x6b\x09" "fixed_pin",
        (const byte*)"\x9e\xef\x0c" "bonding_mode",
        (const byte*)"\x5c\x0b\x0b" "conn_handle",
        (const byte*)"\x00\x48\x14" "authorization_enable",
        (const byte*)"\x58\x87\x03" "<HI",
        (const byte*)"\xe3\xdd\x07" "passkey",
        (const byte*)"\x26\xe0\x09" "authorize",
        (const byte*)"\xdd\x26\x10" "own_address_type",
        (const byte*)"\xf1\x71\x04" "<HBB",
        (const byte*)"\xe2\x7e\x07" "bonding",
        (const byte*)"\x04\x14\x0f" "mitm_protection",
        (const byte*)"\xae\xbe\x07" "adv_len",
        (const byte*)"\x59\x08\x08" "adv_data",
        (const byte*)"\xe7\x8e\x07" "ad_type",
        (const byte*)"\xd9\xb9\x05" "<HHBB",
        (const byte*)"\x1a\x4a\x0d" "scan_interval",
        (const byte*)"\x89\xff\x0b" "scan_window",
        (const byte*)"\xbe\xf4\x11" "filter_duplicates",
        (const byte*)"\x9c\x09\x11" "conn_min_interval",
        (const byte*)"\x42\x60\x11" "conn_max_interval",
        (const byte*)"\xde\x7a\x0c" "conn_latency",
        (const byte*)"\x3f\xee\x0f" "min_conn_length",
        (const byte*)"\x21\x3f\x0f" "max_conn_length",
        (const byte*)"\xa4\x52\x15" "num_whitelist_entries",
        (const byte*)"\xd0\x74\x0a" "addr_array",
        (const byte*)"\xae\xec\x0f" "use_reconn_addr",
        (const byte*)"\xd2\x0f\x0b" "reconn_addr",
        (const byte*)"\x9d\xbb\x09" "scan_type",
        (const byte*)"\xbe\x29\x08" "<BHHBB6s",
        (const byte*)"\x9a\x24\x0e" "procedure_code",
        (const byte*)"\xb1\x64\x08" "<HHHHHHH",
        (const byte*)"\xd7\xee\x0c" "force_rebond",
        (const byte*)"\xa1\x7a\x0f" "private_address",
        (const byte*)"\xfa\xd2\x0f" "adv_data_length",
        (const byte*)"\xbb\xf4\x06" "<HHBBB",
        (const byte*)"\x49\xcc\x11" "peer_address_type",
        (const byte*)"\xce\x46\x0c" "peer_address",
        (const byte*)"\x50\xb3\x09" "<B{:d}sBB",
        (const byte*)"\x0d\x2a\x11" "service_uuid_type",
        (const byte*)"\x8a\x2e\x0c" "service_uuid",
        (const byte*)"\x5f\xc5\x0c" "service_type",
        (const byte*)"\xfc\x7d\x10" "max_attr_records",
        (const byte*)"\x78\xf9\x0a" "<HHHB{:d}s",
        (const byte*)"\x0d\x2f\x0e" "service_handle",
        (const byte*)"\x17\x8d\x15" "included_start_handle",
        (const byte*)"\xf8\xaa\x13" "included_end_handle",
        (const byte*)"\x08\x33\x12" "included_uuid_type",
        (const byte*)"\xef\xc9\x0d" "included_uuid",
        (const byte*)"\x88\x27\x0e" "char_uuid_type",
        (const byte*)"\x6f\xee\x09" "char_uuid",
        (const byte*)"\x31\xd0\x0e" "char_value_len",
        (const byte*)"\x03\xfb\x0f" "char_properties",
        (const byte*)"\x77\xad\x0f" "sec_permissions",
        (const byte*)"\xd0\x54\x0d" "gatt_evt_mask",
        (const byte*)"\x14\x4a\x0e" "encry_key_size",
        (const byte*)"\x26\xea\x0b" "is_variable",
        (const byte*)"\x68\x54\x0b" "char_handle",
        (const byte*)"\xa1\x99\x0e" "desc_uuid_type",
        (const byte*)"\xc8\xe9\x04" "uuid",
        (const byte*)"\xb3\xf4\x12" "desc_value_max_len",
        (const byte*)"\x58\x58\x0e" "desc_value_len",
        (const byte*)"\xa0\x9e\x0a" "desc_value",
        (const byte*)"\xa3\xf7\x0f" "acc_permissions",
        (const byte*)"\xf2\x83\x0a" "<HHBB{:d}s",
        (const byte*)"\x02\x92\x0b" "serv_handle",
        (const byte*)"\x0b\x1b\x0f" "char_val_offset",
        (const byte*)"\x89\xd4\x0a" "char_value",
        (const byte*)"\x59\x87\x03" "<HH",
        (const byte*)"\xc1\x96\x13" "include_serv_handle",
        (const byte*)"\xf0\x68\x02" "<I",
        (const byte*)"\x22\x84\x0a" "event_mask",
        (const byte*)"\x31\x72\x04" "<HHH",
        (const byte*)"\xb0\x3d\x0c" "start_handle",
        (const byte*)"\xdf\x5e\x0a" "end_handle",
        (const byte*)"\xaa\x3c\x0c" "attr_val_len",
        (const byte*)"\x52\xd0\x08" "attr_val",
        (const byte*)"\x0f\xbd\x09" "uuid_type",
        (const byte*)"\xe3\x90\x0b" "attr_handle",
        (const byte*)"\x9c\xd9\x0c" "value_offset",
        (const byte*)"\x3a\x69\x07" "execute",
        (const byte*)"\xb8\xc1\x08" "<HB{:d}s",
        (const byte*)"\xfc\xc8\x11" "start_attr_handle",
        (const byte*)"\xf3\x6d\x0f" "end_attr_handle",
        (const byte*)"\x8c\xc9\x0f" "char_val_handle",
        (const byte*)"\x78\x2f\x0f" "char_end_handle",
        (const byte*)"\x2c\xf2\x0a" "val_offset",
        (const byte*)"\x75\x9d\x0b" "num_handles",
        (const byte*)"\xf7\xb7\x0e" "set_of_handles",
        (const byte*)"\xd0\x09\x09" "<HHB{:d}s",
        (const byte*)"\x06\xd2\x07" "val_len",
        (const byte*)"\xa2\x37\x0a" "attr_value",
        (const byte*)"\xb3\x35\x0c" "write_status",
        (const byte*)"\xb2\xb0\x08" "err_code",
        (const byte*)"\x58\x24\x0b" "att_val_len",
        (const byte*)"\xa0\x6a\x07" "att_val",
        (const byte*)"\x3b\x72\x04" "<HHB",
        (const byte*)"\x87\x56\x13" "security_permission",
        (const byte*)"\xe6\x15\x10" "char_desc_handle",
        (const byte*)"\x85\xaa\x14" "char_desc_val_offset",
        (const byte*)"\x7f\x28\x13" "char_desc_value_len",
        (const byte*)"\x47\x0f\x0f" "char_desc_value",
        (const byte*)"\x48\x3c\x06" "offset",
        (const byte*)"\xf3\xaa\x0b" "update_type",
        (const byte*)"\xfe\x91\x0b" "char_length",
        (const byte*)"\x8d\x67\x0c" "value_length",
        (const byte*)"\x32\x8a\x08" "<BB{:d}s",
        (const byte*)"\x9f\x59\x0d" "en_high_power",
        (const byte*)"\x5d\x3e\x08" "pa_level",
        (const byte*)"\xad\xd4\x0a" "rf_channel",
        (const byte*)"\x71\xbb\x06" "<HHHHH",
        (const byte*)"\xaf\x7e\x0c" "interval_min",
        (const byte*)"\xb1\x7f\x0c" "interval_max",
        (const byte*)"\xbf\x18\x0d" "slave_latency",
        (const byte*)"\x0a\xcc\x12" "timeout_multiplier",
        (const byte*)"\xb1\x4c\x0a" "<HHHHHHHBB",
        (const byte*)"\x77\x54\x03" "id_",
        (const byte*)"\x71\x64\x08" "<HHHHHBB",
        (const byte*)"\x73\x53\x07" "address",
        (const byte*)"\xf3\x94\x08" "<IH{:d}s",
        (const byte*)"\xad\x71\x08" "data_len",
        (const byte*)"\xb8\x86\x03" "<IH",
        (const byte*)"\xc3\x64\x0b" "num_sectors",
        (const byte*)"\x4d\x69\x3c" "bluetooth_low_energy/modules/st_microelectronics/__init__.py",
        (const byte*)"\x00\x41\x3d" "bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py",
        (const byte*)"\x75\x77\x3b" "bluetooth_low_energy.modules.st_microelectronics.bluenrg_ms",
        (const byte*)"\xd2\xcd\x09" "SPBTLE_RF",
        (const byte*)"\xf1\x9f\x28" "bluetooth_low_energy/modules/__init__.py",
        (const byte*)"\x79\x1a\x23" "bluetooth_low_energy/api/central.py",
        (const byte*)"\x45\x17\x24" "bluetooth_low_energy/api/delegate.py",
        (const byte*)"\x37\x28\x20" "bluetooth_low_energy/api/uuid.py",
        (const byte*)"\xf0\xf1\x22" "bluetooth_low_energy.api.constants",
        (const byte*)"\xc8\xe9\x04" "UUID",
        (const byte*)"\xc4\xc3\x07" "__all__",
        (const byte*)"\xe4\x4f\x0e" "__properties__",
        (const byte*)"\x88\xb5\x01" "-",
        (const byte*)"\x30\x30\x0b" "UUID_16_BIT",
        (const byte*)"\x0c\x4a\x0c" "UUID_128_BIT",
        (const byte*)"\x54\x57\x05" "ascii",
        (const byte*)"\xa1\x98\x05" "other",
        (const byte*)"\x87\xde\x2a" "bluetooth_low_energy/api/characteristic.py",
        (const byte*)"\xb6\x88\x0a" "Descriptor",
        (const byte*)"\x0e\xcc\x23" "bluetooth_low_energy.api.descriptor",
        (const byte*)"\x10\x0c\x1d" "bluetooth_low_energy.api.uuid",
        (const byte*)"\x58\x7e\x0e" "Characteristic",
        (const byte*)"\x15\x45\x09" "PROP_READ",
        (const byte*)"\x9a\xd2\x0a" "PROP_WRITE",
        (const byte*)"\xfa\xf0\x09" "PERM_NONE",
        (const byte*)"\x23\x1e\x17" "MASK_DONT_NOTIFY_EVENTS",
        (const byte*)"\xc8\x3a\x0e" "add_descriptor",
        (const byte*)"\x0c\x6c\x0f" "get_descriptors",
        (const byte*)"\x94\x13\x15" "__write_proprerties__",
        (const byte*)"\x3b\xbd\x14" "__read_proprerties__",
        (const byte*)"\x8b\xc0\x05" "props",
        (const byte*)"\xdc\x98\x05" "perms",
        (const byte*)"\x91\xba\x04" "mask",
        (const byte*)"\xe5\xff\x0b" "descriptors",
        (const byte*)"\x43\x89\x0b" "st_constant",
        (const byte*)"\xbf\x56\x12" "MAX_ENCRY_KEY_SIZE",
        (const byte*)"\x5e\x61\x08" "{!s}{:s}",
        (const byte*)"\x89\x66\x02" ", ",
        (const byte*)"\xd6\x64\x0a" "descriptor",
        (const byte*)"\x67\xb9\x23" "bluetooth_low_energy/api/service.py",
        (const byte*)"\xa0\x10\x27" "bluetooth_low_energy.api.characteristic",
        (const byte*)"\x12\x48\x19" "compute_attributes_record",
        (const byte*)"\xd9\xef\x1d" "bluetooth_low_energy.api.util",
        (const byte*)"\xb8\xb4\x07" "Service",
        (const byte*)"\xab\x70\x0f" "SERVICE_PRIMARY",
        (const byte*)"\x66\x6e\x12" "add_characteristic",
        (const byte*)"\xf1\x26\x12" "get_characteristic",
        (const byte*)"\x62\x05\x13" "get_characteristics",
        (const byte*)"\x0b\x68\x0f" "characteristics",
        (const byte*)"\x78\x39\x0e" "characteristic",
        (const byte*)"\xd7\x6a\x25" "bluetooth_low_energy/api/constants.py",
        (const byte*)"\xfb\x61\x08" "constant",
        (const byte*)"\x53\x2d\x52" "bluetooth_low_energy.protocols.hci.vendor_specifics.st_microelectronics.bluenrg_ms",
        (const byte*)"\x71\x90\x08" "st_event",
        (const byte*)"\x6f\x1e\x10" "ADDR_TYPE_PUBLIC",
        (const byte*)"\xf2\x4b\x17" "ADDR_TYPE_RANDOM_STATIC",
        (const byte*)"\xeb\x50\x0f" "PRIMARY_SERVICE",
        (const byte*)"\x1d\xac\x11" "SECONDARY_SERVICE",
        (const byte*)"\xdd\x14\x11" "SERVICE_SECONDARY",
        (const byte*)"\x0b\xa9\x0d" "UUID_TYPE_128",
        (const byte*)"\xf1\xe4\x14" "EVT_LE_CONN_COMPLETE",
        (const byte*)"\xab\x6e\x11" "EVT_GAP_CONNECTED",
        (const byte*)"\x79\x94\x14" "EVT_DISCONN_COMPLETE",
        (const byte*)"\xd5\xb4\x14" "EVT_GAP_DISCONNECTED",
        (const byte*)"\x07\x71\x20" "EVT_BLUE_GATT_ATTRIBUTE_MODIFIED",
        (const byte*)"\x4a\x92\x0f" "EVT_GATTS_WRITE",
        (const byte*)"\xa6\x8d\x1d" "EVT_BLUE_GATT_READ_PERMIT_REQ",
        (const byte*)"\x54\x44\x19" "EVT_GATTS_READ_PERMIT_REQ",
        (const byte*)"\x89\x50\x1e" "EVT_BLUE_GATT_WRITE_PERMIT_REQ",
        (const byte*)"\x7b\xc4\x1a" "EVT_GATTS_WRITE_PERMIT_REQ",
        (const byte*)"\x5f\xcf\x13" "CHAR_PROP_BROADCAST",
        (const byte*)"\x78\x40\x0e" "PROP_BROADCAST",
        (const byte*)"\x52\x2f\x0e" "CHAR_PROP_READ",
        (const byte*)"\x25\x73\x1c" "CHAR_PROP_WRITE_WITHOUT_RESP",
        (const byte*)"\xf6\xa6\x12" "PROP_WRITE_WO_RESP",
        (const byte*)"\x3d\x2b\x0f" "CHAR_PROP_WRITE",
        (const byte*)"\xa3\x69\x10" "CHAR_PROP_NOTIFY",
        (const byte*)"\x64\x8e\x0b" "PROP_NOTIFY",
        (const byte*)"\x39\x28\x12" "CHAR_PROP_INDICATE",
        (const byte*)"\x3e\x69\x0d" "PROP_INDICATE",
        (const byte*)"\x30\x5d\x16" "CHAR_PROP_SIGNED_WRITE",
        (const byte*)"\x38\x7c\x13" "PROP_AUTH_SIGNED_WR",
        (const byte*)"\x57\x34\x14" "ATTR_PERMISSION_NONE",
        (const byte*)"\xb3\x8f\x1b" "ATTR_PERMISSION_AUTHEN_READ",
        (const byte*)"\xfe\xd4\x10" "PERM_AUTHEN_READ",
        (const byte*)"\x25\x62\x1b" "ATTR_PERMISSION_AUTHOR_READ",
        (const byte*)"\x68\xa4\x10" "PERM_AUTHOR_READ",
        (const byte*)"\x53\x4f\x1a" "ATTR_PERMISSION_ENCRY_READ",
        (const byte*)"\x3e\x42\x0f" "PERM_ENCRY_READ",
        (const byte*)"\x7c\xa0\x1c" "ATTR_PERMISSION_AUTHEN_WRITE",
        (const byte*)"\x51\xc1\x11" "PERM_AUTHEN_WRITE",
        (const byte*)"\x2a\x19\x1c" "ATTR_PERMISSION_AUTHOR_WRITE",
        (const byte*)"\x07\x98\x11" "PERM_AUTHOR_WRITE",
        (const byte*)"\x1c\x33\x1b" "ATTR_PERMISSION_ENCRY_WRITE",
        (const byte*)"\x11\xf7\x10" "PERM_ENCRY_WRITE",
        (const byte*)"\x53\x47\x0e" "ATTR_NO_ACCESS",
        (const byte*)"\x61\xc5\x0d" "ACC_NO_ACCESS",
        (const byte*)"\xeb\x01\x15" "ATTR_ACCESS_READ_ONLY",
        (const byte*)"\x22\xbf\x0d" "ACC_READ_ONLY",
        (const byte*)"\xdd\x16\x1a" "ATTR_ACCESS_WRITE_REQ_ONLY",
        (const byte*)"\x74\xa0\x12" "ACC_WRITE_REQ_ONLY",
        (const byte*)"\xa2\xb0\x16" "ATTR_ACCESS_READ_WRITE",
        (const byte*)"\x0b\x5d\x0e" "ACC_READ_WRITE",
        (const byte*)"\xe0\x8e\x22" "ATTR_ACCESS_WRITE_WITHOUT_RESPONSE",
        (const byte*)"\x49\xc8\x1a" "ACC_WRITE_WITHOUT_RESPONSE",
        (const byte*)"\x85\xb2\x20" "ATTR_ACCESS_SIGNED_WRITE_ALLOWED",
        (const byte*)"\xec\x6e\x18" "ACC_SIGNED_WRITE_ALLOWED",
        (const byte*)"\x91\x1e\x17" "GATT_DONT_NOTIFY_EVENTS",
        (const byte*)"\x1e\xc1\x1b" "GATT_NOTIFY_ATTRIBUTE_WRITE",
        (const byte*)"\xac\x55\x1b" "MASK_NOTIFY_ATTRIBUTE_WRITE",
        (const byte*)"\xd9\xff\x2c" "GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP",
        (const byte*)"\x2b\xe2\x2c" "MASK_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP",
        (const byte*)"\xd6\x16\x2b" "GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP",
        (const byte*)"\x64\xa1\x2b" "MASK_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP",
        (const byte*)"\x9c\xd7\x23" "bluetooth_low_energy/api/scanner.py",
        (const byte*)"\xee\xe2\x09" "ScanEntry",
        (const byte*)"\x89\xc5\x23" "bluetooth_low_energy.api.scan_entry",
        (const byte*)"\xa6\xa4\x3a" "bluetooth_low_energy.modules.st_microelectronics.spbtle_rf",
        (const byte*)"\x77\x1a\x04" "uart",
        (const byte*)"\xa3\xd1\x07" "Scanner",
        (const byte*)"\xe6\x94\x08" "response",
        (const byte*)"\x0a\x0b\x18" "EVT_BLUE_HAL_INITIALIZED",
        (const byte*)"\x53\xc4\x0b" "reason_code",
        (const byte*)"\xdc\xac\x0c" "RESET_NORMAL",
        (const byte*)"\xf9\xce\x1a" "CONFIG_DATA_PUBADDR_OFFSET",
        (const byte*)"\xd3\x00\x17" "CONFIG_DATA_PUBADDR_LEN",
        (const byte*)"\x0e\x23\x17" "CONFIG_DATA_MODE_OFFSET",
        (const byte*)"\x04\xc7\x14" "CONFIG_DATA_MODE_LEN",
        (const byte*)"\xa1\x94\x18" "GAP_CENTRAL_ROLE_IDB05A1",
        (const byte*)"\xac\xd3\x10" "PRIVACY_DISABLED",
        (const byte*)"\x70\x59\x19" "EVT_LE_ADVERTISING_REPORT",
        (const byte*)"\x85\x8e\x08" "evt_type",
        (const byte*)"\x0a\xdc\x07" "ADV_IND",
        (const byte*)"\x0a\xa6\x0c" "ADV_SCAN_IND",
        (const byte*)"\xb6\x0f\x0b" "data_length",
        (const byte*)"\x91\x4b\x09" "data_RSSI",
        (const byte*)"\x8e\x09\x1f" "EVT_BLUE_GAP_PROCEDURE_COMPLETE",
        (const byte*)"\x7e\x53\x1a" "GAP_GENERAL_DISCOVERY_PROC",
        (const byte*)"\x02\x24\x03" "evt",
        (const byte*)"\x08\x5c\x0b" "PUBLIC_ADDR",
        (const byte*)"\x96\xad\x26" "bluetooth_low_energy/api/peripheral.py",
        (const byte*)"\x40\x16\x20" "bluetooth_low_energy.api.service",
        (const byte*)"\x29\xea\x0a" "Peripheral",
        (const byte*)"\x01\xae\x10" "set_discoverable",
        (const byte*)"\x46\x7e\x0b" "add_service",
        (const byte*)"\x33\x92\x11" "set_event_handler",
        (const byte*)"\x8a\x41\x0a" "write_uuid",
        (const byte*)"\x05\x6e\x09" "read_uuid",
        (const byte*)"\x54\x8a\x10" "uuid_from_handle",
        (const byte*)"\x14\xec\x0c" "address_type",
        (const byte*)"\x71\x36\x0b" "connectable",
        (const byte*)"\xeb\x28\x08" "services",
        (const byte*)"\x0e\x51\x0d" "event_handler",
        (const byte*)"\xc6\xcc\x11" "connection_handle",
        (const byte*)"\xf8\x7e\x14" "dev_name_char_handle",
        (const byte*)"\x69\xe6\x16" "appearance_char_handle",
        (const byte*)"\x0e\x44\x1b" "GAP_PERIPHERAL_ROLE_IDB05A1",
        (const byte*)"\xf2\x79\x18" "MITM_PROTECTION_REQUIRED",
        (const byte*)"\xaf\x0d\x14" "OOB_AUTH_DATA_ABSENT",
        (const byte*)"\xe1\x9f\x12" "MIN_ENCRY_KEY_SIZE",
        (const byte*)"\x76\xd2\x19" "USE_FIXED_PIN_FOR_PAIRING",
        (const byte*)"\xc2\x5b\x07" "BONDING",
        (const byte*)"\x8b\x7b\x08" "att_data",
        (const byte*)"\x0a\x23\x0b" "data_buffer",
        (const byte*)"\xfb\xd5\x1b" "AD_TYPE_COMPLETE_LOCAL_NAME",
        (const byte*)"\x4a\x5e\x10" "MAX_ADV_DATA_LEN",
        (const byte*)"\x5d\xbb\x11" "NO_WHITE_LIST_USE",
        (const byte*)"\x87\x80\x08" "_service",
        (const byte*)"\x9c\xbd\x0a" "uuid_value",
        (const byte*)"\xb6\x06\x09" "value_len",
        (const byte*)"\x40\xc6\x24" "bluetooth_low_energy/api/__init__.py",
        (const byte*)"\xe9\x1c\x26" "bluetooth_low_energy/api/descriptor.py",
        (const byte*)"\x64\x33\x03" "acc",
        (const byte*)"\xde\x1f\x20" "bluetooth_low_energy/api/util.py",
        (const byte*)"\xc4\x65\x14" "format_advertisement",
        (const byte*)"\x69\x6f\x0d" "CHAR_PROP_EXT",
        (const byte*)"\x98\x75\x07" "service",
        (const byte*)"\x1a\x4e\x05" "FLAGS",
        (const byte*)"\x67\x5f\x0d" "AD_TYPE_FLAGS",
        (const byte*)"\x20\xd2\x18" "AD_TYPE_16_BIT_SERV_UUID",
        (const byte*)"\xa4\xb1\x23" "AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST",
        (const byte*)"\xe6\x8c\x18" "AD_TYPE_32_BIT_SERV_UUID",
        (const byte*)"\x22\xbe\x23" "AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST",
        (const byte*)"\xbc\xff\x19" "AD_TYPE_128_BIT_SERV_UUID",
        (const byte*)"\xb8\x63\x24" "AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST",
        (const byte*)"\xca\x18\x1c" "AD_TYPE_SHORTENED_LOCAL_NAME",
        (const byte*)"\x5d\xc2\x16" "AD_TYPE_TX_POWER_LEVEL",
        (const byte*)"\xa7\x86\x17" "AD_TYPE_CLASS_OF_DEVICE",
        (const byte*)"\xde\x9a\x18" "AD_TYPE_SEC_MGR_TK_VALUE",
        (const byte*)"\x77\xb2\x19" "AD_TYPE_SEC_MGR_OOB_FLAGS",
        (const byte*)"\x46\xe8\x1b" "AD_TYPE_SLAVE_CONN_INTERVAL",
        (const byte*)"\xa5\xc1\x25" "AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST",
        (const byte*)"\x63\xaa\x25" "AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST",
        (const byte*)"\x19\x5b\x26" "AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST",
        (const byte*)"\xea\x51\x14" "AD_TYPE_SERVICE_DATA",
        (const byte*)"\x3f\x51\x22" "AD_TYPE_MANUFACTURER_SPECIFIC_DATA",
        (const byte*)"\x8e\x0a\x26" "bluetooth_low_energy/api/scan_entry.py",
        (const byte*)"\xdc\x6c\x08" "get_data",
        (const byte*)"\x7e\xb0\x04" "rssi",
        (const byte*)"\xf7\x11\x20" "bluetooth_low_energy/__init__.py",
        (const byte*)"\x20\xbd\x07" "0.1-pre",
        (const byte*)"\x3f\x98\x0b" "__version__",
        (const byte*)"\x15\x65\x05" "2.0.2",
        (const byte*)"\xb5\x1a\x16" "__version_bluenrg_dk__",
        (const byte*)"\xfd\x20\x2a" "bluetooth_low_energy/protocols/__init__.py",
        (const byte*)"\x07\xf8\x2d" "bluetooth_low_energy/protocols/at/__init__.py",
        (const byte*)"\x8b\xd4\x53" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/__init__.py",
        (const byte*)"\x6e\x8a\x5c" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/status.py",
        (const byte*)"\xb9\xc3\x11" "BLE_STATUS_FAILED",
        (const byte*)"\xa8\x44\x19" "BLE_STATUS_INVALID_PARAMS",
        (const byte*)"\xa8\xb2\x16" "BLE_STATUS_NOT_ALLOWED",
        (const byte*)"\x82\xf6\x10" "BLE_STATUS_ERROR",
        (const byte*)"\xec\xa2\x1c" "BLE_STATUS_ADDR_NOT_RESOLVED",
        (const byte*)"\xc4\x77\x11" "FLASH_READ_FAILED",
        (const byte*)"\x8b\x82\x12" "FLASH_WRITE_FAILED",
        (const byte*)"\x16\xb9\x12" "FLASH_ERASE_FAILED",
        (const byte*)"\x7a\x82\x16" "BLE_STATUS_INVALID_CID",
        (const byte*)"\x3d\xb6\x15" "TIMER_NOT_VALID_LAYER",
        (const byte*)"\x66\xb2\x1c" "TIMER_INSUFFICIENT_RESOURCES",
        (const byte*)"\x90\x97\x19" "BLE_STATUS_CSRK_NOT_FOUND",
        (const byte*)"\x29\x2a\x18" "BLE_STATUS_IRK_NOT_FOUND",
        (const byte*)"\xef\x56\x1e" "BLE_STATUS_DEV_NOT_FOUND_IN_DB",
        (const byte*)"\x7a\x8d\x16" "BLE_STATUS_SEC_DB_FULL",
        (const byte*)"\x1e\xac\x19" "BLE_STATUS_DEV_NOT_BONDED",
        (const byte*)"\x2f\x99\x1b" "BLE_STATUS_DEV_IN_BLACKLIST",
        (const byte*)"\xde\xce\x19" "BLE_STATUS_INVALID_HANDLE",
        (const byte*)"\x5d\x87\x1c" "BLE_STATUS_INVALID_PARAMETER",
        (const byte*)"\x77\x85\x18" "BLE_STATUS_OUT_OF_HANDLE",
        (const byte*)"\xe1\xef\x1c" "BLE_STATUS_INVALID_OPERATION",
        (const byte*)"\xa1\x70\x21" "BLE_STATUS_INSUFFICIENT_RESOURCES",
        (const byte*)"\xf6\x40\x1c" "BLE_INSUFFICIENT_ENC_KEYSIZE",
        (const byte*)"\x26\x7a\x20" "BLE_STATUS_CHARAC_ALREADY_EXISTS",
        (const byte*)"\x49\x63\x18" "BLE_STATUS_NO_VALID_SLOT",
        (const byte*)"\xfb\x39\x1c" "BLE_STATUS_SCAN_WINDOW_SHORT",
        (const byte*)"\xda\x7c\x1e" "BLE_STATUS_NEW_INTERVAL_FAILED",
        (const byte*)"\x0c\x65\x1d" "BLE_STATUS_INTERVAL_TOO_LARGE",
        (const byte*)"\x7a\x21\x18" "BLE_STATUS_LENGTH_FAILED",
        (const byte*)"\x81\xe3\x12" "BLE_STATUS_TIMEOUT",
        (const byte*)"\xbb\x8d\x26" "BLE_STATUS_PROFILE_ALREADY_INITIALIZED",
        (const byte*)"\x51\x35\x15" "BLE_STATUS_NULL_PARAM",
        (const byte*)"\x2f\x74\x11" "SPI_FRAMING_ERROR",
        (const byte*)"\xdb\x2e\x11" "RADIO_STATE_ERROR",
        (const byte*)"\x7d\xcb\x13" "TIMER_OVERRUN_ERROR",
        (const byte*)"\x16\x1b\x5b" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/event.py",
        (const byte*)"\x27\xbc\x14" "HCI_MAX_PAYLOAD_SIZE",
        (const byte*)"\xc7\xa6\x20" "EVT_BLUE_HAL_EVENTS_LOST_IDB05A1",
        (const byte*)"\x79\xcd\x1f" "EVT_BLUE_HAL_CRASH_INFO_IDB05A1",
        (const byte*)"\xe7\xdd\x21" "EVT_BLUE_GAP_LIMITED_DISCOVERABLE",
        (const byte*)"\x06\xed\x1a" "EVT_BLUE_GAP_PAIRING_CMPLT",
        (const byte*)"\x62\x3d\x1d" "EVT_BLUE_GAP_PASS_KEY_REQUEST",
        (const byte*)"\x49\xe8\x25" "EVT_BLUE_GAP_SLAVE_SECURITY_INITIATED",
        (const byte*)"\xa9\xef\x16" "EVT_BLUE_GAP_BOND_LOST",
        (const byte*)"\xa4\x1c\x19" "EVT_BLUE_GAP_DEVICE_FOUND",
        (const byte*)"\xc6\xed\x26" "EVT_BLUE_GAP_ADDR_NOT_RESOLVED_IDB05A1",
        (const byte*)"\x59\x5f\x29" "EVT_BLUE_GAP_RECONNECTION_ADDRESS_IDB04A1",
        (const byte*)"\xa0\x0c\x22" "EVT_BLUE_GAP_AUTHORIZATION_REQUEST",
        (const byte*)"\xf6\xde\x1c" "EVT_BLUE_L2CAP_CONN_UPD_RESP",
        (const byte*)"\x26\x6d\x20" "EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT",
        (const byte*)"\xe4\xa1\x1b" "EVT_BLUE_L2CAP_CONN_UPD_REQ",
        (const byte*)"\x4c\x1b\x1f" "EVT_BLUE_GATT_PROCEDURE_TIMEOUT",
        (const byte*)"\xc1\xed\x1e" "EVT_BLUE_ATT_EXCHANGE_MTU_RESP",
        (const byte*)"\x7f\xfb\x22" "EVT_BLUE_ATT_FIND_INFORMATION_RESP",
        (const byte*)"\xeb\xa4\x22" "EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP",
        (const byte*)"\xb8\xa0\x1e" "EVT_BLUE_ATT_READ_BY_TYPE_RESP",
        (const byte*)"\xdb\xf6\x16" "EVT_BLUE_ATT_READ_RESP",
        (const byte*)"\xe7\xe1\x1b" "EVT_BLUE_ATT_READ_BLOB_RESP",
        (const byte*)"\x34\xc0\x1f" "EVT_BLUE_ATT_READ_MULTIPLE_RESP",
        (const byte*)"\xf8\x2d\x24" "EVT_BLUE_ATT_READ_BY_GROUP_TYPE_RESP",
        (const byte*)"\xea\xc9\x1f" "EVT_BLUE_ATT_PREPARE_WRITE_RESP",
        (const byte*)"\xb0\x61\x1c" "EVT_BLUE_ATT_EXEC_WRITE_RESP",
        (const byte*)"\xf1\x4c\x18" "EVT_BLUE_GATT_INDICATION",
        (const byte*)"\x08\x30\x1a" "EVT_BLUE_GATT_NOTIFICATION",
        (const byte*)"\x9e\x3d\x20" "EVT_BLUE_GATT_PROCEDURE_COMPLETE",
        (const byte*)"\xd6\x21\x18" "EVT_BLUE_GATT_ERROR_RESP",
        (const byte*)"\x0f\xbf\x29" "EVT_BLUE_GATT_DISC_READ_CHAR_BY_UUID_RESP",
        (const byte*)"\x70\x39\x23" "EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ",
        (const byte*)"\x6c\xe4\x1f" "EVT_BLUE_GATT_TX_POOL_AVAILABLE",
        (const byte*)"\xa3\x76\x27" "EVT_BLUE_GATT_SERVER_CONFIRMATION_EVENT",
        (const byte*)"\x37\x1f\x26" "EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ",
        (const byte*)"\xf9\xd6\x18" "EVT_DISCONN_COMPLETE_BIT",
        (const byte*)"\xa3\xfd\x16" "EVT_ENCRYPT_CHANGE_BIT",
        (const byte*)"\x67\xb4\x24" "EVT_READ_REMOTE_VERSION_COMPLETE_BIT",
        (const byte*)"\x01\x2e\x14" "EVT_CMD_COMPLETE_BIT",
        (const byte*)"\xfc\x02\x12" "EVT_CMD_STATUS_BIT",
        (const byte*)"\x04\xae\x16" "EVT_HARDWARE_ERROR_BIT",
        (const byte*)"\x66\x64\x15" "EVT_NUM_COMP_PKTS_BIT",
        (const byte*)"\x58\x30\x1e" "EVT_ENCRYPTION_KEY_REFRESH_BIT",
        (const byte*)"\x0a\x81\x1c" "EVT_BLUE_HAL_INITIALIZED_BIT",
        (const byte*)"\x5a\xf0\x29" "EVT_BLUE_GAP_SET_LIMITED_DISCOVERABLE_BIT",
        (const byte*)"\x06\x62\x1e" "EVT_BLUE_GAP_PAIRING_CMPLT_BIT",
        (const byte*)"\xe2\x24\x21" "EVT_BLUE_GAP_PASS_KEY_REQUEST_BIT",
        (const byte*)"\xa0\x62\x26" "EVT_BLUE_GAP_AUTHORIZATION_REQUEST_BIT",
        (const byte*)"\x22\xac\x27" "EVT_BLUE_GAP_SECURITY_REQ_INITIATED_BIT",
        (const byte*)"\x29\x95\x1a" "EVT_BLUE_GAP_BOND_LOST_BIT",
        (const byte*)"\x8e\xbe\x23" "EVT_BLUE_GAP_PROCEDURE_COMPLETE_BIT",
        (const byte*)"\xe3\xe4\x22" "EVT_BLUE_GAP_ADDR_NOT_RESOLVED_BIT",
        (const byte*)"\xc6\xfa\x23" "EVT_BLUE_L2CAP_CONN_UPDATE_RESP_BIT",
        (const byte*)"\xa6\xd1\x24" "EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT_BIT",
        (const byte*)"\x54\xea\x22" "EVT_BLUE_L2CAP_CONN_UPDATE_REQ_BIT",
        (const byte*)"\x87\xf6\x24" "EVT_BLUE_GATT_ATTRIBUTE_MODIFIED_BIT",
        (const byte*)"\xcc\x7f\x23" "EVT_BLUE_GATT_PROCEDURE_TIMEOUT_BIT",
        (const byte*)"\x3f\x32\x1e" "EVT_BLUE_EXCHANGE_MTU_RESP_BIT",
        (const byte*)"\x7f\xad\x26" "EVT_BLUE_ATT_FIND_INFORMATION_RESP_BIT",
        (const byte*)"\xeb\x1b\x26" "EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP_BIT",
        (const byte*)"\xb8\xf2\x22" "EVT_BLUE_ATT_READ_BY_TYPE_RESP_BIT",
        (const byte*)"\x5b\x59\x1a" "EVT_BLUE_ATT_READ_RESP_BIT",
        (const byte*)"\xe7\xd7\x1f" "EVT_BLUE_ATT_READ_BLOB_RESP_BIT",
        (const byte*)"\x34\xd1\x23" "EVT_BLUE_ATT_READ_MULTIPLE_RESP_BIT",
        (const byte*)"\xdf\x2d\x23" "EVT_BLUE_ATT_READ_BY_GROUP_RESP_BIT",
        (const byte*)"\x94\xd3\x1b" "EVT_BLUE_ATT_WRITE_RESP_BIT",
        (const byte*)"\x6a\xf1\x23" "EVT_BLUE_ATT_PREPARE_WRITE_RESP_BIT",
        (const byte*)"\xb0\x33\x20" "EVT_BLUE_ATT_EXEC_WRITE_RESP_BIT",
        (const byte*)"\x71\xcf\x1c" "EVT_BLUE_GATT_INDICATION_BIT",
        (const byte*)"\x88\x56\x1e" "EVT_BLUE_GATT_NOTIFICATION_BIT",
        (const byte*)"\x9e\xee\x24" "EVT_BLUE_GATT_PROCEDURE_COMPLETE_BIT",
        (const byte*)"\xd6\x13\x1c" "EVT_BLUE_GATT_ERROR_RESP_BIT",
        (const byte*)"\x6d\x76\x2f" "EVT_BLUE_GATT_DISC_READ_CHARAC_BY_UUID_RESP_BIT",
        (const byte*)"\x89\xa6\x22" "EVT_BLUE_GATT_WRITE_PERMIT_REQ_BIT",
        (const byte*)"\x26\x32\x21" "EVT_BLUE_GATT_READ_PERMIT_REQ_BIT",
        (const byte*)"\x70\xcb\x27" "EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ_BIT",
        (const byte*)"\x6c\xf9\x23" "EVT_BLUE_GATT_TX_POOL_AVAILABLE_BIT",
        (const byte*)"\x65\xd2\x28" "EVT_BLUE_GATT_SERVER_RX_CONFIRMATION_BIT",
        (const byte*)"\x37\xb0\x2a" "EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ_BIT",
        (const byte*)"\xe2\xd0\x1e" "EVT_LL_CONNECTION_COMPLETE_BIT",
        (const byte*)"\x59\xac\x1d" "EVT_LL_ADVERTISING_REPORT_BIT",
        (const byte*)"\x4c\x80\x25" "EVT_LL_CONNECTION_UPDATE_COMPLETE_BIT",
        (const byte*)"\xab\xbb\x24" "EVT_LL_READ_REMOTE_USED_FEATURES_BIT",
        (const byte*)"\xdf\xcc\x16" "EVT_LL_LTK_REQUEST_BIT",
        (const byte*)"\x69\x13\x0a" "crash_type",
        (const byte*)"\xe6\x70\x02" "sp",
        (const byte*)"\x97\x8d\x03" "sp1",
        (const byte*)"\x87\x70\x02" "r0",
        (const byte*)"\x86\x70\x02" "r1",
        (const byte*)"\x85\x70\x02" "r2",
        (const byte*)"\x84\x70\x02" "r3",
        (const byte*)"\x74\x81\x03" "r12",
        (const byte*)"\x9b\x6e\x02" "lr",
        (const byte*)"\x16\x70\x02" "pc",
        (const byte*)"\xec\xee\x04" "xpsr",
        (const byte*)"\x1b\x0b\x0a" "debug_data",
        (const byte*)"\x91\x4b\x09" "data_rssi",
        (const byte*)"\x66\xa7\x0a" "identifier",
        (const byte*)"\x6c\xb9\x06" "result",
        (const byte*)"\x7f\x88\x07" "IDB05A1",
        (const byte*)"\xfe\x94\x07" "IDB04A1",
        (const byte*)"\xaf\x83\x0a" "error_code",
        (const byte*)"\x8e\x0c\x0a" "req_opcode",
        (const byte*)"\x70\xe7\x59" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/cmd.py",
        (const byte*)"\xc8\x4c\x14" "OCF_GAP_SET_EVT_MASK",
        (const byte*)"\x34\x10\x0a" "VENDOR_CMD",
        (const byte*)"\x76\x79\x08" "GAP_INIT",
        (const byte*)"\x89\x4b\x08" "evt_mask",
        (const byte*)"\xb0\x8b\x07" "dv_type",
        (const byte*)"\xff\x74\x08" "num_addr",
        (const byte*)"\x0f\x57\x08" "dev_list",
        (const byte*)"\x06\x75\x09" "GATT_INIT",
        (const byte*)"\xc0\xf9\x5e" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/__init__.py",
        (const byte*)"\x24\xe3\x5e" "bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/constant.py",
        (const byte*)"\x18\x89\x11" "RESET_UPDATER_ACI",
        (const byte*)"\x27\xc2\x16" "RESET_UPDATER_BAD_FLAG",
        (const byte*)"\x44\x5b\x11" "RESET_UPDATER_PIN",
        (const byte*)"\x6a\x0e\x0e" "RESET_WATCHDOG",
        (const byte*)"\x21\x65\x0c" "RESET_LOCKUP",
        (const byte*)"\xe7\xa4\x0e" "RESET_BROWNOUT",
        (const byte*)"\x24\xfe\x0b" "RESET_CRASH",
        (const byte*)"\x90\xdf\x0d" "RESET_ECC_ERR",
        (const byte*)"\xf6\xe1\x16" "CONFIG_DATA_DIV_OFFSET",
        (const byte*)"\xda\x4b\x15" "CONFIG_DATA_ER_OFFSET",
        (const byte*)"\xd6\xc6\x15" "CONFIG_DATA_IR_OFFSET",
        (const byte*)"\xf3\xfe\x1b" "CONFIG_DATA_LL_WITHOUT_HOST",
        (const byte*)"\x4d\x85\x1a" "CONFIG_DATA_RANDOM_ADDRESS",
        (const byte*)"\x51\x4f\x1c" "CONFIG_DATA_WATCHDOG_DISABLE",
        (const byte*)"\xfc\x96\x13" "CONFIG_DATA_DIV_LEN",
        (const byte*)"\xd0\xe9\x12" "CONFIG_DATA_ER_LEN",
        (const byte*)"\x5c\x87\x12" "CONFIG_DATA_IR_LEN",
        (const byte*)"\x6b\x27\x1f" "CONFIG_DATA_LL_WITHOUT_HOST_LEN",
        (const byte*)"\xc9\x87\x20" "CONFIG_DATA_WATCHDOG_DISABLE_LEN",
        (const byte*)"\xea\xca\x0b" "STATUS_IDLE",
        (const byte*)"\x44\x50\x12" "STATUS_ADVERTISING",
        (const byte*)"\x8e\x20\x19" "STATUS_CONNECTED_AS_SLAVE",
        (const byte*)"\xdf\xb6\x0f" "STATUS_SCANNING",
        (const byte*)"\x1f\x1f\x1a" "STATUS_CONNECTED_AS_MASTER",
        (const byte*)"\xab\x3c\x0e" "STATUS_TX_TEST",
        (const byte*)"\x2d\xc5\x0e" "STATUS_RX_TEST",
        (const byte*)"\xc3\x64\x10" "GAP_SERVICE_UUID",
        (const byte*)"\xd7\x0c\x10" "DEVICE_NAME_UUID",
        (const byte*)"\x29\x42\x0f" "APPEARANCE_UUID",
        (const byte*)"\xd1\x35\x1c" "PERIPHERAL_PRIVACY_FLAG_UUID",
        (const byte*)"\x1a\x18\x16" "RECONNECTION_ADDR_UUID",
        (const byte*)"\x11\x7c\x25" "PERIPHERAL_PREFERRED_CONN_PARAMS_UUID",
        (const byte*)"\x3f\x98\x1e" "DEVICE_NAME_CHARACTERISTIC_LEN",
        (const byte*)"\x01\x2c\x1d" "APPEARANCE_CHARACTERISTIC_LEN",
        (const byte*)"\xea\xf6\x25" "PERIPHERAL_PRIVACY_CHARACTERISTIC_LEN",
        (const byte*)"\x72\x1d\x24" "RECONNECTION_ADDR_CHARACTERISTIC_LEN",
        (const byte*)"\xfd\x78\x2e" "PERIPHERAL_PREF_CONN_PARAMS_CHARACTERISTIC_LEN",
        (const byte*)"\x6e\x5d\x25" "FLAG_BIT_LE_LIMITED_DISCOVERABLE_MODE",
        (const byte*)"\xec\xfb\x25" "FLAG_BIT_LE_GENERAL_DISCOVERABLE_MODE",
        (const byte*)"\x91\x30\x1d" "FLAG_BIT_BR_EDR_NOT_SUPPORTED",
        (const byte*)"\x1f\xae\x1d" "FLAG_BIT_LE_BR_EDR_CONTROLLER",
        (const byte*)"\xa3\x20\x17" "FLAG_BIT_LE_BR_EDR_HOST",
        (const byte*)"\x3d\x62\x0f" "DEVICE_NAME_LEN",
        (const byte*)"\xd5\x83\x0c" "BD_ADDR_SIZE",
        (const byte*)"\x59\x9b\x0f" "PRIVACY_ENABLED",
        (const byte*)"\xfc\x38\x14" "DIR_CONN_ADV_INT_MIN",
        (const byte*)"\xe2\x39\x14" "DIR_CONN_ADV_INT_MAX",
        (const byte*)"\xc7\xd6\x16" "UNDIR_CONN_ADV_INT_MIN",
        (const byte*)"\xd9\xd5\x16" "UNDIR_CONN_ADV_INT_MAX",
        (const byte*)"\x5a\x10\x14" "LIM_DISC_ADV_INT_MIN",
        (const byte*)"\x44\x11\x14" "LIM_DISC_ADV_INT_MAX",
        (const byte*)"\xde\xd1\x14" "GEN_DISC_ADV_INT_MIN",
        (const byte*)"\xc0\xd2\x14" "GEN_DISC_ADV_INT_MAX",
        (const byte*)"\xd7\x65\x15" "LIM_DISC_MODE_TIMEOUT",
        (const byte*)"\x2c\x28\x18" "PRIVATE_ADDR_INT_TIMEOUT",
        (const byte*)"\xca\x8b\x1c" "GAP_BROADCASTER_ROLE_IDB05A1",
        (const byte*)"\x6a\x2d\x19" "GAP_OBSERVER_ROLE_IDB05A1",
        (const byte*)"\x0f\x48\x1b" "GAP_PERIPHERAL_ROLE_IDB04A1",
        (const byte*)"\xcb\x8f\x1c" "GAP_BROADCASTER_ROLE_IDB04A1",
        (const byte*)"\x20\xa1\x18" "GAP_CENTRAL_ROLE_IDB04A1",
        (const byte*)"\xeb\x20\x19" "GAP_OBSERVER_ROLE_IDB04A1",
        (const byte*)"\x3c\x77\x1a" "GAP_LIMITED_DISCOVERY_PROC",
        (const byte*)"\xcf\x0c\x17" "GAP_NAME_DISCOVERY_PROC",
        (const byte*)"\x09\x28\x26" "GAP_AUTO_CONNECTION_ESTABLISHMENT_PROC",
        (const byte*)"\x50\x48\x29" "GAP_GENERAL_CONNECTION_ESTABLISHMENT_PROC",
        (const byte*)"\xb4\x3a\x2b" "GAP_SELECTIVE_CONNECTION_ESTABLISHMENT_PROC",
        (const byte*)"\xcb\xd4\x28" "GAP_DIRECT_CONNECTION_ESTABLISHMENT_PROC",
        (const byte*)"\xba\xb4\x1c" "GAP_OBSERVATION_PROC_IDB05A1",
        (const byte*)"\x90\xcf\x18" "WHITE_LIST_FOR_ONLY_SCAN",
        (const byte*)"\x63\xd8\x18" "WHITE_LIST_FOR_ONLY_CONN",
        (const byte*)"\xa5\x13\x12" "WHITE_LIST_FOR_ALL",
        (const byte*)"\xd2\xfb\x0b" "RANDOM_ADDR",
        (const byte*)"\xf5\x22\x12" "STATIC_RANDOM_ADDR",
        (const byte*)"\x00\x5a\x17" "RESOLVABLE_PRIVATE_ADDR",
        (const byte*)"\xd0\x92\x1b" "NON_RESOLVABLE_PRIVATE_ADDR",
        (const byte*)"\x18\x8b\x1c" "HIGH_DUTY_CYCLE_DIRECTED_ADV",
        (const byte*)"\xa2\xaa\x1b" "LOW_DUTY_CYCLE_DIRECTED_ADV",
        (const byte*)"\x78\xb9\x0e" "ADV_DIRECT_IND",
        (const byte*)"\x76\x0d\x0f" "ADV_NONCONN_IND",
        (const byte*)"\x54\xc1\x08" "SCAN_RSP",
        (const byte*)"\xec\x29\x18" "ADV_INTERVAL_LOWEST_CONN",
        (const byte*)"\xc5\x44\x14" "ADV_INTERVAL_HIGHEST",
        (const byte*)"\x43\xff\x1b" "ADV_INTERVAL_LOWEST_NONCONN",
        (const byte*)"\x39\xba\x09" "ADV_CH_37",
        (const byte*)"\x36\xba\x09" "ADV_CH_38",
        (const byte*)"\x37\xba\x09" "ADV_CH_39",
        (const byte*)"\xee\xf0\x0c" "PASSIVE_SCAN",
        (const byte*)"\x89\x70\x0b" "ACTIVE_SCAN",
        (const byte*)"\x59\x4f\x14" "PRIMARY_SERVICE_UUID",
        (const byte*)"\x2f\x7c\x16" "SECONDARY_SERVICE_UUID",
        (const byte*)"\x69\xe2\x14" "INCLUDE_SERVICE_UUID",
        (const byte*)"\xaa\x18\x13" "CHARACTERISTIC_UUID",
        (const byte*)"\x9b\x71\x1c" "CHAR_EXTENDED_PROP_DESC_UUID",
        (const byte*)"\xcf\x7b\x13" "CHAR_USER_DESC_UUID",
        (const byte*)"\x72\xe9\x1c" "CHAR_CLIENT_CONFIG_DESC_UUID",
        (const byte*)"\x2e\xed\x1c" "CHAR_SERVER_CONFIG_DESC_UUID",
        (const byte*)"\xfd\xca\x15" "CHAR_FORMAT_DESC_UUID",
        (const byte*)"\x0d\xc5\x17" "CHAR_AGGR_FMT_DESC_UUID",
        (const byte*)"\x73\xa6\x11" "GATT_SERVICE_UUID",
        (const byte*)"\x17\xae\x14" "SERVICE_CHANGED_UUID",
        (const byte*)"\x46\x78\x15" "ATTR_ACCESS_WRITE_ANY",
        (const byte*)"\xb0\x70\x17" "CHAR_VALUE_LEN_CONSTANT",
        (const byte*)"\x28\x64\x17" "CHAR_VALUE_LEN_VARIABLE",
        (const byte*)"\x47\x50\x0c" "FORMAT_UINT8",
        (const byte*)"\x38\x5a\x0d" "FORMAT_UINT16",
        (const byte*)"\x7e\x79\x0d" "FORMAT_SINT16",
        (const byte*)"\x9f\x79\x0d" "FORMAT_SINT24",
        (const byte*)"\x13\xc1\x0d" "UNIT_UNITLESS",
        (const byte*)"\x19\x34\x11" "UNIT_TEMP_CELSIUS",
        (const byte*)"\xb7\x49\x11" "UNIT_PRESSURE_BAR",
        (const byte*)"\xd7\xcf\x07" "ATT_MTU",
        (const byte*)"\xc8\x9e\x0c" "NOTIFICATION",
        (const byte*)"\xb1\xb9\x0a" "INDICATION",
        (const byte*)"\xe9\x78\x12" "O_CAP_DISPLAY_ONLY",
        (const byte*)"\x0c\x75\x14" "O_CAP_DISPLAY_YES_NO",
        (const byte*)"\xfe\xdb\x13" "O_CAP_KEYBOARD_ONLY",
        (const byte*)"\xce\x6c\x18" "O_CAP_NO_INPUT_NO_OUTPUT",
        (const byte*)"\x90\xcc\x16" "O_CAP_KEYBOARD_DISPLAY",
        (const byte*)"\x5c\x4a\x0a" "NO_BONDING",
        (const byte*)"\x78\xe5\x1c" "MITM_PROTECTION_NOT_REQUIRED",
        (const byte*)"\x8b\xf4\x15" "OOB_AUTH_DATA_PRESENT",
        (const byte*)"\xc2\xcd\x1a" "AUTHORIZATION_NOT_REQUIRED",
        (const byte*)"\x48\xd3\x16" "AUTHORIZATION_REQUIRED",
        (const byte*)"\x8b\x33\x15" "CONNECTION_AUTHORIZED",
        (const byte*)"\x02\x66\x13" "CONNECTION_REJECTED",
        (const byte*)"\x17\x59\x1f" "DONOT_USE_FIXED_PIN_FOR_PAIRING",
        (const byte*)"\xf2\x41\x15" "SM_LINK_AUTHENTICATED",
        (const byte*)"\xdc\xb6\x12" "SM_LINK_AUTHORIZED",
        (const byte*)"\x5d\xcf\x11" "SM_LINK_ENCRYPTED",
        (const byte*)"\xf4\x6d\x14" "PASSKEY_ENTRY_FAILED",
        (const byte*)"\x2b\x6c\x11" "OOB_NOT_AVAILABLE",
        (const byte*)"\x69\x64\x16" "AUTH_REQ_CANNOT_BE_MET",
        (const byte*)"\xdf\x8a\x14" "CONFIRM_VALUE_FAILED",
        (const byte*)"\x34\xc4\x15" "PAIRING_NOT_SUPPORTED",
        (const byte*)"\x26\x58\x1a" "INSUFF_ENCRYPTION_KEY_SIZE",
        (const byte*)"\xf4\x72\x11" "CMD_NOT_SUPPORTED",
        (const byte*)"\xe7\x3e\x12" "UNSPECIFIED_REASON",
        (const byte*)"\xab\xf5\x17" "VERY_EARLY_NEXT_ATTEMPT",
        (const byte*)"\x16\x3a\x11" "SM_INVALID_PARAMS",
        (const byte*)"\x72\x6a\x12" "SM_PAIRING_SUCCESS",
        (const byte*)"\x6a\xac\x12" "SM_PAIRING_TIMEOUT",
        (const byte*)"\xf2\xca\x11" "SM_PAIRING_FAILED",
        (const byte*)"\xb7\x0e\x3f" "bluetooth_low_energy/protocols/hci/vendor_specifics/__init__.py",
        (const byte*)"\x04\x32\x29" "bluetooth_low_energy/protocols/hci/acl.py",
        (const byte*)"\x17\x70\x02" "pb",
        (const byte*)"\xc4\x6e\x02" "bc",
        (const byte*)"\x1e\x96\x0e" "HCI_ACL_STRUCT",
        (const byte*)"\x14\xa7\x1f" "ACL_PB_START_NON_AUTO_L2CAP_PDU",
        (const byte*)"\x04\x54\x14" "ACL_PB_CONT_FRAG_MSG",
        (const byte*)"\xc4\x69\x1b" "ACL_PB_START_AUTO_L2CAP_PDU",
        (const byte*)"\xbd\xfa\x19" "ACL_PB_COMPLETE_L2CAP_PDU",
        (const byte*)"\x17\x03\x08" "PB_FLAGS",
        (const byte*)"\x96\xcf\x07" "HCI_ACL",
        (const byte*)"\xb1\x2e\x0e" "_struct_format",
        (const byte*)"\x30\x33\x07" "_handle",
        (const byte*)"\xe8\x1e\x03" "_pb",
        (const byte*)"\xd0\x43\x08" "_pb_name",
        (const byte*)"\x3b\x20\x03" "_bc",
        (const byte*)"\x78\x86\x08" "_tobytes",
        (const byte*)"\xea\x76\x05" "_data",
        (const byte*)"\x8f\x92\x07" "pb_name",
        (const byte*)"\xa7\x2f\x07" "tobytes",
        (const byte*)"\xc4\x03\x29" "bluetooth_low_energy/protocols/hci/smp.py",
        (const byte*)"\xc1\xf2\x0f" "PAIRING_REQUEST",
        (const byte*)"\xd3\xdf\x10" "PAIRING_RESPONSE",
        (const byte*)"\x42\xa2\x0f" "PAIRING_CONFIRM",
        (const byte*)"\x8b\x61\x0e" "PAIRING_RANDOM",
        (const byte*)"\x73\xf9\x0e" "PAIRING_FAILED",
        (const byte*)"\x59\xa6\x16" "ENCRYPTION_INFORMATION",
        (const byte*)"\x8c\x7f\x15" "MASTER_IDENTIFICATION",
        (const byte*)"\x40\xcf\x14" "IDENTITY_INFORMATION",
        (const byte*)"\xc9\x46\x1c" "IDENTITY_ADDRESS_INFORMATION",
        (const byte*)"\x85\xa1\x13" "SIGNING_INFORMATION",
        (const byte*)"\xdd\x23\x10" "SECURITY_REQUEST",
        (const byte*)"\x46\x4b\x08" "SMP_PDUS",
        (const byte*)"\x0b\x14\x03" "SMP",
        (const byte*)"\x97\x78\x05" "_code",
        (const byte*)"\x0f\xeb\x0a" "_code_name",
        (const byte*)"\x50\x2f\x09" "code_name",
        (const byte*)"\xd8\x5d\x2a" "bluetooth_low_energy/protocols/hci/uart.py",
        (const byte*)"\x16\xa4\x0f" "HCI_ACLDATA_PKT",
        (const byte*)"\x07\xca\x0f" "HCI_SCODATA_PKT",
        (const byte*)"\x4c\x1c\x0e" "HCI_VENDOR_PKT",
        (const byte*)"\x22\xfb\x07" "COMMAND",
        (const byte*)"\x1b\x93\x07" "ACLDATA",
        (const byte*)"\x8a\xd4\x07" "SCODATA",
        (const byte*)"\x29\x8a\x05" "EVENT",
        (const byte*)"\x21\xa7\x06" "VENDOR",
        (const byte*)"\x2e\x8c\x12" "HCI_UART_PKT_TYPES",
        (const byte*)"\x6b\x9e\x13" "_struct_format_size",
        (const byte*)"\xd2\x47\x09" "_pkt_type",
        (const byte*)"\xea\xe1\x0e" "_pkt_type_name",
        (const byte*)"\xf5\x5f\x0d" "pkt_type_name",
        (const byte*)"\x1e\xf6\x2c" "bluetooth_low_energy/protocols/hci/status.py",
        (const byte*)"\x69\x81\x0f" "ERR_CMD_SUCCESS",
        (const byte*)"\x12\x97\x17" "ERR_UNKNOWN_HCI_COMMAND",
        (const byte*)"\x98\x58\x1b" "ERR_UNKNOWN_CONN_IDENTIFIER",
        (const byte*)"\x48\xd8\x10" "ERR_AUTH_FAILURE",
        (const byte*)"\xf9\xef\x16" "ERR_PIN_OR_KEY_MISSING",
        (const byte*)"\x55\x1c\x19" "ERR_MEM_CAPACITY_EXCEEDED",
        (const byte*)"\xcd\x3b\x16" "ERR_CONNECTION_TIMEOUT",
        (const byte*)"\x21\x86\x16" "ERR_COMMAND_DISALLOWED",
        (const byte*)"\x81\xe7\x17" "ERR_UNSUPPORTED_FEATURE",
        (const byte*)"\xe5\x77\x1a" "ERR_INVALID_HCI_CMD_PARAMS",
        (const byte*)"\xfd\x87\x15" "ERR_RMT_USR_TERM_CONN",
        (const byte*)"\x09\xb4\x21" "ERR_RMT_DEV_TERM_CONN_LOW_RESRCES",
        (const byte*)"\x6e\x47\x1f" "ERR_RMT_DEV_TERM_CONN_POWER_OFF",
        (const byte*)"\xaf\x31\x18" "ERR_LOCAL_HOST_TERM_CONN",
        (const byte*)"\x7d\x37\x16" "ERR_UNSUPP_RMT_FEATURE",
        (const byte*)"\xb0\x6a\x15" "ERR_INVALID_LMP_PARAM",
        (const byte*)"\xc1\xf4\x15" "ERR_UNSPECIFIED_ERROR",
        (const byte*)"\x30\x77\x13" "ERR_LL_RESP_TIMEOUT",
        (const byte*)"\x7d\x64\x17" "ERR_LMP_PDU_NOT_ALLOWED",
        (const byte*)"\xcb\x10\x12" "ERR_INSTANT_PASSED",
        (const byte*)"\x57\x9b\x1a" "ERR_PAIR_UNIT_KEY_NOT_SUPP",
        (const byte*)"\xa1\xd8\x13" "ERR_CONTROLLER_BUSY",
        (const byte*)"\xdb\xc9\x18" "ERR_DIRECTED_ADV_TIMEOUT",
        (const byte*)"\xb9\x4e\x1d" "ERR_CONN_END_WITH_MIC_FAILURE",
        (const byte*)"\x8b\x91\x1c" "ERR_CONN_FAILED_TO_ESTABLISH",
        (const byte*)"\x86\xa4\x2b" "bluetooth_low_energy/protocols/hci/l2cap.py",
        (const byte*)"\xf0\x17\x0d" "L2CAP_CID_NUL",
        (const byte*)"\x3f\x44\x0d" "L2CAP_CID_SCH",
        (const byte*)"\xc6\x1a\x0d" "L2CAP_CID_ATT",
        (const byte*)"\xa9\x6d\x10" "L2CAP_CID_LE_SCH",
        (const byte*)"\xe9\x44\x0d" "L2CAP_CID_SMP",
        (const byte*)"\x92\xd6\x03" "NUL",
        (const byte*)"\xdd\x13\x03" "SCH",
        (const byte*)"\x64\xb8\x03" "ATT",
        (const byte*)"\x0b\x9f\x06" "LE_SCH",
        (const byte*)"\x94\x6d\x11" "L2CAP_CHANNEL_IDS",
        (const byte*)"\xe9\xe8\x05" "L2CAP",
        (const byte*)"\xb5\x73\x12" "SCH_COMMAND_REJECT",
        (const byte*)"\xda\xab\x16" "SCH_CONNECTION_REQUEST",
        (const byte*)"\xa8\x82\x17" "SCH_CONNECTION_RESPONSE",
        (const byte*)"\xa4\xb7\x15" "SCH_CONFIGURE_REQUEST",
        (const byte*)"\x56\x28\x16" "SCH_CONFIGURE_RESPONSE",
        (const byte*)"\x64\x76\x19" "SCH_DISCONNECTION_REQUEST",
        (const byte*)"\x96\x3f\x1a" "SCH_DISCONNECTION_RESPONSE",
        (const byte*)"\xcd\x07\x10" "SCH_ECHO_REQUEST",
        (const byte*)"\x5f\xf3\x11" "SCH_ECHO_RESPONSE",
        (const byte*)"\x80\x13\x17" "SCH_INFORMATION_REQUEST",
        (const byte*)"\xb2\xd1\x18" "SCH_INFORMATION_RESPONSE",
        (const byte*)"\xf4\x90\x1a" "SCH_CREATE_CHANNEL_REQUEST",
        (const byte*)"\x06\x2c\x1b" "SCH_CREATE_CHANNEL_RESPONSE",
        (const byte*)"\x01\x9b\x18" "SCH_MOVE_CHANNEL_REQUEST",
        (const byte*)"\x93\x10\x19" "SCH_MOVE_CHANNEL_RESPONSE",
        (const byte*)"\xbf\xd9\x1d" "SCH_MOVE_CHANNEL_CONFIRMATION",
        (const byte*)"\xa3\xb7\x26" "SCH_MOVE_CHANNEL_CONFIRMATION_RESPONSE",
        (const byte*)"\x54\x71\x2a" "LE_SCH_CONNECTION_PARAMETER_UPDATE_REQUEST",
        (const byte*)"\x66\x67\x2b" "LE_SCH_CONNECTION_PARAMETER_UPDATE_RESPONSE",
        (const byte*)"\xc6\x38\x29" "LE_SCH_LE_CREDIT_BASED_CONNECTION_REQUEST",
        (const byte*)"\x34\x8e\x2a" "LE_SCH_LE_CREDIT_BASED_CONNECTION_RESPONSE",
        (const byte*)"\xfa\x56\x1d" "LE_SCH_LE_FLOW_CONTROL_CREDIT",
        (const byte*)"\x83\xb0\x0e" "L2CAP_SCH_PDUS",
        (const byte*)"\x2e\x2e\x09" "L2CAP_SCH",
        (const byte*)"\x74\x22\x04" "_cid",
        (const byte*)"\xcc\xb0\x09" "_cid_name",
        (const byte*)"\xab\x4c\x03" "cid",
        (const byte*)"\x33\x09\x08" "cid_name",
        (const byte*)"\x71\x8b\x04" "<BBH",
        (const byte*)"\x66\xee\x2b" "bluetooth_low_energy/protocols/hci/event.py",
        (const byte*)"\xbf\x7c\x1b" "EVT_LE_CONN_UPDATE_COMPLETE",
        (const byte*)"\xb4\x2e\x29" "EVT_LE_READ_REMOTE_USED_FEATURES_COMPLETE",
        (const byte*)"\x96\xda\x12" "EVT_LE_LTK_REQUEST",
        (const byte*)"\x22\x48\x08" "features",
        (const byte*)"\x9b\x6b\x04" "ediv",
        (const byte*)"\xd3\xdf\x12" "HCI_LE_META_EVENTS",
        (const byte*)"\x27\x86\x11" "EVT_CONN_COMPLETE",
        (const byte*)"\xa3\x27\x12" "EVT_ENCRYPT_CHANGE",
        (const byte*)"\x67\x7e\x20" "EVT_READ_REMOTE_VERSION_COMPLETE",
        (const byte*)"\xe6\x3d\x11" "EVT_NUM_COMP_PKTS",
        (const byte*)"\x91\x61\x18" "EVT_DATA_BUFFER_OVERFLOW",
        (const byte*)"\x4e\x2b\x23" "EVT_ENCRYPTION_KEY_REFRESH_COMPLETE",
        (const byte*)"\xa2\x31\x09" "link_type",
        (const byte*)"\xc3\x73\x09" "encr_mode",
        (const byte*)"\xc2\x78\x07" "encrypt",
        (const byte*)"\x1b\x5f\x0a" "subversion",
        (const byte*)"\xa1\x5c\x04" "ncmd",
        (const byte*)"\x44\x28\x0a" "CMD_STATUS",
        (const byte*)"\x02\x6e\x08" "num_hndl",
        (const byte*)"\x8b\x2f\x04" "hndl",
        (const byte*)"\x2d\x06\x08" "subevent",
        (const byte*)"\x70\x97\x08" "_evtcode",
        (const byte*)"\xba\xb2\x08" "_evtname",
        (const byte*)"\xf4\x52\x0b" "_subevtcode",
        (const byte*)"\x3e\xaf\x0b" "_subevtname",
        (const byte*)"\xed\x86\x07" "_struct",
        (const byte*)"\x40\x5c\x07" "_module",
        (const byte*)"\x65\xc3\x07" "evtname",
        (const byte*)"\xc1\xef\x0a" "subevtname",
        (const byte*)"\x85\xb5\x01" " ",
        (const byte*)"\xe7\xb5\x01" "B",
        (const byte*)"\x40\x4f\x29" "bluetooth_low_energy/protocols/hci/cmd.py",
        (const byte*)"\xf0\xae\x1d" "OCF_SET_CONTROLLER_TO_HOST_FC",
        (const byte*)"\x14\xc1\x16" "OCF_HOST_NUM_COMP_PKTS",
        (const byte*)"\x1b\x1e\x17" "OCF_READ_LOCAL_COMMANDS",
        (const byte*)"\xc8\x32\x17" "OCF_READ_LOCAL_FEATURES",
        (const byte*)"\xbc\xff\x15" "OCF_LE_SET_EVENT_MASK",
        (const byte*)"\xc4\x1a\x12" "OCF_LE_CONN_UPDATE",
        (const byte*)"\x8e\x0a\x26" "OCF_LE_SET_HOST_CHANNEL_CLASSIFICATION",
        (const byte*)"\x2f\x3f\x20" "OCF_LE_READ_REMOTE_USED_FEATURES",
        (const byte*)"\xd6\x01\x17" "OCF_LE_START_ENCRYPTION",
        (const byte*)"\xa1\xa5\x08" "LINK_CTL",
        (const byte*)"\x65\xca\x0a" "DISCONNECT",
        (const byte*)"\xc1\x5e\x08" "HOST_CTL",
        (const byte*)"\x30\xb3\x05" "RESET",
        (const byte*)"\xd3\x4b\x05" "level",
        (const byte*)"\x1b\x66\x0a" "INFO_PARAM",
        (const byte*)"\x73\x0c\x09" "READ_RSSI",
        (const byte*)"\x28\xe1\x06" "LE_CTL",
        (const byte*)"\xd2\xad\x07" "pkt_len",
        (const byte*)"\x41\xa5\x07" "max_pkt",
        (const byte*)"\xf4\xde\x0a" "LE_ENCRYPT",
        (const byte*)"\xa2\xd1\x09" "plaintext",
        (const byte*)"\x1d\xae\x07" "encdata",
        (const byte*)"\xca\xec\x07" "LE_RAND",
        (const byte*)"\x61\x0b\x06" "states",
        (const byte*)"\x10\x5d\x08" "num_pkts",
        (const byte*)"\xd7\x37\x06" "OPCODE",
        (const byte*)"\xe8\x24\x07" "_opcode",
        (const byte*)"\xb4\x11\x04" "_ogf",
        (const byte*)"\x8c\x27\x09" "_ogf_name",
        (const byte*)"\x30\x12\x04" "_ocf",
        (const byte*)"\x88\x37\x09" "_ocf_name",
        (const byte*)"\xc3\x7e\x0f" "_request_struct",
        (const byte*)"\x44\x06\x0d" "_request_data",
        (const byte*)"\x71\x21\x10" "_response_struct",
        (const byte*)"\x76\x42\x0e" "_response_data",
        (const byte*)"\x73\xb3\x08" "ogf_name",
        (const byte*)"\x77\xa3\x08" "ocf_name",
        (const byte*)"\x3c\x87\x0e" "request_struct",
        (const byte*)"\xbb\x5a\x0c" "request_data",
        (const byte*)"\x77\x4c\x0e" "request_length",
        (const byte*)"\x25\xbe\x0f" "response_length",
        (const byte*)"\x0b\x99\x29" "bluetooth_low_energy/protocols/hci/att.py",
        (const byte*)"\x89\x16\x08" "ATT_PDUS",
        (const byte*)"\xc4\xb5\x01" "a",
        (const byte*)"\xc6\xb5\x01" "c",
        (const byte*)"\x2c\xcd\x0a" "ATT_STRUCT",
        (const byte*)"\xd0\x09\x0c" "_opcode_name",
        (const byte*)"\x8f\x54\x0b" "opcode_name",
        (const byte*)"\xb5\x03\x29" "bluetooth_low_energy/protocols/hci/sco.py",
        (const byte*)"\x06\x70\x02" "ps",
        (const byte*)"\x05\x71\x02" "xx",
        (const byte*)"\xef\xe0\x0e" "HCI_SCO_STRUCT",
        (const byte*)"\x07\xa4\x07" "HCI_SCO",
        (const byte*)"\xf9\x1e\x03" "_ps",
        (const byte*)"\xfa\x1d\x03" "_xx",
        (const byte*)"\xf0\x61\x2e" "bluetooth_low_energy/protocols/hci/__init__.py",
        (const byte*)"\x21\xf2\x0a" "logging.py",
        (const byte*)"\xa6\x42\x07" "_stream",
        (const byte*)"\xce\x42\x08" "CRITICAL",
        (const byte*)"\x9d\x19\x05" "ERROR",
        (const byte*)"\x4f\xe2\x07" "WARNING",
        (const byte*)"\xeb\xbb\x04" "INFO",
        (const byte*)"\x32\xb2\x06" "NOTSET",
        (const byte*)"\x89\xf8\x04" "CRIT",
        (const byte*)"\xef\x52\x04" "WARN",
        (const byte*)"\x29\x70\x0b" "_level_dict",
        (const byte*)"\x71\xfd\x06" "Logger",
        (const byte*)"\x4c\x67\x06" "_level",
        (const byte*)"\x5d\x4c\x08" "_loggers",
        (const byte*)"\x47\xff\x09" "getLogger",
        (const byte*)"\x35\xec\x0b" "basicConfig",
        (const byte*)"\x06\x11\x0a" "_level_str",
        (const byte*)"\xaf\x7e\x07" "warning",
        (const byte*)"\xbd\x11\x05" "error",
        (const byte*)"\x0e\x3a\x08" "critical",
        (const byte*)"\xe3\x02\x04" "root",
        (const byte*)"\x73\xdf\x03" "LVL",
        (const byte*)"\x9f\xb5\x01" ":",
        (const byte*)"\x7c\x46\x03" "msg",
        (const byte*)"\xe4\x54\x08" "filename",
        (const byte*)"\x59\xd4\x06" "stream",
        (const byte*)"\x92\xda\x17" "collections/__init__.py",
        (const byte*)"\x05\x99\x05" "deque",
        (const byte*)"\xb4\x95\x0b" "defaultdict",
        (const byte*)"\xd9\x6d\x1a" "collections/defaultdict.py",
        (const byte*)"\x01\x0b\x0b" "__missing__",
        (const byte*)"\xc1\xb5\x01" "d",
        (const byte*)"\x59\x4c\x03" "cls",
        (const byte*)"\x65\x5a\x0f" "default_factory",
        (const byte*)"\xd3\xb5\x01" "v",
        (const byte*)"\xc8\x02\x14" "collections/deque.py",
        (const byte*)"\x71\x9a\x07" "popleft",
        (const byte*)"\xea\xa4\x08" "popright",
        (const byte*)"\xb0\x1e\x0a" "appendleft",
        (const byte*)"\xb8\xf1\x0a" "extendleft",
        (const byte*)"\x56\x18\x06" "maxlen",
        (const byte*)"\xd4\xb5\x01" "q",
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__[34] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x2f, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_message),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 34,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException[36] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a,
    MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x8d, 0x2d, 0x20, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException___init__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 36,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd[26] = {
    0x06, 0x00, 0x00, 0x05, 0x00, 0x03, 0x0a,
    MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x3b, 0x20, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_NotImplementedError & 0xff, MP_QSTR_NotImplementedError >> 8,
    0x64, 0x00, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_cmd),
    MP_ROM_QSTR(MP_QSTR_is_async),
    MP_ROM_QSTR(MP_QSTR_timeout),
    MP_ROM_QSTR(MP_QSTR_retry),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_reset & 0xff, MP_QSTR_hci_reset >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x3f, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_RESET & 0xff, MP_QSTR_OCF_RESET >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_disconnect & 0xff, MP_QSTR_hci_disconnect >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x47, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LINK_CTL & 0xff, MP_QSTR_OGF_LINK_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_DISCONNECT & 0xff, MP_QSTR_OCF_DISCONNECT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
    MP_ROM_QSTR(MP_QSTR_reason),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_local_version & 0xff, MP_QSTR_hci_le_read_local_version >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x53, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_READ_LOCAL_VERSION & 0xff, MP_QSTR_OCF_READ_LOCAL_VERSION >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_buffer_size & 0xff, MP_QSTR_hci_le_read_buffer_size >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x5b, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_BUFFER_SIZE & 0xff, MP_QSTR_OCF_LE_READ_BUFFER_SIZE >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters[75] = {
    0x16, 0x00, 0x00, 0x09, 0x00, 0x08, 0x0f,
    MP_QSTR_hci_le_set_advertising_parameters & 0xff, MP_QSTR_hci_le_set_advertising_parameters >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x65, 0x20, 0x74, 0x20, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHBBB6sBB & 0xff, MP_QSTR__lt_HHBBB6sBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0x66, 0x09, 
    0xc9, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb9, 
    0x64, 0x86, 0x00, 
    0xca, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xba, 
    0x66, 0x01, 
    0x32, 
    0xba, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters[9] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_min_interval),
    MP_ROM_QSTR(MP_QSTR_max_interval),
    MP_ROM_QSTR(MP_QSTR_advtype),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_direct_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_direct_bdaddr),
    MP_ROM_QSTR(MP_QSTR_chan_map),
    MP_ROM_QSTR(MP_QSTR_filter_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 9,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data[75] = {
    0x0b, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_hci_le_set_advertising_data & 0xff, MP_QSTR_hci_le_set_advertising_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x72, 0x20, 0x26, 0x4e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_ADV_DATA & 0xff, MP_QSTR_OCF_LE_SET_ADV_DATA >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_length),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable[73] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0f,
    MP_QSTR_hci_le_set_advertise_enable & 0xff, MP_QSTR_hci_le_set_advertise_enable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x7e, 0x20, 0x49, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb1, 
    0x64, 0x01, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_enable),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 73,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters[71] = {
    0x10, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0e,
    MP_QSTR_hci_le_set_scan_parameters & 0xff, MP_QSTR_hci_le_set_scan_parameters >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x8b, 0x20, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BHHBB & 0xff, MP_QSTR__lt_BHHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x64, 0x86, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_type_),
    MP_ROM_QSTR(MP_QSTR_interval),
    MP_ROM_QSTR(MP_QSTR_window),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_filter_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 71,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable[74] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_hci_le_set_scan_enable & 0xff, MP_QSTR_hci_le_set_scan_enable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0x97, 0x20, 0x49, 0x2a, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB & 0xff, MP_QSTR__lt_BB >> 8,
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb1, 
    0x64, 0x01, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_SCAN_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_SCAN_ENABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_enable),
    MP_ROM_QSTR(MP_QSTR_filter_dup),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 74,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_rand & 0xff, MP_QSTR_hci_le_rand >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xa3, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_RAND & 0xff, MP_QSTR_OCF_LE_RAND >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data[75] = {
    0x0b, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_hci_le_set_scan_resp_data & 0xff, MP_QSTR_hci_le_set_scan_resp_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xab, 0x20, 0x26, 0x4e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA & 0xff, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_length),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_advertising_channel_tx_power & 0xff, MP_QSTR_hci_le_read_advertising_channel_tx_power >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xb7, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER & 0xff, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_hci_le_set_random_address & 0xff, MP_QSTR_hci_le_set_random_address >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xbf, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_6s & 0xff, MP_QSTR__lt_6s >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS & 0xff, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_bdaddr),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_read_bd_addr & 0xff, MP_QSTR_hci_read_bd_addr >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xcb, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_READ_BD_ADDR & 0xff, MP_QSTR_OCF_READ_BD_ADDR >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection[79] = {
    0x1e, 0x00, 0x00, 0x0d, 0x00, 0x0c, 0x10,
    MP_QSTR_hci_le_create_connection & 0xff, MP_QSTR_hci_le_create_connection >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xd6, 0x20, 0x26, 0x71, 0x60, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0d, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0xbc, 
    0x66, 0x0d, 
    0xcd, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_CREATE_CONN & 0xff, MP_QSTR_OCF_LE_CREATE_CONN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbd, 
    0x64, 0x86, 0x00, 
    0xce, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbe, 
    0x66, 0x01, 
    0x32, 
    0xbe, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_0 = {{&mp_type_str}, 52254, 14, (const byte*)"\x3c\x48\x48\x42\x42\x36\x73\x42\x48\x48\x48\x48\x48\x48"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection[14] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_interval),
    MP_ROM_QSTR(MP_QSTR_window),
    MP_ROM_QSTR(MP_QSTR_initiator_filter),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_min_interval),
    MP_ROM_QSTR(MP_QSTR_max_interval),
    MP_ROM_QSTR(MP_QSTR_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_ce_length),
    MP_ROM_QSTR(MP_QSTR_max_ce_length),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 13,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 79,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_create_connection_cancel & 0xff, MP_QSTR_hci_le_create_connection_cancel >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xe6, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL & 0xff, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_le_encrypt & 0xff, MP_QSTR_hci_le_encrypt >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xee, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_16s16s & 0xff, MP_QSTR__lt_16s16s >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_ENCRYPT & 0xff, MP_QSTR_OCF_LE_ENCRYPT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
    MP_ROM_QSTR(MP_QSTR_plaintext_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_le_ltk_request_reply & 0xff, MP_QSTR_hci_le_ltk_request_reply >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x81, 0xfa, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H16s & 0xff, MP_QSTR__lt_H16s >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_LTK_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_REPLY >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
    MP_ROM_QSTR(MP_QSTR_key),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_hci_le_ltk_request_neg_reply & 0xff, MP_QSTR_hci_le_ltk_request_neg_reply >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x06, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_LTK_NEG_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_NEG_REPLY >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_white_list_size & 0xff, MP_QSTR_hci_le_read_white_list_size >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x12, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE & 0xff, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_clear_white_list & 0xff, MP_QSTR_hci_le_clear_white_list >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x1a, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_le_add_device_to_white_list & 0xff, MP_QSTR_hci_le_add_device_to_white_list >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x22, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B6s & 0xff, MP_QSTR__lt_B6s >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_bdaddr),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_le_remove_device_from_white_list & 0xff, MP_QSTR_hci_le_remove_device_from_white_list >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x2e, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B6s & 0xff, MP_QSTR__lt_B6s >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_bdaddr),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_hci_read_transmit_power_level & 0xff, MP_QSTR_hci_read_transmit_power_level >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x3a, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL & 0xff, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
    MP_ROM_QSTR(MP_QSTR_type_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_hci_read_rssi & 0xff, MP_QSTR_hci_read_rssi >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x46, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_STATUS_PARAM & 0xff, MP_QSTR_OGF_STATUS_PARAM >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_READ_RSSI & 0xff, MP_QSTR_OCF_READ_RSSI >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_local_supported_features & 0xff, MP_QSTR_hci_le_read_local_supported_features >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x52, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_hci_le_read_channel_map & 0xff, MP_QSTR_hci_le_read_channel_map >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x5a, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_CHANNEL_MAP & 0xff, MP_QSTR_OCF_LE_READ_CHANNEL_MAP >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_read_supported_states & 0xff, MP_QSTR_hci_le_read_supported_states >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x66, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES & 0xff, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_hci_le_receiver_test & 0xff, MP_QSTR_hci_le_receiver_test >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x6e, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_RECEIVER_TEST & 0xff, MP_QSTR_OCF_LE_RECEIVER_TEST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_frequency),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test[69] = {
    0x0d, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_hci_le_transmitter_test & 0xff, MP_QSTR_hci_le_transmitter_test >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x7a, 0x20, 0x6f, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BBB & 0xff, MP_QSTR__lt_BBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_TRANSMITTER_TEST & 0xff, MP_QSTR_OCF_LE_TRANSMITTER_TEST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x64, 0x86, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_frequency),
    MP_ROM_QSTR(MP_QSTR_length),
    MP_ROM_QSTR(MP_QSTR_payload),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 69,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_hci_le_test_end & 0xff, MP_QSTR_hci_le_test_end >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x91, 0x86, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_LE_TEST_END & 0xff, MP_QSTR_OCF_LE_TEST_END >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI[383] = {
    0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4b,
    MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x8d, 0x32, 0x80, 0x08, 0x6d, 0x20, 0x85, 0x08, 0x8a, 0x0c, 0x85, 0x08, 0x85, 0x08, 0x71, 0x80, 0x0c, 0x8b, 0x0c, 0x89, 0x0c, 0x8d, 0x0d, 0x8a, 0x0c, 0x85, 0x08, 0x8b, 0x0c, 0x85, 0x08, 0x8a, 0x0c, 0x85, 0x08, 0x75, 0x80, 0x10, 0x85, 0x08, 0x8c, 0x0c, 0x8b, 0x0c, 0x89, 0x0c, 0x85, 0x08, 0x85, 0x08, 0x8b, 0x0c, 0x8b, 0x0c, 0x8a, 0x0c, 0x89, 0x0c, 0x85, 0x08, 0x89, 0x0c, 0x85, 0x08, 0x89, 0x0c, 0x8b, 0x0c, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x10, 
    0x14, 0x87, 0x68, 
    0x85, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x0a, 
    0x24, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0x60, 0x0b, 
    0x24, MP_QSTR_hci_reset & 0xff, MP_QSTR_hci_reset >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x0c, 
    0x24, MP_QSTR_hci_disconnect & 0xff, MP_QSTR_hci_disconnect >> 8,
    0x60, 0x0d, 
    0x24, MP_QSTR_hci_le_read_local_version & 0xff, MP_QSTR_hci_le_read_local_version >> 8,
    0x60, 0x0e, 
    0x24, MP_QSTR_hci_le_read_buffer_size & 0xff, MP_QSTR_hci_le_read_buffer_size >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x00, 
    0x80, 
    0x80, 
    0x50, 0x08, 
    0x18, 
    0x61, 0x0f, 
    0x24, MP_QSTR_hci_le_set_advertising_parameters & 0xff, MP_QSTR_hci_le_set_advertising_parameters >> 8,
    0x80, 
    0x17, 0x01, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x10, 
    0x24, MP_QSTR_hci_le_set_advertising_data & 0xff, MP_QSTR_hci_le_set_advertising_data >> 8,
    0x10, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x11, 
    0x24, MP_QSTR_hci_le_set_advertise_enable & 0xff, MP_QSTR_hci_le_set_advertise_enable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x12, 
    0x24, MP_QSTR_hci_le_set_scan_parameters & 0xff, MP_QSTR_hci_le_set_scan_parameters >> 8,
    0x10, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x13, 
    0x24, MP_QSTR_hci_le_set_scan_enable & 0xff, MP_QSTR_hci_le_set_scan_enable >> 8,
    0x60, 0x14, 
    0x24, MP_QSTR_hci_le_rand & 0xff, MP_QSTR_hci_le_rand >> 8,
    0x80, 
    0x17, 0x02, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x15, 
    0x24, MP_QSTR_hci_le_set_scan_resp_data & 0xff, MP_QSTR_hci_le_set_scan_resp_data >> 8,
    0x60, 0x16, 
    0x24, MP_QSTR_hci_le_read_advertising_channel_tx_power & 0xff, MP_QSTR_hci_le_read_advertising_channel_tx_power >> 8,
    0x17, 0x03, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x17, 
    0x24, MP_QSTR_hci_le_set_random_address & 0xff, MP_QSTR_hci_le_set_random_address >> 8,
    0x60, 0x18, 
    0x24, MP_QSTR_hci_read_bd_addr & 0xff, MP_QSTR_hci_read_bd_addr >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x04, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x0c, 
    0x18, 
    0x61, 0x19, 
    0x24, MP_QSTR_hci_le_create_connection & 0xff, MP_QSTR_hci_le_create_connection >> 8,
    0x60, 0x1a, 
    0x24, MP_QSTR_hci_le_create_connection_cancel & 0xff, MP_QSTR_hci_le_create_connection_cancel >> 8,
    0x17, 0x05, 
    0x17, 0x06, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x1b, 
    0x24, MP_QSTR_hci_le_encrypt & 0xff, MP_QSTR_hci_le_encrypt >> 8,
    0x80, 
    0x17, 0x07, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x1c, 
    0x24, MP_QSTR_hci_le_ltk_request_reply & 0xff, MP_QSTR_hci_le_ltk_request_reply >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x1d, 
    0x24, MP_QSTR_hci_le_ltk_request_neg_reply & 0xff, MP_QSTR_hci_le_ltk_request_neg_reply >> 8,
    0x60, 0x1e, 
    0x24, MP_QSTR_hci_le_read_white_list_size & 0xff, MP_QSTR_hci_le_read_white_list_size >> 8,
    0x60, 0x1f, 
    0x24, MP_QSTR_hci_le_clear_white_list & 0xff, MP_QSTR_hci_le_clear_white_list >> 8,
    0x80, 
    0x17, 0x08, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x20, 
    0x24, MP_QSTR_hci_le_add_device_to_white_list & 0xff, MP_QSTR_hci_le_add_device_to_white_list >> 8,
    0x80, 
    0x17, 0x09, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x21, 
    0x24, MP_QSTR_hci_le_remove_device_from_white_list & 0xff, MP_QSTR_hci_le_remove_device_from_white_list >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x22, 
    0x24, MP_QSTR_hci_read_transmit_power_level & 0xff, MP_QSTR_hci_read_transmit_power_level >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x23, 
    0x24, MP_QSTR_hci_read_rssi & 0xff, MP_QSTR_hci_read_rssi >> 8,
    0x60, 0x24, 
    0x24, MP_QSTR_hci_le_read_local_supported_features & 0xff, MP_QSTR_hci_le_read_local_supported_features >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x25, 
    0x24, MP_QSTR_hci_le_read_channel_map & 0xff, MP_QSTR_hci_le_read_channel_map >> 8,
    0x60, 0x26, 
    0x24, MP_QSTR_hci_le_read_supported_states & 0xff, MP_QSTR_hci_le_read_supported_states >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x27, 
    0x24, MP_QSTR_hci_le_receiver_test & 0xff, MP_QSTR_hci_le_receiver_test >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x28, 
    0x24, MP_QSTR_hci_le_transmitter_test & 0xff, MP_QSTR_hci_le_transmitter_test >> 8,
    0x60, 0x29, 
    0x24, MP_QSTR_hci_le_test_end & 0xff, MP_QSTR_hci_le_test_end >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_1 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_2 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_3 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_4 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_5 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_6 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_7 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_8 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_9 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI[42] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_9),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_send_cmd),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_reset),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_disconnect),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_version),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_buffer_size),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_parameters),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertising_data),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_advertise_enable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_parameters),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_enable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_rand),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_scan_resp_data),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_advertising_channel_tx_power),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_set_random_address),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_bd_addr),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_create_connection_cancel),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_encrypt),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_reply),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_ltk_request_neg_reply),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_white_list_size),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_clear_white_list),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_add_device_to_white_list),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_remove_device_from_white_list),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_transmit_power_level),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_read_rssi),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_local_supported_features),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_channel_map),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_read_supported_states),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_receiver_test),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_transmitter_test),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI_hci_le_test_end),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 383,
        .n_obj = 10,
        .n_raw_code = 32,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/base_hci.py, scope bluetooth_low_energy_modules_base_hci_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt_[426] = {
    0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x19,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_base_hci_dot_py >> 8,
    0x21, 0x48, 0x50, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x7e, 0x80, 0x24, 0x6e, 0x40, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x24, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_OCF_DISCONNECT & 0xff, MP_QSTR_OCF_DISCONNECT >> 8,
    0x16, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST >> 8,
    0x16, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST >> 8,
    0x16, MP_QSTR_OCF_LE_CREATE_CONN & 0xff, MP_QSTR_OCF_LE_CREATE_CONN >> 8,
    0x16, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL & 0xff, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL >> 8,
    0x16, MP_QSTR_OCF_LE_ENCRYPT & 0xff, MP_QSTR_OCF_LE_ENCRYPT >> 8,
    0x16, MP_QSTR_OCF_LE_LTK_NEG_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_NEG_REPLY >> 8,
    0x16, MP_QSTR_OCF_LE_LTK_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_REPLY >> 8,
    0x16, MP_QSTR_OCF_LE_RAND & 0xff, MP_QSTR_OCF_LE_RAND >> 8,
    0x16, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER & 0xff, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER >> 8,
    0x16, MP_QSTR_OCF_LE_READ_BUFFER_SIZE & 0xff, MP_QSTR_OCF_LE_READ_BUFFER_SIZE >> 8,
    0x16, MP_QSTR_OCF_LE_READ_CHANNEL_MAP & 0xff, MP_QSTR_OCF_LE_READ_CHANNEL_MAP >> 8,
    0x16, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES >> 8,
    0x16, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES & 0xff, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES >> 8,
    0x16, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE & 0xff, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE >> 8,
    0x16, MP_QSTR_OCF_LE_RECEIVER_TEST & 0xff, MP_QSTR_OCF_LE_RECEIVER_TEST >> 8,
    0x16, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST >> 8,
    0x16, MP_QSTR_OCF_LE_SET_ADV_DATA & 0xff, MP_QSTR_OCF_LE_SET_ADV_DATA >> 8,
    0x16, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS >> 8,
    0x16, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE >> 8,
    0x16, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS & 0xff, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS >> 8,
    0x16, MP_QSTR_OCF_LE_SET_SCAN_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_SCAN_ENABLE >> 8,
    0x16, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS >> 8,
    0x16, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA & 0xff, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA >> 8,
    0x16, MP_QSTR_OCF_LE_TEST_END & 0xff, MP_QSTR_OCF_LE_TEST_END >> 8,
    0x16, MP_QSTR_OCF_LE_TRANSMITTER_TEST & 0xff, MP_QSTR_OCF_LE_TRANSMITTER_TEST >> 8,
    0x16, MP_QSTR_OCF_READ_BD_ADDR & 0xff, MP_QSTR_OCF_READ_BD_ADDR >> 8,
    0x16, MP_QSTR_OCF_READ_LOCAL_VERSION & 0xff, MP_QSTR_OCF_READ_LOCAL_VERSION >> 8,
    0x16, MP_QSTR_OCF_READ_RSSI & 0xff, MP_QSTR_OCF_READ_RSSI >> 8,
    0x16, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL & 0xff, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL >> 8,
    0x16, MP_QSTR_OCF_RESET & 0xff, MP_QSTR_OCF_RESET >> 8,
    0x16, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x16, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x16, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x16, MP_QSTR_OGF_LINK_CTL & 0xff, MP_QSTR_OGF_LINK_CTL >> 8,
    0x16, MP_QSTR_OGF_STATUS_PARAM & 0xff, MP_QSTR_OGF_STATUS_PARAM >> 8,
    0x16, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x50, 0x25, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_cmd & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_cmd >> 8,
    0x69, MP_QSTR_OCF_DISCONNECT & 0xff, MP_QSTR_OCF_DISCONNECT >> 8,
    0x24, MP_QSTR_OCF_DISCONNECT & 0xff, MP_QSTR_OCF_DISCONNECT >> 8,
    0x69, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST >> 8,
    0x24, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST >> 8,
    0x69, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST >> 8,
    0x24, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST >> 8,
    0x69, MP_QSTR_OCF_LE_CREATE_CONN & 0xff, MP_QSTR_OCF_LE_CREATE_CONN >> 8,
    0x24, MP_QSTR_OCF_LE_CREATE_CONN & 0xff, MP_QSTR_OCF_LE_CREATE_CONN >> 8,
    0x69, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL & 0xff, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL >> 8,
    0x24, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL & 0xff, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL >> 8,
    0x69, MP_QSTR_OCF_LE_ENCRYPT & 0xff, MP_QSTR_OCF_LE_ENCRYPT >> 8,
    0x24, MP_QSTR_OCF_LE_ENCRYPT & 0xff, MP_QSTR_OCF_LE_ENCRYPT >> 8,
    0x69, MP_QSTR_OCF_LE_LTK_NEG_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_NEG_REPLY >> 8,
    0x24, MP_QSTR_OCF_LE_LTK_NEG_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_NEG_REPLY >> 8,
    0x69, MP_QSTR_OCF_LE_LTK_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_REPLY >> 8,
    0x24, MP_QSTR_OCF_LE_LTK_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_REPLY >> 8,
    0x69, MP_QSTR_OCF_LE_RAND & 0xff, MP_QSTR_OCF_LE_RAND >> 8,
    0x24, MP_QSTR_OCF_LE_RAND & 0xff, MP_QSTR_OCF_LE_RAND >> 8,
    0x69, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER & 0xff, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER >> 8,
    0x24, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER & 0xff, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER >> 8,
    0x69, MP_QSTR_OCF_LE_READ_BUFFER_SIZE & 0xff, MP_QSTR_OCF_LE_READ_BUFFER_SIZE >> 8,
    0x24, MP_QSTR_OCF_LE_READ_BUFFER_SIZE & 0xff, MP_QSTR_OCF_LE_READ_BUFFER_SIZE >> 8,
    0x69, MP_QSTR_OCF_LE_READ_CHANNEL_MAP & 0xff, MP_QSTR_OCF_LE_READ_CHANNEL_MAP >> 8,
    0x24, MP_QSTR_OCF_LE_READ_CHANNEL_MAP & 0xff, MP_QSTR_OCF_LE_READ_CHANNEL_MAP >> 8,
    0x69, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES >> 8,
    0x24, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES >> 8,
    0x69, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES & 0xff, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES >> 8,
    0x24, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES & 0xff, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES >> 8,
    0x69, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE & 0xff, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE >> 8,
    0x24, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE & 0xff, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE >> 8,
    0x69, MP_QSTR_OCF_LE_RECEIVER_TEST & 0xff, MP_QSTR_OCF_LE_RECEIVER_TEST >> 8,
    0x24, MP_QSTR_OCF_LE_RECEIVER_TEST & 0xff, MP_QSTR_OCF_LE_RECEIVER_TEST >> 8,
    0x69, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST >> 8,
    0x24, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST >> 8,
    0x69, MP_QSTR_OCF_LE_SET_ADV_DATA & 0xff, MP_QSTR_OCF_LE_SET_ADV_DATA >> 8,
    0x24, MP_QSTR_OCF_LE_SET_ADV_DATA & 0xff, MP_QSTR_OCF_LE_SET_ADV_DATA >> 8,
    0x69, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS >> 8,
    0x24, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS >> 8,
    0x69, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE >> 8,
    0x24, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE >> 8,
    0x69, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS & 0xff, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS >> 8,
    0x24, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS & 0xff, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS >> 8,
    0x69, MP_QSTR_OCF_LE_SET_SCAN_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_SCAN_ENABLE >> 8,
    0x24, MP_QSTR_OCF_LE_SET_SCAN_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_SCAN_ENABLE >> 8,
    0x69, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS >> 8,
    0x24, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS >> 8,
    0x69, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA & 0xff, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA >> 8,
    0x24, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA & 0xff, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA >> 8,
    0x69, MP_QSTR_OCF_LE_TEST_END & 0xff, MP_QSTR_OCF_LE_TEST_END >> 8,
    0x24, MP_QSTR_OCF_LE_TEST_END & 0xff, MP_QSTR_OCF_LE_TEST_END >> 8,
    0x69, MP_QSTR_OCF_LE_TRANSMITTER_TEST & 0xff, MP_QSTR_OCF_LE_TRANSMITTER_TEST >> 8,
    0x24, MP_QSTR_OCF_LE_TRANSMITTER_TEST & 0xff, MP_QSTR_OCF_LE_TRANSMITTER_TEST >> 8,
    0x69, MP_QSTR_OCF_READ_BD_ADDR & 0xff, MP_QSTR_OCF_READ_BD_ADDR >> 8,
    0x24, MP_QSTR_OCF_READ_BD_ADDR & 0xff, MP_QSTR_OCF_READ_BD_ADDR >> 8,
    0x69, MP_QSTR_OCF_READ_LOCAL_VERSION & 0xff, MP_QSTR_OCF_READ_LOCAL_VERSION >> 8,
    0x24, MP_QSTR_OCF_READ_LOCAL_VERSION & 0xff, MP_QSTR_OCF_READ_LOCAL_VERSION >> 8,
    0x69, MP_QSTR_OCF_READ_RSSI & 0xff, MP_QSTR_OCF_READ_RSSI >> 8,
    0x24, MP_QSTR_OCF_READ_RSSI & 0xff, MP_QSTR_OCF_READ_RSSI >> 8,
    0x69, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL & 0xff, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL >> 8,
    0x24, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL & 0xff, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL >> 8,
    0x69, MP_QSTR_OCF_RESET & 0xff, MP_QSTR_OCF_RESET >> 8,
    0x24, MP_QSTR_OCF_RESET & 0xff, MP_QSTR_OCF_RESET >> 8,
    0x69, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x24, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x69, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x24, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x69, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x24, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x69, MP_QSTR_OGF_LINK_CTL & 0xff, MP_QSTR_OGF_LINK_CTL >> 8,
    0x24, MP_QSTR_OGF_LINK_CTL & 0xff, MP_QSTR_OGF_LINK_CTL >> 8,
    0x69, MP_QSTR_OGF_STATUS_PARAM & 0xff, MP_QSTR_OGF_STATUS_PARAM >> 8,
    0x24, MP_QSTR_OGF_STATUS_PARAM & 0xff, MP_QSTR_OGF_STATUS_PARAM >> 8,
    0x69, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x24, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x1b, MP_QSTR_Exception & 0xff, MP_QSTR_Exception >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x20, 
    0x60, 0x01, 
    0x16, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt_[2] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__HardwareException),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt__BaseHCI),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_base_hci__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_base_hci__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 426,
        .n_obj = 0,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__[23] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xa0, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__pin & 0xff, MP_QSTR__pin >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_pin),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 23,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__[28] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___enter__ & 0xff, MP_QSTR___enter__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xa3, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR__pin & 0xff, MP_QSTR__pin >> 8,
    0x1e, MP_QSTR_off & 0xff, MP_QSTR_off >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 28,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit___<lambda>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_[20] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR__lt_lambda_gt_ & 0xff, MP_QSTR__lt_lambda_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xa7, 0x00, 0x00, 0xff,
    0xb0, 
    0x11, 
    0xde, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_[1] = {
    MP_ROM_QSTR(MP_QSTR_x),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 20,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__[45] = {
    0x0a, 0x00, 0x00, 0x04, 0x00, 0x00, 0x0a,
    MP_QSTR___exit__ & 0xff, MP_QSTR___exit__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xa6, 0x2a, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR__pin & 0xff, MP_QSTR__pin >> 8,
    0x1e, MP_QSTR_on & 0xff, MP_QSTR_on >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_all & 0xff, MP_QSTR_all >> 8,
    0x1c, MP_QSTR_map & 0xff, MP_QSTR_map >> 8,
    0x60, 0x04, 
    0xb1, 
    0xb2, 
    0xb3, 
    0x51, 0x03, 
    0x64, 0x02, 
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_exc_type),
    MP_ROM_QSTR(MP_QSTR_exc_value),
    MP_ROM_QSTR(MP_QSTR_traceback),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit____lt_lambda_gt_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 45,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext[47] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0b,
    MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x8d, 0x9f, 0x45, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR___enter__ & 0xff, MP_QSTR___enter__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___exit__ & 0xff, MP_QSTR___exit__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext[3] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___enter__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext___exit__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 47,
        .n_obj = 0,
        .n_raw_code = 3,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init___<listcomp>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_[42] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR__lt_listcomp_gt_ & 0xff, MP_QSTR__lt_listcomp_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x89, 0xd0, 0x00, 0x00, 0xff,
    0x51, 0x00, 
    0xb0, 
    0x47, 
    0x43, 0x12, 0x00, 
    0xc1, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x64, 0x02, 
    0x57, 0x14, 
    0x35, 0xeb, 0x7f, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_[1] = {
    MP_ROM_QSTR(MP_QSTR__star_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 42,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__[113] = {
    0x09, 0x00, 0x00, 0x05, 0x00, 0x04, 0x14,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xb6, 0x80, 0x16, 0x2f, 0x4a, 0x26, 0x2d, 0x4a, 0x45, 0x25, 0x25, 0x65, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_SPI & 0xff, MP_QSTR_SPI >> 8,
    0x64, 0x02, 
    0x36, 0x0a, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x50, 0x03, 
    0xc5, 
    0x1c, MP_QSTR_all & 0xff, MP_QSTR_all >> 8,
    0x60, 0x05, 
    0xb5, 
    0x64, 0x01, 
    0x64, 0x01, 
    0x36, 0x0a, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__irq_pin & 0xff, MP_QSTR__irq_pin >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__rst_pin & 0xff, MP_QSTR__rst_pin >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR__nss_pin & 0xff, MP_QSTR__nss_pin >> 8,
    0xb0, 
    0x1d, MP_QSTR__nss_pin & 0xff, MP_QSTR__nss_pin >> 8,
    0x1e, MP_QSTR_on & 0xff, MP_QSTR_on >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_spi_bus),
    MP_ROM_QSTR(MP_QSTR_irq_pin),
    MP_ROM_QSTR(MP_QSTR_rst_pin),
    MP_ROM_QSTR(MP_QSTR_nss_pin),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init____lt_listcomp_gt_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 113,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset[62] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xdd, 0x60, 0x2a, 0x2a, 0x2a, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR__rst_pin & 0xff, MP_QSTR__rst_pin >> 8,
    0x1e, MP_QSTR_off & 0xff, MP_QSTR_off >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_us & 0xff, MP_QSTR_sleep_us >> 8,
    0x85, 
    0x66, 0x01, 
    0x32, 
    0xb0, 
    0x1d, MP_QSTR__rst_pin & 0xff, MP_QSTR__rst_pin >> 8,
    0x1e, MP_QSTR_on & 0xff, MP_QSTR_on >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_us & 0xff, MP_QSTR_sleep_us >> 8,
    0x85, 
    0x66, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 62,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any[32] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_any & 0xff, MP_QSTR_any >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xe6, 0x20, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0xb0, 
    0x1d, MP_QSTR__irq_pin & 0xff, MP_QSTR__irq_pin >> 8,
    0x1e, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x66, 0x00, 
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 32,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output[58] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_set_spi_irq_as_output & 0xff, MP_QSTR_set_spi_irq_as_output >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xea, 0x20, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR__irq_pin & 0xff, MP_QSTR__irq_pin >> 8,
    0x1e, MP_QSTR_init & 0xff, MP_QSTR_init >> 8,
    0x16, MP_QSTR_mode & 0xff, MP_QSTR_mode >> 8,
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_OUT_PP & 0xff, MP_QSTR_OUT_PP >> 8,
    0x16, MP_QSTR_pull & 0xff, MP_QSTR_pull >> 8,
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_PULL_NONE & 0xff, MP_QSTR_PULL_NONE >> 8,
    0x16, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x81, 
    0x66, 0x86, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 58,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input[54] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_set_spi_irq_as_input & 0xff, MP_QSTR_set_spi_irq_as_input >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xee, 0x20, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR__irq_pin & 0xff, MP_QSTR__irq_pin >> 8,
    0x1e, MP_QSTR_init & 0xff, MP_QSTR_init >> 8,
    0x16, MP_QSTR_mode & 0xff, MP_QSTR_mode >> 8,
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_IN & 0xff, MP_QSTR_IN >> 8,
    0x16, MP_QSTR_pull & 0xff, MP_QSTR_pull >> 8,
    0x1c, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_PULL_DOWN & 0xff, MP_QSTR_PULL_DOWN >> 8,
    0x66, 0x84, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 54,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader[53] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR_hw_bootloader & 0xff, MP_QSTR_hw_bootloader >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xf2, 0x20, 0x27, 0x27, 0x2a, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_set_spi_irq_as_output & 0xff, MP_QSTR_set_spi_irq_as_output >> 8,
    0x66, 0x00, 
    0x32, 
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_ms & 0xff, MP_QSTR_sleep_ms >> 8,
    0x84, 
    0x66, 0x01, 
    0x32, 
    0xb0, 
    0x1e, MP_QSTR_set_spi_irq_as_input & 0xff, MP_QSTR_set_spi_irq_as_input >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 53,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run[204] = {
    0x0d, 0x03, 0x00, 0x03, 0x00, 0x02, 0x18,
    MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x81, 0xf9, 0x80, 0x09, 0x26, 0x27, 0x29, 0x20, 0x2c, 0x2a, 0x48, 0x3f, 0x24, 0x51, 0x30, 0x5a, 0x51, 0x00, 0x00, 0xff,
    0x40, 0xa0, 0x00, 
    0x3f, 0x61, 0x00, 
    0xb0, 
    0x1e, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_read & 0xff, MP_QSTR_read >> 8,
    0x16, MP_QSTR_retry & 0xff, MP_QSTR_retry >> 8,
    0x85, 
    0x66, 0x82, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_verify & 0xff, MP_QSTR_hci_verify >> 8,
    0xb4, 
    0x66, 0x01, 
    0x37, 0x08, 0x80, 
    0xb0, 
    0x1e, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb1, 
    0x64, 0x01, 
    0x37, 0x23, 0x80, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_diff & 0xff, MP_QSTR_ticks_diff >> 8,
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xb3, 
    0x66, 0x02, 
    0xb2, 
    0xdb, 
    0x37, 0x0d, 0x80, 
    0xb1, 
    0x64, 0x00, 
    0x32, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xc3, 
    0x35, 0xb3, 0x7f, 
    0x44, 
    0x35, 0x3a, 0x80, 
    0x30, 
    0x1c, MP_QSTR_KeyboardInterrupt & 0xff, MP_QSTR_KeyboardInterrupt >> 8,
    0x1c, MP_QSTR_StopIteration & 0xff, MP_QSTR_StopIteration >> 8,
    0x50, 0x02, 
    0xdf, 
    0x37, 0x12, 0x80, 
    0xc5, 
    0x40, 0x06, 0x00, 
    0xb5, 
    0x5c, 0x01, 
    0x44, 
    0x45, 
    0x11, 
    0x11, 
    0xc5, 
    0x28, 0x05, 
    0x41, 
    0x35, 0x1b, 0x80, 
    0x30, 
    0x1c, MP_QSTR_Exception & 0xff, MP_QSTR_Exception >> 8,
    0xdf, 
    0x37, 0x12, 0x80, 
    0xc5, 
    0x40, 0x06, 0x00, 
    0xb5, 
    0x5c, 0x01, 
    0x44, 
    0x45, 
    0x11, 
    0x11, 
    0xc5, 
    0x28, 0x05, 
    0x41, 
    0x35, 0x01, 0x80, 
    0x41, 
    0x44, 
    0x11, 
    0xb0, 
    0x1e, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x66, 0x00, 
    0x32, 
    0x41, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_callback),
    MP_ROM_QSTR(MP_QSTR_callback_time),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 204,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__[25] = {
    0x02, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x16, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_NotImplementedError & 0xff, MP_QSTR_NotImplementedError >> 8,
    0x64, 0x00, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 25,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__[25] = {
    0x02, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x19, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_NotImplementedError & 0xff, MP_QSTR_NotImplementedError >> 8,
    0x64, 0x00, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 25,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__[25] = {
    0x03, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x1c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_NotImplementedError & 0xff, MP_QSTR_NotImplementedError >> 8,
    0x64, 0x00, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_event),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 25,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read[181] = {
    0x0e, 0x01, 0x00, 0x03, 0x00, 0x02, 0x1c,
    MP_QSTR_read & 0xff, MP_QSTR_read >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x1f, 0x60, 0x42, 0x23, 0x2c, 0x23, 0x2d, 0x2c, 0x2a, 0x6e, 0x26, 0x22, 0x25, 0x27, 0x2c, 0x47, 0x30, 0x68, 0x20, 0x2c, 0x00, 0x00, 0xff,
    0x11, 
    0xc3, 
    0x17, 0x03, 
    0xc4, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb4, 
    0x64, 0x01, 
    0x64, 0x01, 
    0xc5, 
    0x35, 0x6c, 0x80, 
    0x1c, MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    0xb0, 
    0x1d, MP_QSTR__nss_pin & 0xff, MP_QSTR__nss_pin >> 8,
    0x64, 0x01, 
    0x3d, 0x5a, 0x00, 
    0x32, 
    0xb0, 
    0x1d, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0x1e, MP_QSTR_write_readinto & 0xff, MP_QSTR_write_readinto >> 8,
    0xb4, 
    0xb5, 
    0x66, 0x02, 
    0x32, 
    0xb5, 
    0x84, 
    0x21, 
    0x88, 
    0xef, 
    0xb5, 
    0x83, 
    0x21, 
    0xec, 
    0xc6, 
    0xb5, 
    0x80, 
    0x21, 
    0x82, 
    0xd9, 
    0x37, 0x2d, 0x80, 
    0xb6, 
    0x80, 
    0xd8, 
    0x37, 0x27, 0x80, 
    0xb6, 
    0xb1, 
    0xd8, 
    0x37, 0x02, 0x80, 
    0xb1, 
    0xc6, 
    0x17, 0x04, 
    0xb6, 
    0xf3, 
    0xc7, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0xb6, 
    0x64, 0x01, 
    0xc3, 
    0xb0, 
    0x1d, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0x1e, MP_QSTR_write_readinto & 0xff, MP_QSTR_write_readinto >> 8,
    0xb7, 
    0xb3, 
    0x66, 0x02, 
    0x32, 
    0x46, 0x1c, 0x80, 
    0x01, 
    0x35, 0x0c, 0x80, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_us & 0xff, MP_QSTR_sleep_us >> 8,
    0x14, 0x81, 0x16, 
    0x66, 0x01, 
    0x32, 
    0x44, 
    0x11, 
    0x3e, 
    0x41, 
    0xb2, 
    0x81, 
    0xe6, 
    0xc2, 
    0xb2, 
    0x36, 0x90, 0x7f, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_us & 0xff, MP_QSTR_sleep_us >> 8,
    0x14, 0x81, 0x16, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read_0 = {{&mp_type_bytes}, 56494, 5, (const byte*)"\x0b\x00\x00\x00\x00"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read_1 = {{&mp_type_bytes}, 46426, 1, (const byte*)"\xff"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_size),
    MP_ROM_QSTR(MP_QSTR_retry),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read_1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 181,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write[271] = {
    0x10, 0x01, 0x00, 0x04, 0x00, 0x01, 0x25,
    MP_QSTR_write & 0xff, MP_QSTR_write >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x3d, 0x60, 0x42, 0x23, 0x2c, 0x23, 0x2d, 0x2c, 0x24, 0x2a, 0x28, 0x6c, 0x44, 0x2b, 0x2c, 0x2c, 0x24, 0x49, 0x2b, 0x45, 0x27, 0x27, 0x2c, 0x47, 0x47, 0x47, 0x47, 0x30, 0x48, 0x00, 0x00, 0xff,
    0x11, 
    0xc4, 
    0x17, 0x04, 
    0xc5, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb5, 
    0x64, 0x01, 
    0x64, 0x01, 
    0xc6, 
    0x35, 0xc9, 0x80, 
    0x1c, MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    0xb0, 
    0x1d, MP_QSTR__nss_pin & 0xff, MP_QSTR__nss_pin >> 8,
    0x64, 0x01, 
    0x3d, 0xb7, 0x00, 
    0x32, 
    0xb0, 
    0x1d, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0x1e, MP_QSTR_write_readinto & 0xff, MP_QSTR_write_readinto >> 8,
    0xb5, 
    0xb6, 
    0x66, 0x02, 
    0x32, 
    0xb6, 
    0x81, 
    0x21, 
    0xc7, 
    0xb6, 
    0x84, 
    0x21, 
    0x88, 
    0xef, 
    0xb6, 
    0x83, 
    0x21, 
    0xec, 
    0xc8, 
    0xb6, 
    0x80, 
    0x21, 
    0x82, 
    0xd9, 
    0x37, 0x86, 0x80, 
    0xb7, 
    0x80, 
    0xd8, 
    0x36, 0x06, 0x80, 
    0xb8, 
    0x80, 
    0xd8, 
    0x37, 0x7a, 0x80, 
    0xb1, 
    0x37, 0x6f, 0x80, 
    0xb7, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0xdb, 
    0x37, 0x5d, 0x80, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0x64, 0x01, 
    0xc4, 
    0xb0, 
    0x1d, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0x1e, MP_QSTR_write_readinto & 0xff, MP_QSTR_write_readinto >> 8,
    0xb1, 
    0xb4, 
    0x66, 0x02, 
    0x32, 
    0xb2, 
    0x37, 0x3a, 0x80, 
    0xb7, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0xe6, 
    0xc7, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb2, 
    0x64, 0x01, 
    0xb7, 
    0xd8, 
    0x37, 0x05, 0x80, 
    0xb7, 
    0xc9, 
    0x35, 0x07, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb2, 
    0x64, 0x01, 
    0xc9, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0xb9, 
    0x64, 0x01, 
    0xc4, 
    0xb0, 
    0x1d, MP_QSTR__spi_bus & 0xff, MP_QSTR__spi_bus >> 8,
    0x1e, MP_QSTR_write_readinto & 0xff, MP_QSTR_write_readinto >> 8,
    0xb2, 
    0xb4, 
    0x66, 0x02, 
    0x32, 
    0x46, 0x31, 0x80, 
    0x01, 
    0x35, 0x04, 0x80, 
    0x46, 0x2a, 0x80, 
    0x01, 
    0x35, 0x04, 0x80, 
    0x46, 0x23, 0x80, 
    0x01, 
    0x35, 0x04, 0x80, 
    0x46, 0x1c, 0x80, 
    0x01, 
    0x35, 0x0c, 0x80, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_sleep_us & 0xff, MP_QSTR_sleep_us >> 8,
    0x14, 0x81, 0x16, 
    0x66, 0x01, 
    0x32, 
    0x44, 
    0x11, 
    0x3e, 
    0x41, 
    0xb3, 
    0x81, 
    0xe6, 
    0xc3, 
    0xb3, 
    0x36, 0x33, 0x7f, 
    0xb4, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write_0 = {{&mp_type_bytes}, 62767, 5, (const byte*)"\x0a\x00\x00\x00\x00"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_header),
    MP_ROM_QSTR(MP_QSTR_param),
    MP_ROM_QSTR(MP_QSTR_retry),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 271,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify[67] = {
    0x06, 0x00, 0x00, 0x02, 0x00, 0x00, 0x11,
    MP_QSTR_hci_verify & 0xff, MP_QSTR_hci_verify >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x6a, 0x60, 0x26, 0x42, 0x2a, 0x42, 0x23, 0x30, 0x42, 0x00, 0x00, 0xff,
    0xb1, 
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x10, 
    0x5b, 
    0xb1, 
    0x80, 
    0x21, 
    0x1c, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0xdc, 
    0x37, 0x02, 0x80, 
    0x10, 
    0x5b, 
    0xb1, 
    0x82, 
    0x21, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0x81, 
    0x1c, MP_QSTR_HCI_EVENT_HDR_SIZE & 0xff, MP_QSTR_HCI_EVENT_HDR_SIZE >> 8,
    0xf1, 
    0xf2, 
    0xdc, 
    0x37, 0x02, 0x80, 
    0x10, 
    0x5b, 
    0x12, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_hci_pckt),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event[246] = {
    0x0d, 0x00, 0x00, 0x05, 0x00, 0x04, 0x1e,
    MP_QSTR_hci_wait_event & 0xff, MP_QSTR_hci_wait_event >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x7a, 0x60, 0x20, 0x29, 0x23, 0x2c, 0x3b, 0x2a, 0x2b, 0x2d, 0x28, 0x22, 0x24, 0x30, 0x29, 0x42, 0x29, 0x24, 0x29, 0x42, 0x4c, 0x4c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xc5, 
    0x35, 0xa5, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_read & 0xff, MP_QSTR_read >> 8,
    0x16, MP_QSTR_retry & 0xff, MP_QSTR_retry >> 8,
    0xb4, 
    0x66, 0x82, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_verify & 0xff, MP_QSTR_hci_verify >> 8,
    0xb6, 
    0x66, 0x01, 
    0x37, 0x8c, 0x80, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb6, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x37, 0x7b, 0x80, 
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb6, 
    0x66, 0x01, 
    0xc7, 
    0xb7, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x1c, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0xd9, 
    0x37, 0x5a, 0x80, 
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb7, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x01, 
    0xc8, 
    0xb1, 
    0x36, 0x06, 0x80, 
    0xb2, 
    0x36, 0x02, 0x80, 
    0xb8, 
    0x5b, 
    0xb2, 
    0x37, 0x24, 0x80, 
    0xb8, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0x1c, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0x50, 0x02, 
    0xdd, 
    0x37, 0x14, 0x80, 
    0xb8, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0xb2, 
    0xd9, 
    0x37, 0x02, 0x80, 
    0xb8, 
    0x5b, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x05, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0x37, 0x14, 0x80, 
    0xb8, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xb1, 
    0xd9, 
    0x37, 0x02, 0x80, 
    0xb8, 
    0x5b, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x06, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x07, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0x03, 0x80, 
    0x35, 0x00, 0x80, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_diff & 0xff, MP_QSTR_ticks_diff >> 8,
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xb5, 
    0x66, 0x02, 
    0x1c, MP_QSTR_min & 0xff, MP_QSTR_min >> 8,
    0xb3, 
    0x14, 0x87, 0x68, 
    0x64, 0x02, 
    0xda, 
    0x36, 0x3d, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_0 = {{&mp_type_str}, 1774, 21, (const byte*)"\x75\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x73\x75\x62\x65\x76\x74\x63\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_1 = {{&mp_type_str}, 29098, 18, (const byte*)"\x75\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x65\x76\x74\x63\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_2 = {{&mp_type_str}, 55825, 17, (const byte*)"\x6e\x6f\x74\x20\x48\x43\x49\x5f\x45\x56\x45\x4e\x54\x5f\x50\x4b\x54"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_evtcode),
    MP_ROM_QSTR(MP_QSTR_subevtcode),
    MP_ROM_QSTR(MP_QSTR_timeout),
    MP_ROM_QSTR(MP_QSTR_retry),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event_2),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 246,
        .n_obj = 3,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd[507] = {
    0x10, 0x00, 0x00, 0x05, 0x00, 0x03, 0x2e,
    MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0x98, 0x20, 0x2c, 0x4a, 0x2f, 0x2e, 0x30, 0x49, 0x24, 0x62, 0x29, 0x23, 0x2c, 0x3b, 0x2a, 0x2b, 0x2d, 0x2b, 0x2f, 0x2e, 0x2c, 0x2e, 0x2e, 0x30, 0x22, 0x2b, 0x2f, 0x2e, 0x30, 0x22, 0x2b, 0x2c, 0x2b, 0x30, 0x22, 0x2b, 0x30, 0x51, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x64, 0x02, 
    0x36, 0x0a, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x16, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0x1e, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x16, MP_QSTR_split & 0xff, MP_QSTR_split >> 8,
    0x12, 
    0x66, 0x82, 0x00, 
    0x59, 0x02, 
    0xc5, 
    0xc6, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb5, 
    0x64, 0x01, 
    0xb1, 
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0xd9, 
    0x37, 0x10, 0x80, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B3s & 0xff, MP_QSTR__lt_B3s >> 8,
    0x1c, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0xb5, 
    0x66, 0x03, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send & 0xff, MP_QSTR_hci_send >> 8,
    0xb5, 
    0xb6, 
    0x66, 0x02, 
    0x32, 
    0xb2, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xc7, 
    0x35, 0x48, 0x81, 
    0xb0, 
    0x1e, MP_QSTR_read & 0xff, MP_QSTR_read >> 8,
    0x16, MP_QSTR_retry & 0xff, MP_QSTR_retry >> 8,
    0xb4, 
    0x66, 0x82, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_verify & 0xff, MP_QSTR_hci_verify >> 8,
    0xb8, 
    0x66, 0x01, 
    0x37, 0x2f, 0x81, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb8, 
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x37, 0x1e, 0x81, 
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb8, 
    0x66, 0x01, 
    0xc9, 
    0xb9, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x1c, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0xd9, 
    0x37, 0x06, 0x81, 
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb9, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x01, 
    0xca, 
    0xba, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0xd9, 
    0x37, 0x57, 0x80, 
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb1, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xdc, 
    0x37, 0x0e, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xba, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xdc, 
    0x37, 0x1c, 0x80, 
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x0e, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xba, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xba, 
    0x1d, MP_QSTR_struct_size & 0xff, MP_QSTR_struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x26, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0xb8, 
    0x5b, 
    0xba, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_COMPLETE & 0xff, MP_QSTR_EVT_CMD_COMPLETE >> 8,
    0xd9, 
    0x37, 0x2f, 0x80, 
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb1, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xdc, 
    0x37, 0x0e, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0xba, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xba, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xba, 
    0x1d, MP_QSTR_struct_size & 0xff, MP_QSTR_struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x26, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0xb8, 
    0x5b, 
    0xba, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0xd9, 
    0x37, 0x29, 0x80, 
    0xba, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0xb1, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xdc, 
    0x37, 0x0b, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0xba, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xba, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xba, 
    0x1d, MP_QSTR_struct_size & 0xff, MP_QSTR_struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x26, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0xb8, 
    0x5b, 
    0xba, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_HARDWARE_ERROR & 0xff, MP_QSTR_EVT_HARDWARE_ERROR >> 8,
    0xd9, 
    0x37, 0x1e, 0x80, 
    0xba, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xba, 
    0x1d, MP_QSTR_struct_size & 0xff, MP_QSTR_struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x26, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0x1c, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0xb1, 
    0x1d, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0x00, 0x80, 
    0x35, 0x03, 0x80, 
    0x35, 0x00, 0x80, 
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_diff & 0xff, MP_QSTR_ticks_diff >> 8,
    0x1c, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x1e, MP_QSTR_ticks_ms & 0xff, MP_QSTR_ticks_ms >> 8,
    0x66, 0x00, 
    0xb7, 
    0x66, 0x02, 
    0x1c, MP_QSTR_min & 0xff, MP_QSTR_min >> 8,
    0xb3, 
    0x14, 0x87, 0x68, 
    0x64, 0x02, 
    0xda, 
    0x36, 0x9a, 0x7e, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_cmd),
    MP_ROM_QSTR(MP_QSTR_is_async),
    MP_ROM_QSTR(MP_QSTR_timeout),
    MP_ROM_QSTR(MP_QSTR_retry),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 507,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send[31] = {
    0x0a, 0x00, 0x00, 0x04, 0x00, 0x02, 0x0a,
    MP_QSTR_hci_send & 0xff, MP_QSTR_hci_send >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0xc5, 0x60, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_write & 0xff, MP_QSTR_write >> 8,
    0xb1, 
    0xb2, 
    0x16, MP_QSTR_retry & 0xff, MP_QSTR_retry >> 8,
    0xb3, 
    0x66, 0x82, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_header),
    MP_ROM_QSTR(MP_QSTR_param),
    MP_ROM_QSTR(MP_QSTR_retry),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version[164] = {
    0x10, 0x00, 0x00, 0x01, 0x00, 0x00, 0x13,
    MP_QSTR_get_version & 0xff, MP_QSTR_get_version >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0xcb, 0x60, 0x27, 0x25, 0x2b, 0x2a, 0x29, 0x2b, 0x27, 0x37, 0x36, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_hci_le_read_local_version & 0xff, MP_QSTR_hci_le_read_local_version >> 8,
    0x66, 0x00, 
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb2, 
    0x1d, MP_QSTR_hci_revision & 0xff, MP_QSTR_hci_revision >> 8,
    0x14, 0x81, 0x7f, 
    0xee, 
    0xc3, 
    0xb2, 
    0x1d, MP_QSTR_lmp_pal_subversion & 0xff, MP_QSTR_lmp_pal_subversion >> 8,
    0x14, 0x81, 0x70, 
    0xee, 
    0x84, 
    0xf0, 
    0xc4, 
    0xb2, 
    0x1d, MP_QSTR_lmp_pal_subversion & 0xff, MP_QSTR_lmp_pal_subversion >> 8,
    0x8f, 
    0xee, 
    0xc5, 
    0xb5, 
    0x80, 
    0xd9, 
    0x37, 0x06, 0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x35, 0x0a, 0x80, 
    0x1c, MP_QSTR_chr & 0xff, MP_QSTR_chr >> 8,
    0x14, 0x80, 0x60, 
    0xb5, 
    0xf1, 
    0x64, 0x01, 
    0xc6, 
    0xb2, 
    0x1d, MP_QSTR_lmp_pal_subversion & 0xff, MP_QSTR_lmp_pal_subversion >> 8,
    0x14, 0x82, 0x80, 0x00, 
    0xee, 
    0x37, 0x06, 0x80, 
    0x16, MP_QSTR_dev & 0xff, MP_QSTR_dev >> 8,
    0x35, 0x03, 0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0xc7, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0x16, MP_QSTR__dot_ & 0xff, MP_QSTR__dot_ >> 8,
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0x1c, MP_QSTR_map & 0xff, MP_QSTR_map >> 8,
    0x1c, MP_QSTR_str & 0xff, MP_QSTR_str >> 8,
    0xb3, 
    0xb4, 
    0x51, 0x02, 
    0x64, 0x02, 
    0x66, 0x01, 
    0xb6, 
    0xb7, 
    0x51, 0x03, 
    0x66, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 164,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_init_IDB04A1 & 0xff, MP_QSTR_aci_gap_init_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0xe2, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_role),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1[75] = {
    0x0d, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0f,
    MP_QSTR_aci_gap_init_IDB05A1 & 0xff, MP_QSTR_aci_gap_init_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0xef, 0x20, 0x4a, 0x2a, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BBB & 0xff, MP_QSTR__lt_BBB >> 8,
    0xb1, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb2, 
    0x64, 0x01, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x64, 0x86, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_role),
    MP_ROM_QSTR(MP_QSTR_privacy_enabled),
    MP_ROM_QSTR(MP_QSTR_device_name_char_len),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_set_non_discoverable & 0xff, MP_QSTR_aci_gap_set_non_discoverable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x91, 0xfb, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable[86] = {
    0x1c, 0x00, 0x00, 0x0c, 0x00, 0x0b, 0x11,
    MP_QSTR_aci_gap_set_limited_discoverable & 0xff, MP_QSTR_aci_gap_set_limited_discoverable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x07, 0x20, 0x26, 0x77, 0x60, 0x60, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0c, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0xb8, 
    0x66, 0x02, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x66, 0x0c, 
    0xcc, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbc, 
    0x64, 0x86, 0x00, 
    0xcd, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbd, 
    0x66, 0x01, 
    0x32, 
    0xbd, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable_0 = {{&mp_type_str}, 13179, 20, (const byte*)"\x3c\x42\x48\x48\x42\x42\x42\x7b\x3a\x64\x7d\x73\x42\x7b\x3a\x64\x7d\x73\x48\x48"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable[13] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_type),
    MP_ROM_QSTR(MP_QSTR_adv_interv_min),
    MP_ROM_QSTR(MP_QSTR_adv_interv_max),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_adv_filter_policy),
    MP_ROM_QSTR(MP_QSTR_local_name_len),
    MP_ROM_QSTR(MP_QSTR_local_name),
    MP_ROM_QSTR(MP_QSTR_service_uuid_len),
    MP_ROM_QSTR(MP_QSTR_service_uuid_list),
    MP_ROM_QSTR(MP_QSTR_slave_conn_interv_min),
    MP_ROM_QSTR(MP_QSTR_slave_conn_interv_max),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 12,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable[86] = {
    0x1c, 0x00, 0x00, 0x0c, 0x00, 0x0b, 0x11,
    MP_QSTR_aci_gap_set_discoverable & 0xff, MP_QSTR_aci_gap_set_discoverable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x1e, 0x20, 0x26, 0x77, 0x60, 0x40, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0c, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0xb8, 
    0x66, 0x02, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x66, 0x0c, 
    0xcc, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_DISCOVERABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbc, 
    0x64, 0x86, 0x00, 
    0xcd, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbd, 
    0x66, 0x01, 
    0x32, 
    0xbd, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable_0 = {{&mp_type_str}, 13179, 20, (const byte*)"\x3c\x42\x48\x48\x42\x42\x42\x7b\x3a\x64\x7d\x73\x42\x7b\x3a\x64\x7d\x73\x48\x48"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable[13] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_type),
    MP_ROM_QSTR(MP_QSTR_adv_interv_min),
    MP_ROM_QSTR(MP_QSTR_adv_interv_max),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_adv_filter_policy),
    MP_ROM_QSTR(MP_QSTR_local_name_len),
    MP_ROM_QSTR(MP_QSTR_local_name),
    MP_ROM_QSTR(MP_QSTR_service_uuid_len),
    MP_ROM_QSTR(MP_QSTR_service_uuid_list),
    MP_ROM_QSTR(MP_QSTR_slave_conn_interv_min),
    MP_ROM_QSTR(MP_QSTR_slave_conn_interv_max),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 12,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1[73] = {
    0x12, 0x00, 0x00, 0x07, 0x00, 0x06, 0x0f,
    MP_QSTR_aci_gap_set_direct_connectable_IDB05A1 & 0xff, MP_QSTR_aci_gap_set_direct_connectable_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x32, 0x20, 0x72, 0x40, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BBB6sHH & 0xff, MP_QSTR__lt_BBB6sHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0x66, 0x07, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1[7] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_directed_adv_type),
    MP_ROM_QSTR(MP_QSTR_initiator_addr_type),
    MP_ROM_QSTR(MP_QSTR_initiator_addr),
    MP_ROM_QSTR(MP_QSTR_adv_interv_min),
    MP_ROM_QSTR(MP_QSTR_adv_interv_max),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 73,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1[70] = {
    0x0d, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0f,
    MP_QSTR_aci_gap_set_direct_connectable_IDB04A1 & 0xff, MP_QSTR_aci_gap_set_direct_connectable_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x41, 0x20, 0x6f, 0x20, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB6s & 0xff, MP_QSTR__lt_BB6s >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x64, 0x86, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_initiator_addr_type),
    MP_ROM_QSTR(MP_QSTR_initiator_addr),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 70,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_set_io_capability & 0xff, MP_QSTR_aci_gap_set_io_capability >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x4e, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY & 0xff, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_io_capability),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement[86] = {
    0x16, 0x00, 0x00, 0x09, 0x00, 0x08, 0x11,
    MP_QSTR_aci_gap_set_auth_requirement & 0xff, MP_QSTR_aci_gap_set_auth_requirement >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x5d, 0x20, 0x26, 0x23, 0x49, 0x2b, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x09, 
    0xb1, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb2, 
    0x64, 0x01, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb6, 
    0x64, 0x01, 
    0xb7, 
    0xb8, 
    0x66, 0x09, 
    0xc9, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb9, 
    0x64, 0x86, 0x00, 
    0xca, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xba, 
    0x66, 0x01, 
    0x32, 
    0xba, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement_0 = {{&mp_type_str}, 58116, 11, (const byte*)"\x3c\x42\x42\x31\x36\x73\x42\x42\x42\x49\x42"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement[10] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_mitm_mode),
    MP_ROM_QSTR(MP_QSTR_oob_enable),
    MP_ROM_QSTR(MP_QSTR_oob_data),
    MP_ROM_QSTR(MP_QSTR_min_encryption_key_size),
    MP_ROM_QSTR(MP_QSTR_max_encryption_key_size),
    MP_ROM_QSTR(MP_QSTR_use_fixed_pin),
    MP_ROM_QSTR(MP_QSTR_fixed_pin),
    MP_ROM_QSTR(MP_QSTR_bonding_mode),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 9,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement[74] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_aci_gap_set_author_requirement & 0xff, MP_QSTR_aci_gap_set_author_requirement >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x6c, 0x20, 0x4a, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb2, 
    0x64, 0x01, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_authorization_enable),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 74,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_pass_key_response & 0xff, MP_QSTR_aci_gap_pass_key_response >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x78, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HI & 0xff, MP_QSTR__lt_HI >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE & 0xff, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_passkey),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_authorization_response & 0xff, MP_QSTR_aci_gap_authorization_response >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x84, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE & 0xff, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_authorize),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_set_non_connectable_IDB05A1 & 0xff, MP_QSTR_aci_gap_set_non_connectable_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x91, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB & 0xff, MP_QSTR__lt_BB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_type),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_set_non_connectable_IDB04A1 & 0xff, MP_QSTR_aci_gap_set_non_connectable_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0x9e, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_type),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_set_undirected_connectable & 0xff, MP_QSTR_aci_gap_set_undirected_connectable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xab, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB & 0xff, MP_QSTR__lt_BB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_adv_filter_policy),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gap_slave_security_request & 0xff, MP_QSTR_aci_gap_slave_security_request >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xb8, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HBB & 0xff, MP_QSTR__lt_HBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST & 0xff, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_bonding),
    MP_ROM_QSTR(MP_QSTR_mitm_protection),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data[75] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_aci_gap_update_adv_data & 0xff, MP_QSTR_aci_gap_update_adv_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xc5, 0x20, 0x26, 0x4e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA & 0xff, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_len),
    MP_ROM_QSTR(MP_QSTR_adv_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_delete_ad_type & 0xff, MP_QSTR_aci_gap_delete_ad_type >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xd1, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_DELETE_AD_TYPE & 0xff, MP_QSTR_OCF_GAP_DELETE_AD_TYPE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_ad_type),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_get_security_level & 0xff, MP_QSTR_aci_gap_get_security_level >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xdd, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL & 0xff, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_configure_whitelist & 0xff, MP_QSTR_aci_gap_configure_whitelist >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xe5, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST & 0xff, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate[74] = {
    0x0e, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_terminate & 0xff, MP_QSTR_aci_gap_terminate >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xed, 0x20, 0x6e, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_TERMINATE & 0xff, MP_QSTR_OCF_GAP_TERMINATE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_reason),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 74,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_clear_security_database & 0xff, MP_QSTR_aci_gap_clear_security_database >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xa1, 0xfa, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB & 0xff, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_allow_rebond_IDB05A1 & 0xff, MP_QSTR_aci_gap_allow_rebond_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x02, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_allow_rebond_IDB04A1 & 0xff, MP_QSTR_aci_gap_allow_rebond_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x0e, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc[76] = {
    0x10, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0e,
    MP_QSTR_aci_gap_start_limited_discovery_proc & 0xff, MP_QSTR_aci_gap_start_limited_discovery_proc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x18, 0x20, 0x70, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHBB & 0xff, MP_QSTR__lt_HHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 76,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc[76] = {
    0x10, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0e,
    MP_QSTR_aci_gap_start_general_discovery_proc & 0xff, MP_QSTR_aci_gap_start_general_discovery_proc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x27, 0x20, 0x70, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHBB & 0xff, MP_QSTR__lt_HHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 76,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc[84] = {
    0x1c, 0x00, 0x00, 0x0c, 0x00, 0x0b, 0x10,
    MP_QSTR_aci_gap_start_name_discovery_proc & 0xff, MP_QSTR_aci_gap_start_name_discovery_proc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x38, 0x20, 0x26, 0x70, 0x40, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0c, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x66, 0x0c, 
    0xcc, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbc, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xcd, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbd, 
    0x66, 0x01, 
    0x32, 
    0xbd, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc_0 = {{&mp_type_str}, 18620, 13, (const byte*)"\x3c\x48\x48\x42\x36\x73\x42\x48\x48\x48\x48\x48\x48"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc[13] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_conn_min_interval),
    MP_ROM_QSTR(MP_QSTR_conn_max_interval),
    MP_ROM_QSTR(MP_QSTR_conn_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_conn_length),
    MP_ROM_QSTR(MP_QSTR_max_conn_length),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 12,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1[93] = {
    0x1c, 0x00, 0x00, 0x0c, 0x00, 0x0b, 0x11,
    MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB05A1 & 0xff, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x4c, 0x20, 0x26, 0x78, 0x60, 0x40, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0c, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xba, 
    0x87, 
    0xf3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x66, 0x0c, 
    0xcc, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbc, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xcd, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbd, 
    0x66, 0x01, 
    0x32, 
    0xbd, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1_0 = {{&mp_type_str}, 47410, 16, (const byte*)"\x3c\x48\x48\x42\x48\x48\x48\x48\x48\x48\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1[13] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_conn_min_interval),
    MP_ROM_QSTR(MP_QSTR_conn_max_interval),
    MP_ROM_QSTR(MP_QSTR_conn_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_conn_length),
    MP_ROM_QSTR(MP_QSTR_max_conn_length),
    MP_ROM_QSTR(MP_QSTR_num_whitelist_entries),
    MP_ROM_QSTR(MP_QSTR_addr_array),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 12,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1[100] = {
    0x20, 0x00, 0x00, 0x0e, 0x00, 0x0d, 0x11,
    MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB04A1 & 0xff, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x64, 0x20, 0x26, 0x73, 0x60, 0x6c, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0e, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xbc, 
    0x87, 
    0xf3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xba, 
    0x64, 0x01, 
    0xbb, 
    0xbc, 
    0xbd, 
    0x66, 0x0e, 
    0xce, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbe, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xcf, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbf, 
    0x66, 0x01, 
    0x32, 
    0xbf, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1_0 = {{&mp_type_str}, 21525, 19, (const byte*)"\x3c\x48\x48\x42\x48\x48\x48\x48\x48\x48\x42\x36\x73\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1[15] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_conn_min_interval),
    MP_ROM_QSTR(MP_QSTR_conn_max_interval),
    MP_ROM_QSTR(MP_QSTR_conn_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_conn_length),
    MP_ROM_QSTR(MP_QSTR_max_conn_length),
    MP_ROM_QSTR(MP_QSTR_use_reconn_addr),
    MP_ROM_QSTR(MP_QSTR_reconn_addr),
    MP_ROM_QSTR(MP_QSTR_num_whitelist_entries),
    MP_ROM_QSTR(MP_QSTR_addr_array),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 14,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 100,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1[83] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB05A1 & 0xff, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x7a, 0x20, 0x6d, 0x29, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BHHBB & 0xff, MP_QSTR__lt_BHHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x64, 0x01, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_type),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 83,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1[84] = {
    0x12, 0x00, 0x00, 0x07, 0x00, 0x06, 0x0f,
    MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB04A1 & 0xff, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x8a, 0x20, 0x6d, 0x4a, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BHHBB6s & 0xff, MP_QSTR__lt_BHHBB6s >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x64, 0x01, 
    0xb6, 
    0x66, 0x07, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1[7] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_type),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
    MP_ROM_QSTR(MP_QSTR_reconn_addr),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc[93] = {
    0x14, 0x00, 0x00, 0x08, 0x00, 0x07, 0x10,
    MP_QSTR_aci_gap_start_selective_conn_establish_proc & 0xff, MP_QSTR_aci_gap_start_selective_conn_establish_proc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0x9c, 0x20, 0x26, 0x4e, 0x2b, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x08, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x87, 
    0xf3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x64, 0x01, 
    0xb6, 
    0xb7, 
    0x66, 0x08, 
    0xc8, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb8, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc9, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb9, 
    0x66, 0x01, 
    0x32, 
    0xb9, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc_0 = {{&mp_type_str}, 65138, 12, (const byte*)"\x3c\x42\x48\x48\x42\x42\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc[9] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_type),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
    MP_ROM_QSTR(MP_QSTR_num_whitelist_entries),
    MP_ROM_QSTR(MP_QSTR_addr_array),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 8,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection[85] = {
    0x1c, 0x00, 0x00, 0x0c, 0x00, 0x0b, 0x11,
    MP_QSTR_aci_gap_create_connection & 0xff, MP_QSTR_aci_gap_create_connection >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xae, 0x20, 0x26, 0x70, 0x60, 0x20, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0c, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x66, 0x0c, 
    0xcc, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_CREATE_CONNECTION & 0xff, MP_QSTR_OCF_GAP_CREATE_CONNECTION >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbc, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xcd, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbd, 
    0x66, 0x01, 
    0x32, 
    0xbd, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection_0 = {{&mp_type_str}, 18620, 13, (const byte*)"\x3c\x48\x48\x42\x36\x73\x42\x48\x48\x48\x48\x48\x48"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection[13] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_peer_bdaddr),
    MP_ROM_QSTR(MP_QSTR_own_bdaddr_type),
    MP_ROM_QSTR(MP_QSTR_conn_min_interval),
    MP_ROM_QSTR(MP_QSTR_conn_max_interval),
    MP_ROM_QSTR(MP_QSTR_conn_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_conn_length),
    MP_ROM_QSTR(MP_QSTR_max_conn_length),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 12,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 85,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_terminate_gap_procedure & 0xff, MP_QSTR_aci_gap_terminate_gap_procedure >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xc0, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE & 0xff, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_procedure_code),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update[80] = {
    0x14, 0x00, 0x00, 0x08, 0x00, 0x07, 0x0f,
    MP_QSTR_aci_gap_start_connection_update & 0xff, MP_QSTR_aci_gap_start_connection_update >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xcf, 0x20, 0x73, 0x40, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHHHHH & 0xff, MP_QSTR__lt_HHHHHHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0x66, 0x08, 
    0xc8, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE & 0xff, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb8, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc9, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb9, 
    0x66, 0x01, 
    0x32, 
    0xb9, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_conn_min_interval),
    MP_ROM_QSTR(MP_QSTR_conn_max_interval),
    MP_ROM_QSTR(MP_QSTR_conn_latency),
    MP_ROM_QSTR(MP_QSTR_supervision_timeout),
    MP_ROM_QSTR(MP_QSTR_min_conn_length),
    MP_ROM_QSTR(MP_QSTR_max_conn_length),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 8,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 80,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request[80] = {
    0x0e, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR_aci_gap_send_pairing_request & 0xff, MP_QSTR_aci_gap_send_pairing_request >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xde, 0x20, 0x4a, 0x29, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb2, 
    0x64, 0x01, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST & 0xff, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_force_rebond),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 80,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gap_resolve_private_address_IDB05A1 & 0xff, MP_QSTR_aci_gap_resolve_private_address_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xeb, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_6s & 0xff, MP_QSTR__lt_6s >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_private_address),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_resolve_private_address_IDB04A1 & 0xff, MP_QSTR_aci_gap_resolve_private_address_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xb1, 0xf7, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode[86] = {
    0x16, 0x00, 0x00, 0x09, 0x00, 0x08, 0x12,
    MP_QSTR_aci_gap_set_broadcast_mode & 0xff, MP_QSTR_aci_gap_set_broadcast_mode >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x02, 0x20, 0x26, 0x26, 0x70, 0x60, 0x20, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x09, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb5, 
    0xb7, 
    0x87, 
    0xf3, 
    0x66, 0x02, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0x66, 0x09, 
    0xc9, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE & 0xff, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb9, 
    0x64, 0x86, 0x00, 
    0xca, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xba, 
    0x66, 0x01, 
    0x32, 
    0xba, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode_0 = {{&mp_type_str}, 61529, 17, (const byte*)"\x3c\x48\x48\x42\x42\x42\x7b\x3a\x64\x7d\x73\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode[10] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_adv_interv_min),
    MP_ROM_QSTR(MP_QSTR_adv_interv_max),
    MP_ROM_QSTR(MP_QSTR_adv_type),
    MP_ROM_QSTR(MP_QSTR_own_addr_type),
    MP_ROM_QSTR(MP_QSTR_adv_data_length),
    MP_ROM_QSTR(MP_QSTR_adv_data),
    MP_ROM_QSTR(MP_QSTR_num_whitelist_entries),
    MP_ROM_QSTR(MP_QSTR_addr_array),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 9,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure[83] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gap_start_observation_procedure & 0xff, MP_QSTR_aci_gap_start_observation_procedure >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x16, 0x20, 0x6d, 0x29, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHBBB & 0xff, MP_QSTR__lt_HHBBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x64, 0x01, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC & 0xff, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_scan_interval),
    MP_ROM_QSTR(MP_QSTR_scan_window),
    MP_ROM_QSTR(MP_QSTR_scan_type),
    MP_ROM_QSTR(MP_QSTR_own_address_type),
    MP_ROM_QSTR(MP_QSTR_filter_duplicates),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 83,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gap_is_device_bonded & 0xff, MP_QSTR_aci_gap_is_device_bonded >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x24, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B6s & 0xff, MP_QSTR__lt_B6s >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED & 0xff, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_peer_address_type),
    MP_ROM_QSTR(MP_QSTR_peer_address),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gap_get_bonded_devices & 0xff, MP_QSTR_aci_gap_get_bonded_devices >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x30, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES & 0xff, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_gatt_init & 0xff, MP_QSTR_aci_gatt_init >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x3c, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_INIT & 0xff, MP_QSTR_OCF_GATT_INIT >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv[92] = {
    0x0f, 0x00, 0x00, 0x05, 0x00, 0x04, 0x10,
    MP_QSTR_aci_gatt_add_serv & 0xff, MP_QSTR_aci_gatt_add_serv >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x46, 0x20, 0x2e, 0x26, 0x70, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc5, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B_brace_open__colon_d_brace_close_sBB & 0xff, MP_QSTR__lt_B_brace_open__colon_d_brace_close_sBB >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb5, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_ADD_SERV & 0xff, MP_QSTR_OCF_GATT_ADD_SERV >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x64, 0x86, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_uuid_type),
    MP_ROM_QSTR(MP_QSTR_service_uuid),
    MP_ROM_QSTR(MP_QSTR_service_type),
    MP_ROM_QSTR(MP_QSTR_max_attr_records),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 92,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service[94] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x11,
    MP_QSTR_aci_gatt_include_service & 0xff, MP_QSTR_aci_gatt_include_service >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x56, 0x20, 0x2e, 0x26, 0x71, 0x20, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb4, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc6, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_INCLUDE_SERV & 0xff, MP_QSTR_OCF_GATT_INCLUDE_SERV >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_included_start_handle),
    MP_ROM_QSTR(MP_QSTR_included_end_handle),
    MP_ROM_QSTR(MP_QSTR_included_uuid_type),
    MP_ROM_QSTR(MP_QSTR_included_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 94,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char[102] = {
    0x1a, 0x00, 0x00, 0x0a, 0x00, 0x09, 0x11,
    MP_QSTR_aci_gatt_add_char & 0xff, MP_QSTR_aci_gatt_add_char >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x68, 0x20, 0x2e, 0x26, 0x70, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb2, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xca, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0a, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xba, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb9, 
    0x64, 0x01, 
    0x66, 0x0a, 
    0xcb, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_ADD_CHAR & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbb, 
    0x64, 0x86, 0x00, 
    0xcc, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbc, 
    0x66, 0x01, 
    0x32, 
    0xbc, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_0 = {{&mp_type_str}, 34040, 14, (const byte*)"\x3c\x48\x42\x7b\x3a\x64\x7d\x73\x42\x42\x42\x42\x42\x42"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char[11] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_char_uuid_type),
    MP_ROM_QSTR(MP_QSTR_char_uuid),
    MP_ROM_QSTR(MP_QSTR_char_value_len),
    MP_ROM_QSTR(MP_QSTR_char_properties),
    MP_ROM_QSTR(MP_QSTR_sec_permissions),
    MP_ROM_QSTR(MP_QSTR_gatt_evt_mask),
    MP_ROM_QSTR(MP_QSTR_encry_key_size),
    MP_ROM_QSTR(MP_QSTR_is_variable),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 10,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 102,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc[107] = {
    0x20, 0x00, 0x00, 0x0d, 0x00, 0x0c, 0x12,
    MP_QSTR_aci_gatt_add_char_desc & 0xff, MP_QSTR_aci_gatt_add_char_desc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x7b, 0x20, 0x2e, 0x26, 0x74, 0x40, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb3, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xcd, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x0d, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xbd, 
    0xb6, 
    0x66, 0x02, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0xb9, 
    0xba, 
    0xbb, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xbc, 
    0x64, 0x01, 
    0x66, 0x0d, 
    0xce, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_ADD_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR_DESC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xbe, 
    0x64, 0x86, 0x00, 
    0xcf, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbf, 
    0x66, 0x01, 
    0x32, 
    0xbf, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc_0 = {{&mp_type_str}, 30393, 21, (const byte*)"\x3c\x48\x48\x42\x7b\x3a\x64\x7d\x73\x42\x42\x7b\x3a\x64\x7d\x73\x42\x42\x42\x42\x42"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc[14] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
    MP_ROM_QSTR(MP_QSTR_desc_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_QSTR(MP_QSTR_desc_value_max_len),
    MP_ROM_QSTR(MP_QSTR_desc_value_len),
    MP_ROM_QSTR(MP_QSTR_desc_value),
    MP_ROM_QSTR(MP_QSTR_sec_permissions),
    MP_ROM_QSTR(MP_QSTR_acc_permissions),
    MP_ROM_QSTR(MP_QSTR_gatt_evt_mask),
    MP_ROM_QSTR(MP_QSTR_encry_key_size),
    MP_ROM_QSTR(MP_QSTR_is_variable),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 13,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 107,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value[78] = {
    0x10, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gatt_update_char_value & 0xff, MP_QSTR_aci_gatt_update_char_value >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x8e, 0x20, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHBB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHBB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_UPD_CHAR_VAL & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x64, 0x86, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_serv_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
    MP_ROM_QSTR(MP_QSTR_char_val_offset),
    MP_ROM_QSTR(MP_QSTR_char_value_len),
    MP_ROM_QSTR(MP_QSTR_char_value),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gatt_del_char & 0xff, MP_QSTR_aci_gatt_del_char >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0x9b, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DEL_CHAR & 0xff, MP_QSTR_OCF_GATT_DEL_CHAR >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_serv_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_del_service & 0xff, MP_QSTR_aci_gatt_del_service >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xa7, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DEL_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_SERV >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_serv_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gatt_del_include_service & 0xff, MP_QSTR_aci_gatt_del_include_service >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xb4, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DEL_INC_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_INC_SERV >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_serv_handle),
    MP_ROM_QSTR(MP_QSTR_include_serv_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_set_event_mask & 0xff, MP_QSTR_aci_gatt_set_event_mask >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xc0, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_I & 0xff, MP_QSTR__lt_I >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GATT_SET_EVT_MASK >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_event_mask),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_exchange_configuration & 0xff, MP_QSTR_aci_gatt_exchange_configuration >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xcc, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG & 0xff, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req[69] = {
    0x0d, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_att_find_information_req & 0xff, MP_QSTR_aci_att_find_information_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xd9, 0x20, 0x6f, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_FIND_INFO_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_INFO_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x64, 0x86, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 69,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req[78] = {
    0x12, 0x00, 0x00, 0x07, 0x00, 0x06, 0x0f,
    MP_QSTR_aci_att_find_by_type_value_req & 0xff, MP_QSTR_aci_att_find_by_type_value_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xe7, 0x20, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x07, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb5, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0x66, 0x07, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req_0 = {{&mp_type_str}, 49529, 12, (const byte*)"\x3c\x48\x48\x48\x32\x73\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_QSTR(MP_QSTR_attr_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req[93] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x10,
    MP_QSTR_aci_att_read_by_type_req & 0xff, MP_QSTR_aci_att_read_by_type_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xc1, 0xf6, 0x20, 0x2e, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb4, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc6, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
    MP_ROM_QSTR(MP_QSTR_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req[93] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x10,
    MP_QSTR_aci_att_read_by_group_type_req & 0xff, MP_QSTR_aci_att_read_by_group_type_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x06, 0x20, 0x2e, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb4, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc6, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
    MP_ROM_QSTR(MP_QSTR_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req[78] = {
    0x10, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_att_prepare_write_req & 0xff, MP_QSTR_aci_att_prepare_write_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x16, 0x20, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x64, 0x86, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_value_offset),
    MP_ROM_QSTR(MP_QSTR_attr_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_att_execute_write_req & 0xff, MP_QSTR_aci_att_execute_write_req >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x23, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_execute),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_disc_all_prim_services & 0xff, MP_QSTR_aci_gatt_disc_all_prim_services >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x2f, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid[97] = {
    0x10, 0x00, 0x00, 0x04, 0x00, 0x03, 0x10,
    MP_QSTR_aci_gatt_disc_prim_service_by_uuid & 0xff, MP_QSTR_aci_gatt_disc_prim_service_by_uuid >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x3c, 0x20, 0x2e, 0x26, 0x4f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0xb2, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc4, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 97,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_find_included_services & 0xff, MP_QSTR_aci_gatt_find_included_services >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x4b, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES & 0xff, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_disc_all_charac_of_serv & 0xff, MP_QSTR_aci_gatt_disc_all_charac_of_serv >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x59, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_attr_handle),
    MP_ROM_QSTR(MP_QSTR_end_attr_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid[99] = {
    0x12, 0x00, 0x00, 0x06, 0x00, 0x05, 0x10,
    MP_QSTR_aci_gatt_disc_charac_by_uuid & 0xff, MP_QSTR_aci_gatt_disc_charac_by_uuid >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x68, 0x20, 0x2e, 0x26, 0x51, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0xb4, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc6, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
    MP_ROM_QSTR(MP_QSTR_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 99,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_disc_all_charac_descriptors & 0xff, MP_QSTR_aci_gatt_disc_all_charac_descriptors >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x77, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_char_val_handle),
    MP_ROM_QSTR(MP_QSTR_char_end_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val[74] = {
    0x0e, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gatt_read_charac_val & 0xff, MP_QSTR_aci_gatt_read_charac_val >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x84, 0x20, 0x6e, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_CHARAC_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 74,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid[93] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x10,
    MP_QSTR_aci_gatt_read_using_charac_uuid & 0xff, MP_QSTR_aci_gatt_read_using_charac_uuid >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0x93, 0x20, 0x2e, 0x26, 0x51, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0xb4, 
    0x1c, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0xd9, 
    0x37, 0x04, 0x80, 
    0x82, 
    0x35, 0x01, 0x80, 
    0x90, 
    0xc6, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID & 0xff, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_start_handle),
    MP_ROM_QSTR(MP_QSTR_end_handle),
    MP_ROM_QSTR(MP_QSTR_uuid_type),
    MP_ROM_QSTR(MP_QSTR_uuid),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_read_long_charac_val & 0xff, MP_QSTR_aci_gatt_read_long_charac_val >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xa1, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_offset),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val[84] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0f,
    MP_QSTR_aci_gatt_read_multiple_charac_val & 0xff, MP_QSTR_aci_gatt_read_multiple_charac_val >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xaf, 0x20, 0x26, 0x51, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x82, 
    0xf3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_num_handles),
    MP_ROM_QSTR(MP_QSTR_set_of_handles),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value[83] = {
    0x10, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0f,
    MP_QSTR_aci_gatt_write_charac_value & 0xff, MP_QSTR_aci_gatt_write_charac_value >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xbd, 0x20, 0x26, 0x50, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_value),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 83,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val[84] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gatt_write_long_charac_val & 0xff, MP_QSTR_aci_gatt_write_long_charac_val >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xcc, 0x20, 0x26, 0x51, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_offset),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable[84] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gatt_write_charac_reliable & 0xff, MP_QSTR_aci_gatt_write_charac_reliable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xdb, 0x20, 0x26, 0x51, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_offset),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc[84] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_gatt_write_long_charac_desc & 0xff, MP_QSTR_aci_gatt_write_long_charac_desc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xea, 0x20, 0x26, 0x51, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_offset),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc[75] = {
    0x0f, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_read_long_charac_desc & 0xff, MP_QSTR_aci_gatt_read_long_charac_desc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xd1, 0xf8, 0x20, 0x6f, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHH & 0xff, MP_QSTR__lt_HHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_offset),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor[83] = {
    0x10, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0f,
    MP_QSTR_aci_gatt_write_charac_descriptor & 0xff, MP_QSTR_aci_gatt_write_charac_descriptor >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x06, 0x20, 0x26, 0x50, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 83,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc[74] = {
    0x0e, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gatt_read_charac_desc & 0xff, MP_QSTR_aci_gatt_read_charac_desc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x13, 0x20, 0x6e, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_READ_CHAR_DESC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 74,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response[77] = {
    0x0e, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0f,
    MP_QSTR_aci_gatt_write_without_response & 0xff, MP_QSTR_aci_gatt_write_without_response >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x21, 0x20, 0x26, 0x50, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x64, 0x86, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 77,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp[77] = {
    0x0e, 0x00, 0x00, 0x05, 0x00, 0x04, 0x0f,
    MP_QSTR_aci_gatt_signed_write_without_resp & 0xff, MP_QSTR_aci_gatt_signed_write_without_resp >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x2e, 0x20, 0x26, 0x50, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_HHB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0x66, 0x05, 
    0xc5, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb5, 
    0x64, 0x86, 0x00, 
    0xc6, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb6, 
    0x66, 0x01, 
    0x32, 
    0xb6, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_val_len),
    MP_ROM_QSTR(MP_QSTR_attr_val),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 77,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_confirm_indication & 0xff, MP_QSTR_aci_gatt_confirm_indication >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x3a, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_CONFIRM_INDICATION & 0xff, MP_QSTR_OCF_GATT_CONFIRM_INDICATION >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response[84] = {
    0x12, 0x00, 0x00, 0x07, 0x00, 0x06, 0x10,
    MP_QSTR_aci_gatt_write_response & 0xff, MP_QSTR_aci_gatt_write_response >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x48, 0x20, 0x26, 0x2a, 0x4c, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x07, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb5, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb3, 
    0x64, 0x01, 
    0xb4, 
    0xb5, 
    0xb6, 
    0x66, 0x07, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_WRITE_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_RESPONSE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response_0 = {{&mp_type_str}, 7248, 11, (const byte*)"\x3c\x48\x48\x42\x42\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_write_status),
    MP_ROM_QSTR(MP_QSTR_err_code),
    MP_ROM_QSTR(MP_QSTR_att_val_len),
    MP_ROM_QSTR(MP_QSTR_att_val),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_allow_read & 0xff, MP_QSTR_aci_gatt_allow_read >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x55, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_ALLOW_READ & 0xff, MP_QSTR_OCF_GATT_ALLOW_READ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission[69] = {
    0x0d, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0e,
    MP_QSTR_aci_gatt_set_security_permission & 0xff, MP_QSTR_aci_gatt_set_security_permission >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x62, 0x20, 0x6f, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHB & 0xff, MP_QSTR__lt_HHB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc4, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION & 0xff, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb4, 
    0x64, 0x86, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb5, 
    0x66, 0x01, 
    0x32, 
    0xb5, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_security_permission),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 69,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value[78] = {
    0x12, 0x00, 0x00, 0x07, 0x00, 0x06, 0x0f,
    MP_QSTR_aci_gatt_set_desc_value & 0xff, MP_QSTR_aci_gatt_set_desc_value >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x70, 0x20, 0x26, 0x71, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x07, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb5, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0x66, 0x07, 
    0xc7, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_SET_DESC_VAL & 0xff, MP_QSTR_OCF_GATT_SET_DESC_VAL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb7, 
    0x64, 0x86, 0x00, 
    0xc8, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb8, 
    0x66, 0x01, 
    0x32, 
    0xb8, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value_0 = {{&mp_type_str}, 43280, 11, (const byte*)"\x3c\x48\x48\x48\x48\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_serv_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
    MP_ROM_QSTR(MP_QSTR_char_desc_handle),
    MP_ROM_QSTR(MP_QSTR_char_desc_val_offset),
    MP_ROM_QSTR(MP_QSTR_char_desc_value_len),
    MP_ROM_QSTR(MP_QSTR_char_desc_value),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_gatt_read_handle_value & 0xff, MP_QSTR_aci_gatt_read_handle_value >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x7d, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_H & 0xff, MP_QSTR__lt_H >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_gatt_read_handle_value_offset_IDB05A1 & 0xff, MP_QSTR_aci_gatt_read_handle_value_offset_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x8a, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_attr_handle),
    MP_ROM_QSTR(MP_QSTR_offset),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1[79] = {
    0x14, 0x00, 0x00, 0x08, 0x00, 0x07, 0x0f,
    MP_QSTR_aci_gatt_update_char_value_ext_IDB05A1 & 0xff, MP_QSTR_aci_gatt_update_char_value_ext_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0x98, 0x20, 0x26, 0x72, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x17, 0x08, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0x66, 0x08, 
    0xc8, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb8, 
    0x64, 0x86, 0x00, 
    0xc9, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb9, 
    0x66, 0x01, 
    0x32, 
    0xb9, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1_0 = {{&mp_type_str}, 46514, 12, (const byte*)"\x3c\x48\x48\x42\x48\x48\x42\x7b\x3a\x64\x7d\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1[9] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
    MP_ROM_QSTR(MP_QSTR_update_type),
    MP_ROM_QSTR(MP_QSTR_char_length),
    MP_ROM_QSTR(MP_QSTR_value_offset),
    MP_ROM_QSTR(MP_QSTR_value_length),
    MP_ROM_QSTR(MP_QSTR_value),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 8,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 79,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_get_fw_build_number & 0xff, MP_QSTR_aci_hal_get_fw_build_number >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xa9, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER & 0xff, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data[76] = {
    0x0c, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0f,
    MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xb1, 0x20, 0x26, 0x4f, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_BB_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_offset),
    MP_ROM_QSTR(MP_QSTR_length),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 76,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_hal_read_config_data & 0xff, MP_QSTR_aci_hal_read_config_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xbd, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_READ_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_READ_CONFIG_DATA >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_offset),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_hal_set_tx_power_level & 0xff, MP_QSTR_aci_hal_set_tx_power_level >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xc9, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_BB & 0xff, MP_QSTR__lt_BB >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL & 0xff, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_en_high_power),
    MP_ROM_QSTR(MP_QSTR_pa_level),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_le_tx_test_packet_number & 0xff, MP_QSTR_aci_hal_le_tx_test_packet_number >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xd5, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER & 0xff, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_device_standby & 0xff, MP_QSTR_aci_hal_device_standby >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xdd, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_DEVICE_STANDBY & 0xff, MP_QSTR_OCF_HAL_DEVICE_STANDBY >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_hal_tone_start & 0xff, MP_QSTR_aci_hal_tone_start >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xe5, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_TONE_START & 0xff, MP_QSTR_OCF_HAL_TONE_START >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_rf_channel),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_tone_stop & 0xff, MP_QSTR_aci_hal_tone_stop >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xf1, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_TONE_STOP & 0xff, MP_QSTR_OCF_HAL_TONE_STOP >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_get_link_status & 0xff, MP_QSTR_aci_hal_get_link_status >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xe1, 0xf9, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_GET_LINK_STATUS & 0xff, MP_QSTR_OCF_HAL_GET_LINK_STATUS >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_hal_get_anchor_period & 0xff, MP_QSTR_aci_hal_get_anchor_period >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x01, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD & 0xff, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request[78] = {
    0x11, 0x00, 0x00, 0x06, 0x00, 0x05, 0x0f,
    MP_QSTR_aci_l2cap_connection_parameter_update_request & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_request >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x0f, 0x20, 0x71, 0x20, 0x7d, 0x40, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHHH & 0xff, MP_QSTR__lt_HHHHH >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0x66, 0x06, 
    0xc6, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb6, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x64, 0x88, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0xb7, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_interval_min),
    MP_ROM_QSTR(MP_QSTR_interval_max),
    MP_ROM_QSTR(MP_QSTR_slave_latency),
    MP_ROM_QSTR(MP_QSTR_timeout_multiplier),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1[81] = {
    0x19, 0x00, 0x00, 0x0a, 0x00, 0x09, 0x0f,
    MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB05A1 & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB05A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x20, 0x20, 0x71, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHHHHHBB & 0xff, MP_QSTR__lt_HHHHHHHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0xb7, 
    0xb8, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb9, 
    0x64, 0x01, 
    0x66, 0x0a, 
    0xca, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xba, 
    0x64, 0x86, 0x00, 
    0xcb, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xbb, 
    0x66, 0x01, 
    0x32, 
    0xbb, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1[10] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_interval_min),
    MP_ROM_QSTR(MP_QSTR_interval_max),
    MP_ROM_QSTR(MP_QSTR_slave_latency),
    MP_ROM_QSTR(MP_QSTR_timeout_multiplier),
    MP_ROM_QSTR(MP_QSTR_min_ce_length),
    MP_ROM_QSTR(MP_QSTR_max_ce_length),
    MP_ROM_QSTR(MP_QSTR_id_),
    MP_ROM_QSTR(MP_QSTR_accept),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 10,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 81,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1[79] = {
    0x15, 0x00, 0x00, 0x08, 0x00, 0x07, 0x0f,
    MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB04A1 & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB04A1 >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x2f, 0x20, 0x6f, 0x29, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_HHHHHBB & 0xff, MP_QSTR__lt_HHHHHBB >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0xb4, 
    0xb5, 
    0xb6, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb7, 
    0x64, 0x01, 
    0x66, 0x08, 
    0xc8, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb8, 
    0x64, 0x86, 0x00, 
    0xc9, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb9, 
    0x66, 0x01, 
    0x32, 
    0xb9, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1[8] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_conn_handle),
    MP_ROM_QSTR(MP_QSTR_interval_min),
    MP_ROM_QSTR(MP_QSTR_interval_max),
    MP_ROM_QSTR(MP_QSTR_slave_latency),
    MP_ROM_QSTR(MP_QSTR_timeout_multiplier),
    MP_ROM_QSTR(MP_QSTR_id_),
    MP_ROM_QSTR(MP_QSTR_accept),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1 = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 8,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 79,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_updater_start & 0xff, MP_QSTR_aci_updater_start >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x40, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_START & 0xff, MP_QSTR_OCF_UPDATER_START >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_updater_reboot & 0xff, MP_QSTR_aci_updater_reboot >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x48, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_REBOOT & 0xff, MP_QSTR_OCF_UPDATER_REBOOT >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_get_updater_version & 0xff, MP_QSTR_aci_get_updater_version >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x50, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GET_UPDATER_VERSION & 0xff, MP_QSTR_OCF_GET_UPDATER_VERSION >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_get_updater_buffer_size & 0xff, MP_QSTR_aci_get_updater_buffer_size >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x58, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_GET_UPDATER_BUFSIZE & 0xff, MP_QSTR_OCF_GET_UPDATER_BUFSIZE >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_erase_blue_flag & 0xff, MP_QSTR_aci_erase_blue_flag >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x60, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_reset_blue_flag & 0xff, MP_QSTR_aci_reset_blue_flag >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x68, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector[67] = {
    0x0b, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0e,
    MP_QSTR_aci_updater_erase_sector & 0xff, MP_QSTR_aci_updater_erase_sector >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x70, 0x20, 0x6d, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_I & 0xff, MP_QSTR__lt_I >> 8,
    0xb1, 
    0x66, 0x02, 
    0xc2, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_ERASE_SECTOR & 0xff, MP_QSTR_OCF_UPDATER_ERASE_SECTOR >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb2, 
    0x64, 0x86, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb3, 
    0x66, 0x01, 
    0x32, 
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block[76] = {
    0x0c, 0x00, 0x00, 0x04, 0x00, 0x03, 0x0f,
    MP_QSTR_aci_updater_program_data_block & 0xff, MP_QSTR_aci_updater_program_data_block >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x7c, 0x20, 0x26, 0x4f, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_IH_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_IH_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x66, 0x01, 
    0xb1, 
    0xb2, 
    0xb3, 
    0x66, 0x04, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
    MP_ROM_QSTR(MP_QSTR_data_len),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 76,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_updater_read_data_block & 0xff, MP_QSTR_aci_updater_read_data_block >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x88, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_IH & 0xff, MP_QSTR__lt_IH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
    MP_ROM_QSTR(MP_QSTR_data_len),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc[68] = {
    0x0c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR_aci_updater_calc_crc & 0xff, MP_QSTR_aci_updater_calc_crc >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0x94, 0x20, 0x6e, 0x77, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_IH & 0xff, MP_QSTR__lt_IH >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x03, 
    0xc3, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_CALC_CRC & 0xff, MP_QSTR_OCF_UPDATER_CALC_CRC >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x64, 0x86, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0xb4, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
    MP_ROM_QSTR(MP_QSTR_num_sectors),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version[48] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0c,
    MP_QSTR_aci_updater_hw_version & 0xff, MP_QSTR_aci_updater_hw_version >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0xf1, 0xa0, 0x20, 0x73, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0x1c, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_OCF_UPDATER_HW_VERSION & 0xff, MP_QSTR_OCF_UPDATER_HW_VERSION >> 8,
    0x64, 0x84, 0x00, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS[1792] = {
    0x0d, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x1a,
    MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x8d, 0xaa, 0x60, 0x40, 0x40, 0x36, 0x3d, 0x34, 0x7c, 0x80, 0x25, 0x85, 0x09, 0x65, 0x20, 0x65, 0x20, 0x65, 0x20, 0x85, 0x07, 0x8c, 0x1d, 0x65, 0x65, 0x65, 0x8c, 0x1e, 0x89, 0x2d, 0x85, 0x10, 0x8e, 0x1e, 0x8d, 0x2d, 0x6b, 0x60, 0x85, 0x17, 0x89, 0x0c, 0x8b, 0x0d, 0x85, 0x08, 0x75, 0x80, 0x14, 0x75, 0x80, 0x13, 0x8f, 0x10, 0x8c, 0x0e, 0x89, 0x0c, 0x71, 0x80, 0x0e, 0x8a, 0x0d, 0x8a, 0x0c, 0x8a, 0x0c, 0x8a, 0x0d, 0x89, 0x0d, 0x8a, 0x0d, 0x8b, 0x0e, 0x8b, 0x0c, 0x89, 0x0c, 0x85, 0x08, 0x85, 0x08, 0x8a, 0x0d, 0x85, 0x08, 0x89, 0x0c, 0x85, 0x08, 0x8c, 0x0f, 0x8c, 0x0f, 0x74, 0x80, 0x11, 0x74, 0x80, 0x14, 0x77, 0x80, 0x16, 0x8d, 0x10, 0x8f, 0x11, 0x70, 0x80, 0x0e, 0x74, 0x80, 0x13, 0x89, 0x0c, 0x8f, 0x12, 0x8a, 0x0d, 0x8a, 0x0c, 0x85, 0x08, 0x72, 0x80, 0x12, 0x8d, 0x10, 0x8b, 0x0c, 0x85, 0x0c, 0x85, 0x08, 0x8d, 0x10, 0x8e, 0x11, 0x72, 0x80, 0x0f, 0x76, 0x80, 0x12, 0x8e, 0x0f, 0x8a, 0x0c, 0x89, 0x0c, 0x8a, 0x0d, 0x89, 0x0c, 0x89, 0x0c, 0x8b, 0x0d, 0x70, 0x80, 0x0c, 0x8e, 0x10, 0x8e, 0x10, 0x8e, 0x0f, 0x8a, 0x0c, 0x89, 0x0c, 0x8c, 0x0f, 0x8b, 0x0e, 0x8b, 0x0e, 0x8e, 0x10, 0x8c, 0x0e, 0x8b, 0x0d, 0x8f, 0x0f, 0x8c, 0x0e, 0x8d, 0x0e, 0x8e, 0x0e, 0x8f, 0x0f, 0x8f, 0x0f, 0x8f, 0x0f, 0x8c, 0x0e, 0x8e, 0x0e, 0x8b, 0x0d, 0x8e, 0x0d, 0x8e, 0x0d, 0x8a, 0x0c, 0x70, 0x80, 0x0c, 0x8a, 0x0c, 0x8c, 0x0d, 0x70, 0x80, 0x0c, 0x8a, 0x0c, 0x8b, 0x0d, 0x71, 0x80, 0x10, 0x86, 0x08, 0x8d, 0x0c, 0x8a, 0x0c, 0x8b, 0x0c, 0x86, 0x08, 0x86, 0x08, 0x8a, 0x0c, 0x86, 0x08, 0x86, 0x08, 0x86, 0x0c, 0x8e, 0x10, 0x72, 0x80, 0x0d, 0x70, 0x80, 0x10, 0x86, 0x08, 0x86, 0x08, 0x86, 0x08, 0x86, 0x08, 0x86, 0x08, 0x86, 0x08, 0x8a, 0x0c, 0x8d, 0x0c, 0x8b, 0x0c, 0x8b, 0x0c, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1e, MP_QSTR_SPI & 0xff, MP_QSTR_SPI >> 8,
    0x82, 
    0x16, MP_QSTR_baudrate & 0xff, MP_QSTR_baudrate >> 8,
    0x14, 0x83, 0xe8, 0xa4, 0x00, 
    0x16, MP_QSTR_polarity & 0xff, MP_QSTR_polarity >> 8,
    0x80, 
    0x66, 0x84, 0x01, 
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1e, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x16, MP_QSTR_Y3 & 0xff, MP_QSTR_Y3 >> 8,
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_IN & 0xff, MP_QSTR_IN >> 8,
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_PULL_DOWN & 0xff, MP_QSTR_PULL_DOWN >> 8,
    0x66, 0x03, 
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1e, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x16, MP_QSTR_Y4 & 0xff, MP_QSTR_Y4 >> 8,
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_OUT_PP & 0xff, MP_QSTR_OUT_PP >> 8,
    0x66, 0x02, 
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1e, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x16, MP_QSTR_Y5 & 0xff, MP_QSTR_Y5 >> 8,
    0x1b, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x1d, MP_QSTR_Pin & 0xff, MP_QSTR_Pin >> 8,
    0x1d, MP_QSTR_OUT_PP & 0xff, MP_QSTR_OUT_PP >> 8,
    0x66, 0x02, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x2f, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x30, 
    0x24, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x60, 0x31, 
    0x24, MP_QSTR_any & 0xff, MP_QSTR_any >> 8,
    0x60, 0x32, 
    0x24, MP_QSTR_set_spi_irq_as_output & 0xff, MP_QSTR_set_spi_irq_as_output >> 8,
    0x60, 0x33, 
    0x24, MP_QSTR_set_spi_irq_as_input & 0xff, MP_QSTR_set_spi_irq_as_input >> 8,
    0x60, 0x34, 
    0x24, MP_QSTR_hw_bootloader & 0xff, MP_QSTR_hw_bootloader >> 8,
    0x11, 
    0x14, 0x87, 0x68, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x35, 
    0x24, MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    0x60, 0x36, 
    0x24, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x60, 0x37, 
    0x24, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x60, 0x38, 
    0x24, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0x1b, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x85, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x39, 
    0x24, MP_QSTR_read & 0xff, MP_QSTR_read >> 8,
    0x85, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x3a, 
    0x24, MP_QSTR_write & 0xff, MP_QSTR_write >> 8,
    0x60, 0x3b, 
    0x24, MP_QSTR_hci_verify & 0xff, MP_QSTR_hci_verify >> 8,
    0x80, 
    0x80, 
    0x14, 0x87, 0x68, 
    0x85, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x3c, 
    0x24, MP_QSTR_hci_wait_event & 0xff, MP_QSTR_hci_wait_event >> 8,
    0x10, 
    0x14, 0x87, 0x68, 
    0x85, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x3d, 
    0x24, MP_QSTR_hci_send_cmd & 0xff, MP_QSTR_hci_send_cmd >> 8,
    0x17, 0x00, 
    0x85, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x3e, 
    0x24, MP_QSTR_hci_send & 0xff, MP_QSTR_hci_send >> 8,
    0x60, 0x3f, 
    0x24, MP_QSTR_get_version & 0xff, MP_QSTR_get_version >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x40, 
    0x24, MP_QSTR_aci_gap_init_IDB04A1 & 0xff, MP_QSTR_aci_gap_init_IDB04A1 >> 8,
    0x80, 
    0x10, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x41, 
    0x24, MP_QSTR_aci_gap_init_IDB05A1 & 0xff, MP_QSTR_aci_gap_init_IDB05A1 >> 8,
    0x60, 0x42, 
    0x24, MP_QSTR_aci_gap_set_non_discoverable & 0xff, MP_QSTR_aci_gap_set_non_discoverable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x01, 
    0x80, 
    0x17, 0x02, 
    0x80, 
    0x80, 
    0x50, 0x0b, 
    0x18, 
    0x61, 0x43, 
    0x24, MP_QSTR_aci_gap_set_limited_discoverable & 0xff, MP_QSTR_aci_gap_set_limited_discoverable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x03, 
    0x80, 
    0x17, 0x04, 
    0x80, 
    0x80, 
    0x50, 0x0b, 
    0x18, 
    0x61, 0x44, 
    0x24, MP_QSTR_aci_gap_set_discoverable & 0xff, MP_QSTR_aci_gap_set_discoverable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x05, 
    0x80, 
    0x80, 
    0x50, 0x06, 
    0x18, 
    0x61, 0x45, 
    0x24, MP_QSTR_aci_gap_set_direct_connectable_IDB05A1 & 0xff, MP_QSTR_aci_gap_set_direct_connectable_IDB05A1 >> 8,
    0x80, 
    0x80, 
    0x17, 0x06, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x46, 
    0x24, MP_QSTR_aci_gap_set_direct_connectable_IDB04A1 & 0xff, MP_QSTR_aci_gap_set_direct_connectable_IDB04A1 >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x47, 
    0x24, MP_QSTR_aci_gap_set_io_capability & 0xff, MP_QSTR_aci_gap_set_io_capability >> 8,
    0x80, 
    0x10, 
    0x17, 0x07, 
    0x80, 
    0x80, 
    0x10, 
    0x80, 
    0x80, 
    0x50, 0x08, 
    0x18, 
    0x61, 0x48, 
    0x24, MP_QSTR_aci_gap_set_auth_requirement & 0xff, MP_QSTR_aci_gap_set_auth_requirement >> 8,
    0x80, 
    0x10, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x49, 
    0x24, MP_QSTR_aci_gap_set_author_requirement & 0xff, MP_QSTR_aci_gap_set_author_requirement >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x4a, 
    0x24, MP_QSTR_aci_gap_pass_key_response & 0xff, MP_QSTR_aci_gap_pass_key_response >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x4b, 
    0x24, MP_QSTR_aci_gap_authorization_response & 0xff, MP_QSTR_aci_gap_authorization_response >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x4c, 
    0x24, MP_QSTR_aci_gap_set_non_connectable_IDB05A1 & 0xff, MP_QSTR_aci_gap_set_non_connectable_IDB05A1 >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x4d, 
    0x24, MP_QSTR_aci_gap_set_non_connectable_IDB04A1 & 0xff, MP_QSTR_aci_gap_set_non_connectable_IDB04A1 >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x4e, 
    0x24, MP_QSTR_aci_gap_set_undirected_connectable & 0xff, MP_QSTR_aci_gap_set_undirected_connectable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x4f, 
    0x24, MP_QSTR_aci_gap_slave_security_request & 0xff, MP_QSTR_aci_gap_slave_security_request >> 8,
    0x80, 
    0x17, 0x08, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x50, 
    0x24, MP_QSTR_aci_gap_update_adv_data & 0xff, MP_QSTR_aci_gap_update_adv_data >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x51, 
    0x24, MP_QSTR_aci_gap_delete_ad_type & 0xff, MP_QSTR_aci_gap_delete_ad_type >> 8,
    0x60, 0x52, 
    0x24, MP_QSTR_aci_gap_get_security_level & 0xff, MP_QSTR_aci_gap_get_security_level >> 8,
    0x60, 0x53, 
    0x24, MP_QSTR_aci_gap_configure_whitelist & 0xff, MP_QSTR_aci_gap_configure_whitelist >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x54, 
    0x24, MP_QSTR_aci_gap_terminate & 0xff, MP_QSTR_aci_gap_terminate >> 8,
    0x60, 0x55, 
    0x24, MP_QSTR_aci_gap_clear_security_database & 0xff, MP_QSTR_aci_gap_clear_security_database >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x56, 
    0x24, MP_QSTR_aci_gap_allow_rebond_IDB05A1 & 0xff, MP_QSTR_aci_gap_allow_rebond_IDB05A1 >> 8,
    0x60, 0x57, 
    0x24, MP_QSTR_aci_gap_allow_rebond_IDB04A1 & 0xff, MP_QSTR_aci_gap_allow_rebond_IDB04A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x58, 
    0x24, MP_QSTR_aci_gap_start_limited_discovery_proc & 0xff, MP_QSTR_aci_gap_start_limited_discovery_proc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x59, 
    0x24, MP_QSTR_aci_gap_start_general_discovery_proc & 0xff, MP_QSTR_aci_gap_start_general_discovery_proc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x09, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x0b, 
    0x18, 
    0x61, 0x5a, 
    0x24, MP_QSTR_aci_gap_start_name_discovery_proc & 0xff, MP_QSTR_aci_gap_start_name_discovery_proc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x0a, 
    0x50, 0x0b, 
    0x18, 
    0x61, 0x5b, 
    0x24, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB05A1 & 0xff, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB05A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x17, 0x0b, 
    0x80, 
    0x17, 0x0c, 
    0x50, 0x0d, 
    0x18, 
    0x61, 0x5c, 
    0x24, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB04A1 & 0xff, MP_QSTR_aci_gap_start_auto_conn_establish_proc_IDB04A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x5d, 
    0x24, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB05A1 & 0xff, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB05A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x17, 0x0d, 
    0x50, 0x06, 
    0x18, 
    0x61, 0x5e, 
    0x24, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB04A1 & 0xff, MP_QSTR_aci_gap_start_general_conn_establish_proc_IDB04A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x80, 
    0x17, 0x0e, 
    0x50, 0x07, 
    0x18, 
    0x61, 0x5f, 
    0x24, MP_QSTR_aci_gap_start_selective_conn_establish_proc & 0xff, MP_QSTR_aci_gap_start_selective_conn_establish_proc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x0f, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x0b, 
    0x18, 
    0x61, 0x60, 
    0x24, MP_QSTR_aci_gap_create_connection & 0xff, MP_QSTR_aci_gap_create_connection >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x61, 
    0x24, MP_QSTR_aci_gap_terminate_gap_procedure & 0xff, MP_QSTR_aci_gap_terminate_gap_procedure >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x07, 
    0x18, 
    0x61, 0x62, 
    0x24, MP_QSTR_aci_gap_start_connection_update & 0xff, MP_QSTR_aci_gap_start_connection_update >> 8,
    0x80, 
    0x10, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x63, 
    0x24, MP_QSTR_aci_gap_send_pairing_request & 0xff, MP_QSTR_aci_gap_send_pairing_request >> 8,
    0x17, 0x10, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x64, 
    0x24, MP_QSTR_aci_gap_resolve_private_address_IDB05A1 & 0xff, MP_QSTR_aci_gap_resolve_private_address_IDB05A1 >> 8,
    0x60, 0x65, 
    0x24, MP_QSTR_aci_gap_resolve_private_address_IDB04A1 & 0xff, MP_QSTR_aci_gap_resolve_private_address_IDB04A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x11, 
    0x80, 
    0x17, 0x12, 
    0x50, 0x08, 
    0x18, 
    0x61, 0x66, 
    0x24, MP_QSTR_aci_gap_set_broadcast_mode & 0xff, MP_QSTR_aci_gap_set_broadcast_mode >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x67, 
    0x24, MP_QSTR_aci_gap_start_observation_procedure & 0xff, MP_QSTR_aci_gap_start_observation_procedure >> 8,
    0x80, 
    0x17, 0x13, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x68, 
    0x24, MP_QSTR_aci_gap_is_device_bonded & 0xff, MP_QSTR_aci_gap_is_device_bonded >> 8,
    0x60, 0x69, 
    0x24, MP_QSTR_aci_gap_get_bonded_devices & 0xff, MP_QSTR_aci_gap_get_bonded_devices >> 8,
    0x60, 0x6a, 
    0x24, MP_QSTR_aci_gatt_init & 0xff, MP_QSTR_aci_gatt_init >> 8,
    0x80, 
    0x17, 0x14, 
    0x80, 
    0x80, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x6b, 
    0x24, MP_QSTR_aci_gatt_add_serv & 0xff, MP_QSTR_aci_gatt_add_serv >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x15, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x6c, 
    0x24, MP_QSTR_aci_gatt_include_service & 0xff, MP_QSTR_aci_gatt_include_service >> 8,
    0x80, 
    0x80, 
    0x17, 0x16, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x09, 
    0x18, 
    0x61, 0x6d, 
    0x24, MP_QSTR_aci_gatt_add_char & 0xff, MP_QSTR_aci_gatt_add_char >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x17, 
    0x80, 
    0x80, 
    0x17, 0x18, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x0c, 
    0x18, 
    0x61, 0x6e, 
    0x24, MP_QSTR_aci_gatt_add_char_desc & 0xff, MP_QSTR_aci_gatt_add_char_desc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x19, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x6f, 
    0x24, MP_QSTR_aci_gatt_update_char_value & 0xff, MP_QSTR_aci_gatt_update_char_value >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x70, 
    0x24, MP_QSTR_aci_gatt_del_char & 0xff, MP_QSTR_aci_gatt_del_char >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x71, 
    0x24, MP_QSTR_aci_gatt_del_service & 0xff, MP_QSTR_aci_gatt_del_service >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x72, 
    0x24, MP_QSTR_aci_gatt_del_include_service & 0xff, MP_QSTR_aci_gatt_del_include_service >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x73, 
    0x24, MP_QSTR_aci_gatt_set_event_mask & 0xff, MP_QSTR_aci_gatt_set_event_mask >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x74, 
    0x24, MP_QSTR_aci_gatt_exchange_configuration & 0xff, MP_QSTR_aci_gatt_exchange_configuration >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x75, 
    0x24, MP_QSTR_aci_att_find_information_req & 0xff, MP_QSTR_aci_att_find_information_req >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x1a, 
    0x80, 
    0x17, 0x1b, 
    0x50, 0x06, 
    0x18, 
    0x61, 0x76, 
    0x24, MP_QSTR_aci_att_find_by_type_value_req & 0xff, MP_QSTR_aci_att_find_by_type_value_req >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x1c, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x77, 
    0x24, MP_QSTR_aci_att_read_by_type_req & 0xff, MP_QSTR_aci_att_read_by_type_req >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x1d, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x78, 
    0x24, MP_QSTR_aci_att_read_by_group_type_req & 0xff, MP_QSTR_aci_att_read_by_group_type_req >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x1e, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x79, 
    0x24, MP_QSTR_aci_att_prepare_write_req & 0xff, MP_QSTR_aci_att_prepare_write_req >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x7a, 
    0x24, MP_QSTR_aci_att_execute_write_req & 0xff, MP_QSTR_aci_att_execute_write_req >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x7b, 
    0x24, MP_QSTR_aci_gatt_disc_all_prim_services & 0xff, MP_QSTR_aci_gatt_disc_all_prim_services >> 8,
    0x80, 
    0x80, 
    0x17, 0x1f, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x7c, 
    0x24, MP_QSTR_aci_gatt_disc_prim_service_by_uuid & 0xff, MP_QSTR_aci_gatt_disc_prim_service_by_uuid >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x7d, 
    0x24, MP_QSTR_aci_gatt_find_included_services & 0xff, MP_QSTR_aci_gatt_find_included_services >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x7e, 
    0x24, MP_QSTR_aci_gatt_disc_all_charac_of_serv & 0xff, MP_QSTR_aci_gatt_disc_all_charac_of_serv >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x20, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x7f, 
    0x24, MP_QSTR_aci_gatt_disc_charac_by_uuid & 0xff, MP_QSTR_aci_gatt_disc_charac_by_uuid >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x00, 
    0x24, MP_QSTR_aci_gatt_disc_all_charac_descriptors & 0xff, MP_QSTR_aci_gatt_disc_all_charac_descriptors >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x01, 
    0x24, MP_QSTR_aci_gatt_read_charac_val & 0xff, MP_QSTR_aci_gatt_read_charac_val >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x21, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x81, 0x02, 
    0x24, MP_QSTR_aci_gatt_read_using_charac_uuid & 0xff, MP_QSTR_aci_gatt_read_using_charac_uuid >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x03, 
    0x24, MP_QSTR_aci_gatt_read_long_charac_val & 0xff, MP_QSTR_aci_gatt_read_long_charac_val >> 8,
    0x80, 
    0x80, 
    0x17, 0x22, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x04, 
    0x24, MP_QSTR_aci_gatt_read_multiple_charac_val & 0xff, MP_QSTR_aci_gatt_read_multiple_charac_val >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x23, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x81, 0x05, 
    0x24, MP_QSTR_aci_gatt_write_charac_value & 0xff, MP_QSTR_aci_gatt_write_charac_value >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x24, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x81, 0x06, 
    0x24, MP_QSTR_aci_gatt_write_long_charac_val & 0xff, MP_QSTR_aci_gatt_write_long_charac_val >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x25, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x81, 0x07, 
    0x24, MP_QSTR_aci_gatt_write_charac_reliable & 0xff, MP_QSTR_aci_gatt_write_charac_reliable >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x26, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x81, 0x08, 
    0x24, MP_QSTR_aci_gatt_write_long_charac_desc & 0xff, MP_QSTR_aci_gatt_write_long_charac_desc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x09, 
    0x24, MP_QSTR_aci_gatt_read_long_charac_desc & 0xff, MP_QSTR_aci_gatt_read_long_charac_desc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x27, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x81, 0x0a, 
    0x24, MP_QSTR_aci_gatt_write_charac_descriptor & 0xff, MP_QSTR_aci_gatt_write_charac_descriptor >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x0b, 
    0x24, MP_QSTR_aci_gatt_read_charac_desc & 0xff, MP_QSTR_aci_gatt_read_charac_desc >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x28, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x81, 0x0c, 
    0x24, MP_QSTR_aci_gatt_write_without_response & 0xff, MP_QSTR_aci_gatt_write_without_response >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x29, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x81, 0x0d, 
    0x24, MP_QSTR_aci_gatt_signed_write_without_resp & 0xff, MP_QSTR_aci_gatt_signed_write_without_resp >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x0e, 
    0x24, MP_QSTR_aci_gatt_confirm_indication & 0xff, MP_QSTR_aci_gatt_confirm_indication >> 8,
    0x80, 
    0x80, 
    0x10, 
    0x80, 
    0x80, 
    0x17, 0x2a, 
    0x50, 0x06, 
    0x18, 
    0x61, 0x81, 0x0f, 
    0x24, MP_QSTR_aci_gatt_write_response & 0xff, MP_QSTR_aci_gatt_write_response >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x10, 
    0x24, MP_QSTR_aci_gatt_allow_read & 0xff, MP_QSTR_aci_gatt_allow_read >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x11, 
    0x24, MP_QSTR_aci_gatt_set_security_permission & 0xff, MP_QSTR_aci_gatt_set_security_permission >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x2b, 
    0x50, 0x06, 
    0x18, 
    0x61, 0x81, 0x12, 
    0x24, MP_QSTR_aci_gatt_set_desc_value & 0xff, MP_QSTR_aci_gatt_set_desc_value >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x13, 
    0x24, MP_QSTR_aci_gatt_read_handle_value & 0xff, MP_QSTR_aci_gatt_read_handle_value >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x14, 
    0x24, MP_QSTR_aci_gatt_read_handle_value_offset_IDB05A1 & 0xff, MP_QSTR_aci_gatt_read_handle_value_offset_IDB05A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x2c, 
    0x50, 0x07, 
    0x18, 
    0x61, 0x81, 0x15, 
    0x24, MP_QSTR_aci_gatt_update_char_value_ext_IDB05A1 & 0xff, MP_QSTR_aci_gatt_update_char_value_ext_IDB05A1 >> 8,
    0x60, 0x81, 0x16, 
    0x24, MP_QSTR_aci_hal_get_fw_build_number & 0xff, MP_QSTR_aci_hal_get_fw_build_number >> 8,
    0x80, 
    0x80, 
    0x17, 0x2d, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x17, 
    0x24, MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x18, 
    0x24, MP_QSTR_aci_hal_read_config_data & 0xff, MP_QSTR_aci_hal_read_config_data >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x19, 
    0x24, MP_QSTR_aci_hal_set_tx_power_level & 0xff, MP_QSTR_aci_hal_set_tx_power_level >> 8,
    0x60, 0x81, 0x1a, 
    0x24, MP_QSTR_aci_hal_le_tx_test_packet_number & 0xff, MP_QSTR_aci_hal_le_tx_test_packet_number >> 8,
    0x60, 0x81, 0x1b, 
    0x24, MP_QSTR_aci_hal_device_standby & 0xff, MP_QSTR_aci_hal_device_standby >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x1c, 
    0x24, MP_QSTR_aci_hal_tone_start & 0xff, MP_QSTR_aci_hal_tone_start >> 8,
    0x60, 0x81, 0x1d, 
    0x24, MP_QSTR_aci_hal_tone_stop & 0xff, MP_QSTR_aci_hal_tone_stop >> 8,
    0x60, 0x81, 0x1e, 
    0x24, MP_QSTR_aci_hal_get_link_status & 0xff, MP_QSTR_aci_hal_get_link_status >> 8,
    0x60, 0x81, 0x1f, 
    0x24, MP_QSTR_aci_hal_get_anchor_period & 0xff, MP_QSTR_aci_hal_get_anchor_period >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x81, 0x20, 
    0x24, MP_QSTR_aci_l2cap_connection_parameter_update_request & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_request >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x09, 
    0x18, 
    0x61, 0x81, 0x21, 
    0x24, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB05A1 & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB05A1 >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x80, 
    0x10, 
    0x50, 0x07, 
    0x18, 
    0x61, 0x81, 0x22, 
    0x24, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB04A1 & 0xff, MP_QSTR_aci_l2cap_connection_parameter_update_response_IDB04A1 >> 8,
    0x60, 0x81, 0x23, 
    0x24, MP_QSTR_aci_updater_start & 0xff, MP_QSTR_aci_updater_start >> 8,
    0x60, 0x81, 0x24, 
    0x24, MP_QSTR_aci_updater_reboot & 0xff, MP_QSTR_aci_updater_reboot >> 8,
    0x60, 0x81, 0x25, 
    0x24, MP_QSTR_aci_get_updater_version & 0xff, MP_QSTR_aci_get_updater_version >> 8,
    0x60, 0x81, 0x26, 
    0x24, MP_QSTR_aci_get_updater_buffer_size & 0xff, MP_QSTR_aci_get_updater_buffer_size >> 8,
    0x60, 0x81, 0x27, 
    0x24, MP_QSTR_aci_erase_blue_flag & 0xff, MP_QSTR_aci_erase_blue_flag >> 8,
    0x60, 0x81, 0x28, 
    0x24, MP_QSTR_aci_reset_blue_flag & 0xff, MP_QSTR_aci_reset_blue_flag >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x81, 0x29, 
    0x24, MP_QSTR_aci_updater_erase_sector & 0xff, MP_QSTR_aci_updater_erase_sector >> 8,
    0x80, 
    0x80, 
    0x17, 0x2e, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x81, 0x2a, 
    0x24, MP_QSTR_aci_updater_program_data_block & 0xff, MP_QSTR_aci_updater_program_data_block >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x2b, 
    0x24, MP_QSTR_aci_updater_read_data_block & 0xff, MP_QSTR_aci_updater_read_data_block >> 8,
    0x80, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x81, 0x2c, 
    0x24, MP_QSTR_aci_updater_calc_crc & 0xff, MP_QSTR_aci_updater_calc_crc >> 8,
    0x60, 0x81, 0x2d, 
    0x24, MP_QSTR_aci_updater_hw_version & 0xff, MP_QSTR_aci_updater_hw_version >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_1 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_2 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_3 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_4 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_5 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_6 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_7 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_8 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_9 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_10 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_11 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_12 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_13 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_14 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_15 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_16 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_17 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_18 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_19 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_20 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_21 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_22 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_23 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_24 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_25 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_26 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_27 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_28 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_29 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_30 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_31 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_32 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_33 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_34 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_35 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_36 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_37 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_38 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_39 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_40 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_41 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_42 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_43 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_44 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_45 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_46 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS[174] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_24),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_25),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_26),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_27),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_28),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_29),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_30),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_31),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_32),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_33),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_34),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_35),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_36),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_37),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_38),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_39),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_40),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_41),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_42),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_43),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_44),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_45),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_46),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_reset),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_any),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_output),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_set_spi_irq_as_input),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hw_bootloader),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_run),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___start__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___stop__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS___process__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_read),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_write),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_verify),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_wait_event),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send_cmd),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_hci_send),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_get_version),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_init_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_discoverable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_limited_discoverable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_discoverable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_direct_connectable_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_io_capability),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_auth_requirement),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_author_requirement),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_pass_key_response),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_authorization_response),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_non_connectable_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_undirected_connectable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_slave_security_request),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_update_adv_data),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_delete_ad_type),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_security_level),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_configure_whitelist),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_clear_security_database),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_allow_rebond_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_limited_discovery_proc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_discovery_proc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_name_discovery_proc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_auto_conn_establish_proc_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_general_conn_establish_proc_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_selective_conn_establish_proc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_create_connection),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_terminate_gap_procedure),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_connection_update),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_send_pairing_request),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_resolve_private_address_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_set_broadcast_mode),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_start_observation_procedure),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_is_device_bonded),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gap_get_bonded_devices),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_init),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_serv),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_include_service),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_add_char_desc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_char),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_service),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_del_include_service),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_event_mask),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_exchange_configuration),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_information_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_find_by_type_value_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_type_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_read_by_group_type_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_prepare_write_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_att_execute_write_req),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_prim_services),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_prim_service_by_uuid),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_find_included_services),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_of_serv),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_charac_by_uuid),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_disc_all_charac_descriptors),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_val),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_using_charac_uuid),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_val),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_multiple_charac_val),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_value),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_val),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_reliable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_long_charac_desc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_long_charac_desc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_charac_descriptor),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_charac_desc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_without_response),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_signed_write_without_resp),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_confirm_indication),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_write_response),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_allow_read),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_security_permission),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_set_desc_value),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_read_handle_value_offset_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_gatt_update_char_value_ext_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_fw_build_number),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_write_config_data),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_read_config_data),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_set_tx_power_level),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_le_tx_test_packet_number),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_device_standby),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_start),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_tone_stop),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_link_status),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_hal_get_anchor_period),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_request),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB05A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_l2cap_connection_parameter_update_response_IDB04A1),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_start),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_reboot),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_version),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_get_updater_buffer_size),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_erase_blue_flag),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_reset_blue_flag),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_erase_sector),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_program_data_block),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_read_data_block),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_calc_crc),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS_aci_updater_hw_version),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 1792,
        .n_obj = 47,
        .n_raw_code = 127,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py, scope bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_[1399] = {
    0x68, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_bluenrg_ms_dot_py >> 8,
    0x21, 0x28, 0x28, 0x28, 0x1f, 0x23, 0x59, 0x79, 0x20, 0x1f, 0x6c, 0x60, 0x1f, 0x63, 0x40, 0x1f, 0x1f, 0x71, 0x80, 0x07, 0x70, 0x70, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x1f, 0x84, 0x69, 0x70, 0x70, 0x40, 0x4a, 0x4c, 0x24, 0x44, 0x8e, 0x0b, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x24, MP_QSTR_machine & 0xff, MP_QSTR_machine >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x24, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x16, MP_QSTR_heap_lock & 0xff, MP_QSTR_heap_lock >> 8,
    0x16, MP_QSTR_heap_unlock & 0xff, MP_QSTR_heap_unlock >> 8,
    0x50, 0x03, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x69, MP_QSTR_heap_lock & 0xff, MP_QSTR_heap_lock >> 8,
    0x24, MP_QSTR_heap_lock & 0xff, MP_QSTR_heap_lock >> 8,
    0x69, MP_QSTR_heap_unlock & 0xff, MP_QSTR_heap_unlock >> 8,
    0x24, MP_QSTR_heap_unlock & 0xff, MP_QSTR_heap_unlock >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x16, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_modules_dot_base_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_modules_dot_base_hci >> 8,
    0x69, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x24, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x69, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x24, MP_QSTR_HardwareException & 0xff, MP_QSTR_HardwareException >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x16, MP_QSTR_HCI_EVENT_HDR_SIZE & 0xff, MP_QSTR_HCI_EVENT_HDR_SIZE >> 8,
    0x16, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x16, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x50, 0x04, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x24, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x69, MP_QSTR_HCI_EVENT_HDR_SIZE & 0xff, MP_QSTR_HCI_EVENT_HDR_SIZE >> 8,
    0x24, MP_QSTR_HCI_EVENT_HDR_SIZE & 0xff, MP_QSTR_HCI_EVENT_HDR_SIZE >> 8,
    0x69, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x24, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x69, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x24, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0x16, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x50, 0x03, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_cmd & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_cmd >> 8,
    0x69, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x24, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x69, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0x24, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0x69, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x24, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_EVT_CMD_COMPLETE & 0xff, MP_QSTR_EVT_CMD_COMPLETE >> 8,
    0x16, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x16, MP_QSTR_EVT_HARDWARE_ERROR & 0xff, MP_QSTR_EVT_HARDWARE_ERROR >> 8,
    0x16, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0x16, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0x16, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x16, MP_QSTR_HCI_EVENTS & 0xff, MP_QSTR_HCI_EVENTS >> 8,
    0x16, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x50, 0x08, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_event & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_event >> 8,
    0x69, MP_QSTR_EVT_CMD_COMPLETE & 0xff, MP_QSTR_EVT_CMD_COMPLETE >> 8,
    0x24, MP_QSTR_EVT_CMD_COMPLETE & 0xff, MP_QSTR_EVT_CMD_COMPLETE >> 8,
    0x69, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x24, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x69, MP_QSTR_EVT_HARDWARE_ERROR & 0xff, MP_QSTR_EVT_HARDWARE_ERROR >> 8,
    0x24, MP_QSTR_EVT_HARDWARE_ERROR & 0xff, MP_QSTR_EVT_HARDWARE_ERROR >> 8,
    0x69, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0x24, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0x69, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0x24, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0x69, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x24, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x69, MP_QSTR_HCI_EVENTS & 0xff, MP_QSTR_HCI_EVENTS >> 8,
    0x24, MP_QSTR_HCI_EVENTS & 0xff, MP_QSTR_HCI_EVENTS >> 8,
    0x69, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x24, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_status & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_status >> 8,
    0x69, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0x24, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_uart & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_uart >> 8,
    0x69, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x24, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_VENDOR_COMMANDS & 0xff, MP_QSTR_HCI_VENDOR_COMMANDS >> 8,
    0x16, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ >> 8,
    0x16, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ >> 8,
    0x16, MP_QSTR_OCF_ATT_FIND_INFO_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_INFO_REQ >> 8,
    0x16, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ >> 8,
    0x16, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ >> 8,
    0x16, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ >> 8,
    0x16, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x16, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE & 0xff, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE >> 8,
    0x16, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB & 0xff, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB >> 8,
    0x16, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST & 0xff, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST >> 8,
    0x16, MP_QSTR_OCF_GAP_CREATE_CONNECTION & 0xff, MP_QSTR_OCF_GAP_CREATE_CONNECTION >> 8,
    0x16, MP_QSTR_OCF_GAP_DELETE_AD_TYPE & 0xff, MP_QSTR_OCF_GAP_DELETE_AD_TYPE >> 8,
    0x16, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES & 0xff, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES >> 8,
    0x16, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL & 0xff, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL >> 8,
    0x16, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x16, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED & 0xff, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED >> 8,
    0x16, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE & 0xff, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE >> 8,
    0x16, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x16, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST & 0xff, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE & 0xff, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_DISCOVERABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY & 0xff, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE >> 8,
    0x16, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST & 0xff, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST >> 8,
    0x16, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE & 0xff, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE >> 8,
    0x16, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC & 0xff, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC >> 8,
    0x16, MP_QSTR_OCF_GAP_TERMINATE & 0xff, MP_QSTR_OCF_GAP_TERMINATE >> 8,
    0x16, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE & 0xff, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE >> 8,
    0x16, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA & 0xff, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA >> 8,
    0x16, MP_QSTR_OCF_GATT_ADD_CHAR & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR >> 8,
    0x16, MP_QSTR_OCF_GATT_ADD_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR_DESC >> 8,
    0x16, MP_QSTR_OCF_GATT_ADD_SERV & 0xff, MP_QSTR_OCF_GATT_ADD_SERV >> 8,
    0x16, MP_QSTR_OCF_GATT_ALLOW_READ & 0xff, MP_QSTR_OCF_GATT_ALLOW_READ >> 8,
    0x16, MP_QSTR_OCF_GATT_CONFIRM_INDICATION & 0xff, MP_QSTR_OCF_GATT_CONFIRM_INDICATION >> 8,
    0x16, MP_QSTR_OCF_GATT_DEL_CHAR & 0xff, MP_QSTR_OCF_GATT_DEL_CHAR >> 8,
    0x16, MP_QSTR_OCF_GATT_DEL_INC_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_INC_SERV >> 8,
    0x16, MP_QSTR_OCF_GATT_DEL_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_SERV >> 8,
    0x16, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS >> 8,
    0x16, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV >> 8,
    0x16, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES >> 8,
    0x16, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID >> 8,
    0x16, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID >> 8,
    0x16, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG & 0xff, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG >> 8,
    0x16, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES & 0xff, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES >> 8,
    0x16, MP_QSTR_OCF_GATT_INCLUDE_SERV & 0xff, MP_QSTR_OCF_GATT_INCLUDE_SERV >> 8,
    0x16, MP_QSTR_OCF_GATT_INIT & 0xff, MP_QSTR_OCF_GATT_INIT >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_READ_CHAR_DESC >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_CHARAC_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID & 0xff, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID >> 8,
    0x16, MP_QSTR_OCF_GATT_SET_DESC_VAL & 0xff, MP_QSTR_OCF_GATT_SET_DESC_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GATT_SET_EVT_MASK >> 8,
    0x16, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION & 0xff, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION >> 8,
    0x16, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE >> 8,
    0x16, MP_QSTR_OCF_GATT_UPD_CHAR_VAL & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_RESPONSE >> 8,
    0x16, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE >> 8,
    0x16, MP_QSTR_OCF_GET_UPDATER_BUFSIZE & 0xff, MP_QSTR_OCF_GET_UPDATER_BUFSIZE >> 8,
    0x16, MP_QSTR_OCF_GET_UPDATER_VERSION & 0xff, MP_QSTR_OCF_GET_UPDATER_VERSION >> 8,
    0x16, MP_QSTR_OCF_HAL_DEVICE_STANDBY & 0xff, MP_QSTR_OCF_HAL_DEVICE_STANDBY >> 8,
    0x16, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD & 0xff, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD >> 8,
    0x16, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER & 0xff, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER >> 8,
    0x16, MP_QSTR_OCF_HAL_GET_LINK_STATUS & 0xff, MP_QSTR_OCF_HAL_GET_LINK_STATUS >> 8,
    0x16, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER & 0xff, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER >> 8,
    0x16, MP_QSTR_OCF_HAL_READ_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_READ_CONFIG_DATA >> 8,
    0x16, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL & 0xff, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL >> 8,
    0x16, MP_QSTR_OCF_HAL_TONE_START & 0xff, MP_QSTR_OCF_HAL_TONE_START >> 8,
    0x16, MP_QSTR_OCF_HAL_TONE_STOP & 0xff, MP_QSTR_OCF_HAL_TONE_STOP >> 8,
    0x16, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA >> 8,
    0x16, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ >> 8,
    0x16, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x16, MP_QSTR_OCF_UPDATER_CALC_CRC & 0xff, MP_QSTR_OCF_UPDATER_CALC_CRC >> 8,
    0x16, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG >> 8,
    0x16, MP_QSTR_OCF_UPDATER_ERASE_SECTOR & 0xff, MP_QSTR_OCF_UPDATER_ERASE_SECTOR >> 8,
    0x16, MP_QSTR_OCF_UPDATER_HW_VERSION & 0xff, MP_QSTR_OCF_UPDATER_HW_VERSION >> 8,
    0x16, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK >> 8,
    0x16, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK >> 8,
    0x16, MP_QSTR_OCF_UPDATER_REBOOT & 0xff, MP_QSTR_OCF_UPDATER_REBOOT >> 8,
    0x16, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG >> 8,
    0x16, MP_QSTR_OCF_UPDATER_START & 0xff, MP_QSTR_OCF_UPDATER_START >> 8,
    0x50, 0x67, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_cmd & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_cmd >> 8,
    0x69, MP_QSTR_HCI_VENDOR_COMMANDS & 0xff, MP_QSTR_HCI_VENDOR_COMMANDS >> 8,
    0x24, MP_QSTR_HCI_VENDOR_COMMANDS & 0xff, MP_QSTR_HCI_VENDOR_COMMANDS >> 8,
    0x69, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ >> 8,
    0x69, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ >> 8,
    0x69, MP_QSTR_OCF_ATT_FIND_INFO_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_INFO_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_FIND_INFO_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_INFO_REQ >> 8,
    0x69, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ >> 8,
    0x69, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ >> 8,
    0x69, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ >> 8,
    0x24, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ >> 8,
    0x69, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x24, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x69, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE & 0xff, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE >> 8,
    0x24, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE & 0xff, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE >> 8,
    0x69, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB & 0xff, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB >> 8,
    0x24, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB & 0xff, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB >> 8,
    0x69, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST & 0xff, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST >> 8,
    0x24, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST & 0xff, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST >> 8,
    0x69, MP_QSTR_OCF_GAP_CREATE_CONNECTION & 0xff, MP_QSTR_OCF_GAP_CREATE_CONNECTION >> 8,
    0x24, MP_QSTR_OCF_GAP_CREATE_CONNECTION & 0xff, MP_QSTR_OCF_GAP_CREATE_CONNECTION >> 8,
    0x69, MP_QSTR_OCF_GAP_DELETE_AD_TYPE & 0xff, MP_QSTR_OCF_GAP_DELETE_AD_TYPE >> 8,
    0x24, MP_QSTR_OCF_GAP_DELETE_AD_TYPE & 0xff, MP_QSTR_OCF_GAP_DELETE_AD_TYPE >> 8,
    0x69, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES & 0xff, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES >> 8,
    0x24, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES & 0xff, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES >> 8,
    0x69, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL & 0xff, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL >> 8,
    0x24, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL & 0xff, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL >> 8,
    0x69, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x24, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x69, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED & 0xff, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED >> 8,
    0x24, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED & 0xff, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED >> 8,
    0x69, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE & 0xff, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE >> 8,
    0x24, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE & 0xff, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE >> 8,
    0x69, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x24, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x69, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST & 0xff, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST >> 8,
    0x24, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST & 0xff, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE & 0xff, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE & 0xff, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_DISCOVERABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_DISCOVERABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY & 0xff, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY & 0xff, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE >> 8,
    0x24, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE >> 8,
    0x69, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST & 0xff, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST >> 8,
    0x24, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST & 0xff, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST >> 8,
    0x69, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE & 0xff, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE >> 8,
    0x24, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE & 0xff, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE >> 8,
    0x69, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC & 0xff, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC & 0xff, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC >> 8,
    0x24, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC >> 8,
    0x69, MP_QSTR_OCF_GAP_TERMINATE & 0xff, MP_QSTR_OCF_GAP_TERMINATE >> 8,
    0x24, MP_QSTR_OCF_GAP_TERMINATE & 0xff, MP_QSTR_OCF_GAP_TERMINATE >> 8,
    0x69, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE & 0xff, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE >> 8,
    0x24, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE & 0xff, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE >> 8,
    0x69, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA & 0xff, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA >> 8,
    0x24, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA & 0xff, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA >> 8,
    0x69, MP_QSTR_OCF_GATT_ADD_CHAR & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR >> 8,
    0x24, MP_QSTR_OCF_GATT_ADD_CHAR & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR >> 8,
    0x69, MP_QSTR_OCF_GATT_ADD_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR_DESC >> 8,
    0x24, MP_QSTR_OCF_GATT_ADD_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR_DESC >> 8,
    0x69, MP_QSTR_OCF_GATT_ADD_SERV & 0xff, MP_QSTR_OCF_GATT_ADD_SERV >> 8,
    0x24, MP_QSTR_OCF_GATT_ADD_SERV & 0xff, MP_QSTR_OCF_GATT_ADD_SERV >> 8,
    0x69, MP_QSTR_OCF_GATT_ALLOW_READ & 0xff, MP_QSTR_OCF_GATT_ALLOW_READ >> 8,
    0x24, MP_QSTR_OCF_GATT_ALLOW_READ & 0xff, MP_QSTR_OCF_GATT_ALLOW_READ >> 8,
    0x69, MP_QSTR_OCF_GATT_CONFIRM_INDICATION & 0xff, MP_QSTR_OCF_GATT_CONFIRM_INDICATION >> 8,
    0x24, MP_QSTR_OCF_GATT_CONFIRM_INDICATION & 0xff, MP_QSTR_OCF_GATT_CONFIRM_INDICATION >> 8,
    0x69, MP_QSTR_OCF_GATT_DEL_CHAR & 0xff, MP_QSTR_OCF_GATT_DEL_CHAR >> 8,
    0x24, MP_QSTR_OCF_GATT_DEL_CHAR & 0xff, MP_QSTR_OCF_GATT_DEL_CHAR >> 8,
    0x69, MP_QSTR_OCF_GATT_DEL_INC_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_INC_SERV >> 8,
    0x24, MP_QSTR_OCF_GATT_DEL_INC_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_INC_SERV >> 8,
    0x69, MP_QSTR_OCF_GATT_DEL_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_SERV >> 8,
    0x24, MP_QSTR_OCF_GATT_DEL_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_SERV >> 8,
    0x69, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS >> 8,
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS >> 8,
    0x69, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV >> 8,
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV >> 8,
    0x69, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES >> 8,
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES >> 8,
    0x69, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID >> 8,
    0x24, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID >> 8,
    0x69, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID >> 8,
    0x24, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID >> 8,
    0x69, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG & 0xff, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG >> 8,
    0x24, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG & 0xff, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG >> 8,
    0x69, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES & 0xff, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES >> 8,
    0x24, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES & 0xff, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES >> 8,
    0x69, MP_QSTR_OCF_GATT_INCLUDE_SERV & 0xff, MP_QSTR_OCF_GATT_INCLUDE_SERV >> 8,
    0x24, MP_QSTR_OCF_GATT_INCLUDE_SERV & 0xff, MP_QSTR_OCF_GATT_INCLUDE_SERV >> 8,
    0x69, MP_QSTR_OCF_GATT_INIT & 0xff, MP_QSTR_OCF_GATT_INIT >> 8,
    0x24, MP_QSTR_OCF_GATT_INIT & 0xff, MP_QSTR_OCF_GATT_INIT >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_READ_CHAR_DESC >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_READ_CHAR_DESC >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_CHARAC_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_CHARAC_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID & 0xff, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID >> 8,
    0x24, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID & 0xff, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID >> 8,
    0x69, MP_QSTR_OCF_GATT_SET_DESC_VAL & 0xff, MP_QSTR_OCF_GATT_SET_DESC_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_SET_DESC_VAL & 0xff, MP_QSTR_OCF_GATT_SET_DESC_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GATT_SET_EVT_MASK >> 8,
    0x24, MP_QSTR_OCF_GATT_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GATT_SET_EVT_MASK >> 8,
    0x69, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION & 0xff, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION >> 8,
    0x24, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION & 0xff, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION >> 8,
    0x69, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE >> 8,
    0x24, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE >> 8,
    0x69, MP_QSTR_OCF_GATT_UPD_CHAR_VAL & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_UPD_CHAR_VAL & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT >> 8,
    0x24, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_RESPONSE >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_RESPONSE >> 8,
    0x69, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE >> 8,
    0x24, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE >> 8,
    0x69, MP_QSTR_OCF_GET_UPDATER_BUFSIZE & 0xff, MP_QSTR_OCF_GET_UPDATER_BUFSIZE >> 8,
    0x24, MP_QSTR_OCF_GET_UPDATER_BUFSIZE & 0xff, MP_QSTR_OCF_GET_UPDATER_BUFSIZE >> 8,
    0x69, MP_QSTR_OCF_GET_UPDATER_VERSION & 0xff, MP_QSTR_OCF_GET_UPDATER_VERSION >> 8,
    0x24, MP_QSTR_OCF_GET_UPDATER_VERSION & 0xff, MP_QSTR_OCF_GET_UPDATER_VERSION >> 8,
    0x69, MP_QSTR_OCF_HAL_DEVICE_STANDBY & 0xff, MP_QSTR_OCF_HAL_DEVICE_STANDBY >> 8,
    0x24, MP_QSTR_OCF_HAL_DEVICE_STANDBY & 0xff, MP_QSTR_OCF_HAL_DEVICE_STANDBY >> 8,
    0x69, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD & 0xff, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD >> 8,
    0x24, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD & 0xff, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD >> 8,
    0x69, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER & 0xff, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER >> 8,
    0x24, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER & 0xff, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER >> 8,
    0x69, MP_QSTR_OCF_HAL_GET_LINK_STATUS & 0xff, MP_QSTR_OCF_HAL_GET_LINK_STATUS >> 8,
    0x24, MP_QSTR_OCF_HAL_GET_LINK_STATUS & 0xff, MP_QSTR_OCF_HAL_GET_LINK_STATUS >> 8,
    0x69, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER & 0xff, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER >> 8,
    0x24, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER & 0xff, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER >> 8,
    0x69, MP_QSTR_OCF_HAL_READ_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_READ_CONFIG_DATA >> 8,
    0x24, MP_QSTR_OCF_HAL_READ_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_READ_CONFIG_DATA >> 8,
    0x69, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL & 0xff, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL >> 8,
    0x24, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL & 0xff, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL >> 8,
    0x69, MP_QSTR_OCF_HAL_TONE_START & 0xff, MP_QSTR_OCF_HAL_TONE_START >> 8,
    0x24, MP_QSTR_OCF_HAL_TONE_START & 0xff, MP_QSTR_OCF_HAL_TONE_START >> 8,
    0x69, MP_QSTR_OCF_HAL_TONE_STOP & 0xff, MP_QSTR_OCF_HAL_TONE_STOP >> 8,
    0x24, MP_QSTR_OCF_HAL_TONE_STOP & 0xff, MP_QSTR_OCF_HAL_TONE_STOP >> 8,
    0x69, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA >> 8,
    0x24, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA >> 8,
    0x69, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ >> 8,
    0x24, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ >> 8,
    0x69, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x24, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x69, MP_QSTR_OCF_UPDATER_CALC_CRC & 0xff, MP_QSTR_OCF_UPDATER_CALC_CRC >> 8,
    0x24, MP_QSTR_OCF_UPDATER_CALC_CRC & 0xff, MP_QSTR_OCF_UPDATER_CALC_CRC >> 8,
    0x69, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG >> 8,
    0x24, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG >> 8,
    0x69, MP_QSTR_OCF_UPDATER_ERASE_SECTOR & 0xff, MP_QSTR_OCF_UPDATER_ERASE_SECTOR >> 8,
    0x24, MP_QSTR_OCF_UPDATER_ERASE_SECTOR & 0xff, MP_QSTR_OCF_UPDATER_ERASE_SECTOR >> 8,
    0x69, MP_QSTR_OCF_UPDATER_HW_VERSION & 0xff, MP_QSTR_OCF_UPDATER_HW_VERSION >> 8,
    0x24, MP_QSTR_OCF_UPDATER_HW_VERSION & 0xff, MP_QSTR_OCF_UPDATER_HW_VERSION >> 8,
    0x69, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK >> 8,
    0x24, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK >> 8,
    0x69, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK >> 8,
    0x24, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK >> 8,
    0x69, MP_QSTR_OCF_UPDATER_REBOOT & 0xff, MP_QSTR_OCF_UPDATER_REBOOT >> 8,
    0x24, MP_QSTR_OCF_UPDATER_REBOOT & 0xff, MP_QSTR_OCF_UPDATER_REBOOT >> 8,
    0x69, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG >> 8,
    0x24, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG >> 8,
    0x69, MP_QSTR_OCF_UPDATER_START & 0xff, MP_QSTR_OCF_UPDATER_START >> 8,
    0x24, MP_QSTR_OCF_UPDATER_START & 0xff, MP_QSTR_OCF_UPDATER_START >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_constant & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_constant >> 8,
    0x69, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0x24, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_event & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms_dot_event >> 8,
    0x69, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x24, MP_QSTR_ST_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_ST_HCI_VENDOR_EVENTS >> 8,
    0x32, 
    0x1b, MP_QSTR_HCI_VENDOR_COMMANDS & 0xff, MP_QSTR_HCI_VENDOR_COMMANDS >> 8,
    0x1b, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0x1b, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x27, 
    0x1b, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x1e, MP_QSTR_update & 0xff, MP_QSTR_update >> 8,
    0x1b, MP_QSTR_ST_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_ST_HCI_VENDOR_EVENTS >> 8,
    0x66, 0x01, 
    0x32, 
    0x80, 
    0x24, MP_QSTR_HCI_PCK_TYPE_OFFSET & 0xff, MP_QSTR_HCI_PCK_TYPE_OFFSET >> 8,
    0x82, 
    0x24, MP_QSTR_EVENT_PARAMETER_TOT_LEN_OFFSET & 0xff, MP_QSTR_EVENT_PARAMETER_TOT_LEN_OFFSET >> 8,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_CSContext & 0xff, MP_QSTR_CSContext >> 8,
    0x20, 
    0x60, 0x01, 
    0x16, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x1b, MP_QSTR_BaseHCI & 0xff, MP_QSTR_BaseHCI >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_[2] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__CSContext),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt__BlueNRG_MS),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 1399,
        .n_obj = 0,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/__init__.py, scope bluetooth_low_energy_modules_st_microelectronics___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__[35] = {
    0x07, 0x00, 0x03, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x81, 0x0a, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0xb1, 
    0xb2, 
    0x67, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 35,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__[33] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x81, 0x0d, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 33,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__[33] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x81, 0x10, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 33,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__[34] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x81, 0x13, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_event),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 34,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF[55] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0e,
    MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x6d, 0x40, 0x60, 0x20, 0x65, 0x65, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF[4] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___start__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___stop__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF___process__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 55,
        .n_obj = 0,
        .n_raw_code = 4,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py, scope bluetooth_low_energy_modules_st_microelectronics_spbtle_rf_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_[48] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash_st_microelectronics_slash_spbtle_rf_dot_py >> 8,
    0x21, 0x70, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_bluenrg_ms & 0xff, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_bluenrg_ms >> 8,
    0x69, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x24, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x1b, MP_QSTR_BlueNRG_MS & 0xff, MP_QSTR_BlueNRG_MS >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt__SPBTLE_RF),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/modules/__init__.py, scope bluetooth_low_energy_modules___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_modules___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_modules_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_modules_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_modules___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_modules___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/central.py, scope bluetooth_low_energy_api_central_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_central__lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_central_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_central_dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_central__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_central__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/delegate.py, scope bluetooth_low_energy_api_delegate_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_delegate__lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_delegate_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_delegate_dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_delegate__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_delegate__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__[170] = {
    0x07, 0x00, 0x00, 0x02, 0x00, 0x00, 0x12,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x81, 0x09, 0x31, 0x55, 0x29, 0x2a, 0x32, 0x23, 0x25, 0x6f, 0x32, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_str & 0xff, MP_QSTR_str >> 8,
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x37, 0x15, 0x80, 
    0x1c, MP_QSTR_str & 0xff, MP_QSTR_str >> 8,
    0xb1, 
    0x64, 0x01, 
    0x1e, MP_QSTR_replace & 0xff, MP_QSTR_replace >> 8,
    0x16, MP_QSTR__hyphen_ & 0xff, MP_QSTR__hyphen_ >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x66, 0x02, 
    0xc1, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0xb1, 
    0x64, 0x01, 
    0xb0, 
    0x26, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x82, 
    0x90, 
    0x50, 0x02, 
    0xdd, 
    0xd3, 
    0x37, 0x17, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x1c, MP_QSTR_reversed & 0xff, MP_QSTR_reversed >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x64, 0x01, 
    0xb0, 
    0x26, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x82, 
    0xd9, 
    0x37, 0x06, 0x80, 
    0x1c, MP_QSTR_UUID_16_BIT & 0xff, MP_QSTR_UUID_16_BIT >> 8,
    0x35, 0x03, 0x80, 
    0x1c, MP_QSTR_UUID_128_BIT & 0xff, MP_QSTR_UUID_128_BIT >> 8,
    0xb0, 
    0x26, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init___0 = {{&mp_type_str}, 39244, 34, (const byte*)"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44\x20\x6f\x72\x20\x73\x74\x72\x2e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init___1 = {{&mp_type_str}, 43472, 42, (const byte*)"\x55\x55\x49\x44\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x32\x20\x6f\x72\x20\x31\x36\x20\x62\x79\x74\x65\x73\x2c\x20\x67\x6f\x74\x20\x7b\x3a\x64\x7d\x20\x62\x79\x74\x65\x73"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_value),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init___1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 170,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__[39] = {
    0x06, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0b,
    MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x81, 0x18, 0x26, 0x27, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x16, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x84, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__[106] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x81, 0x1e, 0x34, 0x20, 0x80, 0x08, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x1c, MP_QSTR_reversed & 0xff, MP_QSTR_reversed >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x64, 0x01, 
    0x64, 0x01, 
    0xc1, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x90, 
    0xd9, 
    0x37, 0x2a, 0x80, 
    0x17, 0x01, 
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0xb1, 
    0x80, 
    0x88, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x88, 
    0x8c, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x8c, 
    0x90, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x90, 
    0x94, 
    0x58, 0x02, 
    0x21, 
    0xb1, 
    0x94, 
    0xa0, 
    0x58, 0x02, 
    0x21, 
    0x51, 0x05, 
    0x66, 0x01, 
    0x35, 0x01, 0x80, 
    0xb1, 
    0x1e, MP_QSTR_decode & 0xff, MP_QSTR_decode >> 8,
    0x16, MP_QSTR_ascii & 0xff, MP_QSTR_ascii >> 8,
    0x66, 0x01, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str___0 = {{&mp_type_bytes}, 46472, 1, (const byte*)"\x2d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 106,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__[31] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___eq__ & 0xff, MP_QSTR___eq__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x81, 0x2c, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0xb1, 
    0x64, 0x01, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0xd9, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_other),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___hash__ & 0xff, MP_QSTR___hash__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x81, 0x2f, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_hash & 0xff, MP_QSTR_hash >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid__lt_module_gt__UUID
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID[63] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11,
    MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x6d, 0x60, 0x40, 0x85, 0x0f, 0x65, 0x60, 0x85, 0x0e, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___eq__ & 0xff, MP_QSTR___eq__ >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR___hash__ & 0xff, MP_QSTR___hash__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID[5] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___properties__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___eq__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID___hash__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt__UUID,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 63,
        .n_obj = 0,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/uuid.py, scope bluetooth_low_energy_api_uuid_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt_[95] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0d,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_uuid_dot_py >> 8,
    0x21, 0x2a, 0x30, 0x59, 0x8e, 0x2c, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x51, 0x01, 
    0x24, MP_QSTR___all__ & 0xff, MP_QSTR___all__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_uuid__lt_module_gt__UUID),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_uuid__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_uuid__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_uuid__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 95,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__[182] = {
    0x0f, 0x00, 0x00, 0x07, 0x00, 0x05, 0x1b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x0f, 0x2c, 0x29, 0x2c, 0x29, 0x2c, 0x29, 0x2c, 0x49, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x24, 0x26, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x07, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb3, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x08, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x09, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb5, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x0a, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR_props & 0xff, MP_QSTR_props >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR_perms & 0xff, MP_QSTR_perms >> 8,
    0xb5, 
    0xb0, 
    0x26, MP_QSTR_mask & 0xff, MP_QSTR_mask >> 8,
    0x51, 0x00, 
    0xb0, 
    0x26, MP_QSTR_descriptors & 0xff, MP_QSTR_descriptors >> 8,
    0xb6, 
    0x37, 0x11, 0x80, 
    0xb6, 
    0x47, 
    0x43, 0x0c, 0x00, 
    0xc7, 
    0xb0, 
    0x1e, MP_QSTR_add_descriptor & 0xff, MP_QSTR_add_descriptor >> 8,
    0xb7, 
    0x66, 0x01, 
    0x32, 
    0x35, 0xf1, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___0 = {{&mp_type_str}, 12012, 25, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___1 = {{&mp_type_str}, 36465, 25, (const byte*)"\x70\x72\x6f\x70\x73\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___2 = {{&mp_type_str}, 23910, 25, (const byte*)"\x70\x65\x72\x6d\x73\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___3 = {{&mp_type_str}, 47979, 24, (const byte*)"\x6d\x61\x73\x6b\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__[11] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_QSTR(MP_QSTR_char_value_len),
    MP_ROM_QSTR(MP_QSTR_props),
    MP_ROM_QSTR(MP_QSTR_perms),
    MP_ROM_QSTR(MP_QSTR_mask),
    MP_ROM_QSTR(MP_QSTR_descriptors),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init___3),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 182,
        .n_obj = 4,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__[111] = {
    0x16, 0x00, 0x00, 0x03, 0x00, 0x02, 0x13,
    MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x25, 0x25, 0x25, 0x26, 0x27, 0x2a, 0x2a, 0x27, 0x27, 0x27, 0x27, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x16, MP_QSTR_char_uuid_type & 0xff, MP_QSTR_char_uuid_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x16, MP_QSTR_char_uuid & 0xff, MP_QSTR_char_uuid >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x16, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x16, MP_QSTR_char_properties & 0xff, MP_QSTR_char_properties >> 8,
    0xb0, 
    0x1d, MP_QSTR_props & 0xff, MP_QSTR_props >> 8,
    0x16, MP_QSTR_sec_permissions & 0xff, MP_QSTR_sec_permissions >> 8,
    0xb0, 
    0x1d, MP_QSTR_perms & 0xff, MP_QSTR_perms >> 8,
    0x16, MP_QSTR_gatt_evt_mask & 0xff, MP_QSTR_gatt_evt_mask >> 8,
    0xb0, 
    0x1d, MP_QSTR_mask & 0xff, MP_QSTR_mask >> 8,
    0x16, MP_QSTR_encry_key_size & 0xff, MP_QSTR_encry_key_size >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MAX_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MAX_ENCRY_KEY_SIZE >> 8,
    0x16, MP_QSTR_is_variable & 0xff, MP_QSTR_is_variable >> 8,
    0x12, 
    0x64, 0x92, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_char_value_len),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 111,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str___<genexpr>
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_[67] = {
    0x0e, 0x00, 0x04, 0x02, 0x00, 0x00, 0x0a,
    MP_QSTR__lt_genexpr_gt_ & 0xff, MP_QSTR__lt_genexpr_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x8c, 0x39, 0x27, 0x00, 0x00, 0xff,
    0x18, 
    0xb1, 
    0x18, 
    0x18, 
    0x43, 0x29, 0x00, 
    0x59, 0x02, 
    0xc2, 
    0xc3, 
    0x16, MP_QSTR__brace_open__bang_s_brace_close__brace_open__colon_s_brace_close_ & 0xff, MP_QSTR__brace_open__bang_s_brace_close__brace_open__colon_s_brace_close_ >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0xb2, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0x1a, 0x00, 
    0x64, 0x01, 
    0x81, 
    0xf2, 
    0xd7, 
    0x37, 0x06, 0x80, 
    0x16, MP_QSTR__comma__space_ & 0xff, MP_QSTR__comma__space_ >> 8,
    0x35, 0x03, 0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x66, 0x02, 
    0x5d, 
    0x32, 
    0x35, 0xd4, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_[2] = {
    MP_ROM_QSTR(MP_QSTR__star_),
    MP_ROM_QSTR(MP_QSTR__star_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x04,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__[72] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x82, 0x34, 0x28, 0x25, 0x24, 0x28, 0x6a, 0x00, 0x00, 0x01, 0xff,
    0xb0, 
    0x1e, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x66, 0x00, 
    0x23, 0x01, 
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x38, 0x01, 0x80, 
    0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0xb1, 
    0x62, 0x02, 0x01, 
    0x1c, MP_QSTR_enumerate & 0xff, MP_QSTR_enumerate >> 8,
    0x1a, 0x01, 
    0x64, 0x01, 
    0x42, 
    0x64, 0x01, 
    0x66, 0x01, 
    0x66, 0x03, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str___0 = {{&mp_type_str}, 47461, 58, (const byte*)"\x3c\x43\x68\x61\x72\x61\x63\x74\x65\x72\x69\x73\x74\x69\x63\x20\x75\x75\x69\x64\x3d\x7b\x21\x73\x7d\x20\x68\x61\x6e\x64\x6c\x65\x3d\x7b\x3a\x30\x32\x78\x7d\x20\x64\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x73\x3d\x5b\x7b\x3a\x73\x7d\x5d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str___0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str____lt_genexpr_gt_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 72,
        .n_obj = 1,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor[56] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0c,
    MP_QSTR_add_descriptor & 0xff, MP_QSTR_add_descriptor >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x40, 0x20, 0x2c, 0x4e, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x64, 0x02, 
    0x37, 0x0e, 0x80, 
    0xb0, 
    0x1d, MP_QSTR_descriptors & 0xff, MP_QSTR_descriptors >> 8,
    0x1e, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor_0 = {{&mp_type_str}, 41381, 35, (const byte*)"\x64\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_descriptor),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 56,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors[22] = {
    0x02, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x47, 0x20, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_descriptors & 0xff, MP_QSTR_descriptors >> 8,
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 22,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__[85] = {
    0x0e, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0e,
    MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x4b, 0x31, 0x29, 0x26, 0x27, 0x4b, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x03, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_serv_handle & 0xff, MP_QSTR_serv_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x16, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x16, MP_QSTR_char_val_offset & 0xff, MP_QSTR_char_val_offset >> 8,
    0xb2, 
    0x16, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0x16, MP_QSTR_char_value & 0xff, MP_QSTR_char_value >> 8,
    0xb1, 
    0x64, 0x8a, 0x00, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties___0 = {{&mp_type_str}, 8562, 39, (const byte*)"\x62\x75\x66\x66\x65\x72\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x62\x79\x74\x65\x73\x20\x6f\x72\x20\x62\x79\x74\x65\x61\x72\x72\x61\x79\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_buffer),
    MP_ROM_QSTR(MP_QSTR_offset),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 85,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__[30] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___read_proprerties__ & 0xff, MP_QSTR___read_proprerties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x81, 0x56, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x64, 0x82, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 30,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic[108] = {
    0x05, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18,
    MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x6d, 0x60, 0x40, 0x41, 0x76, 0x80, 0x17, 0x8a, 0x0f, 0x85, 0x0c, 0x85, 0x07, 0x65, 0x20, 0x8a, 0x0b, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x94, 
    0x1b, MP_QSTR_PROP_READ & 0xff, MP_QSTR_PROP_READ >> 8,
    0x1b, MP_QSTR_PROP_WRITE & 0xff, MP_QSTR_PROP_WRITE >> 8,
    0xec, 
    0x1b, MP_QSTR_PERM_NONE & 0xff, MP_QSTR_PERM_NONE >> 8,
    0x1b, MP_QSTR_MASK_DONT_NOTIFY_EVENTS & 0xff, MP_QSTR_MASK_DONT_NOTIFY_EVENTS >> 8,
    0x11, 
    0x50, 0x05, 
    0x18, 
    0x61, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x11, 
    0x94, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR_add_descriptor & 0xff, MP_QSTR_add_descriptor >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x11, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x05, 
    0x24, MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    0x60, 0x06, 
    0x24, MP_QSTR___read_proprerties__ & 0xff, MP_QSTR___read_proprerties__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic[7] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___properties__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_add_descriptor),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic_get_descriptors),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___write_proprerties__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic___read_proprerties__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 108,
        .n_obj = 0,
        .n_raw_code = 7,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/characteristic.py, scope bluetooth_low_energy_api_characteristic_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt_[86] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0d,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_characteristic_dot_py >> 8,
    0x21, 0x2a, 0x30, 0x50, 0x8e, 0x54, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_descriptor & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_descriptor >> 8,
    0x69, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x24, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid >> 8,
    0x69, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x24, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x16, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x51, 0x01, 
    0x24, MP_QSTR___all__ & 0xff, MP_QSTR___all__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt__Characteristic),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_characteristic__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_characteristic__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___init__[89] = {
    0x0c, 0x00, 0x00, 0x04, 0x00, 0x02, 0x11,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x81, 0x0c, 0x2c, 0x49, 0x25, 0x25, 0x25, 0x26, 0x24, 0x26, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x04, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_service_type & 0xff, MP_QSTR_service_type >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x51, 0x00, 
    0xb0, 
    0x26, MP_QSTR_characteristics & 0xff, MP_QSTR_characteristics >> 8,
    0xb3, 
    0x37, 0x11, 0x80, 
    0xb3, 
    0x47, 
    0x43, 0x0c, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_add_characteristic & 0xff, MP_QSTR_add_characteristic >> 8,
    0xb4, 
    0x66, 0x01, 
    0x32, 
    0x35, 0xf1, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service___init___0 = {{&mp_type_str}, 12012, 25, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___init__[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_QSTR(MP_QSTR_service_type),
    MP_ROM_QSTR(MP_QSTR_characteristics),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service___init___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 89,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service___properties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__[67] = {
    0x0c, 0x00, 0x00, 0x02, 0x00, 0x01, 0x0d,
    MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x81, 0x18, 0x26, 0x2a, 0x2a, 0x27, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_service_uuid_type & 0xff, MP_QSTR_service_uuid_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x16, MP_QSTR_service_uuid & 0xff, MP_QSTR_service_uuid >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x16, MP_QSTR_service_type & 0xff, MP_QSTR_service_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_type & 0xff, MP_QSTR_service_type >> 8,
    0x16, MP_QSTR_max_attr_records & 0xff, MP_QSTR_max_attr_records >> 8,
    0xb1, 
    0x38, 0x06, 0x80, 
    0x1c, MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    0xb0, 
    0x64, 0x01, 
    0x64, 0x88, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_max_attr_records),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service___str___<genexpr>
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_[67] = {
    0x0e, 0x00, 0x04, 0x02, 0x00, 0x00, 0x0a,
    MP_QSTR__lt_genexpr_gt_ & 0xff, MP_QSTR__lt_genexpr_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x8c, 0x26, 0x27, 0x00, 0x00, 0xff,
    0x18, 
    0xb1, 
    0x18, 
    0x18, 
    0x43, 0x29, 0x00, 
    0x59, 0x02, 
    0xc2, 
    0xc3, 
    0x16, MP_QSTR__brace_open__bang_s_brace_close__brace_open__colon_s_brace_close_ & 0xff, MP_QSTR__brace_open__bang_s_brace_close__brace_open__colon_s_brace_close_ >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb3, 
    0xb2, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0x1a, 0x00, 
    0x64, 0x01, 
    0x81, 
    0xf2, 
    0xd7, 
    0x37, 0x06, 0x80, 
    0x16, MP_QSTR__comma__space_ & 0xff, MP_QSTR__comma__space_ >> 8,
    0x35, 0x03, 0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x66, 0x02, 
    0x5d, 
    0x32, 
    0x35, 0xd4, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_[2] = {
    MP_ROM_QSTR(MP_QSTR__star_),
    MP_ROM_QSTR(MP_QSTR__star_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x04,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service___str__
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str__[72] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x82, 0x21, 0x28, 0x25, 0x24, 0x28, 0x6a, 0x00, 0x00, 0x01, 0xff,
    0xb0, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x23, 0x01, 
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x38, 0x01, 0x80, 
    0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0xb1, 
    0x62, 0x02, 0x01, 
    0x1c, MP_QSTR_enumerate & 0xff, MP_QSTR_enumerate >> 8,
    0x1a, 0x01, 
    0x64, 0x01, 
    0x42, 
    0x64, 0x01, 
    0x66, 0x01, 
    0x66, 0x03, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service___str___0 = {{&mp_type_str}, 60587, 55, (const byte*)"\x3c\x53\x65\x72\x76\x69\x63\x65\x20\x75\x75\x69\x64\x3d\x7b\x21\x73\x7d\x20\x68\x61\x6e\x64\x6c\x65\x3d\x7b\x3a\x30\x32\x78\x7d\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x69\x73\x74\x69\x63\x73\x3d\x5b\x7b\x3a\x73\x7d\x5d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service___str___0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___str____lt_genexpr_gt_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 72,
        .n_obj = 1,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic[56] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0c,
    MP_QSTR_add_characteristic & 0xff, MP_QSTR_add_characteristic >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x81, 0x2d, 0x20, 0x2c, 0x4e, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x64, 0x02, 
    0x37, 0x0e, 0x80, 
    0xb0, 
    0x1d, MP_QSTR_characteristics & 0xff, MP_QSTR_characteristics >> 8,
    0x1e, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic_0 = {{&mp_type_str}, 7909, 43, (const byte*)"\x63\x68\x61\x72\x61\x63\x74\x65\x72\x69\x73\x74\x69\x63\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x43\x68\x61\x72\x61\x63\x74\x65\x72\x69\x73\x74\x69\x63\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_characteristic),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 56,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic[70] = {
    0x09, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0e,
    MP_QSTR_get_characteristic & 0xff, MP_QSTR_get_characteristic >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x81, 0x34, 0x20, 0x2c, 0x29, 0x29, 0x48, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x37, 0x1a, 0x80, 
    0xb0, 
    0x1d, MP_QSTR_characteristics & 0xff, MP_QSTR_characteristics >> 8,
    0x47, 
    0x43, 0x0f, 0x00, 
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb1, 
    0xd9, 
    0x37, 0x02, 0x80, 
    0xb2, 
    0x5b, 
    0x35, 0xee, 0x7f, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic_0 = {{&mp_type_str}, 57157, 23, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 70,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics[22] = {
    0x02, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x81, 0x3d, 0x20, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_characteristics & 0xff, MP_QSTR_characteristics >> 8,
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 22,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service__lt_module_gt__Service
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service[82] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x8d, 0x09, 0x40, 0x8c, 0x0c, 0x89, 0x09, 0x85, 0x0c, 0x85, 0x07, 0x85, 0x09, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x1b, MP_QSTR_SERVICE_PRIMARY & 0xff, MP_QSTR_SERVICE_PRIMARY >> 8,
    0x11, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x80, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR_add_characteristic & 0xff, MP_QSTR_add_characteristic >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR_get_characteristic & 0xff, MP_QSTR_get_characteristic >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service[6] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___properties__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_add_characteristic),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristic),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service_get_characteristics),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt__Service,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt__Service,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 82,
        .n_obj = 0,
        .n_raw_code = 6,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/service.py, scope bluetooth_low_energy_api_service_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_service__lt_module_gt_[120] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_service_dot_py >> 8,
    0x21, 0x30, 0x30, 0x2a, 0x30, 0x70, 0x8e, 0x39, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_characteristic & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_characteristic >> 8,
    0x69, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x24, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_util & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_util >> 8,
    0x69, MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    0x24, MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid >> 8,
    0x69, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x24, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x16, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x51, 0x01, 
    0x24, MP_QSTR___all__ & 0xff, MP_QSTR___all__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_service__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_service__lt_module_gt__Service),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_service__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_service__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_service__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 120,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/constants.py, scope bluetooth_low_energy_api_constants_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_constants__lt_module_gt_[427] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_constants_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_constants_dot_py >> 8,
    0x21, 0x50, 0x30, 0x50, 0x70, 0x40, 0x24, 0x64, 0x29, 0x69, 0x29, 0x69, 0x29, 0x29, 0x29, 0x29, 0x69, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x69, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x69, 0x29, 0x29, 0x29, 0x29, 0x29, 0x69, 0x29, 0x29, 0x20, 0x29, 0x20, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x24, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_constant & 0xff, MP_QSTR_constant >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms >> 8,
    0x69, MP_QSTR_constant & 0xff, MP_QSTR_constant >> 8,
    0x24, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms >> 8,
    0x69, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x24, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_ADDR_TYPE_PUBLIC & 0xff, MP_QSTR_ADDR_TYPE_PUBLIC >> 8,
    0x82, 
    0x24, MP_QSTR_ADDR_TYPE_RANDOM_STATIC & 0xff, MP_QSTR_ADDR_TYPE_RANDOM_STATIC >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_PRIMARY_SERVICE & 0xff, MP_QSTR_PRIMARY_SERVICE >> 8,
    0x24, MP_QSTR_SERVICE_PRIMARY & 0xff, MP_QSTR_SERVICE_PRIMARY >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_SECONDARY_SERVICE & 0xff, MP_QSTR_SECONDARY_SERVICE >> 8,
    0x24, MP_QSTR_SERVICE_SECONDARY & 0xff, MP_QSTR_SERVICE_SECONDARY >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0x24, MP_QSTR_UUID_16_BIT & 0xff, MP_QSTR_UUID_16_BIT >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_UUID_TYPE_128 & 0xff, MP_QSTR_UUID_TYPE_128 >> 8,
    0x24, MP_QSTR_UUID_128_BIT & 0xff, MP_QSTR_UUID_128_BIT >> 8,
    0x1b, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_LE_CONN_COMPLETE & 0xff, MP_QSTR_EVT_LE_CONN_COMPLETE >> 8,
    0x24, MP_QSTR_EVT_GAP_CONNECTED & 0xff, MP_QSTR_EVT_GAP_CONNECTED >> 8,
    0x1b, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_DISCONN_COMPLETE & 0xff, MP_QSTR_EVT_DISCONN_COMPLETE >> 8,
    0x24, MP_QSTR_EVT_GAP_DISCONNECTED & 0xff, MP_QSTR_EVT_GAP_DISCONNECTED >> 8,
    0x1b, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED & 0xff, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED >> 8,
    0x24, MP_QSTR_EVT_GATTS_WRITE & 0xff, MP_QSTR_EVT_GATTS_WRITE >> 8,
    0x1b, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ >> 8,
    0x24, MP_QSTR_EVT_GATTS_READ_PERMIT_REQ & 0xff, MP_QSTR_EVT_GATTS_READ_PERMIT_REQ >> 8,
    0x1b, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ >> 8,
    0x24, MP_QSTR_EVT_GATTS_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_GATTS_WRITE_PERMIT_REQ >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_BROADCAST & 0xff, MP_QSTR_CHAR_PROP_BROADCAST >> 8,
    0x24, MP_QSTR_PROP_BROADCAST & 0xff, MP_QSTR_PROP_BROADCAST >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_READ & 0xff, MP_QSTR_CHAR_PROP_READ >> 8,
    0x24, MP_QSTR_PROP_READ & 0xff, MP_QSTR_PROP_READ >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_WRITE_WITHOUT_RESP & 0xff, MP_QSTR_CHAR_PROP_WRITE_WITHOUT_RESP >> 8,
    0x24, MP_QSTR_PROP_WRITE_WO_RESP & 0xff, MP_QSTR_PROP_WRITE_WO_RESP >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_WRITE & 0xff, MP_QSTR_CHAR_PROP_WRITE >> 8,
    0x24, MP_QSTR_PROP_WRITE & 0xff, MP_QSTR_PROP_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_NOTIFY & 0xff, MP_QSTR_CHAR_PROP_NOTIFY >> 8,
    0x24, MP_QSTR_PROP_NOTIFY & 0xff, MP_QSTR_PROP_NOTIFY >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_INDICATE & 0xff, MP_QSTR_CHAR_PROP_INDICATE >> 8,
    0x24, MP_QSTR_PROP_INDICATE & 0xff, MP_QSTR_PROP_INDICATE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_SIGNED_WRITE & 0xff, MP_QSTR_CHAR_PROP_SIGNED_WRITE >> 8,
    0x24, MP_QSTR_PROP_AUTH_SIGNED_WR & 0xff, MP_QSTR_PROP_AUTH_SIGNED_WR >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_NONE & 0xff, MP_QSTR_ATTR_PERMISSION_NONE >> 8,
    0x24, MP_QSTR_PERM_NONE & 0xff, MP_QSTR_PERM_NONE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_AUTHEN_READ & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHEN_READ >> 8,
    0x24, MP_QSTR_PERM_AUTHEN_READ & 0xff, MP_QSTR_PERM_AUTHEN_READ >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_AUTHOR_READ & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHOR_READ >> 8,
    0x24, MP_QSTR_PERM_AUTHOR_READ & 0xff, MP_QSTR_PERM_AUTHOR_READ >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_ENCRY_READ & 0xff, MP_QSTR_ATTR_PERMISSION_ENCRY_READ >> 8,
    0x24, MP_QSTR_PERM_ENCRY_READ & 0xff, MP_QSTR_PERM_ENCRY_READ >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_AUTHEN_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHEN_WRITE >> 8,
    0x24, MP_QSTR_PERM_AUTHEN_WRITE & 0xff, MP_QSTR_PERM_AUTHEN_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_AUTHOR_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHOR_WRITE >> 8,
    0x24, MP_QSTR_PERM_AUTHOR_WRITE & 0xff, MP_QSTR_PERM_AUTHOR_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_PERMISSION_ENCRY_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_ENCRY_WRITE >> 8,
    0x24, MP_QSTR_PERM_ENCRY_WRITE & 0xff, MP_QSTR_PERM_ENCRY_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_NO_ACCESS & 0xff, MP_QSTR_ATTR_NO_ACCESS >> 8,
    0x24, MP_QSTR_ACC_NO_ACCESS & 0xff, MP_QSTR_ACC_NO_ACCESS >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_ACCESS_READ_ONLY & 0xff, MP_QSTR_ATTR_ACCESS_READ_ONLY >> 8,
    0x24, MP_QSTR_ACC_READ_ONLY & 0xff, MP_QSTR_ACC_READ_ONLY >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_ACCESS_WRITE_REQ_ONLY & 0xff, MP_QSTR_ATTR_ACCESS_WRITE_REQ_ONLY >> 8,
    0x24, MP_QSTR_ACC_WRITE_REQ_ONLY & 0xff, MP_QSTR_ACC_WRITE_REQ_ONLY >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_ACCESS_READ_WRITE & 0xff, MP_QSTR_ATTR_ACCESS_READ_WRITE >> 8,
    0x24, MP_QSTR_ACC_READ_WRITE & 0xff, MP_QSTR_ACC_READ_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_ACCESS_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_ATTR_ACCESS_WRITE_WITHOUT_RESPONSE >> 8,
    0x24, MP_QSTR_ACC_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_ACC_WRITE_WITHOUT_RESPONSE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ATTR_ACCESS_SIGNED_WRITE_ALLOWED & 0xff, MP_QSTR_ATTR_ACCESS_SIGNED_WRITE_ALLOWED >> 8,
    0x24, MP_QSTR_ACC_SIGNED_WRITE_ALLOWED & 0xff, MP_QSTR_ACC_SIGNED_WRITE_ALLOWED >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GATT_DONT_NOTIFY_EVENTS & 0xff, MP_QSTR_GATT_DONT_NOTIFY_EVENTS >> 8,
    0x24, MP_QSTR_MASK_DONT_NOTIFY_EVENTS & 0xff, MP_QSTR_MASK_DONT_NOTIFY_EVENTS >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GATT_NOTIFY_ATTRIBUTE_WRITE & 0xff, MP_QSTR_GATT_NOTIFY_ATTRIBUTE_WRITE >> 8,
    0x24, MP_QSTR_MASK_NOTIFY_ATTRIBUTE_WRITE & 0xff, MP_QSTR_MASK_NOTIFY_ATTRIBUTE_WRITE >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x24, MP_QSTR_MASK_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_MASK_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x1b, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x24, MP_QSTR_MASK_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_MASK_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_constants__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_constants__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 427,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__[102] = {
    0x09, 0x00, 0x03, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x13, 0x2c, 0x2d, 0x51, 0x3a, 0x25, 0x00, 0x00, 0xff,
    0xb2, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x17, 0x01, 
    0x66, 0x02, 
    0xc3, 
    0xb2, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x66, 0x02, 
    0xc4, 
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0xb1, 
    0xb2, 
    0x67, 0x00, 
    0x32, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb3, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x64, 0x02, 
    0x37, 0x04, 0x80, 
    0xb3, 
    0x35, 0x06, 0x80, 
    0x1c, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0xb3, 
    0x64, 0x01, 
    0xb0, 
    0x26, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x51, 0x00, 
    0xb0, 
    0x26, MP_QSTR_response & 0xff, MP_QSTR_response >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init___0 = {{&mp_type_str}, 27929, 12, (const byte*)"\x30\x32\x38\x30\x45\x31\x30\x30\x33\x34\x31\x34"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 102,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__[417] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x2f,
    MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x1d, 0x67, 0x27, 0x29, 0x30, 0x6a, 0x27, 0x29, 0x29, 0x27, 0x24, 0x2e, 0x23, 0x25, 0x6a, 0x40, 0x27, 0x29, 0x2e, 0x24, 0x2e, 0x28, 0x6a, 0x2a, 0x2e, 0x28, 0x6a, 0x27, 0x29, 0x2e, 0x30, 0x2e, 0x28, 0x6a, 0x4f, 0x24, 0x2e, 0x28, 0x4a, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0xb0, 
    0x1e, MP_QSTR_hci_wait_event & 0xff, MP_QSTR_hci_wait_event >> 8,
    0x16, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_HAL_INITIALIZED & 0xff, MP_QSTR_EVT_BLUE_HAL_INITIALIZED >> 8,
    0x66, 0x82, 0x00, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_RESET_NORMAL & 0xff, MP_QSTR_RESET_NORMAL >> 8,
    0xdc, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x16, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET >> 8,
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_PUBADDR_LEN & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_LEN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb0, 
    0x1d, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_MODE_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_MODE_OFFSET >> 8,
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_MODE_LEN & 0xff, MP_QSTR_CONFIG_DATA_MODE_LEN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x17, 0x02, 
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_init & 0xff, MP_QSTR_aci_gatt_init >> 8,
    0x66, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x04, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gap_init_IDB05A1 & 0xff, MP_QSTR_aci_gap_init_IDB05A1 >> 8,
    0x16, MP_QSTR_role & 0xff, MP_QSTR_role >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GAP_CENTRAL_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_CENTRAL_ROLE_IDB05A1 >> 8,
    0x16, MP_QSTR_privacy_enabled & 0xff, MP_QSTR_privacy_enabled >> 8,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_PRIVACY_DISABLED & 0xff, MP_QSTR_PRIVACY_DISABLED >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_device_name_char_len & 0xff, MP_QSTR_device_name_char_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x64, 0x01, 
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_set_tx_power_level & 0xff, MP_QSTR_aci_hal_set_tx_power_level >> 8,
    0x16, MP_QSTR_en_high_power & 0xff, MP_QSTR_en_high_power >> 8,
    0x81, 
    0x16, MP_QSTR_pa_level & 0xff, MP_QSTR_pa_level >> 8,
    0x85, 
    0x66, 0x84, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x06, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_start & 0xff, MP_QSTR_start >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___0 = {{&mp_type_str}, 58884, 40, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x77\x72\x69\x74\x65\x5f\x63\x6f\x6e\x66\x69\x67\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___1 = {{&mp_type_bytes}, 46503, 1, (const byte*)"\x02"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___2 = {{&mp_type_str}, 58884, 40, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x77\x72\x69\x74\x65\x5f\x63\x6f\x6e\x66\x69\x67\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___3 = {{&mp_type_str}, 42842, 28, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x69\x6e\x69\x74\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___4 = {{&mp_type_str}, 44746, 27, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x69\x6e\x69\x74\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___5 = {{&mp_type_str}, 59163, 41, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x73\x65\x74\x5f\x74\x78\x5f\x70\x6f\x77\x65\x72\x5f\x6c\x65\x76\x65\x6c\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__[7] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start___5),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 417,
        .n_obj = 6,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__[25] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x56, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 25,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__[292] = {
    0x0f, 0x00, 0x00, 0x02, 0x00, 0x00, 0x1d,
    MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x59, 0x20, 0x2d, 0x2b, 0x30, 0x2e, 0x2e, 0x2d, 0x27, 0x52, 0x40, 0x1f, 0x28, 0x2d, 0x28, 0x32, 0x27, 0x4f, 0x2e, 0x2e, 0x31, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x1d, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb1, 
    0x66, 0x01, 
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x1c, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0xd9, 
    0x37, 0xe6, 0x80, 
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb2, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x01, 
    0xc3, 
    0xb3, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0xd9, 
    0x37, 0x98, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_LE_ADVERTISING_REPORT & 0xff, MP_QSTR_EVT_LE_ADVERTISING_REPORT >> 8,
    0xd9, 
    0x37, 0x87, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x81, 
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xb3, 
    0x26, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_evt_type & 0xff, MP_QSTR_evt_type >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ADV_IND & 0xff, MP_QSTR_ADV_IND >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ADV_SCAN_IND & 0xff, MP_QSTR_ADV_SCAN_IND >> 8,
    0x50, 0x02, 
    0xdd, 
    0x37, 0x61, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x37, 0x1a, 0x80, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_RSSI & 0xff, MP_QSTR_data_RSSI >> 8,
    0x11, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x64, 0x01, 
    0x35, 0x02, 0x80, 
    0x17, 0x02, 
    0xc4, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x64, 0x01, 
    0xc5, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_bdaddr_type & 0xff, MP_QSTR_bdaddr_type >> 8,
    0xc6, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x37, 0x06, 0x80, 
    0xb4, 
    0x7f, 
    0x21, 
    0x35, 0x01, 0x80, 
    0x80, 
    0xc7, 
    0xb0, 
    0x1d, MP_QSTR_response & 0xff, MP_QSTR_response >> 8,
    0x1e, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0x1c, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0xb5, 
    0xb6, 
    0xb7, 
    0xb4, 
    0x64, 0x04, 
    0x66, 0x01, 
    0x32, 
    0x35, 0x30, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0xd9, 
    0x37, 0x22, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE & 0xff, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE >> 8,
    0xd9, 
    0x37, 0x11, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_procedure_code & 0xff, MP_QSTR_procedure_code >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GAP_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_GAP_GENERAL_DISCOVERY_PROC >> 8,
    0xd9, 
    0x37, 0x00, 0x80, 
    0x35, 0x00, 0x80, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process___0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_evt),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 292,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start[89] = {
    0x0c, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR_start & 0xff, MP_QSTR_start >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x73, 0x20, 0x6f, 0x2d, 0x24, 0x2e, 0x23, 0x25, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_aci_gap_start_general_discovery_proc & 0xff, MP_QSTR_aci_gap_start_general_discovery_proc >> 8,
    0x16, MP_QSTR_scan_interval & 0xff, MP_QSTR_scan_interval >> 8,
    0x90, 
    0x16, MP_QSTR_scan_window & 0xff, MP_QSTR_scan_window >> 8,
    0x90, 
    0x16, MP_QSTR_own_address_type & 0xff, MP_QSTR_own_address_type >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_PUBLIC_ADDR & 0xff, MP_QSTR_PUBLIC_ADDR >> 8,
    0x16, MP_QSTR_filter_duplicates & 0xff, MP_QSTR_filter_duplicates >> 8,
    0x81, 
    0x66, 0x88, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start_0 = {{&mp_type_str}, 50269, 51, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x73\x74\x61\x72\x74\x5f\x67\x65\x6e\x65\x72\x61\x6c\x5f\x64\x69\x73\x63\x6f\x76\x65\x72\x79\x5f\x70\x72\x6f\x63\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 89,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop[70] = {
    0x06, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR_stop & 0xff, MP_QSTR_stop >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x7f, 0x20, 0x2b, 0x24, 0x2e, 0x28, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_aci_gap_terminate_gap_procedure & 0xff, MP_QSTR_aci_gap_terminate_gap_procedure >> 8,
    0x16, MP_QSTR_procedure_code & 0xff, MP_QSTR_procedure_code >> 8,
    0x82, 
    0x66, 0x82, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc1, 
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb1, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop_0 = {{&mp_type_str}, 26482, 46, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x74\x65\x72\x6d\x69\x6e\x61\x74\x65\x5f\x67\x61\x70\x5f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 70,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback[35] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0b,
    MP_QSTR_callback & 0xff, MP_QSTR_callback >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x81, 0x8b, 0x20, 0x28, 0x00, 0x00, 0xff,
    0x1a, 0x00, 
    0x1e, MP_QSTR_stop & 0xff, MP_QSTR_stop >> 8,
    0x66, 0x00, 
    0x32, 
    0x1c, MP_QSTR_StopIteration & 0xff, MP_QSTR_StopIteration >> 8,
    0x64, 0x00, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback[1] = {
    MP_ROM_QSTR(MP_QSTR__star_),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 35,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan[78] = {
    0x0c, 0x01, 0x00, 0x02, 0x00, 0x01, 0x0f,
    MP_QSTR_scan & 0xff, MP_QSTR_scan >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x82, 0x87, 0x20, 0x2b, 0x23, 0x65, 0x20, 0x5b, 0x00, 0x00, 0x00, 0xff,
    0x1a, 0x00, 
    0x1d, MP_QSTR_response & 0xff, MP_QSTR_response >> 8,
    0x1e, MP_QSTR_clear & 0xff, MP_QSTR_clear >> 8,
    0x66, 0x00, 
    0x32, 
    0x40, 0x20, 0x00, 
    0xb0, 
    0x62, 0x02, 0x01, 
    0xc2, 
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    0x1a, 0x00, 
    0x64, 0x02, 
    0x1e, MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    0x16, MP_QSTR_callback & 0xff, MP_QSTR_callback >> 8,
    0xb2, 
    0x16, MP_QSTR_callback_time & 0xff, MP_QSTR_callback_time >> 8,
    0xb1, 
    0x66, 0x84, 0x00, 
    0x32, 
    0x44, 
    0x11, 
    0x1a, 0x00, 
    0x1d, MP_QSTR_response & 0xff, MP_QSTR_response >> 8,
    0x5b, 
    0x41, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_timeout),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan_callback),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner__lt_module_gt__Scanner
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner[84] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16,
    MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x8d, 0x10, 0x40, 0x85, 0x09, 0x85, 0x39, 0x65, 0x20, 0x85, 0x1a, 0x85, 0x0c, 0x85, 0x08, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR_start & 0xff, MP_QSTR_start >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_stop & 0xff, MP_QSTR_stop >> 8,
    0x14, 0x80, 0x64, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x06, 
    0x24, MP_QSTR_scan & 0xff, MP_QSTR_scan >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner[7] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___start__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___stop__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner___process__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_start),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_stop),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner_scan),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 84,
        .n_obj = 0,
        .n_raw_code = 7,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scanner.py, scope bluetooth_low_energy_api_scanner_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt_[204] = {
    0x05, 0x00, 0x00, 0x00, 0x00, 0x00, 0x13,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scanner_dot_py >> 8,
    0x21, 0x34, 0x28, 0x28, 0x30, 0x59, 0x2a, 0x30, 0x50, 0x1f, 0x6c, 0x20, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x24, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x1b, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x1e, MP_QSTR_threshold & 0xff, MP_QSTR_threshold >> 8,
    0x14, 0xa0, 0x00, 
    0x66, 0x01, 
    0x32, 
    0x80, 
    0x11, 
    0x68, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x24, MP_QSTR_utime & 0xff, MP_QSTR_utime >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_binascii & 0xff, MP_QSTR_binascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_scan_entry & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_scan_entry >> 8,
    0x69, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x24, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_spbtle_rf & 0xff, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_spbtle_rf >> 8,
    0x69, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x24, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x16, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x16, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x50, 0x04, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x24, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x69, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x24, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x69, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x24, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x69, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x24, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    0x1b, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Scanner & 0xff, MP_QSTR_Scanner >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scanner__lt_module_gt__Scanner),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_scanner__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scanner__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scanner__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 204,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__[259] = {
    0x13, 0x00, 0x03, 0x02, 0x00, 0x00, 0x22,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x81, 0x14, 0x2d, 0x2d, 0x2b, 0x2b, 0x2b, 0x2c, 0x2b, 0x31, 0x57, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x25, 0x25, 0x45, 0x24, 0x26, 0x4b, 0x24, 0x00, 0x00, 0xff,
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_address_type & 0xff, MP_QSTR_address_type >> 8,
    0x1c, MP_QSTR_ADDR_TYPE_PUBLIC & 0xff, MP_QSTR_ADDR_TYPE_PUBLIC >> 8,
    0x66, 0x02, 
    0xc4, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x66, 0x02, 
    0xc5, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_connectable & 0xff, MP_QSTR_connectable >> 8,
    0x10, 
    0x66, 0x02, 
    0xc6, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x80, 
    0x66, 0x02, 
    0xc7, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0x66, 0x02, 
    0xc8, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x51, 0x00, 
    0x66, 0x02, 
    0xc9, 
    0xb3, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x16, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x11, 
    0x66, 0x02, 
    0xca, 
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0xb2, 
    0xb3, 
    0x67, 0x00, 
    0x32, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x64, 0x02, 
    0x37, 0x04, 0x80, 
    0xb1, 
    0x35, 0x06, 0x80, 
    0x1c, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0xb1, 
    0x64, 0x01, 
    0xc1, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR_address_type & 0xff, MP_QSTR_address_type >> 8,
    0xb5, 
    0xb0, 
    0x26, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0xb6, 
    0xb0, 
    0x26, MP_QSTR_connectable & 0xff, MP_QSTR_connectable >> 8,
    0xb7, 
    0xb0, 
    0x26, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0xb8, 
    0xb0, 
    0x26, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x51, 0x00, 
    0xb0, 
    0x26, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_dev_name_char_handle & 0xff, MP_QSTR_dev_name_char_handle >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_appearance_char_handle & 0xff, MP_QSTR_appearance_char_handle >> 8,
    0xb9, 
    0x37, 0x11, 0x80, 
    0xb9, 
    0x47, 
    0x43, 0x0c, 0x00, 
    0xcb, 
    0xb0, 
    0x1e, MP_QSTR_add_service & 0xff, MP_QSTR_add_service >> 8,
    0xbb, 
    0x66, 0x01, 
    0x32, 
    0x35, 0xf1, 0x7f, 
    0xba, 
    0x37, 0x08, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_set_event_handler & 0xff, MP_QSTR_set_event_handler >> 8,
    0xba, 
    0x66, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 259,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run[35] = {
    0x07, 0x00, 0x03, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x81, 0x33, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    0xb1, 
    0xb2, 
    0x67, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 35,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__[1008] = {
    0x1b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x6a,
    MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x81, 0x37, 0x47, 0x27, 0x6a, 0x26, 0x69, 0x31, 0x6a, 0x40, 0x67, 0x27, 0x29, 0x30, 0x6a, 0x27, 0x29, 0x29, 0x27, 0x24, 0x2e, 0x23, 0x25, 0x6a, 0x40, 0x27, 0x29, 0x2e, 0x24, 0x2e, 0x28, 0x6a, 0x2a, 0x2e, 0x28, 0x6a, 0x27, 0x29, 0x2e, 0x30, 0x2e, 0x28, 0x4a, 0x28, 0x28, 0x68, 0x27, 0x27, 0x4b, 0x2c, 0x2b, 0x2e, 0x28, 0x4a, 0x27, 0x29, 0x2e, 0x27, 0x29, 0x29, 0x55, 0x2d, 0x2e, 0x28, 0x6a, 0x4f, 0x24, 0x2e, 0x28, 0x6a, 0x29, 0x25, 0x28, 0x24, 0x2e, 0x28, 0x2a, 0x68, 0x2b, 0x25, 0x27, 0x27, 0x49, 0x24, 0x2e, 0x28, 0x2a, 0x68, 0x2b, 0x25, 0x27, 0x27, 0x49, 0x24, 0x28, 0x2e, 0x23, 0x25, 0x53, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0xb0, 
    0x1e, MP_QSTR_hci_wait_event & 0xff, MP_QSTR_hci_wait_event >> 8,
    0x16, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_HAL_INITIALIZED & 0xff, MP_QSTR_EVT_BLUE_HAL_INITIALIZED >> 8,
    0x66, 0x82, 0x00, 
    0xc1, 
    0xb1, 
    0x11, 
    0xde, 
    0x37, 0x09, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_RESET_NORMAL & 0xff, MP_QSTR_RESET_NORMAL >> 8,
    0xdc, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x16, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0xb0, 
    0x1e, MP_QSTR_hci_wait_event & 0xff, MP_QSTR_hci_wait_event >> 8,
    0x16, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_HAL_INITIALIZED & 0xff, MP_QSTR_EVT_BLUE_HAL_INITIALIZED >> 8,
    0x66, 0x82, 0x00, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_RESET_NORMAL & 0xff, MP_QSTR_RESET_NORMAL >> 8,
    0xdc, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x16, MP_QSTR_reason_code & 0xff, MP_QSTR_reason_code >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET >> 8,
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_PUBADDR_LEN & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_LEN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb0, 
    0x1d, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x02, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_write_config_data & 0xff, MP_QSTR_aci_hal_write_config_data >> 8,
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_MODE_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_MODE_OFFSET >> 8,
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CONFIG_DATA_MODE_LEN & 0xff, MP_QSTR_CONFIG_DATA_MODE_LEN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x17, 0x03, 
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x04, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_init & 0xff, MP_QSTR_aci_gatt_init >> 8,
    0x66, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gap_init_IDB05A1 & 0xff, MP_QSTR_aci_gap_init_IDB05A1 >> 8,
    0x16, MP_QSTR_role & 0xff, MP_QSTR_role >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB05A1 >> 8,
    0x16, MP_QSTR_privacy_enabled & 0xff, MP_QSTR_privacy_enabled >> 8,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_PRIVACY_DISABLED & 0xff, MP_QSTR_PRIVACY_DISABLED >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_device_name_char_len & 0xff, MP_QSTR_device_name_char_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x64, 0x01, 
    0x66, 0x86, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x06, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb2, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb2, 
    0x1d, MP_QSTR_dev_name_char_handle & 0xff, MP_QSTR_dev_name_char_handle >> 8,
    0xb0, 
    0x26, MP_QSTR_dev_name_char_handle & 0xff, MP_QSTR_dev_name_char_handle >> 8,
    0xb2, 
    0x1d, MP_QSTR_appearance_char_handle & 0xff, MP_QSTR_appearance_char_handle >> 8,
    0xb0, 
    0x26, MP_QSTR_appearance_char_handle & 0xff, MP_QSTR_appearance_char_handle >> 8,
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_update_char_value & 0xff, MP_QSTR_aci_gatt_update_char_value >> 8,
    0x16, MP_QSTR_serv_handle & 0xff, MP_QSTR_serv_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x16, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_dev_name_char_handle & 0xff, MP_QSTR_dev_name_char_handle >> 8,
    0x16, MP_QSTR_char_val_offset & 0xff, MP_QSTR_char_val_offset >> 8,
    0x80, 
    0x16, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_char_value & 0xff, MP_QSTR_char_value >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x66, 0x8a, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x07, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gap_set_auth_requirement & 0xff, MP_QSTR_aci_gap_set_auth_requirement >> 8,
    0x16, MP_QSTR_mitm_mode & 0xff, MP_QSTR_mitm_mode >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MITM_PROTECTION_REQUIRED & 0xff, MP_QSTR_MITM_PROTECTION_REQUIRED >> 8,
    0x16, MP_QSTR_oob_enable & 0xff, MP_QSTR_oob_enable >> 8,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_OOB_AUTH_DATA_ABSENT & 0xff, MP_QSTR_OOB_AUTH_DATA_ABSENT >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_oob_data & 0xff, MP_QSTR_oob_data >> 8,
    0x17, 0x08, 
    0x90, 
    0xf3, 
    0x16, MP_QSTR_min_encryption_key_size & 0xff, MP_QSTR_min_encryption_key_size >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MIN_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MIN_ENCRY_KEY_SIZE >> 8,
    0x16, MP_QSTR_max_encryption_key_size & 0xff, MP_QSTR_max_encryption_key_size >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MAX_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MAX_ENCRY_KEY_SIZE >> 8,
    0x16, MP_QSTR_use_fixed_pin & 0xff, MP_QSTR_use_fixed_pin >> 8,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_USE_FIXED_PIN_FOR_PAIRING & 0xff, MP_QSTR_USE_FIXED_PIN_FOR_PAIRING >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_fixed_pin & 0xff, MP_QSTR_fixed_pin >> 8,
    0x14, 0x87, 0xc4, 0x40, 
    0x16, MP_QSTR_bonding_mode & 0xff, MP_QSTR_bonding_mode >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_BONDING & 0xff, MP_QSTR_BONDING >> 8,
    0x66, 0x90, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x09, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_hal_set_tx_power_level & 0xff, MP_QSTR_aci_hal_set_tx_power_level >> 8,
    0x16, MP_QSTR_en_high_power & 0xff, MP_QSTR_en_high_power >> 8,
    0x81, 
    0x16, MP_QSTR_pa_level & 0xff, MP_QSTR_pa_level >> 8,
    0x85, 
    0x66, 0x84, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x0a, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x47, 
    0x43, 0xe9, 0x00, 
    0xc3, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_add_serv & 0xff, MP_QSTR_aci_gatt_add_serv >> 8,
    0x18, 
    0xb3, 
    0x1e, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x66, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x0b, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb2, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb3, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb3, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0xa2, 0x00, 
    0xc4, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_add_char & 0xff, MP_QSTR_aci_gatt_add_char >> 8,
    0x18, 
    0xb4, 
    0x1e, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x16, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb3, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x16, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0xb4, 
    0x1d, MP_QSTR_char_value_len & 0xff, MP_QSTR_char_value_len >> 8,
    0x66, 0x84, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x0c, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb2, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb4, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb4, 
    0x1e, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x4c, 0x00, 
    0xc5, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_add_char_desc & 0xff, MP_QSTR_aci_gatt_add_char_desc >> 8,
    0x18, 
    0xb5, 
    0x1e, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x16, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb3, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x16, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0xb4, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x66, 0x84, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb5, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x0d, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0xb1, 0x7f, 
    0x35, 0x5b, 0x7f, 
    0x35, 0x14, 0x7f, 
    0xb0, 
    0x1e, MP_QSTR_set_discoverable & 0xff, MP_QSTR_set_discoverable >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___0 = {{&mp_type_str}, 52781, 20, (const byte*)"\x42\x6c\x75\x65\x4e\x52\x47\x2d\x4d\x53\x20\x6e\x6f\x74\x20\x72\x65\x61\x64\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___1 = {{&mp_type_str}, 58884, 40, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x77\x72\x69\x74\x65\x5f\x63\x6f\x6e\x66\x69\x67\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___2 = {{&mp_type_bytes}, 46503, 1, (const byte*)"\x02"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___3 = {{&mp_type_str}, 58884, 40, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x77\x72\x69\x74\x65\x5f\x63\x6f\x6e\x66\x69\x67\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___4 = {{&mp_type_str}, 42842, 28, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x69\x6e\x69\x74\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___5 = {{&mp_type_str}, 44746, 27, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x69\x6e\x69\x74\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___6 = {{&mp_type_str}, 47042, 41, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x75\x70\x64\x61\x74\x65\x5f\x63\x68\x61\x72\x5f\x76\x61\x6c\x75\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___7 = {{&mp_type_bytes}, 46501, 1, (const byte*)"\x00"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___8 = {{&mp_type_str}, 57445, 43, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x73\x65\x74\x5f\x61\x75\x74\x68\x5f\x72\x65\x71\x75\x69\x72\x65\x6d\x65\x6e\x74\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___9 = {{&mp_type_str}, 59163, 41, (const byte*)"\x61\x63\x69\x5f\x68\x61\x6c\x5f\x73\x65\x74\x5f\x74\x78\x5f\x70\x6f\x77\x65\x72\x5f\x6c\x65\x76\x65\x6c\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___10 = {{&mp_type_str}, 8364, 32, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x61\x64\x64\x5f\x73\x65\x72\x76\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___11 = {{&mp_type_str}, 52486, 32, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x61\x64\x64\x5f\x63\x68\x61\x72\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___12 = {{&mp_type_str}, 34600, 37, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x61\x64\x64\x5f\x63\x68\x61\x72\x5f\x64\x65\x73\x63\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__[14] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start___12),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 1008,
        .n_obj = 13,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x81, 0xc0, 0x40, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_reset & 0xff, MP_QSTR_reset >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__[660] = {
    0x15, 0x00, 0x00, 0x02, 0x00, 0x00, 0x3d,
    MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x81, 0xc5, 0x20, 0x2d, 0x2b, 0x30, 0x2e, 0x25, 0x2c, 0x4a, 0x6f, 0x2e, 0x2e, 0x2b, 0x2c, 0x4a, 0x27, 0x4e, 0x2e, 0x2e, 0x2c, 0x4a, 0x2a, 0x27, 0x52, 0x2e, 0x27, 0x27, 0x72, 0x2a, 0x27, 0x2e, 0x24, 0x2e, 0x23, 0x25, 0x2d, 0x2e, 0x2c, 0x4a, 0x2a, 0x27, 0x55, 0x2e, 0x2a, 0x27, 0x2b, 0x2e, 0x23, 0x25, 0x2d, 0x2e, 0x2c, 0x4a, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x1d, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb1, 
    0x66, 0x01, 
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x1c, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0xd9, 
    0x37, 0x36, 0x82, 
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1e, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0xb2, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x01, 
    0xc3, 
    0xb3, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_DISCONN_COMPLETE & 0xff, MP_QSTR_EVT_DISCONN_COMPLETE >> 8,
    0xd9, 
    0x37, 0x2a, 0x80, 
    0x11, 
    0xb0, 
    0x26, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb0, 
    0x1d, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x64, 0x01, 
    0x37, 0x16, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x1c, MP_QSTR_EVT_GAP_DISCONNECTED & 0xff, MP_QSTR_EVT_GAP_DISCONNECTED >> 8,
    0x16, MP_QSTR_handler & 0xff, MP_QSTR_handler >> 8,
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0x66, 0x84, 0x01, 
    0x32, 
    0x35, 0xee, 0x81, 
    0xb3, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0xd9, 
    0x37, 0x44, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_LE_CONN_COMPLETE & 0xff, MP_QSTR_EVT_LE_CONN_COMPLETE >> 8,
    0xd9, 
    0x37, 0x33, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb0, 
    0x26, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb0, 
    0x1d, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x64, 0x01, 
    0x37, 0x1c, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x1c, MP_QSTR_EVT_GAP_CONNECTED & 0xff, MP_QSTR_EVT_GAP_CONNECTED >> 8,
    0x16, MP_QSTR_handler & 0xff, MP_QSTR_handler >> 8,
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_peer_bdaddr & 0xff, MP_QSTR_peer_bdaddr >> 8,
    0x66, 0x84, 0x01, 
    0x32, 
    0x35, 0x9c, 0x81, 
    0xb3, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0x1c, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x1d, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0xd9, 
    0x37, 0x8e, 0x81, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED & 0xff, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED >> 8,
    0xd9, 
    0x37, 0x39, 0x80, 
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb0, 
    0x1d, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x64, 0x01, 
    0x37, 0x2a, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x1c, MP_QSTR_EVT_GATTS_WRITE & 0xff, MP_QSTR_EVT_GATTS_WRITE >> 8,
    0x16, MP_QSTR_handler & 0xff, MP_QSTR_handler >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_att_data & 0xff, MP_QSTR_att_data >> 8,
    0x11, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x84, 0x01, 
    0x32, 
    0x35, 0x44, 0x81, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ >> 8,
    0xd9, 
    0x37, 0xb0, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_write_response & 0xff, MP_QSTR_aci_gatt_write_response >> 8,
    0x16, MP_QSTR_conn_handle & 0xff, MP_QSTR_conn_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x16, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0x16, MP_QSTR_write_status & 0xff, MP_QSTR_write_status >> 8,
    0x10, 
    0x16, MP_QSTR_err_code & 0xff, MP_QSTR_err_code >> 8,
    0x80, 
    0x16, MP_QSTR_att_val_len & 0xff, MP_QSTR_att_val_len >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x16, MP_QSTR_att_val & 0xff, MP_QSTR_att_val >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_buffer & 0xff, MP_QSTR_data_buffer >> 8,
    0x11, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x8c, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc4, 
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x15, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x02, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0x47, 0x80, 
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xd9, 
    0x37, 0x39, 0x80, 
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb0, 
    0x1d, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x64, 0x01, 
    0x37, 0x2a, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x1c, MP_QSTR_EVT_GATTS_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_GATTS_WRITE_PERMIT_REQ >> 8,
    0x16, MP_QSTR_handler & 0xff, MP_QSTR_handler >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_buffer & 0xff, MP_QSTR_data_buffer >> 8,
    0x11, 
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_data_length & 0xff, MP_QSTR_data_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x84, 0x01, 
    0x32, 
    0x35, 0x00, 0x80, 
    0x35, 0x86, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x1c, MP_QSTR_st_event & 0xff, MP_QSTR_st_event >> 8,
    0x1d, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ >> 8,
    0xd9, 
    0x37, 0x78, 0x80, 
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x11, 
    0xde, 
    0xd3, 
    0x37, 0x6b, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_allow_read & 0xff, MP_QSTR_aci_gatt_allow_read >> 8,
    0x16, MP_QSTR_conn_handle & 0xff, MP_QSTR_conn_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x66, 0x82, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc4, 
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x15, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x35, 0x36, 0x80, 
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xd9, 
    0x37, 0x28, 0x80, 
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb0, 
    0x1d, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x64, 0x01, 
    0x37, 0x19, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x1c, MP_QSTR_EVT_GATTS_READ_PERMIT_REQ & 0xff, MP_QSTR_EVT_GATTS_READ_PERMIT_REQ >> 8,
    0x16, MP_QSTR_handler & 0xff, MP_QSTR_handler >> 8,
    0xb3, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1d, MP_QSTR_attr_handle & 0xff, MP_QSTR_attr_handle >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0x66, 0x84, 0x01, 
    0x32, 
    0x35, 0x00, 0x80, 
    0x35, 0x00, 0x80, 
    0x35, 0x00, 0x80, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process___0 = {{&mp_type_str}, 34561, 38, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x77\x72\x69\x74\x65\x5f\x72\x65\x73\x70\x6f\x6e\x73\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process___1 = {{&mp_type_str}, 24916, 34, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x61\x6c\x6c\x6f\x77\x5f\x72\x65\x61\x64\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_evt),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process___1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 660,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable[374] = {
    0x1b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x26,
    MP_QSTR_set_discoverable & 0xff, MP_QSTR_set_discoverable >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x0b, 0x20, 0x60, 0x1f, 0x76, 0x27, 0x29, 0x30, 0x2e, 0x28, 0x6a, 0x47, 0x30, 0x49, 0x27, 0x27, 0x27, 0x29, 0x7e, 0x40, 0x24, 0x2e, 0x28, 0x4a, 0x34, 0x27, 0x2c, 0x2b, 0x2e, 0x28, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x64, 0x01, 
    0x37, 0x26, 0x80, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x16, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s & 0xff, MP_QSTR__lt_B_brace_open__colon_d_brace_close_s >> 8,
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x64, 0x01, 
    0x66, 0x01, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME & 0xff, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME >> 8,
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x66, 0x03, 
    0x35, 0x02, 0x80, 
    0x17, 0x01, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_hci_le_set_scan_resp_data & 0xff, MP_QSTR_hci_le_set_scan_resp_data >> 8,
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MAX_ADV_DATA_LEN & 0xff, MP_QSTR_MAX_ADV_DATA_LEN >> 8,
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x17, 0x02, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MAX_ADV_DATA_LEN & 0xff, MP_QSTR_MAX_ADV_DATA_LEN >> 8,
    0xf3, 
    0x66, 0x84, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_aci_gap_set_discoverable & 0xff, MP_QSTR_aci_gap_set_discoverable >> 8,
    0x16, MP_QSTR_adv_type & 0xff, MP_QSTR_adv_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_connectable & 0xff, MP_QSTR_connectable >> 8,
    0x37, 0x09, 0x80, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ADV_IND & 0xff, MP_QSTR_ADV_IND >> 8,
    0x35, 0x06, 0x80, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_ADV_SCAN_IND & 0xff, MP_QSTR_ADV_SCAN_IND >> 8,
    0x16, MP_QSTR_adv_interv_min & 0xff, MP_QSTR_adv_interv_min >> 8,
    0xb0, 
    0x1d, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x16, MP_QSTR_adv_interv_max & 0xff, MP_QSTR_adv_interv_max >> 8,
    0xb0, 
    0x1d, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x16, MP_QSTR_own_addr_type & 0xff, MP_QSTR_own_addr_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_address_type & 0xff, MP_QSTR_address_type >> 8,
    0x16, MP_QSTR_adv_filter_policy & 0xff, MP_QSTR_adv_filter_policy >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_NO_WHITE_LIST_USE & 0xff, MP_QSTR_NO_WHITE_LIST_USE >> 8,
    0x16, MP_QSTR_local_name_len & 0xff, MP_QSTR_local_name_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0x16, MP_QSTR_local_name & 0xff, MP_QSTR_local_name >> 8,
    0xb1, 
    0x16, MP_QSTR_service_uuid_len & 0xff, MP_QSTR_service_uuid_len >> 8,
    0x80, 
    0x16, MP_QSTR_service_uuid_list & 0xff, MP_QSTR_service_uuid_list >> 8,
    0x17, 0x04, 
    0x16, MP_QSTR_slave_conn_interv_min & 0xff, MP_QSTR_slave_conn_interv_min >> 8,
    0x80, 
    0x16, MP_QSTR_slave_conn_interv_max & 0xff, MP_QSTR_slave_conn_interv_max >> 8,
    0x80, 
    0x66, 0x96, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x37, 0x3e, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gap_update_adv_data & 0xff, MP_QSTR_aci_gap_update_adv_data >> 8,
    0x16, MP_QSTR_adv_len & 0xff, MP_QSTR_adv_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_adv_data & 0xff, MP_QSTR_adv_data >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x84, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc2, 
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x06, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb2, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_1 = {{&mp_type_bytes}, 46501, 1, (const byte*)"\x00"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_2 = {{&mp_type_str}, 2112, 40, (const byte*)"\x68\x63\x69\x5f\x6c\x65\x5f\x73\x65\x74\x5f\x73\x63\x61\x6e\x5f\x72\x65\x73\x70\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_3 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_4 = {{&mp_type_str}, 19348, 39, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x73\x65\x74\x5f\x64\x69\x73\x63\x6f\x76\x65\x72\x61\x62\x6c\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_5 = {{&mp_type_str}, 61634, 38, (const byte*)"\x61\x63\x69\x5f\x67\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x61\x64\x76\x5f\x64\x61\x74\x61\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable[7] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable_5),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 374,
        .n_obj = 6,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service[56] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0c,
    MP_QSTR_add_service & 0xff, MP_QSTR_add_service >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x36, 0x20, 0x2c, 0x4e, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x64, 0x02, 
    0x37, 0x0e, 0x80, 
    0xb0, 
    0x1d, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x1e, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service_0 = {{&mp_type_str}, 45957, 29, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x53\x65\x72\x76\x69\x63\x65\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR__service),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 56,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler[44] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0c,
    MP_QSTR_set_event_handler & 0xff, MP_QSTR_set_event_handler >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x3d, 0x20, 0x29, 0x29, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_callable & 0xff, MP_QSTR_callable >> 8,
    0xb1, 
    0x64, 0x01, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_event_handler & 0xff, MP_QSTR_event_handler >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler_0 = {{&mp_type_str}, 53875, 28, (const byte*)"\x63\x61\x6c\x6c\x62\x61\x63\x6b\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x63\x61\x6c\x6c\x61\x62\x6c\x65\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_callback),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 44,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid[253] = {
    0x1d, 0x00, 0x00, 0x04, 0x00, 0x02, 0x22,
    MP_QSTR_write_uuid & 0xff, MP_QSTR_write_uuid >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x43, 0x20, 0x2c, 0x49, 0x29, 0x42, 0x29, 0x2b, 0x29, 0x25, 0x51, 0x24, 0x2e, 0x23, 0x25, 0x2a, 0x22, 0x2b, 0x29, 0x25, 0x51, 0x24, 0x2e, 0x23, 0x25, 0x2a, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x04, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0xb0, 
    0x1d, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x47, 
    0x43, 0xaa, 0x00, 
    0xc4, 
    0xb4, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x9c, 0x00, 
    0xc5, 
    0xb1, 
    0xb5, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xd9, 
    0x37, 0x3c, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_update_char_value & 0xff, MP_QSTR_aci_gatt_update_char_value >> 8,
    0x18, 
    0xb5, 
    0x1e, MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    0x16, MP_QSTR_buffer & 0xff, MP_QSTR_buffer >> 8,
    0xb2, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0xb3, 
    0x66, 0x84, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc6, 
    0xb6, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
    0xb5, 
    0x1e, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x49, 0x00, 
    0xc7, 
    0xb1, 
    0xb7, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xd9, 
    0x37, 0x3c, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_set_desc_value & 0xff, MP_QSTR_aci_gatt_set_desc_value >> 8,
    0x18, 
    0xb7, 
    0x1e, MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    0x16, MP_QSTR_buffer & 0xff, MP_QSTR_buffer >> 8,
    0xb2, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0xb3, 
    0x66, 0x84, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc6, 
    0xb6, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x06, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb6, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
    0x35, 0xb4, 0x7f, 
    0x35, 0x61, 0x7f, 
    0x35, 0x53, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_0 = {{&mp_type_str}, 57157, 23, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44\x2e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_1 = {{&mp_type_str}, 47042, 41, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x75\x70\x64\x61\x74\x65\x5f\x63\x68\x61\x72\x5f\x76\x61\x6c\x75\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_2 = {{&mp_type_str}, 4216, 38, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x73\x65\x74\x5f\x64\x65\x73\x63\x5f\x76\x61\x6c\x75\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid[7] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid_value),
    MP_ROM_QSTR(MP_QSTR_buffer),
    MP_ROM_QSTR(MP_QSTR_offset),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid_2),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 253,
        .n_obj = 3,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid[162] = {
    0x12, 0x00, 0x00, 0x02, 0x00, 0x00, 0x18,
    MP_QSTR_read_uuid & 0xff, MP_QSTR_read_uuid >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x63, 0x20, 0x2c, 0x49, 0x29, 0x42, 0x29, 0x2b, 0x29, 0x25, 0x28, 0x24, 0x2e, 0x23, 0x25, 0x2a, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x02, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_connection_handle & 0xff, MP_QSTR_connection_handle >> 8,
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0xb0, 
    0x1d, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x47, 
    0x43, 0x59, 0x00, 
    0xc2, 
    0xb2, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x4b, 0x00, 
    0xc3, 
    0xb1, 
    0xb3, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xd9, 
    0x37, 0x3e, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_aci_gatt_read_handle_value & 0xff, MP_QSTR_aci_gatt_read_handle_value >> 8,
    0x18, 
    0xb3, 
    0x1e, MP_QSTR___read_proprerties__ & 0xff, MP_QSTR___read_proprerties__ >> 8,
    0x66, 0x00, 
    0x67, 0x00, 
    0x1d, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xc4, 
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1c, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x1d, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0xdc, 
    0x37, 0x12, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x1d, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x66, 0x01, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb4, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x11, 
    0xb4, 
    0x1d, MP_QSTR_value_len & 0xff, MP_QSTR_value_len >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x35, 0xb2, 0x7f, 
    0x35, 0xa4, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid_0 = {{&mp_type_str}, 57157, 23, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44\x2e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid_1 = {{&mp_type_str}, 59603, 41, (const byte*)"\x61\x63\x69\x5f\x67\x61\x74\x74\x5f\x72\x65\x61\x64\x5f\x68\x61\x6e\x64\x6c\x65\x5f\x76\x61\x6c\x75\x65\x20\x73\x74\x61\x74\x75\x73\x3a\x20\x7b\x3a\x30\x32\x78\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid_value),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid_1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 162,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle[109] = {
    0x13, 0x00, 0x00, 0x02, 0x00, 0x00, 0x12,
    MP_QSTR_uuid_from_handle & 0xff, MP_QSTR_uuid_from_handle >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x91, 0x77, 0x20, 0x29, 0x29, 0x25, 0x2b, 0x29, 0x25, 0x2b, 0x29, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_services & 0xff, MP_QSTR_services >> 8,
    0x47, 
    0x43, 0x4a, 0x00, 
    0xc2, 
    0xb1, 
    0xb2, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb2, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x5b, 
    0xb2, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x2e, 0x00, 
    0xc3, 
    0xb1, 
    0xb3, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x5b, 
    0xb3, 
    0x1e, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x12, 0x00, 
    0xc4, 
    0xb1, 
    0xb4, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb3, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x5b, 
    0x35, 0xeb, 0x7f, 
    0x35, 0xcf, 0x7f, 
    0x35, 0xb3, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 109,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral[110] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1d,
    MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x8d, 0x11, 0x40, 0x85, 0x1f, 0x65, 0x85, 0x8a, 0x65, 0x40, 0x85, 0x46, 0x85, 0x2b, 0x85, 0x07, 0x65, 0x60, 0x8a, 0x20, 0x85, 0x14, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR_run & 0xff, MP_QSTR_run >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___start__ & 0xff, MP_QSTR___start__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___stop__ & 0xff, MP_QSTR___stop__ >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR___process__ & 0xff, MP_QSTR___process__ >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_set_discoverable & 0xff, MP_QSTR_set_discoverable >> 8,
    0x60, 0x06, 
    0x24, MP_QSTR_add_service & 0xff, MP_QSTR_add_service >> 8,
    0x60, 0x07, 
    0x24, MP_QSTR_set_event_handler & 0xff, MP_QSTR_set_event_handler >> 8,
    0x11, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x08, 
    0x24, MP_QSTR_write_uuid & 0xff, MP_QSTR_write_uuid >> 8,
    0x60, 0x09, 
    0x24, MP_QSTR_read_uuid & 0xff, MP_QSTR_read_uuid >> 8,
    0x60, 0x0a, 
    0x24, MP_QSTR_uuid_from_handle & 0xff, MP_QSTR_uuid_from_handle >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral[11] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_run),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___start__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___stop__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral___process__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_discoverable),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_add_service),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_set_event_handler),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_write_uuid),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_read_uuid),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral_uuid_from_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 110,
        .n_obj = 0,
        .n_raw_code = 11,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/peripheral.py, scope bluetooth_low_energy_api_peripheral_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt_[239] = {
    0x05, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_peripheral_dot_py >> 8,
    0x21, 0x34, 0x30, 0x59, 0x28, 0x30, 0x2a, 0x30, 0x30, 0x50, 0x1f, 0x6c, 0x20, 0x9e, 0x73, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x24, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x1b, MP_QSTR_gc & 0xff, MP_QSTR_gc >> 8,
    0x1e, MP_QSTR_threshold & 0xff, MP_QSTR_threshold >> 8,
    0x14, 0xa0, 0x00, 
    0x66, 0x01, 
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_binascii & 0xff, MP_QSTR_binascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_characteristic & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_characteristic >> 8,
    0x69, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x24, MP_QSTR_Characteristic & 0xff, MP_QSTR_Characteristic >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_service & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_service >> 8,
    0x69, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x24, MP_QSTR_Service & 0xff, MP_QSTR_Service >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid >> 8,
    0x69, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x24, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_spbtle_rf & 0xff, MP_QSTR_bluetooth_low_energy_dot_modules_dot_st_microelectronics_dot_spbtle_rf >> 8,
    0x69, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x24, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x16, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x16, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x50, 0x04, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x24, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x69, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x24, MP_QSTR_event & 0xff, MP_QSTR_event >> 8,
    0x69, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x24, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x69, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x24, MP_QSTR_uart & 0xff, MP_QSTR_uart >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0x1b, MP_QSTR_SPBTLE_RF & 0xff, MP_QSTR_SPBTLE_RF >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0x16, MP_QSTR_Peripheral & 0xff, MP_QSTR_Peripheral >> 8,
    0x51, 0x01, 
    0x24, MP_QSTR___all__ & 0xff, MP_QSTR___all__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt__Peripheral),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_peripheral__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_peripheral__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 239,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/__init__.py, scope bluetooth_low_energy_api___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__[157] = {
    0x09, 0x00, 0x00, 0x06, 0x00, 0x03, 0x18,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x81, 0x0b, 0x2c, 0x29, 0x2c, 0x29, 0x2c, 0x29, 0x2c, 0x49, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x06, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb4, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x07, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb3, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x08, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb5, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x09, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0x11, 
    0xb0, 
    0x26, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR_perms & 0xff, MP_QSTR_perms >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR_acc & 0xff, MP_QSTR_acc >> 8,
    0xb5, 
    0xb0, 
    0x26, MP_QSTR_mask & 0xff, MP_QSTR_mask >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___0 = {{&mp_type_str}, 12012, 25, (const byte*)"\x75\x75\x69\x64\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___1 = {{&mp_type_str}, 27294, 23, (const byte*)"\x61\x63\x63\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___2 = {{&mp_type_str}, 23910, 25, (const byte*)"\x70\x65\x72\x6d\x73\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___3 = {{&mp_type_str}, 47979, 24, (const byte*)"\x6d\x61\x73\x6b\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x69\x6e\x74"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__[10] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_uuid),
    MP_ROM_QSTR(MP_QSTR_value),
    MP_ROM_QSTR(MP_QSTR_perms),
    MP_ROM_QSTR(MP_QSTR_acc),
    MP_ROM_QSTR(MP_QSTR_mask),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init___3),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 6,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 157,
        .n_obj = 4,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__[145] = {
    0x1c, 0x00, 0x00, 0x03, 0x00, 0x02, 0x16,
    MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x81, 0x1e, 0x25, 0x25, 0x26, 0x27, 0x27, 0x2a, 0x2a, 0x2c, 0x2c, 0x27, 0x27, 0x27, 0x27, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x16, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0x16, MP_QSTR_desc_uuid_type & 0xff, MP_QSTR_desc_uuid_type >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x16, MP_QSTR_desc_value_max_len & 0xff, MP_QSTR_desc_value_max_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_desc_value_len & 0xff, MP_QSTR_desc_value_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x64, 0x01, 
    0x16, MP_QSTR_desc_value & 0xff, MP_QSTR_desc_value >> 8,
    0xb0, 
    0x1d, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x16, MP_QSTR_sec_permissions & 0xff, MP_QSTR_sec_permissions >> 8,
    0xb0, 
    0x1d, MP_QSTR_perms & 0xff, MP_QSTR_perms >> 8,
    0x16, MP_QSTR_acc_permissions & 0xff, MP_QSTR_acc_permissions >> 8,
    0xb0, 
    0x1d, MP_QSTR_acc & 0xff, MP_QSTR_acc >> 8,
    0x16, MP_QSTR_gatt_evt_mask & 0xff, MP_QSTR_gatt_evt_mask >> 8,
    0xb0, 
    0x1d, MP_QSTR_mask & 0xff, MP_QSTR_mask >> 8,
    0x16, MP_QSTR_encry_key_size & 0xff, MP_QSTR_encry_key_size >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_MAX_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MAX_ENCRY_KEY_SIZE >> 8,
    0x16, MP_QSTR_is_variable & 0xff, MP_QSTR_is_variable >> 8,
    0x12, 
    0x64, 0x98, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_service_handle),
    MP_ROM_QSTR(MP_QSTR_char_handle),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 145,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__[28] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x81, 0x30, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x66, 0x01, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str___0 = {{&mp_type_str}, 30384, 22, (const byte*)"\x3c\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x20\x75\x75\x69\x64\x3d\x7b\x21\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 28,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__[93] = {
    0x10, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0f,
    MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x81, 0x33, 0x31, 0x29, 0x26, 0x27, 0x27, 0x4b, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_isinstance & 0xff, MP_QSTR_isinstance >> 8,
    0xb1, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0x1c, MP_QSTR_bytearray & 0xff, MP_QSTR_bytearray >> 8,
    0x50, 0x02, 
    0x64, 0x02, 
    0x36, 0x09, 0x80, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0x17, 0x03, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_dict & 0xff, MP_QSTR_dict >> 8,
    0x16, MP_QSTR_serv_handle & 0xff, MP_QSTR_serv_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_service_handle & 0xff, MP_QSTR_service_handle >> 8,
    0x16, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_char_handle & 0xff, MP_QSTR_char_handle >> 8,
    0x16, MP_QSTR_char_desc_handle & 0xff, MP_QSTR_char_desc_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x16, MP_QSTR_char_desc_val_offset & 0xff, MP_QSTR_char_desc_val_offset >> 8,
    0xb2, 
    0x16, MP_QSTR_char_desc_value_len & 0xff, MP_QSTR_char_desc_value_len >> 8,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb1, 
    0x64, 0x01, 
    0x16, MP_QSTR_char_desc_value & 0xff, MP_QSTR_char_desc_value >> 8,
    0xb1, 
    0x64, 0x8c, 0x00, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties___0 = {{&mp_type_str}, 8562, 39, (const byte*)"\x62\x75\x66\x66\x65\x72\x20\x6d\x75\x73\x74\x20\x6f\x66\x20\x74\x79\x70\x65\x20\x62\x79\x74\x65\x73\x20\x6f\x72\x20\x62\x79\x74\x65\x61\x72\x72\x61\x79\x2e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_buffer),
    MP_ROM_QSTR(MP_QSTR_offset),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 93,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor[79] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
    MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x6d, 0x40, 0x40, 0x71, 0x80, 0x13, 0x8a, 0x12, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x1b, MP_QSTR_PERM_NONE & 0xff, MP_QSTR_PERM_NONE >> 8,
    0x1b, MP_QSTR_ACC_NO_ACCESS & 0xff, MP_QSTR_ACC_NO_ACCESS >> 8,
    0x1b, MP_QSTR_MASK_DONT_NOTIFY_EVENTS & 0xff, MP_QSTR_MASK_DONT_NOTIFY_EVENTS >> 8,
    0x50, 0x03, 
    0x18, 
    0x61, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x11, 
    0x11, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___properties__ & 0xff, MP_QSTR___properties__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x11, 
    0x80, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x03, 
    0x24, MP_QSTR___write_proprerties__ & 0xff, MP_QSTR___write_proprerties__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor[4] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___properties__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor___write_proprerties__),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 79,
        .n_obj = 0,
        .n_raw_code = 4,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/descriptor.py, scope bluetooth_low_energy_api_descriptor_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt_[69] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_descriptor_dot_py >> 8,
    0x21, 0x2a, 0x50, 0x8e, 0x3a, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR__star_ & 0xff, MP_QSTR__star_ >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_constants >> 8,
    0x6a, 
    0x80, 
    0x16, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_uuid >> 8,
    0x69, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x24, MP_QSTR_UUID & 0xff, MP_QSTR_UUID >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x16, MP_QSTR_Descriptor & 0xff, MP_QSTR_Descriptor >> 8,
    0x51, 0x01, 
    0x24, MP_QSTR___all__ & 0xff, MP_QSTR___all__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt__Descriptor),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_descriptor__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_descriptor__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 69,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/util.py, scope bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record
STATIC const byte bytecode_data_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record[136] = {
    0x0c, 0x00, 0x00, 0x01, 0x00, 0x00, 0x18,
    MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py >> 8,
    0x61, 0x40, 0x20, 0x22, 0x6b, 0x24, 0x45, 0x2b, 0x2b, 0x64, 0x2b, 0x64, 0x2b, 0x44, 0x71, 0x26, 0x42, 0x00, 0x00, 0xff,
    0x81, 
    0xc1, 
    0xb0, 
    0x1e, MP_QSTR_get_characteristics & 0xff, MP_QSTR_get_characteristics >> 8,
    0x66, 0x00, 
    0x47, 
    0x43, 0x53, 0x00, 
    0xc2, 
    0xb1, 
    0x82, 
    0xe5, 
    0xc1, 
    0xb2, 
    0x1d, MP_QSTR_props & 0xff, MP_QSTR_props >> 8,
    0xc3, 
    0xb3, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_NOTIFY & 0xff, MP_QSTR_CHAR_PROP_NOTIFY >> 8,
    0xee, 
    0x36, 0x0b, 0x80, 
    0xb3, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_INDICATE & 0xff, MP_QSTR_CHAR_PROP_INDICATE >> 8,
    0xee, 
    0x37, 0x04, 0x80, 
    0xb1, 
    0x82, 
    0xe5, 
    0xc1, 
    0xb3, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_BROADCAST & 0xff, MP_QSTR_CHAR_PROP_BROADCAST >> 8,
    0xee, 
    0x37, 0x04, 0x80, 
    0xb1, 
    0x82, 
    0xe5, 
    0xc1, 
    0xb3, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_CHAR_PROP_EXT & 0xff, MP_QSTR_CHAR_PROP_EXT >> 8,
    0xee, 
    0x37, 0x04, 0x80, 
    0xb1, 
    0x82, 
    0xe5, 
    0xc1, 
    0xb1, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb2, 
    0x1e, MP_QSTR_get_descriptors & 0xff, MP_QSTR_get_descriptors >> 8,
    0x66, 0x00, 
    0x64, 0x01, 
    0xe5, 
    0xc1, 
    0x35, 0xaa, 0x7f, 
    0xb1, 
    0x81, 
    0xd9, 
    0x37, 0x02, 0x80, 
    0x85, 
    0xc1, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record[1] = {
    MP_ROM_QSTR(MP_QSTR_service),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 136,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/util.py, scope bluetooth_low_energy_api_util__lt_module_gt__format_advertisement
STATIC const byte bytecode_data_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement[339] = {
    0x0e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x29,
    MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py >> 8,
    0x81, 0x23, 0x20, 0x42, 0x4a, 0x29, 0x29, 0x29, 0x29, 0x29, 0x49, 0x29, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x29, 0x29, 0x49, 0x49, 0x4a, 0x22, 0x27, 0x23, 0x23, 0x34, 0x2e, 0x42, 0x36, 0x4f, 0x4e, 0x4c, 0x00, 0x00, 0xff,
    0x53, 0x13, 
    0x16, MP_QSTR_FLAGS & 0xff, MP_QSTR_FLAGS >> 8,
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_FLAGS & 0xff, MP_QSTR_AD_TYPE_FLAGS >> 8,
    0x54, 
    0x17, 0x01, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID >> 8,
    0x54, 
    0x17, 0x02, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x54, 
    0x17, 0x03, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID >> 8,
    0x54, 
    0x17, 0x04, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x54, 
    0x17, 0x05, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID >> 8,
    0x54, 
    0x17, 0x06, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x54, 
    0x17, 0x07, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SHORTENED_LOCAL_NAME & 0xff, MP_QSTR_AD_TYPE_SHORTENED_LOCAL_NAME >> 8,
    0x54, 
    0x17, 0x08, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME & 0xff, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME >> 8,
    0x54, 
    0x17, 0x09, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_TX_POWER_LEVEL & 0xff, MP_QSTR_AD_TYPE_TX_POWER_LEVEL >> 8,
    0x54, 
    0x17, 0x0a, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_CLASS_OF_DEVICE & 0xff, MP_QSTR_AD_TYPE_CLASS_OF_DEVICE >> 8,
    0x54, 
    0x17, 0x0b, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SEC_MGR_TK_VALUE & 0xff, MP_QSTR_AD_TYPE_SEC_MGR_TK_VALUE >> 8,
    0x54, 
    0x17, 0x0c, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SEC_MGR_OOB_FLAGS & 0xff, MP_QSTR_AD_TYPE_SEC_MGR_OOB_FLAGS >> 8,
    0x54, 
    0x17, 0x0d, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SLAVE_CONN_INTERVAL & 0xff, MP_QSTR_AD_TYPE_SLAVE_CONN_INTERVAL >> 8,
    0x54, 
    0x17, 0x0e, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST >> 8,
    0x54, 
    0x17, 0x0f, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST >> 8,
    0x54, 
    0x17, 0x10, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST >> 8,
    0x54, 
    0x17, 0x11, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_SERVICE_DATA & 0xff, MP_QSTR_AD_TYPE_SERVICE_DATA >> 8,
    0x54, 
    0x17, 0x12, 
    0x1c, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x1d, MP_QSTR_AD_TYPE_MANUFACTURER_SPECIFIC_DATA & 0xff, MP_QSTR_AD_TYPE_MANUFACTURER_SPECIFIC_DATA >> 8,
    0x54, 
    0xc1, 
    0x80, 
    0xc2, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x64, 0x01, 
    0xc3, 
    0x53, 0x00, 
    0xc4, 
    0x35, 0x5d, 0x80, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x1e, MP_QSTR_from_bytes & 0xff, MP_QSTR_from_bytes >> 8,
    0xb0, 
    0xb2, 
    0xb2, 
    0x81, 
    0xf1, 
    0x58, 0x02, 
    0x21, 
    0x16, MP_QSTR_little & 0xff, MP_QSTR_little >> 8,
    0x66, 0x02, 
    0xc5, 
    0xb5, 
    0x80, 
    0xd9, 
    0x36, 0x08, 0x80, 
    0xb2, 
    0xb5, 
    0xf1, 
    0xb3, 
    0xd8, 
    0x37, 0x02, 0x80, 
    0xb4, 
    0x5b, 
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0x1e, MP_QSTR_from_bytes & 0xff, MP_QSTR_from_bytes >> 8,
    0xb0, 
    0xb2, 
    0x81, 
    0xf1, 
    0xb2, 
    0x82, 
    0xf1, 
    0x58, 0x02, 
    0x21, 
    0x16, MP_QSTR_little & 0xff, MP_QSTR_little >> 8,
    0x66, 0x02, 
    0xc6, 
    0xb0, 
    0xb2, 
    0x82, 
    0xf1, 
    0xb2, 
    0x82, 
    0xf1, 
    0xb5, 
    0xf1, 
    0x81, 
    0xf2, 
    0x58, 0x02, 
    0x21, 
    0xc7, 
    0xb4, 
    0x1e, MP_QSTR_update & 0xff, MP_QSTR_update >> 8,
    0x53, 0x01, 
    0xb7, 
    0xb1, 
    0xb6, 
    0x21, 
    0x54, 
    0x66, 0x01, 
    0x32, 
    0xb2, 
    0xb5, 
    0x81, 
    0xf1, 
    0xe5, 
    0xc2, 
    0xb2, 
    0xb3, 
    0xd7, 
    0x36, 0x9d, 0x7f, 
    0xb4, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_0 = {{&mp_type_str}, 21629, 16, (const byte*)"\x31\x36\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_1 = {{&mp_type_str}, 56537, 27, (const byte*)"\x31\x36\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44\x5f\x43\x4d\x50\x4c\x54\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_2 = {{&mp_type_str}, 11835, 16, (const byte*)"\x33\x32\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_3 = {{&mp_type_str}, 863, 27, (const byte*)"\x33\x32\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44\x5f\x43\x4d\x50\x4c\x54\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_4 = {{&mp_type_str}, 56577, 17, (const byte*)"\x31\x32\x38\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_5 = {{&mp_type_str}, 64613, 28, (const byte*)"\x31\x32\x38\x5f\x42\x49\x54\x5f\x53\x45\x52\x56\x5f\x55\x55\x49\x44\x5f\x43\x4d\x50\x4c\x54\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_6 = {{&mp_type_str}, 1687, 20, (const byte*)"\x53\x48\x4f\x52\x54\x45\x4e\x45\x44\x5f\x4c\x4f\x43\x41\x4c\x5f\x4e\x41\x4d\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_7 = {{&mp_type_str}, 41926, 19, (const byte*)"\x43\x4f\x4d\x50\x4c\x45\x54\x45\x5f\x4c\x4f\x43\x41\x4c\x5f\x4e\x41\x4d\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_8 = {{&mp_type_str}, 34880, 14, (const byte*)"\x54\x58\x5f\x50\x4f\x57\x45\x52\x5f\x4c\x45\x56\x45\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_9 = {{&mp_type_str}, 60058, 15, (const byte*)"\x43\x4c\x41\x53\x53\x5f\x4f\x46\x5f\x44\x45\x56\x49\x43\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_10 = {{&mp_type_str}, 40707, 16, (const byte*)"\x53\x45\x43\x5f\x4d\x47\x52\x5f\x54\x4b\x5f\x56\x41\x4c\x55\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_11 = {{&mp_type_str}, 4746, 17, (const byte*)"\x53\x45\x43\x5f\x4d\x47\x52\x5f\x4f\x4f\x42\x5f\x46\x4c\x41\x47\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_12 = {{&mp_type_str}, 49787, 19, (const byte*)"\x53\x4c\x41\x56\x45\x5f\x43\x4f\x4e\x4e\x5f\x49\x4e\x54\x45\x52\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_13 = {{&mp_type_str}, 37656, 29, (const byte*)"\x53\x45\x52\x56\x5f\x53\x4f\x4c\x49\x43\x49\x54\x5f\x31\x36\x5f\x42\x49\x54\x5f\x55\x55\x49\x44\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_14 = {{&mp_type_str}, 6878, 29, (const byte*)"\x53\x45\x52\x56\x5f\x53\x4f\x4c\x49\x43\x49\x54\x5f\x33\x32\x5f\x42\x49\x54\x5f\x55\x55\x49\x44\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_15 = {{&mp_type_str}, 25476, 30, (const byte*)"\x53\x45\x52\x56\x5f\x53\x4f\x4c\x49\x43\x49\x54\x5f\x31\x32\x38\x5f\x42\x49\x54\x5f\x55\x55\x49\x44\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_16 = {{&mp_type_str}, 49527, 12, (const byte*)"\x53\x45\x52\x56\x49\x43\x45\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_17 = {{&mp_type_str}, 62434, 26, (const byte*)"\x4d\x41\x4e\x55\x46\x41\x43\x54\x55\x52\x45\x52\x5f\x53\x50\x45\x43\x49\x46\x49\x43\x5f\x44\x41\x54\x41"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement[19] = {
    MP_ROM_QSTR(MP_QSTR_data),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement_17),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 339,
        .n_obj = 18,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/util.py, scope bluetooth_low_energy_api_util_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_util__lt_module_gt_[46] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0b,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_util_dot_py >> 8,
    0x21, 0x70, 0x85, 0x1e, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_constant & 0xff, MP_QSTR_constant >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_vendor_specifics_dot_st_microelectronics_dot_bluenrg_ms >> 8,
    0x69, MP_QSTR_constant & 0xff, MP_QSTR_constant >> 8,
    0x24, MP_QSTR_st_constant & 0xff, MP_QSTR_st_constant >> 8,
    0x32, 
    0x60, 0x00, 
    0x24, MP_QSTR_compute_attributes_record & 0xff, MP_QSTR_compute_attributes_record >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_util__lt_module_gt_[2] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_util__lt_module_gt__compute_attributes_record),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_util__lt_module_gt__format_advertisement),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_util__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_util__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_util__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 46,
        .n_obj = 0,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scan_entry.py, scope bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__
STATIC const byte bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__[41] = {
    0x07, 0x00, 0x00, 0x05, 0x00, 0x00, 0x0c,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py >> 8,
    0x81, 0x08, 0x25, 0x25, 0x25, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_address_type & 0xff, MP_QSTR_address_type >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR_rssi & 0xff, MP_QSTR_rssi >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__[5] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_address),
    MP_ROM_QSTR(MP_QSTR_address_type),
    MP_ROM_QSTR(MP_QSTR_rssi),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 41,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scan_entry.py, scope bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data
STATIC const byte bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data[27] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_get_data & 0xff, MP_QSTR_get_data >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py >> 8,
    0x81, 0x0e, 0x20, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 27,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scan_entry.py, scope bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry
STATIC const byte bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry[43] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c,
    MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py >> 8,
    0x6d, 0x40, 0x40, 0x65, 0x60, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR_get_data & 0xff, MP_QSTR_get_data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry[2] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry_get_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 43,
        .n_obj = 0,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/api/scan_entry.py, scope bluetooth_low_energy_api_scan_entry_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt_[48] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_api_slash_scan_entry_dot_py >> 8,
    0x21, 0x70, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_api_dot_util & 0xff, MP_QSTR_bluetooth_low_energy_dot_api_dot_util >> 8,
    0x69, MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    0x24, MP_QSTR_format_advertisement & 0xff, MP_QSTR_format_advertisement >> 8,
    0x32, 
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_ScanEntry & 0xff, MP_QSTR_ScanEntry >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt__ScanEntry),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_api_scan_entry__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_api_scan_entry__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 48,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/__init__.py, scope bluetooth_low_energy___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy___init____lt_module_gt_[29] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash___init___dot_py >> 8,
    0x27, 0x00, 0x00, 0xff,
    0x16, MP_QSTR_0_dot_1_hyphen_pre & 0xff, MP_QSTR_0_dot_1_hyphen_pre >> 8,
    0x24, MP_QSTR___version__ & 0xff, MP_QSTR___version__ >> 8,
    0x16, MP_QSTR_2_dot_0_dot_2 & 0xff, MP_QSTR_2_dot_0_dot_2 >> 8,
    0x24, MP_QSTR___version_bluenrg_dk__ & 0xff, MP_QSTR___version_bluenrg_dk__ >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 29,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/__init__.py, scope bluetooth_low_energy_protocols___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/at/__init__.py, scope bluetooth_low_energy_protocols_at___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_at___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_at_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_at_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_at___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_at___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/__init__.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/status.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_status_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_status__lt_module_gt_[284] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x37,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_status_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_status_dot_py >> 8,
    0x21, 0x70, 0x60, 0x40, 0x66, 0x66, 0x20, 0x66, 0x26, 0x46, 0x26, 0x26, 0x46, 0x46, 0x26, 0x46, 0x26, 0x26, 0x26, 0x26, 0x26, 0x46, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x66, 0x20, 0x66, 0x20, 0x66, 0x40, 0x66, 0x40, 0x66, 0x60, 0x66, 0x20, 0x26, 0x26, 0x86, 0x07, 0x64, 0x40, 0x64, 0x40, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x14, 0x80, 0x41, 
    0x24, MP_QSTR_BLE_STATUS_FAILED & 0xff, MP_QSTR_BLE_STATUS_FAILED >> 8,
    0x14, 0x80, 0x42, 
    0x24, MP_QSTR_BLE_STATUS_INVALID_PARAMS & 0xff, MP_QSTR_BLE_STATUS_INVALID_PARAMS >> 8,
    0x14, 0x80, 0x46, 
    0x24, MP_QSTR_BLE_STATUS_NOT_ALLOWED & 0xff, MP_QSTR_BLE_STATUS_NOT_ALLOWED >> 8,
    0x14, 0x80, 0x47, 
    0x24, MP_QSTR_BLE_STATUS_ERROR & 0xff, MP_QSTR_BLE_STATUS_ERROR >> 8,
    0x14, 0x80, 0x48, 
    0x24, MP_QSTR_BLE_STATUS_ADDR_NOT_RESOLVED & 0xff, MP_QSTR_BLE_STATUS_ADDR_NOT_RESOLVED >> 8,
    0x14, 0x80, 0x49, 
    0x24, MP_QSTR_FLASH_READ_FAILED & 0xff, MP_QSTR_FLASH_READ_FAILED >> 8,
    0x14, 0x80, 0x4a, 
    0x24, MP_QSTR_FLASH_WRITE_FAILED & 0xff, MP_QSTR_FLASH_WRITE_FAILED >> 8,
    0x14, 0x80, 0x4b, 
    0x24, MP_QSTR_FLASH_ERASE_FAILED & 0xff, MP_QSTR_FLASH_ERASE_FAILED >> 8,
    0x14, 0x80, 0x50, 
    0x24, MP_QSTR_BLE_STATUS_INVALID_CID & 0xff, MP_QSTR_BLE_STATUS_INVALID_CID >> 8,
    0x14, 0x80, 0x54, 
    0x24, MP_QSTR_TIMER_NOT_VALID_LAYER & 0xff, MP_QSTR_TIMER_NOT_VALID_LAYER >> 8,
    0x14, 0x80, 0x55, 
    0x24, MP_QSTR_TIMER_INSUFFICIENT_RESOURCES & 0xff, MP_QSTR_TIMER_INSUFFICIENT_RESOURCES >> 8,
    0x14, 0x80, 0x5a, 
    0x24, MP_QSTR_BLE_STATUS_CSRK_NOT_FOUND & 0xff, MP_QSTR_BLE_STATUS_CSRK_NOT_FOUND >> 8,
    0x14, 0x80, 0x5b, 
    0x24, MP_QSTR_BLE_STATUS_IRK_NOT_FOUND & 0xff, MP_QSTR_BLE_STATUS_IRK_NOT_FOUND >> 8,
    0x14, 0x80, 0x5c, 
    0x24, MP_QSTR_BLE_STATUS_DEV_NOT_FOUND_IN_DB & 0xff, MP_QSTR_BLE_STATUS_DEV_NOT_FOUND_IN_DB >> 8,
    0x14, 0x80, 0x5d, 
    0x24, MP_QSTR_BLE_STATUS_SEC_DB_FULL & 0xff, MP_QSTR_BLE_STATUS_SEC_DB_FULL >> 8,
    0x14, 0x80, 0x5e, 
    0x24, MP_QSTR_BLE_STATUS_DEV_NOT_BONDED & 0xff, MP_QSTR_BLE_STATUS_DEV_NOT_BONDED >> 8,
    0x14, 0x80, 0x5f, 
    0x24, MP_QSTR_BLE_STATUS_DEV_IN_BLACKLIST & 0xff, MP_QSTR_BLE_STATUS_DEV_IN_BLACKLIST >> 8,
    0x14, 0x80, 0x60, 
    0x24, MP_QSTR_BLE_STATUS_INVALID_HANDLE & 0xff, MP_QSTR_BLE_STATUS_INVALID_HANDLE >> 8,
    0x14, 0x80, 0x61, 
    0x24, MP_QSTR_BLE_STATUS_INVALID_PARAMETER & 0xff, MP_QSTR_BLE_STATUS_INVALID_PARAMETER >> 8,
    0x14, 0x80, 0x62, 
    0x24, MP_QSTR_BLE_STATUS_OUT_OF_HANDLE & 0xff, MP_QSTR_BLE_STATUS_OUT_OF_HANDLE >> 8,
    0x14, 0x80, 0x63, 
    0x24, MP_QSTR_BLE_STATUS_INVALID_OPERATION & 0xff, MP_QSTR_BLE_STATUS_INVALID_OPERATION >> 8,
    0x14, 0x80, 0x64, 
    0x24, MP_QSTR_BLE_STATUS_INSUFFICIENT_RESOURCES & 0xff, MP_QSTR_BLE_STATUS_INSUFFICIENT_RESOURCES >> 8,
    0x14, 0x80, 0x65, 
    0x24, MP_QSTR_BLE_INSUFFICIENT_ENC_KEYSIZE & 0xff, MP_QSTR_BLE_INSUFFICIENT_ENC_KEYSIZE >> 8,
    0x14, 0x80, 0x66, 
    0x24, MP_QSTR_BLE_STATUS_CHARAC_ALREADY_EXISTS & 0xff, MP_QSTR_BLE_STATUS_CHARAC_ALREADY_EXISTS >> 8,
    0x14, 0x81, 0x02, 
    0x24, MP_QSTR_BLE_STATUS_NO_VALID_SLOT & 0xff, MP_QSTR_BLE_STATUS_NO_VALID_SLOT >> 8,
    0x14, 0x81, 0x03, 
    0x24, MP_QSTR_BLE_STATUS_SCAN_WINDOW_SHORT & 0xff, MP_QSTR_BLE_STATUS_SCAN_WINDOW_SHORT >> 8,
    0x14, 0x81, 0x04, 
    0x24, MP_QSTR_BLE_STATUS_NEW_INTERVAL_FAILED & 0xff, MP_QSTR_BLE_STATUS_NEW_INTERVAL_FAILED >> 8,
    0x14, 0x81, 0x05, 
    0x24, MP_QSTR_BLE_STATUS_INTERVAL_TOO_LARGE & 0xff, MP_QSTR_BLE_STATUS_INTERVAL_TOO_LARGE >> 8,
    0x14, 0x81, 0x06, 
    0x24, MP_QSTR_BLE_STATUS_LENGTH_FAILED & 0xff, MP_QSTR_BLE_STATUS_LENGTH_FAILED >> 8,
    0x14, 0x81, 0x7f, 
    0x24, MP_QSTR_BLE_STATUS_TIMEOUT & 0xff, MP_QSTR_BLE_STATUS_TIMEOUT >> 8,
    0x14, 0x81, 0x70, 
    0x24, MP_QSTR_BLE_STATUS_PROFILE_ALREADY_INITIALIZED & 0xff, MP_QSTR_BLE_STATUS_PROFILE_ALREADY_INITIALIZED >> 8,
    0x14, 0x81, 0x71, 
    0x24, MP_QSTR_BLE_STATUS_NULL_PARAM & 0xff, MP_QSTR_BLE_STATUS_NULL_PARAM >> 8,
    0x80, 
    0x24, MP_QSTR_SPI_FRAMING_ERROR & 0xff, MP_QSTR_SPI_FRAMING_ERROR >> 8,
    0x81, 
    0x24, MP_QSTR_RADIO_STATE_ERROR & 0xff, MP_QSTR_RADIO_STATE_ERROR >> 8,
    0x82, 
    0x24, MP_QSTR_TIMER_OVERRUN_ERROR & 0xff, MP_QSTR_TIMER_OVERRUN_ERROR >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_status__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_status__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 284,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/event.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_[2986] = {
    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x73,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_event_dot_py >> 8,
    0x21, 0x28, 0x50, 0x50, 0x24, 0x24, 0x24, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x66, 0x60, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x45, 0x22, 0x20, 0x22, 0x22, 0x6f, 0x20, 0x22, 0x22, 0x79, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2b, 0x20, 0x7e, 0x20, 0x69, 0x20, 0x22, 0x22, 0x2b, 0x72, 0x20, 0x22, 0x22, 0x71, 0x20, 0x69, 0x20, 0x69, 0x20, 0x22, 0x22, 0x2c, 0x2b, 0x36, 0x2b, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x2b, 0x2c, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x71, 0x20, 0x22, 0x22, 0x7b, 0x20, 0x22, 0x22, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2c, 0x2c, 0x2b, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2c, 0x2b, 0x2b, 0x2b, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x2c, 0x20, 0x5e, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x1f, 0x65, 0x20, 0x20, 0x22, 0x22, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2c, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x2c, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2c, 0x2b, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x20, 0x7f, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x20, 0x1f, 0x61, 0x20, 0x22, 0x22, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x71, 0x20, 0x22, 0x22, 0x2b, 0x2c, 0x2c, 0x2c, 0x20, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x24, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_EVT_BLUE_HAL_INITIALIZED & 0xff, MP_QSTR_EVT_BLUE_HAL_INITIALIZED >> 8,
    0x82, 
    0x24, MP_QSTR_EVT_BLUE_HAL_EVENTS_LOST_IDB05A1 & 0xff, MP_QSTR_EVT_BLUE_HAL_EVENTS_LOST_IDB05A1 >> 8,
    0x83, 
    0x24, MP_QSTR_EVT_BLUE_HAL_CRASH_INFO_IDB05A1 & 0xff, MP_QSTR_EVT_BLUE_HAL_CRASH_INFO_IDB05A1 >> 8,
    0x14, 0x88, 0x00, 
    0x24, MP_QSTR_EVT_BLUE_GAP_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_EVT_BLUE_GAP_LIMITED_DISCOVERABLE >> 8,
    0x14, 0x88, 0x01, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT & 0xff, MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT >> 8,
    0x14, 0x88, 0x02, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST & 0xff, MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST >> 8,
    0x14, 0x88, 0x04, 
    0x24, MP_QSTR_EVT_BLUE_GAP_SLAVE_SECURITY_INITIATED & 0xff, MP_QSTR_EVT_BLUE_GAP_SLAVE_SECURITY_INITIATED >> 8,
    0x14, 0x88, 0x05, 
    0x24, MP_QSTR_EVT_BLUE_GAP_BOND_LOST & 0xff, MP_QSTR_EVT_BLUE_GAP_BOND_LOST >> 8,
    0x14, 0x88, 0x06, 
    0x24, MP_QSTR_EVT_BLUE_GAP_DEVICE_FOUND & 0xff, MP_QSTR_EVT_BLUE_GAP_DEVICE_FOUND >> 8,
    0x14, 0x88, 0x07, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE & 0xff, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE >> 8,
    0x14, 0x88, 0x08, 
    0x24, MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_IDB05A1 & 0xff, MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_IDB05A1 >> 8,
    0x14, 0x88, 0x08, 
    0x24, MP_QSTR_EVT_BLUE_GAP_RECONNECTION_ADDRESS_IDB04A1 & 0xff, MP_QSTR_EVT_BLUE_GAP_RECONNECTION_ADDRESS_IDB04A1 >> 8,
    0x14, 0x88, 0x03, 
    0x24, MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST & 0xff, MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST >> 8,
    0x14, 0x90, 0x00, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_RESP & 0xff, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_RESP >> 8,
    0x14, 0x90, 0x01, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT & 0xff, MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT >> 8,
    0x14, 0x90, 0x02, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_REQ & 0xff, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPD_REQ >> 8,
    0x14, 0x98, 0x01, 
    0x24, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED & 0xff, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED >> 8,
    0x14, 0x98, 0x02, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT & 0xff, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT >> 8,
    0x14, 0x98, 0x03, 
    0x24, MP_QSTR_EVT_BLUE_ATT_EXCHANGE_MTU_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_EXCHANGE_MTU_RESP >> 8,
    0x14, 0x98, 0x04, 
    0x24, MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP >> 8,
    0x14, 0x98, 0x05, 
    0x24, MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP >> 8,
    0x14, 0x98, 0x06, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP >> 8,
    0x14, 0x98, 0x07, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_RESP >> 8,
    0x14, 0x98, 0x08, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP >> 8,
    0x14, 0x98, 0x09, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP >> 8,
    0x14, 0x98, 0x0a, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_TYPE_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_TYPE_RESP >> 8,
    0x14, 0x98, 0x0c, 
    0x24, MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP >> 8,
    0x14, 0x98, 0x0d, 
    0x24, MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP & 0xff, MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP >> 8,
    0x14, 0x98, 0x0e, 
    0x24, MP_QSTR_EVT_BLUE_GATT_INDICATION & 0xff, MP_QSTR_EVT_BLUE_GATT_INDICATION >> 8,
    0x14, 0x98, 0x0f, 
    0x24, MP_QSTR_EVT_BLUE_GATT_NOTIFICATION & 0xff, MP_QSTR_EVT_BLUE_GATT_NOTIFICATION >> 8,
    0x14, 0x98, 0x10, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE & 0xff, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE >> 8,
    0x14, 0x98, 0x11, 
    0x24, MP_QSTR_EVT_BLUE_GATT_ERROR_RESP & 0xff, MP_QSTR_EVT_BLUE_GATT_ERROR_RESP >> 8,
    0x14, 0x98, 0x12, 
    0x24, MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHAR_BY_UUID_RESP & 0xff, MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHAR_BY_UUID_RESP >> 8,
    0x14, 0x98, 0x13, 
    0x24, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ >> 8,
    0x14, 0x98, 0x14, 
    0x24, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ >> 8,
    0x14, 0x98, 0x15, 
    0x24, MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ >> 8,
    0x14, 0x98, 0x16, 
    0x24, MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE & 0xff, MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE >> 8,
    0x14, 0x98, 0x17, 
    0x24, MP_QSTR_EVT_BLUE_GATT_SERVER_CONFIRMATION_EVENT & 0xff, MP_QSTR_EVT_BLUE_GATT_SERVER_CONFIRMATION_EVENT >> 8,
    0x14, 0x98, 0x18, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ & 0xff, MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ >> 8,
    0x80, 
    0x24, MP_QSTR_EVT_DISCONN_COMPLETE_BIT & 0xff, MP_QSTR_EVT_DISCONN_COMPLETE_BIT >> 8,
    0x81, 
    0x24, MP_QSTR_EVT_ENCRYPT_CHANGE_BIT & 0xff, MP_QSTR_EVT_ENCRYPT_CHANGE_BIT >> 8,
    0x82, 
    0x24, MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE_BIT & 0xff, MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE_BIT >> 8,
    0x83, 
    0x24, MP_QSTR_EVT_CMD_COMPLETE_BIT & 0xff, MP_QSTR_EVT_CMD_COMPLETE_BIT >> 8,
    0x84, 
    0x24, MP_QSTR_EVT_CMD_STATUS_BIT & 0xff, MP_QSTR_EVT_CMD_STATUS_BIT >> 8,
    0x85, 
    0x24, MP_QSTR_EVT_HARDWARE_ERROR_BIT & 0xff, MP_QSTR_EVT_HARDWARE_ERROR_BIT >> 8,
    0x86, 
    0x24, MP_QSTR_EVT_NUM_COMP_PKTS_BIT & 0xff, MP_QSTR_EVT_NUM_COMP_PKTS_BIT >> 8,
    0x87, 
    0x24, MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_BIT & 0xff, MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_BIT >> 8,
    0x88, 
    0x24, MP_QSTR_EVT_BLUE_HAL_INITIALIZED_BIT & 0xff, MP_QSTR_EVT_BLUE_HAL_INITIALIZED_BIT >> 8,
    0x89, 
    0x24, MP_QSTR_EVT_BLUE_GAP_SET_LIMITED_DISCOVERABLE_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_SET_LIMITED_DISCOVERABLE_BIT >> 8,
    0x8a, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_PAIRING_CMPLT_BIT >> 8,
    0x8b, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_PASS_KEY_REQUEST_BIT >> 8,
    0x8c, 
    0x24, MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_AUTHORIZATION_REQUEST_BIT >> 8,
    0x8d, 
    0x24, MP_QSTR_EVT_BLUE_GAP_SECURITY_REQ_INITIATED_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_SECURITY_REQ_INITIATED_BIT >> 8,
    0x8e, 
    0x24, MP_QSTR_EVT_BLUE_GAP_BOND_LOST_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_BOND_LOST_BIT >> 8,
    0x8f, 
    0x24, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_PROCEDURE_COMPLETE_BIT >> 8,
    0x90, 
    0x24, MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_BIT & 0xff, MP_QSTR_EVT_BLUE_GAP_ADDR_NOT_RESOLVED_BIT >> 8,
    0x91, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_RESP_BIT >> 8,
    0x92, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT_BIT & 0xff, MP_QSTR_EVT_BLUE_L2CAP_PROCEDURE_TIMEOUT_BIT >> 8,
    0x93, 
    0x24, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_REQ_BIT & 0xff, MP_QSTR_EVT_BLUE_L2CAP_CONN_UPDATE_REQ_BIT >> 8,
    0x94, 
    0x24, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_ATTRIBUTE_MODIFIED_BIT >> 8,
    0x95, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_TIMEOUT_BIT >> 8,
    0x96, 
    0x24, MP_QSTR_EVT_BLUE_EXCHANGE_MTU_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_EXCHANGE_MTU_RESP_BIT >> 8,
    0x97, 
    0x24, MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_FIND_INFORMATION_RESP_BIT >> 8,
    0x98, 
    0x24, MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_FIND_BY_TYPE_VAL_RESP_BIT >> 8,
    0x99, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BY_TYPE_RESP_BIT >> 8,
    0x9a, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_RESP_BIT >> 8,
    0x9b, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BLOB_RESP_BIT >> 8,
    0x9c, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_MULTIPLE_RESP_BIT >> 8,
    0x9d, 
    0x24, MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_READ_BY_GROUP_RESP_BIT >> 8,
    0x9e, 
    0x24, MP_QSTR_EVT_BLUE_ATT_WRITE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_WRITE_RESP_BIT >> 8,
    0x9f, 
    0x24, MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_PREPARE_WRITE_RESP_BIT >> 8,
    0xa0, 
    0x24, MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_ATT_EXEC_WRITE_RESP_BIT >> 8,
    0xa1, 
    0x24, MP_QSTR_EVT_BLUE_GATT_INDICATION_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_INDICATION_BIT >> 8,
    0xa2, 
    0x24, MP_QSTR_EVT_BLUE_GATT_NOTIFICATION_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_NOTIFICATION_BIT >> 8,
    0xa3, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_PROCEDURE_COMPLETE_BIT >> 8,
    0xa4, 
    0x24, MP_QSTR_EVT_BLUE_GATT_ERROR_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_ERROR_RESP_BIT >> 8,
    0xa5, 
    0x24, MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHARAC_BY_UUID_RESP_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_DISC_READ_CHARAC_BY_UUID_RESP_BIT >> 8,
    0xa6, 
    0x24, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_WRITE_PERMIT_REQ_BIT >> 8,
    0xa7, 
    0x24, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_PERMIT_REQ_BIT >> 8,
    0xa8, 
    0x24, MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_READ_MULTI_PERMIT_REQ_BIT >> 8,
    0xa9, 
    0x24, MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_TX_POOL_AVAILABLE_BIT >> 8,
    0xaa, 
    0x24, MP_QSTR_EVT_BLUE_GATT_SERVER_RX_CONFIRMATION_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_SERVER_RX_CONFIRMATION_BIT >> 8,
    0xab, 
    0x24, MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ_BIT & 0xff, MP_QSTR_EVT_BLUE_GATT_PREPARE_WRITE_PERMIT_REQ_BIT >> 8,
    0xac, 
    0x24, MP_QSTR_EVT_LL_CONNECTION_COMPLETE_BIT & 0xff, MP_QSTR_EVT_LL_CONNECTION_COMPLETE_BIT >> 8,
    0xad, 
    0x24, MP_QSTR_EVT_LL_ADVERTISING_REPORT_BIT & 0xff, MP_QSTR_EVT_LL_ADVERTISING_REPORT_BIT >> 8,
    0xae, 
    0x24, MP_QSTR_EVT_LL_CONNECTION_UPDATE_COMPLETE_BIT & 0xff, MP_QSTR_EVT_LL_CONNECTION_UPDATE_COMPLETE_BIT >> 8,
    0xaf, 
    0x24, MP_QSTR_EVT_LL_READ_REMOTE_USED_FEATURES_BIT & 0xff, MP_QSTR_EVT_LL_READ_REMOTE_USED_FEATURES_BIT >> 8,
    0x14, 0x30, 
    0x24, MP_QSTR_EVT_LL_LTK_REQUEST_BIT & 0xff, MP_QSTR_EVT_LL_LTK_REQUEST_BIT >> 8,
    0x53, 0x27, 
    0x17, 0x00, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x01, 
    0x54, 
    0x51, 0x02, 
    0x81, 
    0x54, 
    0x17, 0x02, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x03, 
    0x54, 
    0x51, 0x02, 
    0x82, 
    0x54, 
    0x17, 0x04, 
    0x53, 0x0d, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_crash_type & 0xff, MP_QSTR_crash_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_sp & 0xff, MP_QSTR_sp >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x85, 
    0xec, 
    0x16, MP_QSTR_sp1 & 0xff, MP_QSTR_sp1 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x89, 
    0xec, 
    0x16, MP_QSTR_r0 & 0xff, MP_QSTR_r0 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x8d, 
    0xec, 
    0x16, MP_QSTR_r1 & 0xff, MP_QSTR_r1 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x91, 
    0xec, 
    0x16, MP_QSTR_r2 & 0xff, MP_QSTR_r2 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x95, 
    0xec, 
    0x16, MP_QSTR_r3 & 0xff, MP_QSTR_r3 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x99, 
    0xec, 
    0x16, MP_QSTR_r12 & 0xff, MP_QSTR_r12 >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x9d, 
    0xec, 
    0x16, MP_QSTR_lr & 0xff, MP_QSTR_lr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0xa1, 
    0xec, 
    0x16, MP_QSTR_pc & 0xff, MP_QSTR_pc >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0xa5, 
    0xec, 
    0x16, MP_QSTR_xpsr & 0xff, MP_QSTR_xpsr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0xa9, 
    0xec, 
    0x17, 0x05, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0xae, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0xae, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_debug_data & 0xff, MP_QSTR_debug_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x06, 
    0x11, 
    0x51, 0x02, 
    0x14, 0x88, 0x00, 
    0x54, 
    0x17, 0x07, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x08, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x01, 
    0x54, 
    0x17, 0x09, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x0a, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x02, 
    0x54, 
    0x17, 0x0b, 
    0x11, 
    0x51, 0x02, 
    0x14, 0x88, 0x04, 
    0x54, 
    0x17, 0x0c, 
    0x11, 
    0x51, 0x02, 
    0x14, 0x88, 0x05, 
    0x54, 
    0x17, 0x0d, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_evt_type & 0xff, MP_QSTR_evt_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x0e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x17, 0x0f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x89, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x89, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data_rssi & 0xff, MP_QSTR_data_rssi >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x06, 
    0x54, 
    0x17, 0x10, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x11, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x82, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x07, 
    0x54, 
    0x17, 0x12, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x13, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x08, 
    0x54, 
    0x17, 0x14, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x15, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x08, 
    0x54, 
    0x17, 0x16, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x17, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x88, 0x03, 
    0x54, 
    0x17, 0x18, 
    0x53, 0x06, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x19, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x1a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_identifier & 0xff, MP_QSTR_identifier >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x17, 0x1b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x87, 
    0xec, 
    0x16, MP_QSTR_result & 0xff, MP_QSTR_result >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x90, 0x00, 
    0x54, 
    0x17, 0x1c, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x1d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x1e, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x90, 0x01, 
    0x54, 
    0x17, 0x1f, 
    0x53, 0x08, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x20, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x21, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_identifier & 0xff, MP_QSTR_identifier >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x22, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x17, 0x23, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x24, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x17, 0x25, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x26, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x90, 0x02, 
    0x54, 
    0x17, 0x27, 
    0x53, 0x02, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x28, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x29, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x2a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_att_data & 0xff, MP_QSTR_att_data >> 8,
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x2b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x2c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x2d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_att_data & 0xff, MP_QSTR_att_data >> 8,
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x01, 
    0x54, 
    0x17, 0x2e, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x2f, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x02, 
    0x54, 
    0x17, 0x30, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x31, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x32, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x33, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x03, 
    0x54, 
    0x17, 0x34, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x35, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x36, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x84, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x84, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x37, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x04, 
    0x54, 
    0x17, 0x38, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x39, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x3a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x3b, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x05, 
    0x54, 
    0x17, 0x3c, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x3d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x3e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x17, 0x3f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x84, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x84, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x40, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x06, 
    0x54, 
    0x17, 0x41, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x42, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x43, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x44, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x07, 
    0x54, 
    0x17, 0x45, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x46, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x47, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x48, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x08, 
    0x54, 
    0x17, 0x49, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x4a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x4b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x4c, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x09, 
    0x54, 
    0x17, 0x4d, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x4e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x4f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x17, 0x50, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x84, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x84, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x51, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x0a, 
    0x54, 
    0x17, 0x52, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x53, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x54, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x55, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x56, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x0c, 
    0x54, 
    0x17, 0x57, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x58, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x59, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x0d, 
    0x54, 
    0x17, 0x5a, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x5b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x5c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x5d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_value & 0xff, MP_QSTR_attr_value >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x0e, 
    0x54, 
    0x17, 0x5e, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x5f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x60, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x61, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_value & 0xff, MP_QSTR_attr_value >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x0f, 
    0x54, 
    0x17, 0x62, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x63, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x64, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_error_code & 0xff, MP_QSTR_error_code >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x10, 
    0x54, 
    0x17, 0x65, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x66, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x67, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_req_opcode & 0xff, MP_QSTR_req_opcode >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x68, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_error_code & 0xff, MP_QSTR_error_code >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x11, 
    0x54, 
    0x17, 0x69, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x6a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x6b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x6c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_value & 0xff, MP_QSTR_attr_value >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x12, 
    0x54, 
    0x17, 0x6d, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x6e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x6f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x70, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x71, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x13, 
    0x54, 
    0x17, 0x72, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x73, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x74, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x75, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x14, 
    0x54, 
    0x17, 0x76, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x77, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x78, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x15, 
    0x54, 
    0x17, 0x79, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x7a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x7b, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x16, 
    0x54, 
    0x17, 0x7c, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x7d, 
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x17, 
    0x54, 
    0x17, 0x7e, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x7f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x00, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x81, 0x01, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x98, 0x18, 
    0x54, 
    0x24, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__0 = {{&mp_type_str}, 64498, 20, (const byte*)"\x42\x4c\x55\x45\x5f\x48\x41\x4c\x5f\x49\x4e\x49\x54\x49\x41\x4c\x49\x5a\x45\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__1 = {{&mp_type_str}, 50259, 11, (const byte*)"\x72\x65\x61\x73\x6f\x6e\x5f\x63\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__2 = {{&mp_type_str}, 8063, 28, (const byte*)"\x42\x4c\x55\x45\x5f\x48\x41\x4c\x5f\x45\x56\x45\x4e\x54\x53\x5f\x4c\x4f\x53\x54\x5f\x49\x44\x42\x30\x35\x41\x31"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__3 = {{&mp_type_str}, 42497, 11, (const byte*)"\x6c\x6f\x73\x74\x5f\x65\x76\x65\x6e\x74\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__4 = {{&mp_type_str}, 15617, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x48\x41\x4c\x5f\x43\x52\x41\x53\x48\x5f\x49\x4e\x46\x4f\x5f\x49\x44\x42\x30\x35\x41\x31"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__5 = {{&mp_type_str}, 291, 14, (const byte*)"\x64\x65\x62\x75\x67\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__6 = {{&mp_type_str}, 14303, 29, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x4c\x49\x4d\x49\x54\x45\x44\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__7 = {{&mp_type_str}, 37758, 22, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x50\x41\x49\x52\x49\x4e\x47\x5f\x43\x4d\x50\x4c\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__8 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__9 = {{&mp_type_str}, 37594, 25, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x50\x41\x53\x53\x5f\x4b\x45\x59\x5f\x52\x45\x51\x55\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__10 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__11 = {{&mp_type_str}, 25137, 33, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x53\x4c\x41\x56\x45\x5f\x53\x45\x43\x55\x52\x49\x54\x59\x5f\x49\x4e\x49\x54\x49\x41\x54\x45\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__12 = {{&mp_type_str}, 4241, 18, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x42\x4f\x4e\x44\x5f\x4c\x4f\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__13 = {{&mp_type_str}, 39068, 21, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x44\x45\x56\x49\x43\x45\x5f\x46\x4f\x55\x4e\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__14 = {{&mp_type_str}, 44727, 11, (const byte*)"\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__15 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__16 = {{&mp_type_str}, 32758, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x50\x52\x4f\x43\x45\x44\x55\x52\x45\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__17 = {{&mp_type_str}, 9370, 14, (const byte*)"\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x5f\x63\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__18 = {{&mp_type_str}, 18814, 34, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x41\x44\x44\x52\x5f\x4e\x4f\x54\x5f\x52\x45\x53\x4f\x4c\x56\x45\x44\x5f\x49\x44\x42\x30\x35\x41\x31"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__19 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__20 = {{&mp_type_str}, 1889, 37, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x52\x45\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x5f\x41\x44\x44\x52\x45\x53\x53\x5f\x49\x44\x42\x30\x34\x41\x31"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__21 = {{&mp_type_str}, 52621, 20, (const byte*)"\x72\x65\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x5f\x61\x64\x64\x72\x65\x73\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__22 = {{&mp_type_str}, 44952, 30, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x50\x5f\x41\x55\x54\x48\x4f\x52\x49\x5a\x41\x54\x49\x4f\x4e\x5f\x52\x45\x51\x55\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__23 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__24 = {{&mp_type_str}, 9486, 24, (const byte*)"\x42\x4c\x55\x45\x5f\x4c\x32\x43\x41\x50\x5f\x43\x4f\x4e\x4e\x5f\x55\x50\x44\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__25 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__26 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__27 = {{&mp_type_str}, 59338, 12, (const byte*)"\x6c\x32\x63\x61\x70\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__28 = {{&mp_type_str}, 21854, 28, (const byte*)"\x42\x4c\x55\x45\x5f\x4c\x32\x43\x41\x50\x5f\x50\x52\x4f\x43\x45\x44\x55\x52\x45\x5f\x54\x49\x4d\x45\x4f\x55\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__29 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__30 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__31 = {{&mp_type_str}, 61852, 23, (const byte*)"\x42\x4c\x55\x45\x5f\x4c\x32\x43\x41\x50\x5f\x43\x4f\x4e\x4e\x5f\x55\x50\x44\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__32 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__33 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__34 = {{&mp_type_str}, 59338, 12, (const byte*)"\x6c\x32\x63\x61\x70\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__35 = {{&mp_type_str}, 32431, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__36 = {{&mp_type_str}, 32689, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__37 = {{&mp_type_str}, 6335, 13, (const byte*)"\x73\x6c\x61\x76\x65\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__38 = {{&mp_type_str}, 62145, 12, (const byte*)"\x74\x69\x6d\x65\x6f\x75\x74\x5f\x6d\x75\x6c\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__39 = {{&mp_type_str}, 2303, 28, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x41\x54\x54\x52\x49\x42\x55\x54\x45\x5f\x4d\x4f\x44\x49\x46\x49\x45\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__40 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__41 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__42 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__43 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__44 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__45 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__46 = {{&mp_type_str}, 7092, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x50\x52\x4f\x43\x45\x44\x55\x52\x45\x5f\x54\x49\x4d\x45\x4f\x55\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__47 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__48 = {{&mp_type_str}, 11961, 26, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x45\x58\x43\x48\x41\x4e\x47\x45\x5f\x4d\x54\x55\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__49 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__50 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__51 = {{&mp_type_str}, 59270, 13, (const byte*)"\x73\x65\x72\x76\x65\x72\x5f\x72\x78\x5f\x6d\x74\x75"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__52 = {{&mp_type_str}, 52423, 30, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x46\x49\x4e\x44\x5f\x49\x4e\x46\x4f\x52\x4d\x41\x54\x49\x4f\x4e\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__53 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__54 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__55 = {{&mp_type_str}, 36776, 16, (const byte*)"\x68\x61\x6e\x64\x6c\x65\x5f\x75\x75\x69\x64\x5f\x70\x61\x69\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__56 = {{&mp_type_str}, 59603, 30, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x46\x49\x4e\x44\x5f\x42\x59\x5f\x54\x59\x50\x45\x5f\x56\x41\x4c\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__57 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__58 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__59 = {{&mp_type_str}, 25392, 17, (const byte*)"\x68\x61\x6e\x64\x6c\x65\x73\x5f\x69\x6e\x66\x6f\x5f\x6c\x69\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__60 = {{&mp_type_str}, 57984, 26, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x42\x59\x5f\x54\x59\x50\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__61 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__62 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__63 = {{&mp_type_str}, 35213, 24, (const byte*)"\x68\x61\x6e\x64\x6c\x65\x5f\x76\x61\x6c\x75\x65\x5f\x70\x61\x69\x72\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__64 = {{&mp_type_str}, 38478, 17, (const byte*)"\x68\x61\x6e\x64\x6c\x65\x5f\x76\x61\x6c\x75\x65\x5f\x70\x61\x69\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__65 = {{&mp_type_str}, 59683, 18, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__66 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__67 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__68 = {{&mp_type_str}, 55181, 15, (const byte*)"\x61\x74\x74\x72\x69\x62\x75\x74\x65\x5f\x76\x61\x6c\x75\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__69 = {{&mp_type_str}, 36703, 23, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x42\x4c\x4f\x42\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__70 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__71 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__72 = {{&mp_type_str}, 22085, 20, (const byte*)"\x70\x61\x72\x74\x5f\x61\x74\x74\x72\x69\x62\x75\x74\x65\x5f\x76\x61\x6c\x75\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__73 = {{&mp_type_str}, 33676, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x4d\x55\x4c\x54\x49\x50\x4c\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__74 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__75 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__76 = {{&mp_type_str}, 51318, 13, (const byte*)"\x73\x65\x74\x5f\x6f\x66\x5f\x76\x61\x6c\x75\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__77 = {{&mp_type_str}, 51776, 32, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x42\x59\x5f\x47\x52\x4f\x55\x50\x5f\x54\x59\x50\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__78 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__79 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__80 = {{&mp_type_str}, 43381, 21, (const byte*)"\x61\x74\x74\x72\x69\x62\x75\x74\x65\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__81 = {{&mp_type_str}, 12107, 19, (const byte*)"\x61\x74\x74\x72\x69\x62\x75\x74\x65\x5f\x64\x61\x74\x61\x5f\x6c\x69\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__82 = {{&mp_type_str}, 1362, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x50\x52\x45\x50\x41\x52\x45\x5f\x57\x52\x49\x54\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__83 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__84 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__85 = {{&mp_type_str}, 30956, 16, (const byte*)"\x61\x74\x74\x72\x69\x62\x75\x74\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__86 = {{&mp_type_str}, 61674, 15, (const byte*)"\x70\x61\x72\x74\x5f\x61\x74\x74\x72\x5f\x76\x61\x6c\x75\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__87 = {{&mp_type_str}, 41352, 24, (const byte*)"\x42\x4c\x55\x45\x5f\x41\x54\x54\x5f\x45\x58\x45\x43\x5f\x57\x52\x49\x54\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__88 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__89 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__90 = {{&mp_type_str}, 48457, 20, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x49\x4e\x44\x49\x43\x41\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__91 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__92 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__93 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__94 = {{&mp_type_str}, 50672, 22, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x4e\x4f\x54\x49\x46\x49\x43\x41\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__95 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__96 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__97 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__98 = {{&mp_type_str}, 40038, 28, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x50\x52\x4f\x43\x45\x44\x55\x52\x45\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__99 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__100 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__101 = {{&mp_type_str}, 54446, 20, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x45\x52\x52\x4f\x52\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__102 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__103 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__104 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__105 = {{&mp_type_str}, 65143, 37, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x52\x45\x41\x44\x5f\x43\x48\x41\x52\x5f\x42\x59\x5f\x55\x55\x49\x44\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__106 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__107 = {{&mp_type_str}, 57445, 17, (const byte*)"\x65\x76\x65\x6e\x74\x5f\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__108 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__109 = {{&mp_type_str}, 17521, 26, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x50\x45\x52\x4d\x49\x54\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__110 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__111 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__112 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__113 = {{&mp_type_str}, 8970, 11, (const byte*)"\x64\x61\x74\x61\x5f\x62\x75\x66\x66\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__114 = {{&mp_type_str}, 49694, 25, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x50\x45\x52\x4d\x49\x54\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__115 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__116 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__117 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__118 = {{&mp_type_str}, 42440, 31, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x4d\x55\x4c\x54\x49\x5f\x50\x45\x52\x4d\x49\x54\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__119 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__120 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__121 = {{&mp_type_str}, 56532, 27, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x54\x58\x5f\x50\x4f\x4f\x4c\x5f\x41\x56\x41\x49\x4c\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__122 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__123 = {{&mp_type_str}, 43504, 17, (const byte*)"\x61\x76\x61\x69\x6c\x61\x62\x6c\x65\x5f\x62\x75\x66\x66\x65\x72\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__124 = {{&mp_type_str}, 13595, 35, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x53\x45\x52\x56\x45\x52\x5f\x43\x4f\x4e\x46\x49\x52\x4d\x41\x54\x49\x4f\x4e\x5f\x45\x56\x45\x4e\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__125 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__126 = {{&mp_type_str}, 48399, 34, (const byte*)"\x42\x4c\x55\x45\x5f\x47\x41\x54\x54\x5f\x50\x52\x45\x50\x41\x52\x45\x5f\x57\x52\x49\x54\x45\x5f\x50\x45\x52\x4d\x49\x54\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__127 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__128 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__129 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_[130] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__24),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__25),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__26),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__27),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__28),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__29),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__30),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__31),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__32),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__33),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__34),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__35),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__36),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__37),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__38),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__39),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__40),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__41),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__42),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__43),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__44),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__45),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__46),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__47),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__48),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__49),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__50),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__51),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__52),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__53),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__54),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__55),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__56),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__57),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__58),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__59),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__60),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__61),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__62),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__63),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__64),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__65),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__66),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__67),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__68),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__69),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__70),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__71),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__72),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__73),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__74),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__75),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__76),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__77),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__78),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__79),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__80),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__81),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__82),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__83),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__84),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__85),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__86),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__87),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__88),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__89),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__90),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__91),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__92),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__93),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__94),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__95),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__96),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__97),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__98),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__99),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__100),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__101),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__102),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__103),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__104),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__105),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__106),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__107),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__108),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__109),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__110),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__111),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__112),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__113),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__114),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__115),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__116),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__117),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__118),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__119),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__120),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__121),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__122),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__123),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__124),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__125),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__126),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__127),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__128),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt__129),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 2986,
        .n_obj = 130,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/cmd.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_[7636] = {
    0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x87, 0x02,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_cmd_dot_py >> 8,
    0x21, 0x28, 0x50, 0x50, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x46, 0x43, 0x22, 0x20, 0x43, 0x22, 0x2c, 0x6f, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2b, 0x4c, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x6f, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x35, 0x79, 0x20, 0x43, 0x22, 0x2c, 0x2b, 0x6f, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x6f, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x2c, 0x20, 0x7e, 0x20, 0x22, 0x22, 0x2c, 0x4b, 0x22, 0x2c, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x70, 0x20, 0x43, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x22, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x35, 0x2b, 0x4f, 0x22, 0x2b, 0x2b, 0x79, 0x22, 0x72, 0x20, 0x22, 0x22, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x36, 0x2b, 0x2b, 0x2b, 0x2c, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x4c, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x4c, 0x22, 0x72, 0x43, 0x22, 0x22, 0x2c, 0x2b, 0x4f, 0x22, 0x70, 0x22, 0x2c, 0x2b, 0x2b, 0x71, 0x20, 0x22, 0x22, 0x22, 0x2b, 0x4f, 0x22, 0x6f, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2c, 0x4b, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x43, 0x22, 0x2c, 0x2b, 0x2c, 0x2c, 0x71, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x22, 0x22, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x4b, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x35, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x4b, 0x22, 0x72, 0x20, 0x43, 0x22, 0x72, 0x20, 0x22, 0x22, 0x22, 0x2c, 0x2b, 0x2b, 0x2b, 0x4f, 0x22, 0x2c, 0x2b, 0x2b, 0x2b, 0x2b, 0x79, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2c, 0x2b, 0x2b, 0x2b, 0x2b, 0x2b, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2b, 0x35, 0x2b, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x22, 0x5a, 0x45, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x2c, 0x2c, 0x20, 0x1f, 0x61, 0x20, 0x23, 0x22, 0x2c, 0x56, 0x22, 0x72, 0x64, 0x22, 0x72, 0x20, 0x44, 0x22, 0x2c, 0x72, 0x20, 0x44, 0x22, 0x2c, 0x72, 0x20, 0x44, 0x22, 0x2c, 0x72, 0x20, 0x44, 0x22, 0x2c, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x36, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x56, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x56, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x56, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x56, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x44, 0x22, 0x72, 0x20, 0x23, 0x22, 0x4c, 0x22, 0x2c, 0x2c, 0x20, 0x1f, 0x61, 0x20, 0x23, 0x22, 0x2c, 0x4c, 0x22, 0x2c, 0x2c, 0x20, 0x1f, 0x61, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x20, 0x5a, 0x22, 0x72, 0x20, 0x23, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x4c, 0x22, 0x72, 0x20, 0x23, 0x22, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x50, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x2c, 0x70, 0x22, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x24, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x32, 
    0x80, 
    0x24, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER & 0xff, MP_QSTR_OCF_HAL_GET_FW_BUILD_NUMBER >> 8,
    0x8c, 
    0x24, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_WRITE_CONFIG_DATA >> 8,
    0x8d, 
    0x24, MP_QSTR_OCF_HAL_READ_CONFIG_DATA & 0xff, MP_QSTR_OCF_HAL_READ_CONFIG_DATA >> 8,
    0x8f, 
    0x24, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL & 0xff, MP_QSTR_OCF_HAL_SET_TX_POWER_LEVEL >> 8,
    0x93, 
    0x24, MP_QSTR_OCF_HAL_DEVICE_STANDBY & 0xff, MP_QSTR_OCF_HAL_DEVICE_STANDBY >> 8,
    0x94, 
    0x24, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER & 0xff, MP_QSTR_OCF_HAL_LE_TX_TEST_PACKET_NUMBER >> 8,
    0x95, 
    0x24, MP_QSTR_OCF_HAL_TONE_START & 0xff, MP_QSTR_OCF_HAL_TONE_START >> 8,
    0x96, 
    0x24, MP_QSTR_OCF_HAL_TONE_STOP & 0xff, MP_QSTR_OCF_HAL_TONE_STOP >> 8,
    0x97, 
    0x24, MP_QSTR_OCF_HAL_GET_LINK_STATUS & 0xff, MP_QSTR_OCF_HAL_GET_LINK_STATUS >> 8,
    0x99, 
    0x24, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD & 0xff, MP_QSTR_OCF_HAL_GET_ANCHOR_PERIOD >> 8,
    0xa0, 
    0x24, MP_QSTR_OCF_UPDATER_START & 0xff, MP_QSTR_OCF_UPDATER_START >> 8,
    0xa1, 
    0x24, MP_QSTR_OCF_UPDATER_REBOOT & 0xff, MP_QSTR_OCF_UPDATER_REBOOT >> 8,
    0xa2, 
    0x24, MP_QSTR_OCF_GET_UPDATER_VERSION & 0xff, MP_QSTR_OCF_GET_UPDATER_VERSION >> 8,
    0xa3, 
    0x24, MP_QSTR_OCF_GET_UPDATER_BUFSIZE & 0xff, MP_QSTR_OCF_GET_UPDATER_BUFSIZE >> 8,
    0xa4, 
    0x24, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_ERASE_BLUE_FLAG >> 8,
    0xa5, 
    0x24, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG & 0xff, MP_QSTR_OCF_UPDATER_RESET_BLUE_FLAG >> 8,
    0xa6, 
    0x24, MP_QSTR_OCF_UPDATER_ERASE_SECTOR & 0xff, MP_QSTR_OCF_UPDATER_ERASE_SECTOR >> 8,
    0xa8, 
    0x24, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_READ_DATA_BLOCK >> 8,
    0xa7, 
    0x24, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK & 0xff, MP_QSTR_OCF_UPDATER_PROG_DATA_BLOCK >> 8,
    0xa9, 
    0x24, MP_QSTR_OCF_UPDATER_CALC_CRC & 0xff, MP_QSTR_OCF_UPDATER_CALC_CRC >> 8,
    0xaa, 
    0x24, MP_QSTR_OCF_UPDATER_HW_VERSION & 0xff, MP_QSTR_OCF_UPDATER_HW_VERSION >> 8,
    0x14, 0x81, 0x01, 
    0x24, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_DISCOVERABLE >> 8,
    0x14, 0x81, 0x02, 
    0x24, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_LIMITED_DISCOVERABLE >> 8,
    0x14, 0x81, 0x03, 
    0x24, MP_QSTR_OCF_GAP_SET_DISCOVERABLE & 0xff, MP_QSTR_OCF_GAP_SET_DISCOVERABLE >> 8,
    0x14, 0x81, 0x04, 
    0x24, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_DIRECT_CONNECTABLE >> 8,
    0x14, 0x81, 0x05, 
    0x24, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY & 0xff, MP_QSTR_OCF_GAP_SET_IO_CAPABILITY >> 8,
    0x14, 0x81, 0x06, 
    0x24, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTH_REQUIREMENT >> 8,
    0x14, 0x81, 0x07, 
    0x24, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT & 0xff, MP_QSTR_OCF_GAP_SET_AUTHOR_REQUIREMENT >> 8,
    0x14, 0x81, 0x08, 
    0x24, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE & 0xff, MP_QSTR_OCF_GAP_PASSKEY_RESPONSE >> 8,
    0x14, 0x81, 0x09, 
    0x24, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE & 0xff, MP_QSTR_OCF_GAP_AUTHORIZATION_RESPONSE >> 8,
    0x14, 0x81, 0x0a, 
    0x24, MP_QSTR_OCF_GAP_INIT & 0xff, MP_QSTR_OCF_GAP_INIT >> 8,
    0x14, 0x81, 0x0b, 
    0x24, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_NON_CONNECTABLE >> 8,
    0x14, 0x81, 0x0c, 
    0x24, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE & 0xff, MP_QSTR_OCF_GAP_SET_UNDIRECTED_CONNECTABLE >> 8,
    0x14, 0x81, 0x0d, 
    0x24, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST & 0xff, MP_QSTR_OCF_GAP_SLAVE_SECURITY_REQUEST >> 8,
    0x14, 0x81, 0x0e, 
    0x24, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA & 0xff, MP_QSTR_OCF_GAP_UPDATE_ADV_DATA >> 8,
    0x14, 0x81, 0x0f, 
    0x24, MP_QSTR_OCF_GAP_DELETE_AD_TYPE & 0xff, MP_QSTR_OCF_GAP_DELETE_AD_TYPE >> 8,
    0x14, 0x81, 0x10, 
    0x24, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL & 0xff, MP_QSTR_OCF_GAP_GET_SECURITY_LEVEL >> 8,
    0x14, 0x81, 0x11, 
    0x24, MP_QSTR_OCF_GAP_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GAP_SET_EVT_MASK >> 8,
    0x14, 0x81, 0x12, 
    0x24, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST & 0xff, MP_QSTR_OCF_GAP_CONFIGURE_WHITELIST >> 8,
    0x14, 0x81, 0x13, 
    0x24, MP_QSTR_OCF_GAP_TERMINATE & 0xff, MP_QSTR_OCF_GAP_TERMINATE >> 8,
    0x14, 0x81, 0x14, 
    0x24, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB & 0xff, MP_QSTR_OCF_GAP_CLEAR_SECURITY_DB >> 8,
    0x14, 0x81, 0x15, 
    0x24, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB & 0xff, MP_QSTR_OCF_GAP_ALLOW_REBOND_DB >> 8,
    0x14, 0x81, 0x16, 
    0x24, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_LIMITED_DISCOVERY_PROC >> 8,
    0x14, 0x81, 0x17, 
    0x24, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_DISCOVERY_PROC >> 8,
    0x14, 0x81, 0x18, 
    0x24, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_OCF_GAP_START_NAME_DISCOVERY_PROC >> 8,
    0x14, 0x81, 0x19, 
    0x24, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_AUTO_CONN_ESTABLISH_PROC >> 8,
    0x14, 0x81, 0x1a, 
    0x24, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_GENERAL_CONN_ESTABLISH_PROC >> 8,
    0x14, 0x81, 0x1b, 
    0x24, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC & 0xff, MP_QSTR_OCF_GAP_START_SELECTIVE_CONN_ESTABLISH_PROC >> 8,
    0x14, 0x81, 0x1c, 
    0x24, MP_QSTR_OCF_GAP_CREATE_CONNECTION & 0xff, MP_QSTR_OCF_GAP_CREATE_CONNECTION >> 8,
    0x14, 0x81, 0x1d, 
    0x24, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE & 0xff, MP_QSTR_OCF_GAP_TERMINATE_GAP_PROCEDURE >> 8,
    0x14, 0x81, 0x1e, 
    0x24, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE & 0xff, MP_QSTR_OCF_GAP_START_CONNECTION_UPDATE >> 8,
    0x14, 0x81, 0x1f, 
    0x24, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST & 0xff, MP_QSTR_OCF_GAP_SEND_PAIRING_REQUEST >> 8,
    0x14, 0x81, 0x20, 
    0x24, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS & 0xff, MP_QSTR_OCF_GAP_RESOLVE_PRIVATE_ADDRESS >> 8,
    0x14, 0x81, 0x21, 
    0x24, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE & 0xff, MP_QSTR_OCF_GAP_SET_BROADCAST_MODE >> 8,
    0x14, 0x81, 0x22, 
    0x24, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC & 0xff, MP_QSTR_OCF_GAP_START_OBSERVATION_PROC >> 8,
    0x14, 0x81, 0x23, 
    0x24, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES & 0xff, MP_QSTR_OCF_GAP_GET_BONDED_DEVICES >> 8,
    0x14, 0x81, 0x24, 
    0x24, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED & 0xff, MP_QSTR_OCF_GAP_IS_DEVICE_BONDED >> 8,
    0x14, 0x82, 0x01, 
    0x24, MP_QSTR_OCF_GATT_INIT & 0xff, MP_QSTR_OCF_GATT_INIT >> 8,
    0x14, 0x82, 0x02, 
    0x24, MP_QSTR_OCF_GATT_ADD_SERV & 0xff, MP_QSTR_OCF_GATT_ADD_SERV >> 8,
    0x14, 0x82, 0x03, 
    0x24, MP_QSTR_OCF_GATT_INCLUDE_SERV & 0xff, MP_QSTR_OCF_GATT_INCLUDE_SERV >> 8,
    0x14, 0x82, 0x04, 
    0x24, MP_QSTR_OCF_GATT_ADD_CHAR & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR >> 8,
    0x14, 0x82, 0x05, 
    0x24, MP_QSTR_OCF_GATT_ADD_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_ADD_CHAR_DESC >> 8,
    0x14, 0x82, 0x06, 
    0x24, MP_QSTR_OCF_GATT_UPD_CHAR_VAL & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL >> 8,
    0x14, 0x82, 0x07, 
    0x24, MP_QSTR_OCF_GATT_DEL_CHAR & 0xff, MP_QSTR_OCF_GATT_DEL_CHAR >> 8,
    0x14, 0x82, 0x08, 
    0x24, MP_QSTR_OCF_GATT_DEL_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_SERV >> 8,
    0x14, 0x82, 0x09, 
    0x24, MP_QSTR_OCF_GATT_DEL_INC_SERV & 0xff, MP_QSTR_OCF_GATT_DEL_INC_SERV >> 8,
    0x14, 0x82, 0x0a, 
    0x24, MP_QSTR_OCF_GATT_SET_EVT_MASK & 0xff, MP_QSTR_OCF_GATT_SET_EVT_MASK >> 8,
    0x14, 0x82, 0x0b, 
    0x24, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG & 0xff, MP_QSTR_OCF_GATT_EXCHANGE_CONFIG >> 8,
    0x14, 0x82, 0x0c, 
    0x24, MP_QSTR_OCF_ATT_FIND_INFO_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_INFO_REQ >> 8,
    0x14, 0x82, 0x0d, 
    0x24, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ & 0xff, MP_QSTR_OCF_ATT_FIND_BY_TYPE_VALUE_REQ >> 8,
    0x14, 0x82, 0x0e, 
    0x24, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_TYPE_REQ >> 8,
    0x14, 0x82, 0x0f, 
    0x24, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ & 0xff, MP_QSTR_OCF_ATT_READ_BY_GROUP_TYPE_REQ >> 8,
    0x14, 0x82, 0x10, 
    0x24, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_PREPARE_WRITE_REQ >> 8,
    0x14, 0x82, 0x11, 
    0x24, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ & 0xff, MP_QSTR_OCF_ATT_EXECUTE_WRITE_REQ >> 8,
    0x14, 0x82, 0x12, 
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_PRIM_SERVICES >> 8,
    0x14, 0x82, 0x13, 
    0x24, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_PRIM_SERVICE_BY_UUID >> 8,
    0x14, 0x82, 0x14, 
    0x24, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES & 0xff, MP_QSTR_OCF_GATT_FIND_INCLUDED_SERVICES >> 8,
    0x14, 0x82, 0x15, 
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_OF_SERV >> 8,
    0x14, 0x82, 0x16, 
    0x24, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID & 0xff, MP_QSTR_OCF_GATT_DISC_CHARAC_BY_UUID >> 8,
    0x14, 0x82, 0x17, 
    0x24, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS & 0xff, MP_QSTR_OCF_GATT_DISC_ALL_CHARAC_DESCRIPTORS >> 8,
    0x14, 0x82, 0x18, 
    0x24, MP_QSTR_OCF_GATT_READ_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_CHARAC_VAL >> 8,
    0x14, 0x82, 0x09, 
    0x24, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID & 0xff, MP_QSTR_OCF_GATT_READ_USING_CHARAC_UUID >> 8,
    0x14, 0x82, 0x1a, 
    0x24, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_VAL >> 8,
    0x14, 0x82, 0x1b, 
    0x24, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_READ_MULTIPLE_CHARAC_VAL >> 8,
    0x14, 0x82, 0x1c, 
    0x24, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_VALUE >> 8,
    0x14, 0x82, 0x1d, 
    0x24, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_VAL >> 8,
    0x14, 0x82, 0x1e, 
    0x24, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE & 0xff, MP_QSTR_OCF_GATT_WRITE_CHARAC_RELIABLE >> 8,
    0x14, 0x82, 0x1f, 
    0x24, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_LONG_CHARAC_DESC >> 8,
    0x14, 0x82, 0x20, 
    0x24, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC & 0xff, MP_QSTR_OCF_GATT_READ_LONG_CHARAC_DESC >> 8,
    0x14, 0x82, 0x21, 
    0x24, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_WRITE_CHAR_DESC >> 8,
    0x14, 0x82, 0x22, 
    0x24, MP_QSTR_OCF_GATT_READ_CHAR_DESC & 0xff, MP_QSTR_OCF_GATT_READ_CHAR_DESC >> 8,
    0x14, 0x82, 0x23, 
    0x24, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_WITHOUT_RESPONSE >> 8,
    0x14, 0x82, 0x24, 
    0x24, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_OCF_GATT_SIGNED_WRITE_WITHOUT_RESPONSE >> 8,
    0x14, 0x82, 0x25, 
    0x24, MP_QSTR_OCF_GATT_CONFIRM_INDICATION & 0xff, MP_QSTR_OCF_GATT_CONFIRM_INDICATION >> 8,
    0x14, 0x82, 0x26, 
    0x24, MP_QSTR_OCF_GATT_WRITE_RESPONSE & 0xff, MP_QSTR_OCF_GATT_WRITE_RESPONSE >> 8,
    0x14, 0x82, 0x27, 
    0x24, MP_QSTR_OCF_GATT_ALLOW_READ & 0xff, MP_QSTR_OCF_GATT_ALLOW_READ >> 8,
    0x14, 0x82, 0x28, 
    0x24, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION & 0xff, MP_QSTR_OCF_GATT_SET_SECURITY_PERMISSION >> 8,
    0x14, 0x82, 0x29, 
    0x24, MP_QSTR_OCF_GATT_SET_DESC_VAL & 0xff, MP_QSTR_OCF_GATT_SET_DESC_VAL >> 8,
    0x14, 0x82, 0x2a, 
    0x24, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE >> 8,
    0x14, 0x82, 0x2b, 
    0x24, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET & 0xff, MP_QSTR_OCF_GATT_READ_HANDLE_VALUE_OFFSET >> 8,
    0x14, 0x82, 0x2c, 
    0x24, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT & 0xff, MP_QSTR_OCF_GATT_UPD_CHAR_VAL_EXT >> 8,
    0x14, 0x83, 0x01, 
    0x24, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_REQ >> 8,
    0x14, 0x83, 0x02, 
    0x24, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP & 0xff, MP_QSTR_OCF_L2CAP_CONN_PARAM_UPDATE_RESP >> 8,
    0x16, MP_QSTR_VENDOR_CMD & 0xff, MP_QSTR_VENDOR_CMD >> 8,
    0x53, 0x67, 
    0x17, 0x00, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x01, 
    0x54, 
    0x51, 0x03, 
    0x80, 
    0x54, 
    0x17, 0x02, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8c, 
    0x54, 
    0x17, 0x03, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x51, 0x03, 
    0x8d, 
    0x54, 
    0x17, 0x04, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x05, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_pa_level & 0xff, MP_QSTR_pa_level >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8f, 
    0x54, 
    0x17, 0x06, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x93, 
    0x54, 
    0x17, 0x07, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x81, 
    0xec, 
    0x17, 0x08, 
    0x54, 
    0x51, 0x03, 
    0x94, 
    0x54, 
    0x17, 0x09, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_rf_channel & 0xff, MP_QSTR_rf_channel >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x95, 
    0x54, 
    0x17, 0x0a, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_rf_channel & 0xff, MP_QSTR_rf_channel >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x96, 
    0x54, 
    0x17, 0x0b, 
    0x11, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x0c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x89, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x0d, 
    0x54, 
    0x51, 0x03, 
    0x97, 
    0x54, 
    0x17, 0x0e, 
    0x11, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x81, 
    0xec, 
    0x17, 0x0f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x85, 
    0xec, 
    0x17, 0x10, 
    0x54, 
    0x51, 0x03, 
    0x99, 
    0x54, 
    0x17, 0x11, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa0, 
    0x54, 
    0x17, 0x12, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa1, 
    0x54, 
    0x17, 0x13, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_version & 0xff, MP_QSTR_version >> 8,
    0x54, 
    0x51, 0x03, 
    0xa2, 
    0x54, 
    0x17, 0x14, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x15, 
    0x54, 
    0x51, 0x03, 
    0xa3, 
    0x54, 
    0x17, 0x16, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa4, 
    0x54, 
    0x17, 0x17, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa5, 
    0x54, 
    0x17, 0x18, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa6, 
    0x54, 
    0x17, 0x19, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_data_len & 0xff, MP_QSTR_data_len >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0xa8, 
    0x54, 
    0x17, 0x1a, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_data_len & 0xff, MP_QSTR_data_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x86, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x86, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x81, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x03, 
    0xa7, 
    0x54, 
    0x17, 0x1b, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x1c, 
    0x54, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_crc & 0xff, MP_QSTR_crc >> 8,
    0x54, 
    0x51, 0x03, 
    0xa9, 
    0x54, 
    0x17, 0x1d, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_version & 0xff, MP_QSTR_version >> 8,
    0x54, 
    0x51, 0x03, 
    0xaa, 
    0x54, 
    0x17, 0x1e, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x01, 
    0x54, 
    0x17, 0x1f, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x02, 
    0x54, 
    0x17, 0x20, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x03, 
    0x54, 
    0x17, 0x21, 
    0x53, 0x02, 
    0x53, 0x06, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x22, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x23, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x24, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x25, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x89, 
    0xec, 
    0x17, 0x26, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8b, 
    0xec, 
    0x17, 0x27, 
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x28, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x29, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x2a, 
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x04, 
    0x54, 
    0x17, 0x2b, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x2c, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x05, 
    0x54, 
    0x17, 0x2d, 
    0x53, 0x08, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_mitm_mode & 0xff, MP_QSTR_mitm_mode >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_oob_enable & 0xff, MP_QSTR_oob_enable >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_oob_data & 0xff, MP_QSTR_oob_data >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x92, 
    0xec, 
    0x17, 0x2e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x93, 
    0xec, 
    0x17, 0x2f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x94, 
    0xec, 
    0x17, 0x30, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x95, 
    0xec, 
    0x16, MP_QSTR_fixed_pin & 0xff, MP_QSTR_fixed_pin >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x99, 
    0xec, 
    0x17, 0x31, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x06, 
    0x54, 
    0x17, 0x32, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x33, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x34, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x07, 
    0x54, 
    0x17, 0x35, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x36, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_passkey & 0xff, MP_QSTR_passkey >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x08, 
    0x54, 
    0x17, 0x37, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x38, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_authorize & 0xff, MP_QSTR_authorize >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x09, 
    0x54, 
    0x16, MP_QSTR_GAP_INIT & 0xff, MP_QSTR_GAP_INIT >> 8,
    0x53, 0x02, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_role & 0xff, MP_QSTR_role >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x39, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x3a, 
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_role & 0xff, MP_QSTR_role >> 8,
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x3b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x3c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x17, 0x3d, 
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0a, 
    0x54, 
    0x17, 0x3e, 
    0x53, 0x02, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x3f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x40, 
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x41, 
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0b, 
    0x54, 
    0x17, 0x42, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x43, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x44, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0c, 
    0x54, 
    0x17, 0x45, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x46, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_bonding & 0xff, MP_QSTR_bonding >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x17, 0x47, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0d, 
    0x54, 
    0x17, 0x48, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0e, 
    0x54, 
    0x17, 0x49, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_ad_type & 0xff, MP_QSTR_ad_type >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x0f, 
    0x54, 
    0x17, 0x4a, 
    0x11, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x4b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_bonding & 0xff, MP_QSTR_bonding >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_oob_data & 0xff, MP_QSTR_oob_data >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x4c, 
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x10, 
    0x54, 
    0x17, 0x4d, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_evt_mask & 0xff, MP_QSTR_evt_mask >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x11, 
    0x54, 
    0x17, 0x4e, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x12, 
    0x54, 
    0x17, 0x4f, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_reason & 0xff, MP_QSTR_reason >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x13, 
    0x54, 
    0x17, 0x50, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x14, 
    0x54, 
    0x17, 0x51, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x52, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x15, 
    0x54, 
    0x17, 0x53, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x54, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x55, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x56, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x57, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x16, 
    0x54, 
    0x17, 0x58, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x59, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x5a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x5b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x5c, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x17, 
    0x54, 
    0x17, 0x5d, 
    0x53, 0x0b, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x5e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x5f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x60, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x61, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8b, 
    0xec, 
    0x17, 0x62, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x63, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8e, 
    0xec, 
    0x17, 0x64, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x90, 
    0xec, 
    0x17, 0x65, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x92, 
    0xec, 
    0x17, 0x66, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x94, 
    0xec, 
    0x17, 0x67, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x96, 
    0xec, 
    0x17, 0x68, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x18, 
    0x54, 
    0x17, 0x69, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x19, 
    0x54, 
    0x17, 0x6a, 
    0x53, 0x02, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_scan_type & 0xff, MP_QSTR_scan_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x6b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x6c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x6d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x6e, 
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x06, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_scan_type & 0xff, MP_QSTR_scan_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x6f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x70, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x71, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x72, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x73, 
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1a, 
    0x54, 
    0x17, 0x74, 
    0x53, 0x07, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_scan_type & 0xff, MP_QSTR_scan_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x75, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x17, 0x76, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x77, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x78, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x87, 
    0xec, 
    0x17, 0x79, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x88, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x88, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_addr_array & 0xff, MP_QSTR_addr_array >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1b, 
    0x54, 
    0x17, 0x7a, 
    0x53, 0x0b, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x7b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x7c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x7d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x7e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8b, 
    0xec, 
    0x17, 0x7f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x81, 0x00, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8e, 
    0xec, 
    0x17, 0x81, 0x01, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x90, 
    0xec, 
    0x17, 0x81, 0x02, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x92, 
    0xec, 
    0x17, 0x81, 0x03, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x94, 
    0xec, 
    0x17, 0x81, 0x04, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x96, 
    0xec, 
    0x17, 0x81, 0x05, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1c, 
    0x54, 
    0x17, 0x81, 0x06, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1d, 
    0x54, 
    0x17, 0x81, 0x07, 
    0x53, 0x07, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x08, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x09, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x81, 0x0a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x17, 0x81, 0x0b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x81, 0x0c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x17, 0x81, 0x0d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x81, 0x0e, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1e, 
    0x54, 
    0x17, 0x81, 0x0f, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x10, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x11, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x1f, 
    0x54, 
    0x17, 0x81, 0x12, 
    0x53, 0x02, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_address & 0xff, MP_QSTR_address >> 8,
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x11, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x20, 
    0x54, 
    0x17, 0x81, 0x13, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x14, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x15, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_dv_type & 0xff, MP_QSTR_dv_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x81, 0x16, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x86, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x86, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x81, 0x17, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x21, 
    0x54, 
    0x17, 0x81, 0x18, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x19, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x1a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_scan_type & 0xff, MP_QSTR_scan_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x81, 0x1b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x81, 0x1c, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x22, 
    0x54, 
    0x17, 0x81, 0x1d, 
    0x11, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_num_addr & 0xff, MP_QSTR_num_addr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x82, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_dev_list & 0xff, MP_QSTR_dev_list >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x23, 
    0x54, 
    0x17, 0x81, 0x1e, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x1f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x81, 0x20, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x81, 0x24, 
    0x54, 
    0x16, MP_QSTR_GATT_INIT & 0xff, MP_QSTR_GATT_INIT >> 8,
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x01, 
    0x54, 
    0x17, 0x81, 0x21, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x02, 
    0x54, 
    0x17, 0x81, 0x22, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x03, 
    0x54, 
    0x17, 0x81, 0x23, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x04, 
    0x54, 
    0x17, 0x81, 0x24, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x05, 
    0x54, 
    0x17, 0x81, 0x25, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x06, 
    0x54, 
    0x17, 0x81, 0x26, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x27, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x28, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x07, 
    0x54, 
    0x17, 0x81, 0x29, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x2a, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x08, 
    0x54, 
    0x17, 0x81, 0x2b, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x2c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x2d, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x09, 
    0x54, 
    0x17, 0x81, 0x2e, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT32 & 0xff, MP_QSTR_UINT32 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_evt_mask & 0xff, MP_QSTR_evt_mask >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0a, 
    0x54, 
    0x17, 0x81, 0x2f, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x30, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0b, 
    0x54, 
    0x17, 0x81, 0x31, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x32, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x33, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0c, 
    0x54, 
    0x17, 0x81, 0x34, 
    0x53, 0x06, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x35, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x36, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x86, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x17, 0x81, 0x37, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x89, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x89, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0d, 
    0x54, 
    0x17, 0x81, 0x38, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x39, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x3a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0e, 
    0x54, 
    0x17, 0x81, 0x3b, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x3c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x3d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x0f, 
    0x54, 
    0x17, 0x81, 0x3e, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x3f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x40, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x81, 0x41, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x81, 0x42, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x10, 
    0x54, 
    0x17, 0x81, 0x43, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x44, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_execute & 0xff, MP_QSTR_execute >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x11, 
    0x54, 
    0x17, 0x81, 0x45, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x46, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x12, 
    0x54, 
    0x17, 0x81, 0x47, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x48, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x13, 
    0x54, 
    0x17, 0x81, 0x49, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x4a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x4b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x14, 
    0x54, 
    0x17, 0x81, 0x4c, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x4d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x4e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x15, 
    0x54, 
    0x17, 0x81, 0x4f, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x16, 
    0x54, 
    0x17, 0x81, 0x50, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x51, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x52, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x17, 
    0x54, 
    0x17, 0x81, 0x53, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x54, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x55, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x18, 
    0x54, 
    0x17, 0x81, 0x56, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x57, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x58, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_end_handle & 0xff, MP_QSTR_end_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_uuid_type & 0xff, MP_QSTR_uuid_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_uuid & 0xff, MP_QSTR_uuid >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x09, 
    0x54, 
    0x17, 0x81, 0x59, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x5a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x5b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_offset & 0xff, MP_QSTR_val_offset >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1a, 
    0x54, 
    0x17, 0x81, 0x5c, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x5d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x5e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x81, 0x5f, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1b, 
    0x54, 
    0x17, 0x81, 0x60, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1c, 
    0x54, 
    0x17, 0x81, 0x61, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x62, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x63, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_offset & 0xff, MP_QSTR_val_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_val_len & 0xff, MP_QSTR_val_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1d, 
    0x54, 
    0x17, 0x81, 0x64, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x65, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x66, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_offset & 0xff, MP_QSTR_val_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_val_len & 0xff, MP_QSTR_val_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1e, 
    0x54, 
    0x17, 0x81, 0x67, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x68, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x69, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_offset & 0xff, MP_QSTR_val_offset >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_val_len & 0xff, MP_QSTR_val_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x87, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x1f, 
    0x54, 
    0x17, 0x81, 0x6a, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x6b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x6c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_offset & 0xff, MP_QSTR_val_offset >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x20, 
    0x54, 
    0x17, 0x81, 0x6d, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x21, 
    0x54, 
    0x17, 0x81, 0x6e, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x6f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x70, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x22, 
    0x54, 
    0x17, 0x81, 0x71, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x72, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x73, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_len & 0xff, MP_QSTR_val_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x23, 
    0x54, 
    0x17, 0x81, 0x74, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x75, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x76, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_val_len & 0xff, MP_QSTR_val_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x85, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_attr_val & 0xff, MP_QSTR_attr_val >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x24, 
    0x54, 
    0x17, 0x81, 0x77, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x78, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x25, 
    0x54, 
    0x17, 0x81, 0x79, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x26, 
    0x54, 
    0x17, 0x81, 0x7a, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x7b, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x27, 
    0x54, 
    0x17, 0x81, 0x7c, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x81, 0x7d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x81, 0x7e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x81, 0x7f, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x28, 
    0x54, 
    0x17, 0x82, 0x00, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x29, 
    0x54, 
    0x17, 0x82, 0x01, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x02, 
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_value_len & 0xff, MP_QSTR_value_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x2a, 
    0x54, 
    0x17, 0x82, 0x03, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x04, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_offset & 0xff, MP_QSTR_offset >> 8,
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_value_len & 0xff, MP_QSTR_value_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x83, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x2b, 
    0x54, 
    0x17, 0x82, 0x05, 
    0x53, 0x07, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x06, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x82, 0x07, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x82, 0x08, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x17, 0x82, 0x09, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x87, 
    0xec, 
    0x17, 0x82, 0x0a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x89, 
    0xec, 
    0x17, 0x82, 0x0b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x8a, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x8a, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_value & 0xff, MP_QSTR_value >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x82, 0x2c, 
    0x54, 
    0x17, 0x82, 0x0c, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x0d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x82, 0x0e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x82, 0x0f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x17, 0x82, 0x10, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x82, 0x11, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x83, 0x01, 
    0x54, 
    0x17, 0x82, 0x12, 
    0x53, 0x02, 
    0x53, 0x09, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x13, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x82, 0x14, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x82, 0x15, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x17, 0x82, 0x16, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x82, 0x17, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x17, 0x82, 0x18, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x82, 0x19, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8e, 
    0xec, 
    0x16, MP_QSTR_id & 0xff, MP_QSTR_id >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8f, 
    0xec, 
    0x16, MP_QSTR_accept & 0xff, MP_QSTR_accept >> 8,
    0x54, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x54, 
    0x53, 0x07, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x82, 0x1a, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x82, 0x1b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x82, 0x1c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x17, 0x82, 0x1d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x82, 0x1e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8a, 
    0xec, 
    0x16, MP_QSTR_id & 0xff, MP_QSTR_id >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8b, 
    0xec, 
    0x16, MP_QSTR_accept & 0xff, MP_QSTR_accept >> 8,
    0x54, 
    0x16, MP_QSTR_IDB04A1 & 0xff, MP_QSTR_IDB04A1 >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x14, 0x83, 0x02, 
    0x54, 
    0x51, 0x02, 
    0x24, MP_QSTR_HCI_VENDOR_COMMANDS & 0xff, MP_QSTR_HCI_VENDOR_COMMANDS >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__0 = {{&mp_type_str}, 29042, 23, (const byte*)"\x48\x41\x4c\x5f\x47\x45\x54\x5f\x46\x57\x5f\x42\x55\x49\x4c\x44\x5f\x4e\x55\x4d\x42\x45\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__1 = {{&mp_type_str}, 21839, 12, (const byte*)"\x62\x75\x69\x6c\x64\x5f\x6e\x75\x6d\x62\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__2 = {{&mp_type_str}, 41688, 21, (const byte*)"\x48\x41\x4c\x5f\x57\x52\x49\x54\x45\x5f\x43\x4f\x4e\x46\x49\x47\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__3 = {{&mp_type_str}, 56087, 20, (const byte*)"\x48\x41\x4c\x5f\x52\x45\x41\x44\x5f\x43\x4f\x4e\x46\x49\x47\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__4 = {{&mp_type_str}, 61799, 22, (const byte*)"\x48\x41\x4c\x5f\x53\x45\x54\x5f\x54\x58\x5f\x50\x4f\x57\x45\x52\x5f\x4c\x45\x56\x45\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__5 = {{&mp_type_str}, 22943, 13, (const byte*)"\x65\x6e\x5f\x68\x69\x67\x68\x5f\x70\x6f\x77\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__6 = {{&mp_type_str}, 5583, 18, (const byte*)"\x48\x41\x4c\x5f\x44\x45\x56\x49\x43\x45\x5f\x53\x54\x41\x4e\x44\x42\x59"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__7 = {{&mp_type_str}, 63527, 28, (const byte*)"\x48\x41\x4c\x5f\x4c\x45\x5f\x54\x58\x5f\x54\x45\x53\x54\x5f\x50\x41\x43\x4b\x45\x54\x5f\x4e\x55\x4d\x42\x45\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__8 = {{&mp_type_str}, 14900, 17, (const byte*)"\x6e\x75\x6d\x62\x65\x72\x5f\x6f\x66\x5f\x70\x61\x63\x6b\x65\x74\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__9 = {{&mp_type_str}, 21424, 14, (const byte*)"\x48\x41\x4c\x5f\x54\x4f\x4e\x45\x5f\x53\x54\x41\x52\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__10 = {{&mp_type_str}, 26408, 13, (const byte*)"\x48\x41\x4c\x5f\x54\x4f\x4e\x45\x5f\x53\x54\x4f\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__11 = {{&mp_type_str}, 60957, 19, (const byte*)"\x48\x41\x4c\x5f\x47\x45\x54\x5f\x4c\x49\x4e\x4b\x5f\x53\x54\x41\x54\x55\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__12 = {{&mp_type_str}, 19662, 11, (const byte*)"\x6c\x69\x6e\x6b\x5f\x73\x74\x61\x74\x75\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__13 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__14 = {{&mp_type_str}, 33365, 21, (const byte*)"\x48\x41\x4c\x5f\x47\x45\x54\x5f\x41\x4e\x43\x48\x4f\x52\x5f\x50\x45\x52\x49\x4f\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__15 = {{&mp_type_str}, 51462, 13, (const byte*)"\x61\x6e\x63\x68\x6f\x72\x5f\x70\x65\x72\x69\x6f\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__16 = {{&mp_type_str}, 22305, 13, (const byte*)"\x6d\x61\x78\x5f\x66\x72\x65\x65\x5f\x73\x6c\x6f\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__17 = {{&mp_type_str}, 45593, 13, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x53\x54\x41\x52\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__18 = {{&mp_type_str}, 7896, 14, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x52\x45\x42\x4f\x4f\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__19 = {{&mp_type_str}, 810, 19, (const byte*)"\x47\x45\x54\x5f\x55\x50\x44\x41\x54\x45\x52\x5f\x56\x45\x52\x53\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__20 = {{&mp_type_str}, 14148, 19, (const byte*)"\x47\x45\x54\x5f\x55\x50\x44\x41\x54\x45\x52\x5f\x42\x55\x46\x53\x49\x5a\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__21 = {{&mp_type_str}, 54719, 11, (const byte*)"\x62\x75\x66\x66\x65\x72\x5f\x73\x69\x7a\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__22 = {{&mp_type_str}, 37707, 23, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x45\x52\x41\x53\x45\x5f\x42\x4c\x55\x45\x5f\x46\x4c\x41\x47"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__23 = {{&mp_type_str}, 65534, 23, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x52\x45\x53\x45\x54\x5f\x42\x4c\x55\x45\x5f\x46\x4c\x41\x47"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__24 = {{&mp_type_str}, 16442, 20, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x45\x52\x41\x53\x45\x5f\x53\x45\x43\x54\x4f\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__25 = {{&mp_type_str}, 21170, 23, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x52\x45\x41\x44\x5f\x44\x41\x54\x41\x5f\x42\x4c\x4f\x43\x4b"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__26 = {{&mp_type_str}, 41002, 23, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x50\x52\x4f\x47\x5f\x44\x41\x54\x41\x5f\x42\x4c\x4f\x43\x4b"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__27 = {{&mp_type_str}, 16889, 16, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x43\x41\x4c\x43\x5f\x43\x52\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__28 = {{&mp_type_str}, 25795, 11, (const byte*)"\x6e\x75\x6d\x5f\x73\x65\x63\x74\x6f\x72\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__29 = {{&mp_type_str}, 12579, 18, (const byte*)"\x55\x50\x44\x41\x54\x45\x52\x5f\x48\x57\x5f\x56\x45\x52\x53\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__30 = {{&mp_type_str}, 18008, 24, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x4e\x4f\x4e\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__31 = {{&mp_type_str}, 3107, 28, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x4c\x49\x4d\x49\x54\x45\x44\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__32 = {{&mp_type_str}, 49416, 20, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__33 = {{&mp_type_str}, 52279, 26, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x44\x49\x52\x45\x43\x54\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__34 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__35 = {{&mp_type_str}, 65186, 17, (const byte*)"\x64\x69\x72\x65\x63\x74\x65\x64\x5f\x61\x64\x76\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__36 = {{&mp_type_str}, 36805, 18, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__37 = {{&mp_type_str}, 36034, 13, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__38 = {{&mp_type_str}, 24142, 14, (const byte*)"\x61\x64\x76\x5f\x69\x6e\x74\x65\x72\x76\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__39 = {{&mp_type_str}, 24400, 14, (const byte*)"\x61\x64\x76\x5f\x69\x6e\x74\x65\x72\x76\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__40 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__41 = {{&mp_type_str}, 36805, 18, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__42 = {{&mp_type_str}, 36034, 13, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__43 = {{&mp_type_str}, 1912, 21, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x49\x4f\x5f\x43\x41\x50\x41\x42\x49\x4c\x49\x54\x59"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__44 = {{&mp_type_str}, 27820, 13, (const byte*)"\x69\x6f\x5f\x63\x61\x70\x61\x62\x69\x6c\x69\x74\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__45 = {{&mp_type_str}, 47865, 24, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x41\x55\x54\x48\x5f\x52\x45\x51\x55\x49\x52\x45\x4d\x45\x4e\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__46 = {{&mp_type_str}, 42605, 23, (const byte*)"\x6d\x69\x6e\x5f\x65\x6e\x63\x72\x79\x70\x74\x69\x6f\x6e\x5f\x6b\x65\x79\x5f\x73\x69\x7a\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__47 = {{&mp_type_str}, 56819, 23, (const byte*)"\x6d\x61\x78\x5f\x65\x6e\x63\x72\x79\x70\x74\x69\x6f\x6e\x5f\x6b\x65\x79\x5f\x73\x69\x7a\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__48 = {{&mp_type_str}, 43847, 13, (const byte*)"\x75\x73\x65\x5f\x66\x69\x78\x65\x64\x5f\x70\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__49 = {{&mp_type_str}, 61342, 12, (const byte*)"\x62\x6f\x6e\x64\x69\x6e\x67\x5f\x6d\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__50 = {{&mp_type_str}, 51524, 26, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x41\x55\x54\x48\x4f\x52\x5f\x52\x45\x51\x55\x49\x52\x45\x4d\x45\x4e\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__51 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__52 = {{&mp_type_str}, 18432, 20, (const byte*)"\x61\x75\x74\x68\x6f\x72\x69\x7a\x61\x74\x69\x6f\x6e\x5f\x65\x6e\x61\x62\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__53 = {{&mp_type_str}, 58038, 20, (const byte*)"\x47\x41\x50\x5f\x50\x41\x53\x53\x4b\x45\x59\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__54 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__55 = {{&mp_type_str}, 6251, 26, (const byte*)"\x47\x41\x50\x5f\x41\x55\x54\x48\x4f\x52\x49\x5a\x41\x54\x49\x4f\x4e\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__56 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__57 = {{&mp_type_str}, 20761, 15, (const byte*)"\x70\x72\x69\x76\x61\x63\x79\x5f\x65\x6e\x61\x62\x6c\x65\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__58 = {{&mp_type_str}, 48762, 20, (const byte*)"\x64\x65\x76\x69\x63\x65\x5f\x6e\x61\x6d\x65\x5f\x63\x68\x61\x72\x5f\x6c\x65\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__59 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__60 = {{&mp_type_str}, 32504, 20, (const byte*)"\x64\x65\x76\x5f\x6e\x61\x6d\x65\x5f\x63\x68\x61\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__61 = {{&mp_type_str}, 58985, 22, (const byte*)"\x61\x70\x70\x65\x61\x72\x61\x6e\x63\x65\x5f\x63\x68\x61\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__62 = {{&mp_type_str}, 15637, 23, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x4e\x4f\x4e\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__63 = {{&mp_type_str}, 7195, 22, (const byte*)"\x61\x64\x76\x65\x72\x74\x69\x73\x69\x6e\x67\x5f\x65\x76\x65\x6e\x74\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__64 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__65 = {{&mp_type_str}, 7195, 22, (const byte*)"\x61\x64\x76\x65\x72\x74\x69\x73\x69\x6e\x67\x5f\x65\x76\x65\x6e\x74\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__66 = {{&mp_type_str}, 7021, 30, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x55\x4e\x44\x49\x52\x45\x43\x54\x45\x44\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__67 = {{&mp_type_str}, 1782, 17, (const byte*)"\x61\x64\x76\x5f\x66\x69\x6c\x74\x65\x72\x5f\x70\x6f\x6c\x69\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__68 = {{&mp_type_str}, 17432, 13, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__69 = {{&mp_type_str}, 12294, 26, (const byte*)"\x47\x41\x50\x5f\x53\x4c\x41\x56\x45\x5f\x53\x45\x43\x55\x52\x49\x54\x59\x5f\x52\x45\x51\x55\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__70 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__71 = {{&mp_type_str}, 5124, 15, (const byte*)"\x6d\x69\x74\x6d\x5f\x70\x72\x6f\x74\x65\x63\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__72 = {{&mp_type_str}, 3934, 19, (const byte*)"\x47\x41\x50\x5f\x55\x50\x44\x41\x54\x45\x5f\x41\x44\x56\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__73 = {{&mp_type_str}, 30536, 18, (const byte*)"\x47\x41\x50\x5f\x44\x45\x4c\x45\x54\x45\x5f\x41\x44\x5f\x54\x59\x50\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__74 = {{&mp_type_str}, 24570, 22, (const byte*)"\x47\x41\x50\x5f\x47\x45\x54\x5f\x53\x45\x43\x55\x52\x49\x54\x59\x5f\x4c\x45\x56\x45\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__75 = {{&mp_type_str}, 5124, 15, (const byte*)"\x6d\x69\x74\x6d\x5f\x70\x72\x6f\x74\x65\x63\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__76 = {{&mp_type_str}, 54389, 16, (const byte*)"\x70\x61\x73\x73\x6b\x65\x79\x5f\x72\x65\x71\x75\x69\x72\x65\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__77 = {{&mp_type_str}, 31293, 16, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x45\x56\x54\x5f\x4d\x41\x53\x4b"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__78 = {{&mp_type_str}, 16254, 23, (const byte*)"\x47\x41\x50\x5f\x43\x4f\x4e\x46\x49\x47\x55\x52\x45\x5f\x57\x48\x49\x54\x45\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__79 = {{&mp_type_str}, 21173, 13, (const byte*)"\x47\x41\x50\x5f\x54\x45\x52\x4d\x49\x4e\x41\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__80 = {{&mp_type_str}, 58341, 21, (const byte*)"\x47\x41\x50\x5f\x43\x4c\x45\x41\x52\x5f\x53\x45\x43\x55\x52\x49\x54\x59\x5f\x44\x42"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__81 = {{&mp_type_str}, 46627, 19, (const byte*)"\x47\x41\x50\x5f\x41\x4c\x4c\x4f\x57\x5f\x52\x45\x42\x4f\x4e\x44\x5f\x44\x42"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__82 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__83 = {{&mp_type_str}, 29027, 32, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x4c\x49\x4d\x49\x54\x45\x44\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x59\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__84 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__85 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__86 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__87 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__88 = {{&mp_type_str}, 22177, 32, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x47\x45\x4e\x45\x52\x41\x4c\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x59\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__89 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__90 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__91 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__92 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__93 = {{&mp_type_str}, 2224, 29, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x4e\x41\x4d\x45\x5f\x44\x49\x53\x43\x4f\x56\x45\x52\x59\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__94 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__95 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__96 = {{&mp_type_str}, 25866, 16, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__97 = {{&mp_type_str}, 50221, 11, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__98 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__99 = {{&mp_type_str}, 2460, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__100 = {{&mp_type_str}, 24642, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__101 = {{&mp_type_str}, 31454, 12, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__102 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__103 = {{&mp_type_str}, 60991, 15, (const byte*)"\x6d\x69\x6e\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__104 = {{&mp_type_str}, 16161, 15, (const byte*)"\x6d\x61\x78\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__105 = {{&mp_type_str}, 52926, 34, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x41\x55\x54\x4f\x5f\x43\x4f\x4e\x4e\x5f\x45\x53\x54\x41\x42\x4c\x49\x53\x48\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__106 = {{&mp_type_str}, 41223, 37, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x47\x45\x4e\x45\x52\x41\x4c\x5f\x43\x4f\x4e\x4e\x5f\x45\x53\x54\x41\x42\x4c\x49\x53\x48\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__107 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__108 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__109 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__110 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__111 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__112 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__113 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__114 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__115 = {{&mp_type_str}, 4050, 11, (const byte*)"\x72\x65\x63\x6f\x6e\x6e\x5f\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__116 = {{&mp_type_str}, 25699, 39, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x53\x45\x4c\x45\x43\x54\x49\x56\x45\x5f\x43\x4f\x4e\x4e\x5f\x45\x53\x54\x41\x42\x4c\x49\x53\x48\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__117 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__118 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__119 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__120 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__121 = {{&mp_type_str}, 21156, 21, (const byte*)"\x6e\x75\x6d\x5f\x77\x68\x69\x74\x65\x6c\x69\x73\x74\x5f\x65\x6e\x74\x72\x69\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__122 = {{&mp_type_str}, 48193, 21, (const byte*)"\x47\x41\x50\x5f\x43\x52\x45\x41\x54\x45\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__123 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__124 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__125 = {{&mp_type_str}, 25866, 16, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__126 = {{&mp_type_str}, 50221, 11, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__127 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__128 = {{&mp_type_str}, 2460, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__129 = {{&mp_type_str}, 24642, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__130 = {{&mp_type_str}, 31454, 12, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__131 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__132 = {{&mp_type_str}, 60991, 15, (const byte*)"\x6d\x69\x6e\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__133 = {{&mp_type_str}, 16161, 15, (const byte*)"\x6d\x61\x78\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__134 = {{&mp_type_str}, 41454, 27, (const byte*)"\x47\x41\x50\x5f\x54\x45\x52\x4d\x49\x4e\x41\x54\x45\x5f\x47\x41\x50\x5f\x50\x52\x4f\x43\x45\x44\x55\x52\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__135 = {{&mp_type_str}, 21771, 27, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x5f\x55\x50\x44\x41\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__136 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__137 = {{&mp_type_str}, 2460, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__138 = {{&mp_type_str}, 24642, 17, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__139 = {{&mp_type_str}, 31454, 12, (const byte*)"\x63\x6f\x6e\x6e\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__140 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__141 = {{&mp_type_str}, 60991, 15, (const byte*)"\x6d\x69\x6e\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__142 = {{&mp_type_str}, 16161, 15, (const byte*)"\x6d\x61\x78\x5f\x63\x6f\x6e\x6e\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__143 = {{&mp_type_str}, 33035, 24, (const byte*)"\x47\x41\x50\x5f\x53\x45\x4e\x44\x5f\x50\x41\x49\x52\x49\x4e\x47\x5f\x52\x45\x51\x55\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__144 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__145 = {{&mp_type_str}, 61143, 12, (const byte*)"\x66\x6f\x72\x63\x65\x5f\x72\x65\x62\x6f\x6e\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__146 = {{&mp_type_str}, 60611, 27, (const byte*)"\x47\x41\x50\x5f\x52\x45\x53\x4f\x4c\x56\x45\x5f\x50\x52\x49\x56\x41\x54\x45\x5f\x41\x44\x44\x52\x45\x53\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__147 = {{&mp_type_str}, 37554, 22, (const byte*)"\x47\x41\x50\x5f\x53\x45\x54\x5f\x42\x52\x4f\x41\x44\x43\x41\x53\x54\x5f\x4d\x4f\x44\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__148 = {{&mp_type_str}, 24142, 14, (const byte*)"\x61\x64\x76\x5f\x69\x6e\x74\x65\x72\x76\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__149 = {{&mp_type_str}, 24400, 14, (const byte*)"\x61\x64\x76\x5f\x69\x6e\x74\x65\x72\x76\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__150 = {{&mp_type_str}, 17432, 13, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__151 = {{&mp_type_str}, 40919, 12, (const byte*)"\x76\x61\x72\x5f\x6c\x65\x6e\x5f\x64\x61\x74\x61"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__152 = {{&mp_type_str}, 49728, 26, (const byte*)"\x47\x41\x50\x5f\x53\x54\x41\x52\x54\x5f\x4f\x42\x53\x45\x52\x56\x41\x54\x49\x4f\x4e\x5f\x50\x52\x4f\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__153 = {{&mp_type_str}, 18970, 13, (const byte*)"\x73\x63\x61\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__154 = {{&mp_type_str}, 65417, 11, (const byte*)"\x73\x63\x61\x6e\x5f\x77\x69\x6e\x64\x6f\x77"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__155 = {{&mp_type_str}, 9949, 16, (const byte*)"\x6f\x77\x6e\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__156 = {{&mp_type_str}, 62654, 17, (const byte*)"\x66\x69\x6c\x74\x65\x72\x5f\x64\x75\x70\x6c\x69\x63\x61\x74\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__157 = {{&mp_type_str}, 43447, 22, (const byte*)"\x47\x41\x50\x5f\x47\x45\x54\x5f\x42\x4f\x4e\x44\x45\x44\x5f\x44\x45\x56\x49\x43\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__158 = {{&mp_type_str}, 33128, 20, (const byte*)"\x47\x41\x50\x5f\x49\x53\x5f\x44\x45\x56\x49\x43\x45\x5f\x42\x4f\x4e\x44\x45\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__159 = {{&mp_type_str}, 52297, 17, (const byte*)"\x70\x65\x65\x72\x5f\x61\x64\x64\x72\x65\x73\x73\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__160 = {{&mp_type_str}, 18126, 12, (const byte*)"\x70\x65\x65\x72\x5f\x61\x64\x64\x72\x65\x73\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__161 = {{&mp_type_str}, 58704, 13, (const byte*)"\x47\x41\x54\x54\x5f\x41\x44\x44\x5f\x53\x45\x52\x56"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__162 = {{&mp_type_str}, 26605, 17, (const byte*)"\x47\x41\x54\x54\x5f\x49\x4e\x43\x4c\x55\x44\x45\x5f\x53\x45\x52\x56"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__163 = {{&mp_type_str}, 13754, 13, (const byte*)"\x47\x41\x54\x54\x5f\x41\x44\x44\x5f\x43\x48\x41\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__164 = {{&mp_type_str}, 34004, 18, (const byte*)"\x47\x41\x54\x54\x5f\x41\x44\x44\x5f\x43\x48\x41\x52\x5f\x44\x45\x53\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__165 = {{&mp_type_str}, 59070, 17, (const byte*)"\x47\x41\x54\x54\x5f\x55\x50\x44\x5f\x43\x48\x41\x52\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__166 = {{&mp_type_str}, 32278, 13, (const byte*)"\x47\x41\x54\x54\x5f\x44\x45\x4c\x5f\x43\x48\x41\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__167 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__168 = {{&mp_type_str}, 21608, 11, (const byte*)"\x63\x68\x61\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__169 = {{&mp_type_str}, 16060, 13, (const byte*)"\x47\x41\x54\x54\x5f\x44\x45\x4c\x5f\x53\x45\x52\x56"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__170 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__171 = {{&mp_type_str}, 52199, 17, (const byte*)"\x47\x41\x54\x54\x5f\x44\x45\x4c\x5f\x49\x4e\x43\x5f\x53\x45\x52\x56"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__172 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__173 = {{&mp_type_str}, 18137, 15, (const byte*)"\x69\x6e\x63\x5f\x73\x65\x72\x76\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__174 = {{&mp_type_str}, 45261, 17, (const byte*)"\x47\x41\x54\x54\x5f\x53\x45\x54\x5f\x45\x56\x54\x5f\x4d\x41\x53\x4b"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__175 = {{&mp_type_str}, 64690, 20, (const byte*)"\x47\x41\x54\x54\x5f\x45\x58\x43\x48\x41\x4e\x47\x45\x5f\x43\x4f\x4e\x46\x49\x47"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__176 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__177 = {{&mp_type_str}, 58582, 17, (const byte*)"\x41\x54\x54\x5f\x46\x49\x4e\x44\x5f\x49\x4e\x46\x4f\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__178 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__179 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__180 = {{&mp_type_str}, 43728, 26, (const byte*)"\x41\x54\x54\x5f\x46\x49\x4e\x44\x5f\x42\x59\x5f\x54\x59\x50\x45\x5f\x56\x41\x4c\x55\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__181 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__182 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__183 = {{&mp_type_str}, 15530, 12, (const byte*)"\x61\x74\x74\x72\x5f\x76\x61\x6c\x5f\x6c\x65\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__184 = {{&mp_type_str}, 60051, 20, (const byte*)"\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x42\x59\x5f\x54\x59\x50\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__185 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__186 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__187 = {{&mp_type_str}, 24339, 26, (const byte*)"\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x42\x59\x5f\x47\x52\x4f\x55\x50\x5f\x54\x59\x50\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__188 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__189 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__190 = {{&mp_type_str}, 61217, 21, (const byte*)"\x41\x54\x54\x5f\x50\x52\x45\x50\x41\x52\x45\x5f\x57\x52\x49\x54\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__191 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__192 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__193 = {{&mp_type_str}, 55708, 12, (const byte*)"\x76\x61\x6c\x75\x65\x5f\x6f\x66\x66\x73\x65\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__194 = {{&mp_type_str}, 15530, 12, (const byte*)"\x61\x74\x74\x72\x5f\x76\x61\x6c\x5f\x6c\x65\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__195 = {{&mp_type_str}, 63455, 21, (const byte*)"\x41\x54\x54\x5f\x45\x58\x45\x43\x55\x54\x45\x5f\x57\x52\x49\x54\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__196 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__197 = {{&mp_type_str}, 47159, 27, (const byte*)"\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x41\x4c\x4c\x5f\x50\x52\x49\x4d\x5f\x53\x45\x52\x56\x49\x43\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__198 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__199 = {{&mp_type_str}, 30668, 30, (const byte*)"\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x50\x52\x49\x4d\x5f\x53\x45\x52\x56\x49\x43\x45\x5f\x42\x59\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__200 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__201 = {{&mp_type_str}, 59471, 27, (const byte*)"\x47\x41\x54\x54\x5f\x46\x49\x4e\x44\x5f\x49\x4e\x43\x4c\x55\x44\x45\x44\x5f\x53\x45\x52\x56\x49\x43\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__202 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__203 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__204 = {{&mp_type_str}, 39297, 28, (const byte*)"\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x41\x4c\x4c\x5f\x43\x48\x41\x52\x41\x43\x5f\x4f\x46\x5f\x53\x45\x52\x56"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__205 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__206 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__207 = {{&mp_type_str}, 10098, 24, (const byte*)"\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x43\x48\x41\x52\x41\x43\x5f\x42\x59\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__208 = {{&mp_type_str}, 48517, 32, (const byte*)"\x47\x41\x54\x54\x5f\x44\x49\x53\x43\x5f\x41\x4c\x4c\x5f\x43\x48\x41\x52\x41\x43\x5f\x44\x45\x53\x43\x52\x49\x50\x54\x4f\x52\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__209 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__210 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__211 = {{&mp_type_str}, 4815, 20, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x43\x48\x41\x52\x41\x43\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__212 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__213 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__214 = {{&mp_type_str}, 3360, 27, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x55\x53\x49\x4e\x47\x5f\x43\x48\x41\x52\x41\x43\x5f\x55\x55\x49\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__215 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__216 = {{&mp_type_str}, 15792, 12, (const byte*)"\x73\x74\x61\x72\x74\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__217 = {{&mp_type_str}, 7162, 25, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x4c\x4f\x4e\x47\x5f\x43\x48\x41\x52\x41\x43\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__218 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__219 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__220 = {{&mp_type_str}, 57376, 29, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x4d\x55\x4c\x54\x49\x50\x4c\x45\x5f\x43\x48\x41\x52\x41\x43\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__221 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__222 = {{&mp_type_str}, 40309, 11, (const byte*)"\x6e\x75\x6d\x5f\x68\x61\x6e\x64\x6c\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__223 = {{&mp_type_str}, 47095, 14, (const byte*)"\x73\x65\x74\x5f\x6f\x66\x5f\x68\x61\x6e\x64\x6c\x65\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__224 = {{&mp_type_str}, 29842, 21, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x43\x48\x41\x52\x5f\x56\x41\x4c\x55\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__225 = {{&mp_type_str}, 39125, 26, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x4c\x4f\x4e\x47\x5f\x43\x48\x41\x52\x41\x43\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__226 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__227 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__228 = {{&mp_type_str}, 31331, 26, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x43\x48\x41\x52\x41\x43\x5f\x52\x45\x4c\x49\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__229 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__230 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__231 = {{&mp_type_str}, 63647, 27, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x4c\x4f\x4e\x47\x5f\x43\x48\x41\x52\x41\x43\x5f\x44\x45\x53\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__232 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__233 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__234 = {{&mp_type_str}, 35984, 26, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x4c\x4f\x4e\x47\x5f\x43\x48\x41\x52\x41\x43\x5f\x44\x45\x53\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__235 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__236 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__237 = {{&mp_type_str}, 12552, 20, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x43\x48\x41\x52\x5f\x44\x45\x53\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__238 = {{&mp_type_str}, 27879, 19, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x43\x48\x41\x52\x5f\x44\x45\x53\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__239 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__240 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__241 = {{&mp_type_str}, 8014, 27, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x57\x49\x54\x48\x4f\x55\x54\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__242 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__243 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__244 = {{&mp_type_str}, 40291, 34, (const byte*)"\x47\x41\x54\x54\x5f\x53\x49\x47\x4e\x45\x44\x5f\x57\x52\x49\x54\x45\x5f\x57\x49\x54\x48\x4f\x55\x54\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__245 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__246 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__247 = {{&mp_type_str}, 6341, 23, (const byte*)"\x47\x41\x54\x54\x5f\x43\x4f\x4e\x46\x49\x52\x4d\x5f\x49\x4e\x44\x49\x43\x41\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__248 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__249 = {{&mp_type_str}, 31581, 19, (const byte*)"\x47\x41\x54\x54\x5f\x57\x52\x49\x54\x45\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__250 = {{&mp_type_str}, 11368, 15, (const byte*)"\x47\x41\x54\x54\x5f\x41\x4c\x4c\x4f\x57\x5f\x52\x45\x41\x44"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__251 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__252 = {{&mp_type_str}, 54883, 28, (const byte*)"\x47\x41\x54\x54\x5f\x53\x45\x54\x5f\x53\x45\x43\x55\x52\x49\x54\x59\x5f\x50\x45\x52\x4d\x49\x53\x53\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__253 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__254 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__255 = {{&mp_type_str}, 22151, 19, (const byte*)"\x73\x65\x63\x75\x72\x69\x74\x79\x5f\x70\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__256 = {{&mp_type_str}, 43988, 17, (const byte*)"\x47\x41\x54\x54\x5f\x53\x45\x54\x5f\x44\x45\x53\x43\x5f\x56\x41\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__257 = {{&mp_type_str}, 12239, 22, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x48\x41\x4e\x44\x4c\x45\x5f\x56\x41\x4c\x55\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__258 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__259 = {{&mp_type_str}, 36221, 29, (const byte*)"\x47\x41\x54\x54\x5f\x52\x45\x41\x44\x5f\x48\x41\x4e\x44\x4c\x45\x5f\x56\x41\x4c\x55\x45\x5f\x4f\x46\x46\x53\x45\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__260 = {{&mp_type_str}, 37091, 11, (const byte*)"\x61\x74\x74\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__261 = {{&mp_type_str}, 7688, 21, (const byte*)"\x47\x41\x54\x54\x5f\x55\x50\x44\x5f\x43\x48\x41\x52\x5f\x56\x41\x4c\x5f\x45\x58\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__262 = {{&mp_type_str}, 12045, 14, (const byte*)"\x73\x65\x72\x76\x69\x63\x65\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__263 = {{&mp_type_str}, 21608, 11, (const byte*)"\x63\x68\x61\x72\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__264 = {{&mp_type_str}, 43763, 11, (const byte*)"\x75\x70\x64\x61\x74\x65\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__265 = {{&mp_type_str}, 37374, 11, (const byte*)"\x63\x68\x61\x72\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__266 = {{&mp_type_str}, 55708, 12, (const byte*)"\x76\x61\x6c\x75\x65\x5f\x6f\x66\x66\x73\x65\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__267 = {{&mp_type_str}, 26509, 12, (const byte*)"\x76\x61\x6c\x75\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__268 = {{&mp_type_str}, 7677, 27, (const byte*)"\x4c\x32\x43\x41\x50\x5f\x43\x4f\x4e\x4e\x5f\x50\x41\x52\x41\x4d\x5f\x55\x50\x44\x41\x54\x45\x5f\x52\x45\x51"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__269 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__270 = {{&mp_type_str}, 32431, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__271 = {{&mp_type_str}, 32689, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__272 = {{&mp_type_str}, 6335, 13, (const byte*)"\x73\x6c\x61\x76\x65\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__273 = {{&mp_type_str}, 52234, 18, (const byte*)"\x74\x69\x6d\x65\x6f\x75\x74\x5f\x6d\x75\x6c\x74\x69\x70\x6c\x69\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__274 = {{&mp_type_str}, 56719, 28, (const byte*)"\x4c\x32\x43\x41\x50\x5f\x43\x4f\x4e\x4e\x5f\x50\x41\x52\x41\x4d\x5f\x55\x50\x44\x41\x54\x45\x5f\x52\x45\x53\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__275 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__276 = {{&mp_type_str}, 32431, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__277 = {{&mp_type_str}, 32689, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__278 = {{&mp_type_str}, 6335, 13, (const byte*)"\x73\x6c\x61\x76\x65\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__279 = {{&mp_type_str}, 52234, 18, (const byte*)"\x74\x69\x6d\x65\x6f\x75\x74\x5f\x6d\x75\x6c\x74\x69\x70\x6c\x69\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__280 = {{&mp_type_str}, 56501, 13, (const byte*)"\x6d\x69\x6e\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__281 = {{&mp_type_str}, 18859, 13, (const byte*)"\x6d\x61\x78\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__282 = {{&mp_type_str}, 2908, 11, (const byte*)"\x63\x6f\x6e\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__283 = {{&mp_type_str}, 32431, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x69\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__284 = {{&mp_type_str}, 32689, 12, (const byte*)"\x69\x6e\x74\x65\x72\x76\x61\x6c\x5f\x6d\x61\x78"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__285 = {{&mp_type_str}, 6335, 13, (const byte*)"\x73\x6c\x61\x76\x65\x5f\x6c\x61\x74\x65\x6e\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__286 = {{&mp_type_str}, 52234, 18, (const byte*)"\x74\x69\x6d\x65\x6f\x75\x74\x5f\x6d\x75\x6c\x74\x69\x70\x6c\x69\x65\x72"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_[287] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__24),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__25),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__26),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__27),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__28),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__29),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__30),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__31),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__32),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__33),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__34),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__35),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__36),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__37),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__38),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__39),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__40),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__41),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__42),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__43),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__44),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__45),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__46),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__47),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__48),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__49),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__50),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__51),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__52),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__53),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__54),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__55),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__56),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__57),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__58),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__59),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__60),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__61),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__62),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__63),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__64),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__65),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__66),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__67),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__68),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__69),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__70),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__71),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__72),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__73),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__74),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__75),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__76),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__77),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__78),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__79),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__80),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__81),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__82),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__83),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__84),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__85),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__86),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__87),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__88),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__89),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__90),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__91),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__92),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__93),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__94),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__95),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__96),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__97),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__98),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__99),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__100),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__101),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__102),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__103),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__104),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__105),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__106),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__107),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__108),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__109),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__110),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__111),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__112),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__113),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__114),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__115),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__116),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__117),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__118),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__119),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__120),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__121),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__122),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__123),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__124),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__125),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__126),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__127),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__128),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__129),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__130),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__131),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__132),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__133),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__134),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__135),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__136),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__137),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__138),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__139),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__140),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__141),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__142),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__143),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__144),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__145),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__146),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__147),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__148),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__149),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__150),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__151),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__152),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__153),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__154),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__155),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__156),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__157),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__158),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__159),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__160),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__161),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__162),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__163),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__164),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__165),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__166),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__167),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__168),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__169),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__170),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__171),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__172),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__173),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__174),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__175),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__176),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__177),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__178),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__179),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__180),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__181),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__182),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__183),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__184),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__185),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__186),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__187),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__188),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__189),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__190),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__191),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__192),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__193),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__194),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__195),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__196),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__197),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__198),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__199),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__200),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__201),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__202),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__203),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__204),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__205),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__206),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__207),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__208),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__209),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__210),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__211),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__212),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__213),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__214),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__215),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__216),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__217),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__218),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__219),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__220),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__221),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__222),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__223),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__224),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__225),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__226),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__227),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__228),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__229),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__230),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__231),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__232),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__233),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__234),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__235),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__236),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__237),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__238),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__239),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__240),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__241),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__242),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__243),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__244),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__245),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__246),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__247),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__248),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__249),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__250),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__251),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__252),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__253),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__254),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__255),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__256),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__257),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__258),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__259),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__260),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__261),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__262),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__263),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__264),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__265),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__266),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__267),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__268),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__269),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__270),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__271),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__272),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__273),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__274),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__275),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__276),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__277),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__278),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__279),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__280),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__281),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__282),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__283),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__284),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__285),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt__286),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 7636,
        .n_obj = 287,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/__init__.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/constant.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_constant_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_constant__lt_module_gt_[1209] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0x74,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_constant_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash_st_microelectronics_slash_bluenrg_ms_slash_constant_dot_py >> 8,
    0x21, 0x70, 0x20, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x84, 0x08, 0x44, 0x44, 0x44, 0x64, 0x20, 0x44, 0x86, 0x07, 0x64, 0x64, 0x40, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x64, 0x60, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x64, 0x20, 0x26, 0x27, 0x27, 0x27, 0x27, 0x67, 0x20, 0x24, 0x24, 0x24, 0x24, 0x64, 0x40, 0x64, 0x24, 0x24, 0x24, 0x24, 0x64, 0x20, 0x24, 0x24, 0x24, 0x24, 0x24, 0x64, 0x24, 0x64, 0x64, 0x64, 0x64, 0x64, 0x64, 0x24, 0x24, 0x64, 0x64, 0x66, 0x44, 0x24, 0x64, 0x24, 0x64, 0x20, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x66, 0x20, 0x47, 0x67, 0x24, 0x24, 0x24, 0x44, 0x24, 0x24, 0x24, 0x84, 0x07, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x46, 0x66, 0x40, 0x64, 0x64, 0x44, 0x64, 0x24, 0x24, 0x24, 0x24, 0x64, 0x24, 0x64, 0x20, 0x44, 0x44, 0x44, 0x44, 0x64, 0x40, 0x44, 0x47, 0x66, 0x24, 0x24, 0x64, 0x24, 0x64, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x26, 0x67, 0x20, 0x24, 0x24, 0x24, 0x24, 0x24, 0x64, 0x20, 0x64, 0x20, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x26, 0x66, 0x40, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x64, 0x20, 0x24, 0x64, 0x20, 0x24, 0x64, 0x40, 0x64, 0x64, 0x20, 0x64, 0x64, 0x20, 0x24, 0x64, 0x20, 0x24, 0x64, 0x24, 0x24, 0x24, 0x44, 0x27, 0x27, 0x67, 0x44, 0x24, 0x64, 0x24, 0x24, 0x24, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x24, 0x64, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x64, 0x24, 0x24, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_RESET_NORMAL & 0xff, MP_QSTR_RESET_NORMAL >> 8,
    0x82, 
    0x24, MP_QSTR_RESET_UPDATER_ACI & 0xff, MP_QSTR_RESET_UPDATER_ACI >> 8,
    0x83, 
    0x24, MP_QSTR_RESET_UPDATER_BAD_FLAG & 0xff, MP_QSTR_RESET_UPDATER_BAD_FLAG >> 8,
    0x84, 
    0x24, MP_QSTR_RESET_UPDATER_PIN & 0xff, MP_QSTR_RESET_UPDATER_PIN >> 8,
    0x85, 
    0x24, MP_QSTR_RESET_WATCHDOG & 0xff, MP_QSTR_RESET_WATCHDOG >> 8,
    0x86, 
    0x24, MP_QSTR_RESET_LOCKUP & 0xff, MP_QSTR_RESET_LOCKUP >> 8,
    0x87, 
    0x24, MP_QSTR_RESET_BROWNOUT & 0xff, MP_QSTR_RESET_BROWNOUT >> 8,
    0x88, 
    0x24, MP_QSTR_RESET_CRASH & 0xff, MP_QSTR_RESET_CRASH >> 8,
    0x89, 
    0x24, MP_QSTR_RESET_ECC_ERR & 0xff, MP_QSTR_RESET_ECC_ERR >> 8,
    0x80, 
    0x24, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_OFFSET >> 8,
    0x86, 
    0x24, MP_QSTR_CONFIG_DATA_DIV_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_DIV_OFFSET >> 8,
    0x88, 
    0x24, MP_QSTR_CONFIG_DATA_ER_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_ER_OFFSET >> 8,
    0x98, 
    0x24, MP_QSTR_CONFIG_DATA_IR_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_IR_OFFSET >> 8,
    0xac, 
    0x24, MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST & 0xff, MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST >> 8,
    0x14, 0x81, 0x00, 
    0x24, MP_QSTR_CONFIG_DATA_RANDOM_ADDRESS & 0xff, MP_QSTR_CONFIG_DATA_RANDOM_ADDRESS >> 8,
    0xad, 
    0x24, MP_QSTR_CONFIG_DATA_MODE_OFFSET & 0xff, MP_QSTR_CONFIG_DATA_MODE_OFFSET >> 8,
    0xaf, 
    0x24, MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE & 0xff, MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE >> 8,
    0x86, 
    0x24, MP_QSTR_CONFIG_DATA_PUBADDR_LEN & 0xff, MP_QSTR_CONFIG_DATA_PUBADDR_LEN >> 8,
    0x82, 
    0x24, MP_QSTR_CONFIG_DATA_DIV_LEN & 0xff, MP_QSTR_CONFIG_DATA_DIV_LEN >> 8,
    0x90, 
    0x24, MP_QSTR_CONFIG_DATA_ER_LEN & 0xff, MP_QSTR_CONFIG_DATA_ER_LEN >> 8,
    0x90, 
    0x24, MP_QSTR_CONFIG_DATA_IR_LEN & 0xff, MP_QSTR_CONFIG_DATA_IR_LEN >> 8,
    0x81, 
    0x24, MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST_LEN & 0xff, MP_QSTR_CONFIG_DATA_LL_WITHOUT_HOST_LEN >> 8,
    0x81, 
    0x24, MP_QSTR_CONFIG_DATA_MODE_LEN & 0xff, MP_QSTR_CONFIG_DATA_MODE_LEN >> 8,
    0x81, 
    0x24, MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE_LEN & 0xff, MP_QSTR_CONFIG_DATA_WATCHDOG_DISABLE_LEN >> 8,
    0x80, 
    0x24, MP_QSTR_STATUS_IDLE & 0xff, MP_QSTR_STATUS_IDLE >> 8,
    0x81, 
    0x24, MP_QSTR_STATUS_ADVERTISING & 0xff, MP_QSTR_STATUS_ADVERTISING >> 8,
    0x82, 
    0x24, MP_QSTR_STATUS_CONNECTED_AS_SLAVE & 0xff, MP_QSTR_STATUS_CONNECTED_AS_SLAVE >> 8,
    0x83, 
    0x24, MP_QSTR_STATUS_SCANNING & 0xff, MP_QSTR_STATUS_SCANNING >> 8,
    0x85, 
    0x24, MP_QSTR_STATUS_CONNECTED_AS_MASTER & 0xff, MP_QSTR_STATUS_CONNECTED_AS_MASTER >> 8,
    0x86, 
    0x24, MP_QSTR_STATUS_TX_TEST & 0xff, MP_QSTR_STATUS_TX_TEST >> 8,
    0x87, 
    0x24, MP_QSTR_STATUS_RX_TEST & 0xff, MP_QSTR_STATUS_RX_TEST >> 8,
    0x14, 0xb0, 0x00, 
    0x24, MP_QSTR_GAP_SERVICE_UUID & 0xff, MP_QSTR_GAP_SERVICE_UUID >> 8,
    0x14, 0x80, 0xd4, 0x00, 
    0x24, MP_QSTR_DEVICE_NAME_UUID & 0xff, MP_QSTR_DEVICE_NAME_UUID >> 8,
    0x14, 0x80, 0xd4, 0x01, 
    0x24, MP_QSTR_APPEARANCE_UUID & 0xff, MP_QSTR_APPEARANCE_UUID >> 8,
    0x14, 0x80, 0xd4, 0x02, 
    0x24, MP_QSTR_PERIPHERAL_PRIVACY_FLAG_UUID & 0xff, MP_QSTR_PERIPHERAL_PRIVACY_FLAG_UUID >> 8,
    0x14, 0x80, 0xd4, 0x03, 
    0x24, MP_QSTR_RECONNECTION_ADDR_UUID & 0xff, MP_QSTR_RECONNECTION_ADDR_UUID >> 8,
    0x14, 0x80, 0xd4, 0x04, 
    0x24, MP_QSTR_PERIPHERAL_PREFERRED_CONN_PARAMS_UUID & 0xff, MP_QSTR_PERIPHERAL_PREFERRED_CONN_PARAMS_UUID >> 8,
    0x88, 
    0x24, MP_QSTR_DEVICE_NAME_CHARACTERISTIC_LEN & 0xff, MP_QSTR_DEVICE_NAME_CHARACTERISTIC_LEN >> 8,
    0x82, 
    0x24, MP_QSTR_APPEARANCE_CHARACTERISTIC_LEN & 0xff, MP_QSTR_APPEARANCE_CHARACTERISTIC_LEN >> 8,
    0x81, 
    0x24, MP_QSTR_PERIPHERAL_PRIVACY_CHARACTERISTIC_LEN & 0xff, MP_QSTR_PERIPHERAL_PRIVACY_CHARACTERISTIC_LEN >> 8,
    0x86, 
    0x24, MP_QSTR_RECONNECTION_ADDR_CHARACTERISTIC_LEN & 0xff, MP_QSTR_RECONNECTION_ADDR_CHARACTERISTIC_LEN >> 8,
    0x88, 
    0x24, MP_QSTR_PERIPHERAL_PREF_CONN_PARAMS_CHARACTERISTIC_LEN & 0xff, MP_QSTR_PERIPHERAL_PREF_CONN_PARAMS_CHARACTERISTIC_LEN >> 8,
    0x81, 
    0x24, MP_QSTR_AD_TYPE_FLAGS & 0xff, MP_QSTR_AD_TYPE_FLAGS >> 8,
    0x81, 
    0x24, MP_QSTR_FLAG_BIT_LE_LIMITED_DISCOVERABLE_MODE & 0xff, MP_QSTR_FLAG_BIT_LE_LIMITED_DISCOVERABLE_MODE >> 8,
    0x82, 
    0x24, MP_QSTR_FLAG_BIT_LE_GENERAL_DISCOVERABLE_MODE & 0xff, MP_QSTR_FLAG_BIT_LE_GENERAL_DISCOVERABLE_MODE >> 8,
    0x84, 
    0x24, MP_QSTR_FLAG_BIT_BR_EDR_NOT_SUPPORTED & 0xff, MP_QSTR_FLAG_BIT_BR_EDR_NOT_SUPPORTED >> 8,
    0x88, 
    0x24, MP_QSTR_FLAG_BIT_LE_BR_EDR_CONTROLLER & 0xff, MP_QSTR_FLAG_BIT_LE_BR_EDR_CONTROLLER >> 8,
    0x90, 
    0x24, MP_QSTR_FLAG_BIT_LE_BR_EDR_HOST & 0xff, MP_QSTR_FLAG_BIT_LE_BR_EDR_HOST >> 8,
    0x82, 
    0x24, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID >> 8,
    0x83, 
    0x24, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_16_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x84, 
    0x24, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID >> 8,
    0x85, 
    0x24, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_32_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x86, 
    0x24, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID & 0xff, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID >> 8,
    0x87, 
    0x24, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST & 0xff, MP_QSTR_AD_TYPE_128_BIT_SERV_UUID_CMPLT_LIST >> 8,
    0x88, 
    0x24, MP_QSTR_AD_TYPE_SHORTENED_LOCAL_NAME & 0xff, MP_QSTR_AD_TYPE_SHORTENED_LOCAL_NAME >> 8,
    0x89, 
    0x24, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME & 0xff, MP_QSTR_AD_TYPE_COMPLETE_LOCAL_NAME >> 8,
    0x8a, 
    0x24, MP_QSTR_AD_TYPE_TX_POWER_LEVEL & 0xff, MP_QSTR_AD_TYPE_TX_POWER_LEVEL >> 8,
    0x8d, 
    0x24, MP_QSTR_AD_TYPE_CLASS_OF_DEVICE & 0xff, MP_QSTR_AD_TYPE_CLASS_OF_DEVICE >> 8,
    0x90, 
    0x24, MP_QSTR_AD_TYPE_SEC_MGR_TK_VALUE & 0xff, MP_QSTR_AD_TYPE_SEC_MGR_TK_VALUE >> 8,
    0x91, 
    0x24, MP_QSTR_AD_TYPE_SEC_MGR_OOB_FLAGS & 0xff, MP_QSTR_AD_TYPE_SEC_MGR_OOB_FLAGS >> 8,
    0x92, 
    0x24, MP_QSTR_AD_TYPE_SLAVE_CONN_INTERVAL & 0xff, MP_QSTR_AD_TYPE_SLAVE_CONN_INTERVAL >> 8,
    0x94, 
    0x24, MP_QSTR_AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_16_BIT_UUID_LIST >> 8,
    0x9f, 
    0x24, MP_QSTR_AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_32_BIT_UUID_LIST >> 8,
    0x95, 
    0x24, MP_QSTR_AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST & 0xff, MP_QSTR_AD_TYPE_SERV_SOLICIT_128_BIT_UUID_LIST >> 8,
    0x96, 
    0x24, MP_QSTR_AD_TYPE_SERVICE_DATA & 0xff, MP_QSTR_AD_TYPE_SERVICE_DATA >> 8,
    0x14, 0x81, 0x7f, 
    0x24, MP_QSTR_AD_TYPE_MANUFACTURER_SPECIFIC_DATA & 0xff, MP_QSTR_AD_TYPE_MANUFACTURER_SPECIFIC_DATA >> 8,
    0x9f, 
    0x24, MP_QSTR_MAX_ADV_DATA_LEN & 0xff, MP_QSTR_MAX_ADV_DATA_LEN >> 8,
    0x87, 
    0x24, MP_QSTR_DEVICE_NAME_LEN & 0xff, MP_QSTR_DEVICE_NAME_LEN >> 8,
    0x86, 
    0x24, MP_QSTR_BD_ADDR_SIZE & 0xff, MP_QSTR_BD_ADDR_SIZE >> 8,
    0x81, 
    0x24, MP_QSTR_PRIVACY_ENABLED & 0xff, MP_QSTR_PRIVACY_ENABLED >> 8,
    0x80, 
    0x24, MP_QSTR_PRIVACY_DISABLED & 0xff, MP_QSTR_PRIVACY_DISABLED >> 8,
    0x14, 0x83, 0x10, 
    0x24, MP_QSTR_DIR_CONN_ADV_INT_MIN & 0xff, MP_QSTR_DIR_CONN_ADV_INT_MIN >> 8,
    0x14, 0x86, 0x20, 
    0x24, MP_QSTR_DIR_CONN_ADV_INT_MAX & 0xff, MP_QSTR_DIR_CONN_ADV_INT_MAX >> 8,
    0x14, 0x90, 0x00, 
    0x24, MP_QSTR_UNDIR_CONN_ADV_INT_MIN & 0xff, MP_QSTR_UNDIR_CONN_ADV_INT_MIN >> 8,
    0x14, 0xa0, 0x00, 
    0x24, MP_QSTR_UNDIR_CONN_ADV_INT_MAX & 0xff, MP_QSTR_UNDIR_CONN_ADV_INT_MAX >> 8,
    0x14, 0x83, 0x10, 
    0x24, MP_QSTR_LIM_DISC_ADV_INT_MIN & 0xff, MP_QSTR_LIM_DISC_ADV_INT_MIN >> 8,
    0x14, 0x86, 0x20, 
    0x24, MP_QSTR_LIM_DISC_ADV_INT_MAX & 0xff, MP_QSTR_LIM_DISC_ADV_INT_MAX >> 8,
    0x14, 0x90, 0x00, 
    0x24, MP_QSTR_GEN_DISC_ADV_INT_MIN & 0xff, MP_QSTR_GEN_DISC_ADV_INT_MIN >> 8,
    0x14, 0xa0, 0x00, 
    0x24, MP_QSTR_GEN_DISC_ADV_INT_MAX & 0xff, MP_QSTR_GEN_DISC_ADV_INT_MAX >> 8,
    0x14, 0x8a, 0xfe, 0x20, 
    0x24, MP_QSTR_LIM_DISC_MODE_TIMEOUT & 0xff, MP_QSTR_LIM_DISC_MODE_TIMEOUT >> 8,
    0x14, 0xb6, 0xf7, 0x20, 
    0x24, MP_QSTR_PRIVATE_ADDR_INT_TIMEOUT & 0xff, MP_QSTR_PRIVATE_ADDR_INT_TIMEOUT >> 8,
    0x81, 
    0x24, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB05A1 >> 8,
    0x82, 
    0x24, MP_QSTR_GAP_BROADCASTER_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_BROADCASTER_ROLE_IDB05A1 >> 8,
    0x84, 
    0x24, MP_QSTR_GAP_CENTRAL_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_CENTRAL_ROLE_IDB05A1 >> 8,
    0x88, 
    0x24, MP_QSTR_GAP_OBSERVER_ROLE_IDB05A1 & 0xff, MP_QSTR_GAP_OBSERVER_ROLE_IDB05A1 >> 8,
    0x81, 
    0x24, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB04A1 & 0xff, MP_QSTR_GAP_PERIPHERAL_ROLE_IDB04A1 >> 8,
    0x82, 
    0x24, MP_QSTR_GAP_BROADCASTER_ROLE_IDB04A1 & 0xff, MP_QSTR_GAP_BROADCASTER_ROLE_IDB04A1 >> 8,
    0x83, 
    0x24, MP_QSTR_GAP_CENTRAL_ROLE_IDB04A1 & 0xff, MP_QSTR_GAP_CENTRAL_ROLE_IDB04A1 >> 8,
    0x84, 
    0x24, MP_QSTR_GAP_OBSERVER_ROLE_IDB04A1 & 0xff, MP_QSTR_GAP_OBSERVER_ROLE_IDB04A1 >> 8,
    0x81, 
    0x24, MP_QSTR_GAP_LIMITED_DISCOVERY_PROC & 0xff, MP_QSTR_GAP_LIMITED_DISCOVERY_PROC >> 8,
    0x82, 
    0x24, MP_QSTR_GAP_GENERAL_DISCOVERY_PROC & 0xff, MP_QSTR_GAP_GENERAL_DISCOVERY_PROC >> 8,
    0x84, 
    0x24, MP_QSTR_GAP_NAME_DISCOVERY_PROC & 0xff, MP_QSTR_GAP_NAME_DISCOVERY_PROC >> 8,
    0x88, 
    0x24, MP_QSTR_GAP_AUTO_CONNECTION_ESTABLISHMENT_PROC & 0xff, MP_QSTR_GAP_AUTO_CONNECTION_ESTABLISHMENT_PROC >> 8,
    0x90, 
    0x24, MP_QSTR_GAP_GENERAL_CONNECTION_ESTABLISHMENT_PROC & 0xff, MP_QSTR_GAP_GENERAL_CONNECTION_ESTABLISHMENT_PROC >> 8,
    0xa0, 
    0x24, MP_QSTR_GAP_SELECTIVE_CONNECTION_ESTABLISHMENT_PROC & 0xff, MP_QSTR_GAP_SELECTIVE_CONNECTION_ESTABLISHMENT_PROC >> 8,
    0x14, 0x80, 0x40, 
    0x24, MP_QSTR_GAP_DIRECT_CONNECTION_ESTABLISHMENT_PROC & 0xff, MP_QSTR_GAP_DIRECT_CONNECTION_ESTABLISHMENT_PROC >> 8,
    0x14, 0x81, 0x00, 
    0x24, MP_QSTR_GAP_OBSERVATION_PROC_IDB05A1 & 0xff, MP_QSTR_GAP_OBSERVATION_PROC_IDB05A1 >> 8,
    0x80, 
    0x24, MP_QSTR_NO_WHITE_LIST_USE & 0xff, MP_QSTR_NO_WHITE_LIST_USE >> 8,
    0x81, 
    0x24, MP_QSTR_WHITE_LIST_FOR_ONLY_SCAN & 0xff, MP_QSTR_WHITE_LIST_FOR_ONLY_SCAN >> 8,
    0x82, 
    0x24, MP_QSTR_WHITE_LIST_FOR_ONLY_CONN & 0xff, MP_QSTR_WHITE_LIST_FOR_ONLY_CONN >> 8,
    0x83, 
    0x24, MP_QSTR_WHITE_LIST_FOR_ALL & 0xff, MP_QSTR_WHITE_LIST_FOR_ALL >> 8,
    0x80, 
    0x24, MP_QSTR_PUBLIC_ADDR & 0xff, MP_QSTR_PUBLIC_ADDR >> 8,
    0x81, 
    0x24, MP_QSTR_RANDOM_ADDR & 0xff, MP_QSTR_RANDOM_ADDR >> 8,
    0x81, 
    0x24, MP_QSTR_STATIC_RANDOM_ADDR & 0xff, MP_QSTR_STATIC_RANDOM_ADDR >> 8,
    0x82, 
    0x24, MP_QSTR_RESOLVABLE_PRIVATE_ADDR & 0xff, MP_QSTR_RESOLVABLE_PRIVATE_ADDR >> 8,
    0x83, 
    0x24, MP_QSTR_NON_RESOLVABLE_PRIVATE_ADDR & 0xff, MP_QSTR_NON_RESOLVABLE_PRIVATE_ADDR >> 8,
    0x81, 
    0x24, MP_QSTR_HIGH_DUTY_CYCLE_DIRECTED_ADV & 0xff, MP_QSTR_HIGH_DUTY_CYCLE_DIRECTED_ADV >> 8,
    0x84, 
    0x24, MP_QSTR_LOW_DUTY_CYCLE_DIRECTED_ADV & 0xff, MP_QSTR_LOW_DUTY_CYCLE_DIRECTED_ADV >> 8,
    0x80, 
    0x24, MP_QSTR_ADV_IND & 0xff, MP_QSTR_ADV_IND >> 8,
    0x81, 
    0x24, MP_QSTR_ADV_DIRECT_IND & 0xff, MP_QSTR_ADV_DIRECT_IND >> 8,
    0x82, 
    0x24, MP_QSTR_ADV_SCAN_IND & 0xff, MP_QSTR_ADV_SCAN_IND >> 8,
    0x83, 
    0x24, MP_QSTR_ADV_NONCONN_IND & 0xff, MP_QSTR_ADV_NONCONN_IND >> 8,
    0x84, 
    0x24, MP_QSTR_SCAN_RSP & 0xff, MP_QSTR_SCAN_RSP >> 8,
    0xa0, 
    0x24, MP_QSTR_ADV_INTERVAL_LOWEST_CONN & 0xff, MP_QSTR_ADV_INTERVAL_LOWEST_CONN >> 8,
    0x14, 0x81, 0x80, 0x00, 
    0x24, MP_QSTR_ADV_INTERVAL_HIGHEST & 0xff, MP_QSTR_ADV_INTERVAL_HIGHEST >> 8,
    0x14, 0x81, 0x20, 
    0x24, MP_QSTR_ADV_INTERVAL_LOWEST_NONCONN & 0xff, MP_QSTR_ADV_INTERVAL_LOWEST_NONCONN >> 8,
    0x81, 
    0x24, MP_QSTR_ADV_CH_37 & 0xff, MP_QSTR_ADV_CH_37 >> 8,
    0x82, 
    0x24, MP_QSTR_ADV_CH_38 & 0xff, MP_QSTR_ADV_CH_38 >> 8,
    0x84, 
    0x24, MP_QSTR_ADV_CH_39 & 0xff, MP_QSTR_ADV_CH_39 >> 8,
    0x80, 
    0x24, MP_QSTR_PASSIVE_SCAN & 0xff, MP_QSTR_PASSIVE_SCAN >> 8,
    0x81, 
    0x24, MP_QSTR_ACTIVE_SCAN & 0xff, MP_QSTR_ACTIVE_SCAN >> 8,
    0x14, 0x80, 0xd0, 0x00, 
    0x24, MP_QSTR_PRIMARY_SERVICE_UUID & 0xff, MP_QSTR_PRIMARY_SERVICE_UUID >> 8,
    0x14, 0x80, 0xd0, 0x01, 
    0x24, MP_QSTR_SECONDARY_SERVICE_UUID & 0xff, MP_QSTR_SECONDARY_SERVICE_UUID >> 8,
    0x14, 0x80, 0xd0, 0x02, 
    0x24, MP_QSTR_INCLUDE_SERVICE_UUID & 0xff, MP_QSTR_INCLUDE_SERVICE_UUID >> 8,
    0x14, 0x80, 0xd0, 0x03, 
    0x24, MP_QSTR_CHARACTERISTIC_UUID & 0xff, MP_QSTR_CHARACTERISTIC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x00, 
    0x24, MP_QSTR_CHAR_EXTENDED_PROP_DESC_UUID & 0xff, MP_QSTR_CHAR_EXTENDED_PROP_DESC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x01, 
    0x24, MP_QSTR_CHAR_USER_DESC_UUID & 0xff, MP_QSTR_CHAR_USER_DESC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x02, 
    0x24, MP_QSTR_CHAR_CLIENT_CONFIG_DESC_UUID & 0xff, MP_QSTR_CHAR_CLIENT_CONFIG_DESC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x03, 
    0x24, MP_QSTR_CHAR_SERVER_CONFIG_DESC_UUID & 0xff, MP_QSTR_CHAR_SERVER_CONFIG_DESC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x04, 
    0x24, MP_QSTR_CHAR_FORMAT_DESC_UUID & 0xff, MP_QSTR_CHAR_FORMAT_DESC_UUID >> 8,
    0x14, 0x80, 0xd2, 0x05, 
    0x24, MP_QSTR_CHAR_AGGR_FMT_DESC_UUID & 0xff, MP_QSTR_CHAR_AGGR_FMT_DESC_UUID >> 8,
    0x14, 0xb0, 0x01, 
    0x24, MP_QSTR_GATT_SERVICE_UUID & 0xff, MP_QSTR_GATT_SERVICE_UUID >> 8,
    0x14, 0x80, 0xd4, 0x05, 
    0x24, MP_QSTR_SERVICE_CHANGED_UUID & 0xff, MP_QSTR_SERVICE_CHANGED_UUID >> 8,
    0x80, 
    0x24, MP_QSTR_ATTR_NO_ACCESS & 0xff, MP_QSTR_ATTR_NO_ACCESS >> 8,
    0x81, 
    0x24, MP_QSTR_ATTR_ACCESS_READ_ONLY & 0xff, MP_QSTR_ATTR_ACCESS_READ_ONLY >> 8,
    0x82, 
    0x24, MP_QSTR_ATTR_ACCESS_WRITE_REQ_ONLY & 0xff, MP_QSTR_ATTR_ACCESS_WRITE_REQ_ONLY >> 8,
    0x83, 
    0x24, MP_QSTR_ATTR_ACCESS_READ_WRITE & 0xff, MP_QSTR_ATTR_ACCESS_READ_WRITE >> 8,
    0x84, 
    0x24, MP_QSTR_ATTR_ACCESS_WRITE_WITHOUT_RESPONSE & 0xff, MP_QSTR_ATTR_ACCESS_WRITE_WITHOUT_RESPONSE >> 8,
    0x88, 
    0x24, MP_QSTR_ATTR_ACCESS_SIGNED_WRITE_ALLOWED & 0xff, MP_QSTR_ATTR_ACCESS_SIGNED_WRITE_ALLOWED >> 8,
    0x8e, 
    0x24, MP_QSTR_ATTR_ACCESS_WRITE_ANY & 0xff, MP_QSTR_ATTR_ACCESS_WRITE_ANY >> 8,
    0x81, 
    0x24, MP_QSTR_CHAR_PROP_BROADCAST & 0xff, MP_QSTR_CHAR_PROP_BROADCAST >> 8,
    0x82, 
    0x24, MP_QSTR_CHAR_PROP_READ & 0xff, MP_QSTR_CHAR_PROP_READ >> 8,
    0x84, 
    0x24, MP_QSTR_CHAR_PROP_WRITE_WITHOUT_RESP & 0xff, MP_QSTR_CHAR_PROP_WRITE_WITHOUT_RESP >> 8,
    0x88, 
    0x24, MP_QSTR_CHAR_PROP_WRITE & 0xff, MP_QSTR_CHAR_PROP_WRITE >> 8,
    0x90, 
    0x24, MP_QSTR_CHAR_PROP_NOTIFY & 0xff, MP_QSTR_CHAR_PROP_NOTIFY >> 8,
    0xa0, 
    0x24, MP_QSTR_CHAR_PROP_INDICATE & 0xff, MP_QSTR_CHAR_PROP_INDICATE >> 8,
    0x14, 0x80, 0x40, 
    0x24, MP_QSTR_CHAR_PROP_SIGNED_WRITE & 0xff, MP_QSTR_CHAR_PROP_SIGNED_WRITE >> 8,
    0x14, 0x81, 0x00, 
    0x24, MP_QSTR_CHAR_PROP_EXT & 0xff, MP_QSTR_CHAR_PROP_EXT >> 8,
    0x80, 
    0x24, MP_QSTR_ATTR_PERMISSION_NONE & 0xff, MP_QSTR_ATTR_PERMISSION_NONE >> 8,
    0x81, 
    0x24, MP_QSTR_ATTR_PERMISSION_AUTHEN_READ & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHEN_READ >> 8,
    0x82, 
    0x24, MP_QSTR_ATTR_PERMISSION_AUTHOR_READ & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHOR_READ >> 8,
    0x84, 
    0x24, MP_QSTR_ATTR_PERMISSION_ENCRY_READ & 0xff, MP_QSTR_ATTR_PERMISSION_ENCRY_READ >> 8,
    0x88, 
    0x24, MP_QSTR_ATTR_PERMISSION_AUTHEN_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHEN_WRITE >> 8,
    0x90, 
    0x24, MP_QSTR_ATTR_PERMISSION_AUTHOR_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_AUTHOR_WRITE >> 8,
    0xa0, 
    0x24, MP_QSTR_ATTR_PERMISSION_ENCRY_WRITE & 0xff, MP_QSTR_ATTR_PERMISSION_ENCRY_WRITE >> 8,
    0x81, 
    0x24, MP_QSTR_UUID_TYPE_16 & 0xff, MP_QSTR_UUID_TYPE_16 >> 8,
    0x82, 
    0x24, MP_QSTR_UUID_TYPE_128 & 0xff, MP_QSTR_UUID_TYPE_128 >> 8,
    0x81, 
    0x24, MP_QSTR_PRIMARY_SERVICE & 0xff, MP_QSTR_PRIMARY_SERVICE >> 8,
    0x82, 
    0x24, MP_QSTR_SECONDARY_SERVICE & 0xff, MP_QSTR_SECONDARY_SERVICE >> 8,
    0x80, 
    0x24, MP_QSTR_GATT_DONT_NOTIFY_EVENTS & 0xff, MP_QSTR_GATT_DONT_NOTIFY_EVENTS >> 8,
    0x81, 
    0x24, MP_QSTR_GATT_NOTIFY_ATTRIBUTE_WRITE & 0xff, MP_QSTR_GATT_NOTIFY_ATTRIBUTE_WRITE >> 8,
    0x82, 
    0x24, MP_QSTR_GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_GATT_NOTIFY_WRITE_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x84, 
    0x24, MP_QSTR_GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP & 0xff, MP_QSTR_GATT_NOTIFY_READ_REQ_AND_WAIT_FOR_APPL_RESP >> 8,
    0x80, 
    0x24, MP_QSTR_CHAR_VALUE_LEN_CONSTANT & 0xff, MP_QSTR_CHAR_VALUE_LEN_CONSTANT >> 8,
    0x81, 
    0x24, MP_QSTR_CHAR_VALUE_LEN_VARIABLE & 0xff, MP_QSTR_CHAR_VALUE_LEN_VARIABLE >> 8,
    0x87, 
    0x24, MP_QSTR_MIN_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MIN_ENCRY_KEY_SIZE >> 8,
    0x90, 
    0x24, MP_QSTR_MAX_ENCRY_KEY_SIZE & 0xff, MP_QSTR_MAX_ENCRY_KEY_SIZE >> 8,
    0x84, 
    0x24, MP_QSTR_FORMAT_UINT8 & 0xff, MP_QSTR_FORMAT_UINT8 >> 8,
    0x86, 
    0x24, MP_QSTR_FORMAT_UINT16 & 0xff, MP_QSTR_FORMAT_UINT16 >> 8,
    0x8e, 
    0x24, MP_QSTR_FORMAT_SINT16 & 0xff, MP_QSTR_FORMAT_SINT16 >> 8,
    0x8f, 
    0x24, MP_QSTR_FORMAT_SINT24 & 0xff, MP_QSTR_FORMAT_SINT24 >> 8,
    0x14, 0x80, 0xce, 0x00, 
    0x24, MP_QSTR_UNIT_UNITLESS & 0xff, MP_QSTR_UNIT_UNITLESS >> 8,
    0x14, 0x80, 0xce, 0x2f, 
    0x24, MP_QSTR_UNIT_TEMP_CELSIUS & 0xff, MP_QSTR_UNIT_TEMP_CELSIUS >> 8,
    0x14, 0x80, 0xcf, 0x00, 
    0x24, MP_QSTR_UNIT_PRESSURE_BAR & 0xff, MP_QSTR_UNIT_PRESSURE_BAR >> 8,
    0x97, 
    0x24, MP_QSTR_ATT_MTU & 0xff, MP_QSTR_ATT_MTU >> 8,
    0x81, 
    0x24, MP_QSTR_NOTIFICATION & 0xff, MP_QSTR_NOTIFICATION >> 8,
    0x82, 
    0x24, MP_QSTR_INDICATION & 0xff, MP_QSTR_INDICATION >> 8,
    0x80, 
    0x24, MP_QSTR_O_CAP_DISPLAY_ONLY & 0xff, MP_QSTR_O_CAP_DISPLAY_ONLY >> 8,
    0x81, 
    0x24, MP_QSTR_O_CAP_DISPLAY_YES_NO & 0xff, MP_QSTR_O_CAP_DISPLAY_YES_NO >> 8,
    0x82, 
    0x24, MP_QSTR_O_CAP_KEYBOARD_ONLY & 0xff, MP_QSTR_O_CAP_KEYBOARD_ONLY >> 8,
    0x83, 
    0x24, MP_QSTR_O_CAP_NO_INPUT_NO_OUTPUT & 0xff, MP_QSTR_O_CAP_NO_INPUT_NO_OUTPUT >> 8,
    0x84, 
    0x24, MP_QSTR_O_CAP_KEYBOARD_DISPLAY & 0xff, MP_QSTR_O_CAP_KEYBOARD_DISPLAY >> 8,
    0x81, 
    0x24, MP_QSTR_BONDING & 0xff, MP_QSTR_BONDING >> 8,
    0x80, 
    0x24, MP_QSTR_NO_BONDING & 0xff, MP_QSTR_NO_BONDING >> 8,
    0x80, 
    0x24, MP_QSTR_MITM_PROTECTION_NOT_REQUIRED & 0xff, MP_QSTR_MITM_PROTECTION_NOT_REQUIRED >> 8,
    0x81, 
    0x24, MP_QSTR_MITM_PROTECTION_REQUIRED & 0xff, MP_QSTR_MITM_PROTECTION_REQUIRED >> 8,
    0x80, 
    0x24, MP_QSTR_OOB_AUTH_DATA_ABSENT & 0xff, MP_QSTR_OOB_AUTH_DATA_ABSENT >> 8,
    0x81, 
    0x24, MP_QSTR_OOB_AUTH_DATA_PRESENT & 0xff, MP_QSTR_OOB_AUTH_DATA_PRESENT >> 8,
    0x80, 
    0x24, MP_QSTR_AUTHORIZATION_NOT_REQUIRED & 0xff, MP_QSTR_AUTHORIZATION_NOT_REQUIRED >> 8,
    0x81, 
    0x24, MP_QSTR_AUTHORIZATION_REQUIRED & 0xff, MP_QSTR_AUTHORIZATION_REQUIRED >> 8,
    0x81, 
    0x24, MP_QSTR_CONNECTION_AUTHORIZED & 0xff, MP_QSTR_CONNECTION_AUTHORIZED >> 8,
    0x82, 
    0x24, MP_QSTR_CONNECTION_REJECTED & 0xff, MP_QSTR_CONNECTION_REJECTED >> 8,
    0x80, 
    0x24, MP_QSTR_USE_FIXED_PIN_FOR_PAIRING & 0xff, MP_QSTR_USE_FIXED_PIN_FOR_PAIRING >> 8,
    0x81, 
    0x24, MP_QSTR_DONOT_USE_FIXED_PIN_FOR_PAIRING & 0xff, MP_QSTR_DONOT_USE_FIXED_PIN_FOR_PAIRING >> 8,
    0x81, 
    0x24, MP_QSTR_SM_LINK_AUTHENTICATED & 0xff, MP_QSTR_SM_LINK_AUTHENTICATED >> 8,
    0x82, 
    0x24, MP_QSTR_SM_LINK_AUTHORIZED & 0xff, MP_QSTR_SM_LINK_AUTHORIZED >> 8,
    0x84, 
    0x24, MP_QSTR_SM_LINK_ENCRYPTED & 0xff, MP_QSTR_SM_LINK_ENCRYPTED >> 8,
    0x81, 
    0x24, MP_QSTR_PASSKEY_ENTRY_FAILED & 0xff, MP_QSTR_PASSKEY_ENTRY_FAILED >> 8,
    0x82, 
    0x24, MP_QSTR_OOB_NOT_AVAILABLE & 0xff, MP_QSTR_OOB_NOT_AVAILABLE >> 8,
    0x83, 
    0x24, MP_QSTR_AUTH_REQ_CANNOT_BE_MET & 0xff, MP_QSTR_AUTH_REQ_CANNOT_BE_MET >> 8,
    0x84, 
    0x24, MP_QSTR_CONFIRM_VALUE_FAILED & 0xff, MP_QSTR_CONFIRM_VALUE_FAILED >> 8,
    0x85, 
    0x24, MP_QSTR_PAIRING_NOT_SUPPORTED & 0xff, MP_QSTR_PAIRING_NOT_SUPPORTED >> 8,
    0x86, 
    0x24, MP_QSTR_INSUFF_ENCRYPTION_KEY_SIZE & 0xff, MP_QSTR_INSUFF_ENCRYPTION_KEY_SIZE >> 8,
    0x87, 
    0x24, MP_QSTR_CMD_NOT_SUPPORTED & 0xff, MP_QSTR_CMD_NOT_SUPPORTED >> 8,
    0x88, 
    0x24, MP_QSTR_UNSPECIFIED_REASON & 0xff, MP_QSTR_UNSPECIFIED_REASON >> 8,
    0x89, 
    0x24, MP_QSTR_VERY_EARLY_NEXT_ATTEMPT & 0xff, MP_QSTR_VERY_EARLY_NEXT_ATTEMPT >> 8,
    0x8a, 
    0x24, MP_QSTR_SM_INVALID_PARAMS & 0xff, MP_QSTR_SM_INVALID_PARAMS >> 8,
    0x80, 
    0x24, MP_QSTR_SM_PAIRING_SUCCESS & 0xff, MP_QSTR_SM_PAIRING_SUCCESS >> 8,
    0x81, 
    0x24, MP_QSTR_SM_PAIRING_TIMEOUT & 0xff, MP_QSTR_SM_PAIRING_TIMEOUT >> 8,
    0x82, 
    0x24, MP_QSTR_SM_PAIRING_FAILED & 0xff, MP_QSTR_SM_PAIRING_FAILED >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_constant__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_constant__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 1209,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/vendor_specifics/__init__.py, scope bluetooth_low_energy_protocols_hci_vendor_specifics___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics___init____lt_module_gt_[16] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_vendor_specifics_slash___init___dot_py >> 8,
    0x00, 0x00, 0xff,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_vendor_specifics___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 16,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__[90] = {
    0x0c, 0x00, 0x00, 0x05, 0x00, 0x03, 0x10,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x81, 0x35, 0x25, 0x54, 0x25, 0x25, 0x29, 0x25, 0x2b, 0x00, 0x00, 0xff,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x37, 0x09, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb4, 
    0x64, 0x01, 
    0x35, 0x01, 0x80, 
    0x80, 
    0xb3, 
    0xb2, 
    0xb1, 
    0x66, 0x04, 
    0xc5, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__handle & 0xff, MP_QSTR__handle >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__pb & 0xff, MP_QSTR__pb >> 8,
    0x1c, MP_QSTR_PB_FLAGS & 0xff, MP_QSTR_PB_FLAGS >> 8,
    0xb2, 
    0x21, 
    0xb0, 
    0x26, MP_QSTR__pb_name & 0xff, MP_QSTR__pb_name >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__bc & 0xff, MP_QSTR__bc >> 8,
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x82, 
    0x64, 0x02, 
    0xb0, 
    0x26, MP_QSTR__tobytes & 0xff, MP_QSTR__tobytes >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init___0 = {{&mp_type_str}, 39713, 26, (const byte*)"\x7b\x3a\x30\x31\x36\x62\x7d\x7b\x3a\x30\x32\x62\x7d\x7b\x3a\x30\x32\x62\x7d\x7b\x3a\x30\x31\x32\x62\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
    MP_ROM_QSTR(MP_QSTR_pb),
    MP_ROM_QSTR(MP_QSTR_bc),
    MP_ROM_QSTR(MP_QSTR_data),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 90,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__[144] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x16,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x81, 0x40, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__handle & 0xff, MP_QSTR__handle >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_pb & 0xff, MP_QSTR_pb >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__pb & 0xff, MP_QSTR__pb >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_pb_name & 0xff, MP_QSTR_pb_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__pb_name & 0xff, MP_QSTR__pb_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_bc & 0xff, MP_QSTR_bc >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__bc & 0xff, MP_QSTR__bc >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_tobytes & 0xff, MP_QSTR_tobytes >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__tobytes & 0xff, MP_QSTR__tobytes >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 144,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__[72] = {
    0x0c, 0x00, 0x00, 0x01, 0x00, 0x00, 0x13,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x81, 0x50, 0x20, 0x63, 0x20, 0x24, 0x27, 0x24, 0x24, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_pb_name & 0xff, MP_QSTR_pb_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_pb & 0xff, MP_QSTR_pb >> 8,
    0xb0, 
    0x1d, MP_QSTR_bc & 0xff, MP_QSTR_bc >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x07, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str___0 = {{&mp_type_str}, 10225, 74, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x68\x61\x6e\x64\x6c\x65\x3d\x30\x78\x7b\x3a\x30\x34\x78\x7d\x20\x70\x62\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x62\x63\x3d\x30\x78\x7b\x3a\x30\x32\x78\x7d\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 72,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer[90] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x81, 0x61, 0x80, 0x09, 0x26, 0x56, 0x49, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x01, 
    0x1c, MP_QSTR_HCI_ACL_STRUCT & 0xff, MP_QSTR_HCI_ACL_STRUCT >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0xc1, 
    0xb0, 
    0x1c, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0xb1, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb1, 
    0x1d, MP_QSTR_pb & 0xff, MP_QSTR_pb >> 8,
    0xb1, 
    0x1d, MP_QSTR_bc & 0xff, MP_QSTR_bc >> 8,
    0xb0, 
    0x64, 0x04, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 90,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer[39] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x81, 0x73, 0x60, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_tobytes & 0xff, MP_QSTR_tobytes >> 8,
    0x66, 0x02, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL[98] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x8d, 0x30, 0x20, 0x26, 0x4e, 0x8c, 0x0b, 0x85, 0x10, 0x85, 0x10, 0x8a, 0x13, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_I & 0xff, MP_QSTR__lt_I >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x80, 
    0x80, 
    0x17, 0x00, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 98,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/acl.py, scope bluetooth_low_energy_protocols_hci_acl_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_[254] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1e,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_acl_dot_py >> 8,
    0x21, 0x28, 0x28, 0x39, 0x50, 0x80, 0x0e, 0x22, 0x3e, 0x3e, 0x3e, 0x6f, 0x80, 0x08, 0x24, 0x24, 0x24, 0x44, 0x22, 0x24, 0x24, 0x24, 0x67, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x80, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x8c, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x8c, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x82, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_pb & 0xff, MP_QSTR_pb >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x8e, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x82, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_bc & 0xff, MP_QSTR_bc >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x54, 
    0x24, MP_QSTR_HCI_ACL_STRUCT & 0xff, MP_QSTR_HCI_ACL_STRUCT >> 8,
    0x80, 
    0x24, MP_QSTR_ACL_PB_START_NON_AUTO_L2CAP_PDU & 0xff, MP_QSTR_ACL_PB_START_NON_AUTO_L2CAP_PDU >> 8,
    0x81, 
    0x24, MP_QSTR_ACL_PB_CONT_FRAG_MSG & 0xff, MP_QSTR_ACL_PB_CONT_FRAG_MSG >> 8,
    0x82, 
    0x24, MP_QSTR_ACL_PB_START_AUTO_L2CAP_PDU & 0xff, MP_QSTR_ACL_PB_START_AUTO_L2CAP_PDU >> 8,
    0x83, 
    0x24, MP_QSTR_ACL_PB_COMPLETE_L2CAP_PDU & 0xff, MP_QSTR_ACL_PB_COMPLETE_L2CAP_PDU >> 8,
    0x53, 0x04, 
    0x17, 0x00, 
    0x80, 
    0x54, 
    0x17, 0x01, 
    0x81, 
    0x54, 
    0x17, 0x02, 
    0x82, 
    0x54, 
    0x17, 0x03, 
    0x83, 
    0x54, 
    0x24, MP_QSTR_PB_FLAGS & 0xff, MP_QSTR_PB_FLAGS >> 8,
    0x20, 
    0x60, 0x04, 
    0x16, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HCI_ACL & 0xff, MP_QSTR_HCI_ACL >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__0 = {{&mp_type_str}, 7656, 24, (const byte*)"\x53\x54\x41\x52\x54\x5f\x4e\x4f\x4e\x5f\x41\x55\x54\x4f\x5f\x4c\x32\x43\x41\x50\x5f\x50\x44\x55"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__1 = {{&mp_type_str}, 59960, 13, (const byte*)"\x43\x4f\x4e\x54\x5f\x46\x52\x41\x47\x5f\x4d\x53\x47"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__2 = {{&mp_type_str}, 17720, 20, (const byte*)"\x53\x54\x41\x52\x54\x5f\x41\x55\x54\x4f\x5f\x4c\x32\x43\x41\x50\x5f\x50\x44\x55"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__3 = {{&mp_type_str}, 3969, 18, (const byte*)"\x43\x4f\x4d\x50\x4c\x45\x54\x45\x5f\x4c\x32\x43\x41\x50\x5f\x50\x44\x55"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_[5] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__3),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt__HCI_ACL),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 254,
        .n_obj = 4,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__[39] = {
    0x05, 0x00, 0x00, 0x03, 0x00, 0x01, 0x0b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x81, 0x2c, 0x25, 0x29, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__code & 0xff, MP_QSTR__code >> 8,
    0x1c, MP_QSTR_SMP_PDUS & 0xff, MP_QSTR_SMP_PDUS >> 8,
    0xb1, 
    0x21, 
    0xb0, 
    0x26, MP_QSTR__code_name & 0xff, MP_QSTR__code_name >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_code),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__[99] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x10,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x81, 0x31, 0x28, 0x25, 0x28, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__code & 0xff, MP_QSTR__code >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_code_name & 0xff, MP_QSTR_code_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__code_name & 0xff, MP_QSTR__code_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 99,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__[61] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x81, 0x3b, 0x20, 0x63, 0x24, 0x27, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_code_name & 0xff, MP_QSTR_code_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x05, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str___0 = {{&mp_type_str}, 59075, 48, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x63\x6f\x64\x65\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 61,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer[68] = {
    0x08, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x81, 0x49, 0x80, 0x0d, 0x3c, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x80, 
    0x21, 
    0xc1, 
    0xb0, 
    0x1c, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0xb1, 
    0xb0, 
    0x64, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 68,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer[39] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x81, 0x5b, 0x60, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0x66, 0x02, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP[96] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x8d, 0x27, 0x20, 0x26, 0x4e, 0x6a, 0x40, 0x85, 0x0a, 0x85, 0x0d, 0x8a, 0x13, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x17, 0x00, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 96,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/smp.py, scope bluetooth_low_energy_protocols_hci_smp_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_[201] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_smp_dot_py >> 8,
    0x21, 0x28, 0x39, 0x50, 0x80, 0x07, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x67, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_PAIRING_REQUEST & 0xff, MP_QSTR_PAIRING_REQUEST >> 8,
    0x82, 
    0x24, MP_QSTR_PAIRING_RESPONSE & 0xff, MP_QSTR_PAIRING_RESPONSE >> 8,
    0x83, 
    0x24, MP_QSTR_PAIRING_CONFIRM & 0xff, MP_QSTR_PAIRING_CONFIRM >> 8,
    0x84, 
    0x24, MP_QSTR_PAIRING_RANDOM & 0xff, MP_QSTR_PAIRING_RANDOM >> 8,
    0x85, 
    0x24, MP_QSTR_PAIRING_FAILED & 0xff, MP_QSTR_PAIRING_FAILED >> 8,
    0x86, 
    0x24, MP_QSTR_ENCRYPTION_INFORMATION & 0xff, MP_QSTR_ENCRYPTION_INFORMATION >> 8,
    0x87, 
    0x24, MP_QSTR_MASTER_IDENTIFICATION & 0xff, MP_QSTR_MASTER_IDENTIFICATION >> 8,
    0x88, 
    0x24, MP_QSTR_IDENTITY_INFORMATION & 0xff, MP_QSTR_IDENTITY_INFORMATION >> 8,
    0x89, 
    0x24, MP_QSTR_IDENTITY_ADDRESS_INFORMATION & 0xff, MP_QSTR_IDENTITY_ADDRESS_INFORMATION >> 8,
    0x8a, 
    0x24, MP_QSTR_SIGNING_INFORMATION & 0xff, MP_QSTR_SIGNING_INFORMATION >> 8,
    0x8b, 
    0x24, MP_QSTR_SECURITY_REQUEST & 0xff, MP_QSTR_SECURITY_REQUEST >> 8,
    0x53, 0x0b, 
    0x17, 0x00, 
    0x81, 
    0x54, 
    0x17, 0x01, 
    0x82, 
    0x54, 
    0x17, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x03, 
    0x84, 
    0x54, 
    0x17, 0x04, 
    0x85, 
    0x54, 
    0x17, 0x05, 
    0x86, 
    0x54, 
    0x17, 0x06, 
    0x87, 
    0x54, 
    0x17, 0x07, 
    0x88, 
    0x54, 
    0x17, 0x08, 
    0x89, 
    0x54, 
    0x17, 0x09, 
    0x8a, 
    0x54, 
    0x17, 0x0a, 
    0x8b, 
    0x54, 
    0x24, MP_QSTR_SMP_PDUS & 0xff, MP_QSTR_SMP_PDUS >> 8,
    0x20, 
    0x60, 0x0b, 
    0x16, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__0 = {{&mp_type_str}, 21057, 15, (const byte*)"\x50\x61\x69\x72\x69\x6e\x67\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__1 = {{&mp_type_str}, 22323, 16, (const byte*)"\x50\x61\x69\x72\x69\x6e\x67\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__2 = {{&mp_type_str}, 2754, 15, (const byte*)"\x50\x61\x69\x72\x69\x6e\x67\x5f\x43\x6f\x6e\x66\x69\x72\x6d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__3 = {{&mp_type_str}, 22251, 14, (const byte*)"\x50\x61\x69\x72\x69\x6e\x67\x5f\x52\x61\x6e\x64\x6f\x6d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__4 = {{&mp_type_str}, 60883, 14, (const byte*)"\x50\x61\x69\x72\x69\x6e\x67\x5f\x46\x61\x69\x6c\x65\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__5 = {{&mp_type_str}, 32057, 22, (const byte*)"\x45\x6e\x63\x72\x79\x70\x74\x69\x6f\x6e\x5f\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__6 = {{&mp_type_str}, 44748, 21, (const byte*)"\x4d\x61\x73\x74\x65\x72\x5f\x49\x64\x65\x6e\x74\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__7 = {{&mp_type_str}, 60960, 20, (const byte*)"\x49\x64\x65\x6e\x74\x69\x74\x79\x5f\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__8 = {{&mp_type_str}, 4790, 28, (const byte*)"\x49\x64\x65\x6e\x74\x69\x74\x79\x5f\x41\x64\x64\x72\x65\x73\x73\x20\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__9 = {{&mp_type_str}, 28485, 19, (const byte*)"\x53\x69\x67\x6e\x69\x6e\x67\x5f\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__10 = {{&mp_type_str}, 31293, 16, (const byte*)"\x53\x65\x63\x75\x72\x69\x74\x79\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_[12] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__10),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt__SMP),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 201,
        .n_obj = 11,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__[39] = {
    0x05, 0x00, 0x00, 0x03, 0x00, 0x01, 0x0b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x81, 0x1d, 0x25, 0x29, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__pkt_type & 0xff, MP_QSTR__pkt_type >> 8,
    0x1c, MP_QSTR_HCI_UART_PKT_TYPES & 0xff, MP_QSTR_HCI_UART_PKT_TYPES >> 8,
    0xb1, 
    0x21, 
    0xb0, 
    0x26, MP_QSTR__pkt_type_name & 0xff, MP_QSTR__pkt_type_name >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_pkt_type),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__[70] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0f,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x81, 0x22, 0x28, 0x25, 0x27, 0x25, 0x28, 0x45, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__pkt_type & 0xff, MP_QSTR__pkt_type >> 8,
    0x5b, 
    0xb1, 
    0x17, 0x02, 
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__pkt_type_name & 0xff, MP_QSTR__pkt_type_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x5b, 
    0x1c, MP_QSTR_AttributeError & 0xff, MP_QSTR_AttributeError >> 8,
    0xb1, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr___0 = {{&mp_type_str}, 24565, 13, (const byte*)"\x70\x6b\x74\x5f\x74\x79\x70\x65\x5f\x6e\x61\x6d\x65"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 70,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__[52] = {
    0x08, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x81, 0x2c, 0x25, 0x27, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_pkt_type_name & 0xff, MP_QSTR_pkt_type_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x04, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str___0 = {{&mp_type_str}, 1055, 40, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x70\x6b\x74\x5f\x74\x79\x70\x65\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 52,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer[67] = {
    0x08, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x81, 0x35, 0x80, 0x10, 0x26, 0x33, 0x23, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1d, MP_QSTR__struct_format_size & 0xff, MP_QSTR__struct_format_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x80, 
    0x21, 
    0xc1, 
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0xb1, 
    0xb0, 
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1d, MP_QSTR__struct_format_size & 0xff, MP_QSTR__struct_format_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0x64, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer[41] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x81, 0x4b, 0x60, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x1c, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_pkt_type & 0xff, MP_QSTR_pkt_type >> 8,
    0x66, 0x02, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 41,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART[96] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x8d, 0x18, 0x20, 0x26, 0x4e, 0x6a, 0x40, 0x85, 0x0a, 0x85, 0x08, 0x8a, 0x17, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_format_size & 0xff, MP_QSTR__struct_format_size >> 8,
    0x17, 0x00, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 96,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/uart.py, scope bluetooth_low_energy_protocols_hci_uart_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_[169] = {
    0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x15,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_uart_dot_py >> 8,
    0x21, 0x28, 0x79, 0x1f, 0x75, 0x60, 0x60, 0x20, 0x22, 0x27, 0x27, 0x27, 0x27, 0x6a, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x16, MP_QSTR_HCI_ACLDATA_PKT & 0xff, MP_QSTR_HCI_ACLDATA_PKT >> 8,
    0x16, MP_QSTR_HCI_SCODATA_PKT & 0xff, MP_QSTR_HCI_SCODATA_PKT >> 8,
    0x16, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x16, MP_QSTR_HCI_VENDOR_PKT & 0xff, MP_QSTR_HCI_VENDOR_PKT >> 8,
    0x50, 0x05, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x24, MP_QSTR_COMMAND & 0xff, MP_QSTR_COMMAND >> 8,
    0x69, MP_QSTR_HCI_ACLDATA_PKT & 0xff, MP_QSTR_HCI_ACLDATA_PKT >> 8,
    0x24, MP_QSTR_ACLDATA & 0xff, MP_QSTR_ACLDATA >> 8,
    0x69, MP_QSTR_HCI_SCODATA_PKT & 0xff, MP_QSTR_HCI_SCODATA_PKT >> 8,
    0x24, MP_QSTR_SCODATA & 0xff, MP_QSTR_SCODATA >> 8,
    0x69, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x24, MP_QSTR_EVENT & 0xff, MP_QSTR_EVENT >> 8,
    0x69, MP_QSTR_HCI_VENDOR_PKT & 0xff, MP_QSTR_HCI_VENDOR_PKT >> 8,
    0x24, MP_QSTR_VENDOR & 0xff, MP_QSTR_VENDOR >> 8,
    0x32, 
    0x53, 0x05, 
    0x16, MP_QSTR_COMMAND & 0xff, MP_QSTR_COMMAND >> 8,
    0x1b, MP_QSTR_COMMAND & 0xff, MP_QSTR_COMMAND >> 8,
    0x54, 
    0x16, MP_QSTR_ACLDATA & 0xff, MP_QSTR_ACLDATA >> 8,
    0x1b, MP_QSTR_ACLDATA & 0xff, MP_QSTR_ACLDATA >> 8,
    0x54, 
    0x16, MP_QSTR_SCODATA & 0xff, MP_QSTR_SCODATA >> 8,
    0x1b, MP_QSTR_SCODATA & 0xff, MP_QSTR_SCODATA >> 8,
    0x54, 
    0x16, MP_QSTR_EVENT & 0xff, MP_QSTR_EVENT >> 8,
    0x1b, MP_QSTR_EVENT & 0xff, MP_QSTR_EVENT >> 8,
    0x54, 
    0x16, MP_QSTR_VENDOR & 0xff, MP_QSTR_VENDOR >> 8,
    0x1b, MP_QSTR_VENDOR & 0xff, MP_QSTR_VENDOR >> 8,
    0x54, 
    0x24, MP_QSTR_HCI_UART_PKT_TYPES & 0xff, MP_QSTR_HCI_UART_PKT_TYPES >> 8,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HCI_UART & 0xff, MP_QSTR_HCI_UART >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt__HCI_UART),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 169,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/status.py, scope bluetooth_low_energy_protocols_hci_status_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_status__lt_module_gt_[169] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_status_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_status_dot_py >> 8,
    0x21, 0x70, 0x80, 0x07, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x25, 0x25, 0x25, 0x00, 0x00, 0xff,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x24, MP_QSTR_ERR_CMD_SUCCESS & 0xff, MP_QSTR_ERR_CMD_SUCCESS >> 8,
    0x80, 
    0x24, MP_QSTR_BLE_STATUS_SUCCESS & 0xff, MP_QSTR_BLE_STATUS_SUCCESS >> 8,
    0x81, 
    0x24, MP_QSTR_ERR_UNKNOWN_HCI_COMMAND & 0xff, MP_QSTR_ERR_UNKNOWN_HCI_COMMAND >> 8,
    0x82, 
    0x24, MP_QSTR_ERR_UNKNOWN_CONN_IDENTIFIER & 0xff, MP_QSTR_ERR_UNKNOWN_CONN_IDENTIFIER >> 8,
    0x85, 
    0x24, MP_QSTR_ERR_AUTH_FAILURE & 0xff, MP_QSTR_ERR_AUTH_FAILURE >> 8,
    0x86, 
    0x24, MP_QSTR_ERR_PIN_OR_KEY_MISSING & 0xff, MP_QSTR_ERR_PIN_OR_KEY_MISSING >> 8,
    0x87, 
    0x24, MP_QSTR_ERR_MEM_CAPACITY_EXCEEDED & 0xff, MP_QSTR_ERR_MEM_CAPACITY_EXCEEDED >> 8,
    0x88, 
    0x24, MP_QSTR_ERR_CONNECTION_TIMEOUT & 0xff, MP_QSTR_ERR_CONNECTION_TIMEOUT >> 8,
    0x8c, 
    0x24, MP_QSTR_ERR_COMMAND_DISALLOWED & 0xff, MP_QSTR_ERR_COMMAND_DISALLOWED >> 8,
    0x91, 
    0x24, MP_QSTR_ERR_UNSUPPORTED_FEATURE & 0xff, MP_QSTR_ERR_UNSUPPORTED_FEATURE >> 8,
    0x92, 
    0x24, MP_QSTR_ERR_INVALID_HCI_CMD_PARAMS & 0xff, MP_QSTR_ERR_INVALID_HCI_CMD_PARAMS >> 8,
    0x93, 
    0x24, MP_QSTR_ERR_RMT_USR_TERM_CONN & 0xff, MP_QSTR_ERR_RMT_USR_TERM_CONN >> 8,
    0x94, 
    0x24, MP_QSTR_ERR_RMT_DEV_TERM_CONN_LOW_RESRCES & 0xff, MP_QSTR_ERR_RMT_DEV_TERM_CONN_LOW_RESRCES >> 8,
    0x95, 
    0x24, MP_QSTR_ERR_RMT_DEV_TERM_CONN_POWER_OFF & 0xff, MP_QSTR_ERR_RMT_DEV_TERM_CONN_POWER_OFF >> 8,
    0x96, 
    0x24, MP_QSTR_ERR_LOCAL_HOST_TERM_CONN & 0xff, MP_QSTR_ERR_LOCAL_HOST_TERM_CONN >> 8,
    0x9a, 
    0x24, MP_QSTR_ERR_UNSUPP_RMT_FEATURE & 0xff, MP_QSTR_ERR_UNSUPP_RMT_FEATURE >> 8,
    0x9e, 
    0x24, MP_QSTR_ERR_INVALID_LMP_PARAM & 0xff, MP_QSTR_ERR_INVALID_LMP_PARAM >> 8,
    0x9f, 
    0x24, MP_QSTR_ERR_UNSPECIFIED_ERROR & 0xff, MP_QSTR_ERR_UNSPECIFIED_ERROR >> 8,
    0xa2, 
    0x24, MP_QSTR_ERR_LL_RESP_TIMEOUT & 0xff, MP_QSTR_ERR_LL_RESP_TIMEOUT >> 8,
    0xa4, 
    0x24, MP_QSTR_ERR_LMP_PDU_NOT_ALLOWED & 0xff, MP_QSTR_ERR_LMP_PDU_NOT_ALLOWED >> 8,
    0xa8, 
    0x24, MP_QSTR_ERR_INSTANT_PASSED & 0xff, MP_QSTR_ERR_INSTANT_PASSED >> 8,
    0xa9, 
    0x24, MP_QSTR_ERR_PAIR_UNIT_KEY_NOT_SUPP & 0xff, MP_QSTR_ERR_PAIR_UNIT_KEY_NOT_SUPP >> 8,
    0x14, 0x3a, 
    0x24, MP_QSTR_ERR_CONTROLLER_BUSY & 0xff, MP_QSTR_ERR_CONTROLLER_BUSY >> 8,
    0x14, 0x3c, 
    0x24, MP_QSTR_ERR_DIRECTED_ADV_TIMEOUT & 0xff, MP_QSTR_ERR_DIRECTED_ADV_TIMEOUT >> 8,
    0x14, 0x3d, 
    0x24, MP_QSTR_ERR_CONN_END_WITH_MIC_FAILURE & 0xff, MP_QSTR_ERR_CONN_END_WITH_MIC_FAILURE >> 8,
    0x14, 0x3e, 
    0x24, MP_QSTR_ERR_CONN_FAILED_TO_ESTABLISH & 0xff, MP_QSTR_ERR_CONN_FAILED_TO_ESTABLISH >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_status__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_status__lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 169,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__[39] = {
    0x05, 0x00, 0x00, 0x03, 0x00, 0x01, 0x0b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0x20, 0x25, 0x29, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__cid & 0xff, MP_QSTR__cid >> 8,
    0x1c, MP_QSTR_L2CAP_CHANNEL_IDS & 0xff, MP_QSTR_L2CAP_CHANNEL_IDS >> 8,
    0xb1, 
    0x21, 
    0xb0, 
    0x26, MP_QSTR__cid_name & 0xff, MP_QSTR__cid_name >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_cid),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__[99] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x10,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__cid & 0xff, MP_QSTR__cid >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_cid_name & 0xff, MP_QSTR_cid_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__cid_name & 0xff, MP_QSTR__cid_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 99,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__[61] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0x2f, 0x20, 0x63, 0x24, 0x27, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid_name & 0xff, MP_QSTR_cid_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x05, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str___0 = {{&mp_type_str}, 60192, 47, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x63\x69\x64\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 61,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer[71] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0x3d, 0x80, 0x17, 0x26, 0x26, 0x51, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x59, 0x02, 
    0xc1, 
    0xc2, 
    0xb0, 
    0x1c, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0xb2, 
    0xb0, 
    0x64, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 71,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer[46] = {
    0x06, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0d,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0x5c, 0x26, 0x24, 0x24, 0x26, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0x66, 0x03, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 46,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP[95] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x13,
    MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x8d, 0x1c, 0x26, 0x4e, 0x6a, 0x40, 0x85, 0x0a, 0x85, 0x0d, 0x8a, 0x20, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_HH & 0xff, MP_QSTR__lt_HH >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x17, 0x00, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 95,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__[47] = {
    0x06, 0x00, 0x00, 0x04, 0x00, 0x01, 0x0c,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0xa3, 0x25, 0x25, 0x2b, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__code & 0xff, MP_QSTR__code >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__cid & 0xff, MP_QSTR__cid >> 8,
    0x1c, MP_QSTR_L2CAP_SCH_PDUS & 0xff, MP_QSTR_L2CAP_SCH_PDUS >> 8,
    0x1c, MP_QSTR_id & 0xff, MP_QSTR_id >> 8,
    0x21, 
    0xb0, 
    0x26, MP_QSTR__cid_name & 0xff, MP_QSTR__cid_name >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_code),
    MP_ROM_QSTR(MP_QSTR_cid),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 47,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__[114] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x12,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0xa9, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR__code & 0xff, MP_QSTR__code >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__code & 0xff, MP_QSTR__code >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__cid & 0xff, MP_QSTR__cid >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_cid_name & 0xff, MP_QSTR_cid_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__cid_name & 0xff, MP_QSTR__cid_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 114,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__[66] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x11,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0xb5, 0x20, 0x63, 0x24, 0x27, 0x24, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid_name & 0xff, MP_QSTR_cid_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x06, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str___0 = {{&mp_type_str}, 29782, 59, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x63\x6f\x64\x65\x3d\x7b\x3a\x30\x32\x78\x7d\x20\x63\x69\x64\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 66,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer[73] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0xc4, 0x80, 0x10, 0x26, 0x26, 0x52, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x59, 0x03, 
    0xc1, 
    0xc2, 
    0xc3, 
    0xb0, 
    0x1c, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0xb1, 
    0xb2, 
    0xb0, 
    0x64, 0x03, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 73,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer[52] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x81, 0xdc, 0x60, 0x26, 0x24, 0x24, 0x24, 0x26, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0xb0, 
    0x1d, MP_QSTR_cid & 0xff, MP_QSTR_cid >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x66, 0x04, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 52,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH[96] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x8d, 0x9e, 0x20, 0x26, 0x4e, 0x6a, 0x60, 0x85, 0x0c, 0x85, 0x0e, 0x8a, 0x19, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_BBH & 0xff, MP_QSTR__lt_BBH >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x17, 0x00, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 96,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/l2cap.py, scope bluetooth_low_energy_protocols_hci_l2cap_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_[396] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4f,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_l2cap_dot_py >> 8,
    0x21, 0x28, 0x39, 0x50, 0x80, 0x07, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x25, 0x25, 0x25, 0x25, 0x68, 0x8e, 0x49, 0x60, 0x20, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x20, 0x24, 0x20, 0x24, 0x20, 0x24, 0x20, 0x24, 0x20, 0x24, 0x20, 0x67, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x24, MP_QSTR_L2CAP_CID_NUL & 0xff, MP_QSTR_L2CAP_CID_NUL >> 8,
    0x81, 
    0x24, MP_QSTR_L2CAP_CID_SCH & 0xff, MP_QSTR_L2CAP_CID_SCH >> 8,
    0x84, 
    0x24, MP_QSTR_L2CAP_CID_ATT & 0xff, MP_QSTR_L2CAP_CID_ATT >> 8,
    0x85, 
    0x24, MP_QSTR_L2CAP_CID_LE_SCH & 0xff, MP_QSTR_L2CAP_CID_LE_SCH >> 8,
    0x86, 
    0x24, MP_QSTR_L2CAP_CID_SMP & 0xff, MP_QSTR_L2CAP_CID_SMP >> 8,
    0x53, 0x05, 
    0x16, MP_QSTR_NUL & 0xff, MP_QSTR_NUL >> 8,
    0x80, 
    0x54, 
    0x16, MP_QSTR_SCH & 0xff, MP_QSTR_SCH >> 8,
    0x81, 
    0x54, 
    0x16, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x84, 
    0x54, 
    0x16, MP_QSTR_LE_SCH & 0xff, MP_QSTR_LE_SCH >> 8,
    0x85, 
    0x54, 
    0x16, MP_QSTR_SMP & 0xff, MP_QSTR_SMP >> 8,
    0x86, 
    0x54, 
    0x24, MP_QSTR_L2CAP_CHANNEL_IDS & 0xff, MP_QSTR_L2CAP_CHANNEL_IDS >> 8,
    0x20, 
    0x60, 0x16, 
    0x16, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_L2CAP & 0xff, MP_QSTR_L2CAP >> 8,
    0x81, 
    0x24, MP_QSTR_SCH_COMMAND_REJECT & 0xff, MP_QSTR_SCH_COMMAND_REJECT >> 8,
    0x82, 
    0x24, MP_QSTR_SCH_CONNECTION_REQUEST & 0xff, MP_QSTR_SCH_CONNECTION_REQUEST >> 8,
    0x83, 
    0x24, MP_QSTR_SCH_CONNECTION_RESPONSE & 0xff, MP_QSTR_SCH_CONNECTION_RESPONSE >> 8,
    0x84, 
    0x24, MP_QSTR_SCH_CONFIGURE_REQUEST & 0xff, MP_QSTR_SCH_CONFIGURE_REQUEST >> 8,
    0x85, 
    0x24, MP_QSTR_SCH_CONFIGURE_RESPONSE & 0xff, MP_QSTR_SCH_CONFIGURE_RESPONSE >> 8,
    0x86, 
    0x24, MP_QSTR_SCH_DISCONNECTION_REQUEST & 0xff, MP_QSTR_SCH_DISCONNECTION_REQUEST >> 8,
    0x87, 
    0x24, MP_QSTR_SCH_DISCONNECTION_RESPONSE & 0xff, MP_QSTR_SCH_DISCONNECTION_RESPONSE >> 8,
    0x88, 
    0x24, MP_QSTR_SCH_ECHO_REQUEST & 0xff, MP_QSTR_SCH_ECHO_REQUEST >> 8,
    0x89, 
    0x24, MP_QSTR_SCH_ECHO_RESPONSE & 0xff, MP_QSTR_SCH_ECHO_RESPONSE >> 8,
    0x8a, 
    0x24, MP_QSTR_SCH_INFORMATION_REQUEST & 0xff, MP_QSTR_SCH_INFORMATION_REQUEST >> 8,
    0x8b, 
    0x24, MP_QSTR_SCH_INFORMATION_RESPONSE & 0xff, MP_QSTR_SCH_INFORMATION_RESPONSE >> 8,
    0x8c, 
    0x24, MP_QSTR_SCH_CREATE_CHANNEL_REQUEST & 0xff, MP_QSTR_SCH_CREATE_CHANNEL_REQUEST >> 8,
    0x8d, 
    0x24, MP_QSTR_SCH_CREATE_CHANNEL_RESPONSE & 0xff, MP_QSTR_SCH_CREATE_CHANNEL_RESPONSE >> 8,
    0x8e, 
    0x24, MP_QSTR_SCH_MOVE_CHANNEL_REQUEST & 0xff, MP_QSTR_SCH_MOVE_CHANNEL_REQUEST >> 8,
    0x8f, 
    0x24, MP_QSTR_SCH_MOVE_CHANNEL_RESPONSE & 0xff, MP_QSTR_SCH_MOVE_CHANNEL_RESPONSE >> 8,
    0x90, 
    0x24, MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION & 0xff, MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION >> 8,
    0x91, 
    0x24, MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION_RESPONSE & 0xff, MP_QSTR_SCH_MOVE_CHANNEL_CONFIRMATION_RESPONSE >> 8,
    0x92, 
    0x24, MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_REQUEST & 0xff, MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_REQUEST >> 8,
    0x93, 
    0x24, MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_RESPONSE & 0xff, MP_QSTR_LE_SCH_CONNECTION_PARAMETER_UPDATE_RESPONSE >> 8,
    0x94, 
    0x24, MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_REQUEST & 0xff, MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_REQUEST >> 8,
    0x95, 
    0x24, MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_RESPONSE & 0xff, MP_QSTR_LE_SCH_LE_CREDIT_BASED_CONNECTION_RESPONSE >> 8,
    0x96, 
    0x24, MP_QSTR_LE_SCH_LE_FLOW_CONTROL_CREDIT & 0xff, MP_QSTR_LE_SCH_LE_FLOW_CONTROL_CREDIT >> 8,
    0x53, 0x16, 
    0x17, 0x00, 
    0x81, 
    0x54, 
    0x17, 0x01, 
    0x82, 
    0x54, 
    0x17, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x03, 
    0x84, 
    0x54, 
    0x17, 0x04, 
    0x85, 
    0x54, 
    0x17, 0x05, 
    0x86, 
    0x54, 
    0x17, 0x06, 
    0x87, 
    0x54, 
    0x17, 0x07, 
    0x88, 
    0x54, 
    0x17, 0x08, 
    0x89, 
    0x54, 
    0x17, 0x09, 
    0x8a, 
    0x54, 
    0x17, 0x0a, 
    0x8b, 
    0x54, 
    0x17, 0x0b, 
    0x8c, 
    0x54, 
    0x17, 0x0c, 
    0x8d, 
    0x54, 
    0x17, 0x0d, 
    0x8e, 
    0x54, 
    0x17, 0x0e, 
    0x8f, 
    0x54, 
    0x17, 0x0f, 
    0x90, 
    0x54, 
    0x17, 0x10, 
    0x91, 
    0x54, 
    0x17, 0x11, 
    0x92, 
    0x54, 
    0x17, 0x12, 
    0x93, 
    0x54, 
    0x17, 0x13, 
    0x94, 
    0x54, 
    0x17, 0x14, 
    0x95, 
    0x54, 
    0x17, 0x15, 
    0x96, 
    0x54, 
    0x24, MP_QSTR_L2CAP_SCH_PDUS & 0xff, MP_QSTR_L2CAP_SCH_PDUS >> 8,
    0x20, 
    0x60, 0x17, 
    0x16, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_L2CAP_SCH & 0xff, MP_QSTR_L2CAP_SCH >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__0 = {{&mp_type_str}, 11573, 18, (const byte*)"\x53\x43\x48\x20\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x72\x65\x6a\x65\x63\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__1 = {{&mp_type_str}, 6650, 22, (const byte*)"\x53\x43\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__2 = {{&mp_type_str}, 31784, 23, (const byte*)"\x53\x43\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__3 = {{&mp_type_str}, 44868, 21, (const byte*)"\x53\x43\x48\x20\x43\x6f\x6e\x66\x69\x67\x75\x72\x65\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__4 = {{&mp_type_str}, 2838, 22, (const byte*)"\x53\x43\x48\x20\x43\x6f\x6e\x66\x69\x67\x75\x72\x65\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__5 = {{&mp_type_str}, 30596, 25, (const byte*)"\x53\x43\x48\x20\x44\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__6 = {{&mp_type_str}, 15574, 26, (const byte*)"\x53\x43\x48\x20\x44\x69\x73\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__7 = {{&mp_type_str}, 27757, 16, (const byte*)"\x53\x43\x48\x20\x45\x63\x68\x6f\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__8 = {{&mp_type_str}, 53919, 17, (const byte*)"\x53\x43\x48\x20\x45\x63\x68\x6f\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__9 = {{&mp_type_str}, 45472, 23, (const byte*)"\x53\x43\x48\x20\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__10 = {{&mp_type_str}, 23090, 24, (const byte*)"\x53\x43\x48\x20\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__11 = {{&mp_type_str}, 12043, 26, (const byte*)"\x53\x43\x48\x20\x43\x72\x65\x61\x74\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__12 = {{&mp_type_str}, 31673, 27, (const byte*)"\x53\x43\x48\x20\x43\x72\x65\x61\x74\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__13 = {{&mp_type_str}, 44542, 24, (const byte*)"\x53\x43\x48\x20\x4d\x6f\x76\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x72\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__14 = {{&mp_type_str}, 28588, 25, (const byte*)"\x53\x43\x48\x20\x4d\x6f\x76\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__15 = {{&mp_type_str}, 21024, 29, (const byte*)"\x53\x43\x48\x20\x4d\x6f\x76\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x43\x6f\x6e\x66\x69\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__16 = {{&mp_type_str}, 29987, 38, (const byte*)"\x53\x43\x48\x20\x4d\x6f\x76\x65\x20\x43\x68\x61\x6e\x6e\x65\x6c\x20\x43\x6f\x6e\x66\x69\x72\x6d\x61\x74\x69\x6f\x6e\x20\x72\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__17 = {{&mp_type_str}, 22996, 42, (const byte*)"\x4c\x45\x20\x53\x43\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x5f\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x5f\x55\x70\x64\x61\x74\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__18 = {{&mp_type_str}, 34694, 43, (const byte*)"\x4c\x45\x20\x53\x43\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x5f\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x5f\x55\x70\x64\x61\x74\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__19 = {{&mp_type_str}, 36057, 41, (const byte*)"\x4c\x45\x20\x53\x43\x48\x20\x4c\x45\x5f\x43\x72\x65\x64\x69\x74\x5f\x42\x61\x73\x65\x64\x5f\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__20 = {{&mp_type_str}, 58027, 42, (const byte*)"\x4c\x45\x20\x53\x43\x48\x20\x4c\x45\x5f\x43\x72\x65\x64\x69\x74\x5f\x42\x61\x73\x65\x64\x5f\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__21 = {{&mp_type_str}, 26554, 29, (const byte*)"\x4c\x45\x20\x53\x43\x48\x20\x4c\x45\x5f\x46\x6c\x6f\x77\x5f\x43\x6f\x6e\x74\x72\x6f\x6c\x5f\x43\x72\x65\x64\x69\x74"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_[24] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__21),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt__L2CAP_SCH),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 396,
        .n_obj = 22,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__[191] = {
    0x0e, 0x00, 0x00, 0x04, 0x00, 0x02, 0x1b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x81, 0xe0, 0x29, 0x2a, 0x2c, 0x26, 0x4a, 0x49, 0x25, 0x27, 0x2c, 0x28, 0x2c, 0x54, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_HCI_EVENTS & 0xff, MP_QSTR_HCI_EVENTS >> 8,
    0xb1, 
    0x21, 
    0x59, 0x02, 
    0xc4, 
    0xc5, 
    0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x50, 0x02, 
    0x59, 0x02, 
    0xc6, 
    0xc7, 
    0xb1, 
    0x14, 0x3e, 
    0x14, 0x81, 0x7f, 
    0x50, 0x02, 
    0xdd, 
    0x37, 0x59, 0x80, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb2, 
    0x66, 0x01, 
    0xb5, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0xc8, 
    0xb8, 
    0x1d, MP_QSTR_subevent & 0xff, MP_QSTR_subevent >> 8,
    0xc6, 
    0xb1, 
    0x14, 0x3e, 
    0xd9, 
    0x37, 0x0c, 0x80, 
    0x1c, MP_QSTR_HCI_LE_META_EVENTS & 0xff, MP_QSTR_HCI_LE_META_EVENTS >> 8,
    0xb6, 
    0x21, 
    0x59, 0x02, 
    0xc7, 
    0xc5, 
    0x35, 0x14, 0x80, 
    0xb1, 
    0x14, 0x81, 0x7f, 
    0xd9, 
    0x37, 0x0c, 0x80, 
    0x1c, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0xb6, 
    0x21, 
    0x59, 0x02, 
    0xc7, 
    0xc5, 
    0x35, 0x00, 0x80, 
    0x1c, MP_QSTR_bytes & 0xff, MP_QSTR_bytes >> 8,
    0xb8, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x11, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb2, 
    0x64, 0x01, 
    0x58, 0x02, 
    0x21, 
    0x64, 0x01, 
    0xc2, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__evtcode & 0xff, MP_QSTR__evtcode >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR__evtname & 0xff, MP_QSTR__evtname >> 8,
    0xb6, 
    0xb0, 
    0x26, MP_QSTR__subevtcode & 0xff, MP_QSTR__subevtcode >> 8,
    0xb7, 
    0xb0, 
    0x26, MP_QSTR__subevtname & 0xff, MP_QSTR__subevtname >> 8,
    0xb5, 
    0xb0, 
    0x26, MP_QSTR__struct & 0xff, MP_QSTR__struct >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__module & 0xff, MP_QSTR__module >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_evtcode),
    MP_ROM_QSTR(MP_QSTR_data),
    MP_ROM_QSTR(MP_QSTR_module),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 191,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__[221] = {
    0x09, 0x00, 0x00, 0x02, 0x00, 0x00, 0x1d,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x81, 0xf8, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x27, 0x2d, 0x28, 0x29, 0x22, 0x26, 0x2c, 0x31, 0x49, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__evtcode & 0xff, MP_QSTR__evtcode >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_evtname & 0xff, MP_QSTR_evtname >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__evtname & 0xff, MP_QSTR__evtname >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__subevtcode & 0xff, MP_QSTR__subevtcode >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_subevtname & 0xff, MP_QSTR_subevtname >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__subevtname & 0xff, MP_QSTR__subevtname >> 8,
    0x5b, 
    0xb1, 
    0x17, 0x02, 
    0xd9, 
    0x37, 0x0d, 0x80, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_sizeof & 0xff, MP_QSTR_sizeof >> 8,
    0xb0, 
    0x1d, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x66, 0x01, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0xd9, 
    0x37, 0x37, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__struct & 0xff, MP_QSTR__struct >> 8,
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x66, 0x01, 
    0xb0, 
    0x1d, MP_QSTR__struct & 0xff, MP_QSTR__struct >> 8,
    0x1e, MP_QSTR_get & 0xff, MP_QSTR_get >> 8,
    0xb0, 
    0x1d, MP_QSTR__module & 0xff, MP_QSTR__module >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct & 0xff, MP_QSTR__struct >> 8,
    0x66, 0x02, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr___0 = {{&mp_type_str}, 9256, 11, (const byte*)"\x73\x74\x72\x75\x63\x74\x5f\x73\x69\x7a\x65"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 221,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__[91] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x12,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x91, 0x10, 0x20, 0x43, 0x24, 0x27, 0x24, 0x44, 0x60, 0x5c, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_evtname & 0xff, MP_QSTR_evtname >> 8,
    0xb0, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xb0, 
    0x1d, MP_QSTR__subevtcode & 0xff, MP_QSTR__subevtcode >> 8,
    0x37, 0x12, 0x80, 
    0x17, 0x02, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR__subevtname & 0xff, MP_QSTR__subevtname >> 8,
    0xb0, 
    0x1d, MP_QSTR__subevtcode & 0xff, MP_QSTR__subevtcode >> 8,
    0x66, 0x02, 
    0x35, 0x03, 0x80, 
    0x16, MP_QSTR__space_ & 0xff, MP_QSTR__space_ >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x06, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str___0 = {{&mp_type_str}, 19755, 54, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x65\x76\x74\x63\x6f\x64\x65\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x7b\x3a\x73\x7d\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str___1 = {{&mp_type_str}, 6422, 27, (const byte*)"\x20\x73\x75\x62\x65\x76\x74\x63\x6f\x64\x65\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str___1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 91,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer[75] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x91, 0x23, 0x80, 0x0c, 0x26, 0x26, 0x51, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x59, 0x02, 
    0xc1, 
    0xc2, 
    0xb0, 
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb0, 
    0x64, 0x82, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 75,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer[94] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x14,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x91, 0x37, 0x27, 0x26, 0x28, 0x24, 0x24, 0x26, 0x26, 0x26, 0x24, 0x24, 0x26, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x37, 0x22, 0x80, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x16, MP_QSTR_B & 0xff, MP_QSTR_B >> 8,
    0xf1, 
    0xb0, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xb0, 
    0x1d, MP_QSTR_subevtcode & 0xff, MP_QSTR_subevtcode >> 8,
    0x66, 0x04, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x66, 0x03, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 94,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT[99] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x8d, 0xdb, 0x20, 0x26, 0x4e, 0x8d, 0x18, 0x85, 0x18, 0x85, 0x12, 0x8a, 0x15, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_BB & 0xff, MP_QSTR__lt_BB >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x17, 0x00, 
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x50, 0x02, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 99,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/event.py, scope bluetooth_low_energy_protocols_hci_event_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt_[1267] = {
    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x81, 0x19,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_event_dot_py >> 8,
    0x21, 0x28, 0x28, 0x39, 0x50, 0x50, 0x80, 0x15, 0x60, 0x60, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x2c, 0x2b, 0x35, 0x2c, 0x2c, 0x2b, 0x6f, 0x20, 0x22, 0x22, 0x2c, 0x2b, 0x36, 0x2b, 0x20, 0x7e, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x2c, 0x2c, 0x6f, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x7a, 0x20, 0x22, 0x22, 0x2c, 0x36, 0x73, 0x60, 0x45, 0x80, 0x07, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x25, 0x25, 0x46, 0x22, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x36, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2b, 0x2c, 0x2b, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x70, 0x43, 0x22, 0x2c, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x20, 0x2f, 0x22, 0x2c, 0x75, 0x40, 0x20, 0x22, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x71, 0x20, 0x22, 0x22, 0x2c, 0x7f, 0x43, 0x22, 0x2c, 0x1f, 0x64, 0x40, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci >> 8,
    0x69, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x24, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_EVT_LE_CONN_COMPLETE & 0xff, MP_QSTR_EVT_LE_CONN_COMPLETE >> 8,
    0x82, 
    0x24, MP_QSTR_EVT_LE_ADVERTISING_REPORT & 0xff, MP_QSTR_EVT_LE_ADVERTISING_REPORT >> 8,
    0x83, 
    0x24, MP_QSTR_EVT_LE_CONN_UPDATE_COMPLETE & 0xff, MP_QSTR_EVT_LE_CONN_UPDATE_COMPLETE >> 8,
    0x84, 
    0x24, MP_QSTR_EVT_LE_READ_REMOTE_USED_FEATURES_COMPLETE & 0xff, MP_QSTR_EVT_LE_READ_REMOTE_USED_FEATURES_COMPLETE >> 8,
    0x85, 
    0x24, MP_QSTR_EVT_LE_LTK_REQUEST & 0xff, MP_QSTR_EVT_LE_LTK_REQUEST >> 8,
    0x53, 0x05, 
    0x17, 0x00, 
    0x53, 0x09, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_role & 0xff, MP_QSTR_role >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x01, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x85, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x02, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8b, 
    0xec, 
    0x16, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8d, 
    0xec, 
    0x16, MP_QSTR_latency & 0xff, MP_QSTR_latency >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8f, 
    0xec, 
    0x17, 0x03, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x91, 
    0xec, 
    0x17, 0x04, 
    0x54, 
    0x51, 0x02, 
    0x81, 
    0x54, 
    0x17, 0x05, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_evt_type & 0xff, MP_QSTR_evt_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x06, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x17, 0x07, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x89, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x89, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data_RSSI & 0xff, MP_QSTR_data_RSSI >> 8,
    0x54, 
    0x51, 0x02, 
    0x82, 
    0x54, 
    0x17, 0x08, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x16, MP_QSTR_latency & 0xff, MP_QSTR_latency >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x87, 
    0xec, 
    0x17, 0x09, 
    0x54, 
    0x51, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x0a, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_features & 0xff, MP_QSTR_features >> 8,
    0x54, 
    0x51, 0x02, 
    0x84, 
    0x54, 
    0x17, 0x0b, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_random & 0xff, MP_QSTR_random >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x16, MP_QSTR_ediv & 0xff, MP_QSTR_ediv >> 8,
    0x54, 
    0x51, 0x02, 
    0x85, 
    0x54, 
    0x24, MP_QSTR_HCI_LE_META_EVENTS & 0xff, MP_QSTR_HCI_LE_META_EVENTS >> 8,
    0x53, 0x00, 
    0x24, MP_QSTR_HCI_VENDOR_EVENTS & 0xff, MP_QSTR_HCI_VENDOR_EVENTS >> 8,
    0x83, 
    0x24, MP_QSTR_EVT_CONN_COMPLETE & 0xff, MP_QSTR_EVT_CONN_COMPLETE >> 8,
    0x85, 
    0x24, MP_QSTR_EVT_DISCONN_COMPLETE & 0xff, MP_QSTR_EVT_DISCONN_COMPLETE >> 8,
    0x88, 
    0x24, MP_QSTR_EVT_ENCRYPT_CHANGE & 0xff, MP_QSTR_EVT_ENCRYPT_CHANGE >> 8,
    0x8c, 
    0x24, MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE & 0xff, MP_QSTR_EVT_READ_REMOTE_VERSION_COMPLETE >> 8,
    0x8f, 
    0x24, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x8e, 
    0x24, MP_QSTR_EVT_CMD_COMPLETE & 0xff, MP_QSTR_EVT_CMD_COMPLETE >> 8,
    0x90, 
    0x24, MP_QSTR_EVT_HARDWARE_ERROR & 0xff, MP_QSTR_EVT_HARDWARE_ERROR >> 8,
    0x93, 
    0x24, MP_QSTR_EVT_NUM_COMP_PKTS & 0xff, MP_QSTR_EVT_NUM_COMP_PKTS >> 8,
    0x9a, 
    0x24, MP_QSTR_EVT_DATA_BUFFER_OVERFLOW & 0xff, MP_QSTR_EVT_DATA_BUFFER_OVERFLOW >> 8,
    0x14, 0x30, 
    0x24, MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_COMPLETE & 0xff, MP_QSTR_EVT_ENCRYPTION_KEY_REFRESH_COMPLETE >> 8,
    0x14, 0x3e, 
    0x24, MP_QSTR_EVT_LE_META_EVENT & 0xff, MP_QSTR_EVT_LE_META_EVENT >> 8,
    0x14, 0x81, 0x7f, 
    0x24, MP_QSTR_EVT_VENDOR & 0xff, MP_QSTR_EVT_VENDOR >> 8,
    0x53, 0x0c, 
    0x17, 0x0c, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x89, 
    0xec, 
    0x16, MP_QSTR_link_type & 0xff, MP_QSTR_link_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8a, 
    0xec, 
    0x16, MP_QSTR_encr_mode & 0xff, MP_QSTR_encr_mode >> 8,
    0x54, 
    0x51, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x0d, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_reason & 0xff, MP_QSTR_reason >> 8,
    0x54, 
    0x51, 0x02, 
    0x85, 
    0x54, 
    0x17, 0x0e, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_encrypt & 0xff, MP_QSTR_encrypt >> 8,
    0x54, 
    0x51, 0x02, 
    0x88, 
    0x54, 
    0x17, 0x0f, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x17, 0x10, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_version & 0xff, MP_QSTR_version >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x11, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_subversion & 0xff, MP_QSTR_subversion >> 8,
    0x54, 
    0x51, 0x02, 
    0x8c, 
    0x54, 
    0x17, 0x12, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_ncmd & 0xff, MP_QSTR_ncmd >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0x54, 
    0x51, 0x02, 
    0x8e, 
    0x54, 
    0x16, MP_QSTR_CMD_STATUS & 0xff, MP_QSTR_CMD_STATUS >> 8,
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_ncmd & 0xff, MP_QSTR_ncmd >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0x54, 
    0x51, 0x02, 
    0x8f, 
    0x54, 
    0x17, 0x13, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_code & 0xff, MP_QSTR_code >> 8,
    0x54, 
    0x51, 0x02, 
    0x90, 
    0x54, 
    0x17, 0x14, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_num_hndl & 0xff, MP_QSTR_num_hndl >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x84, 
    0xf4, 
    0x82, 
    0xf2, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_hndl & 0xff, MP_QSTR_hndl >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x15, 
    0x54, 
    0x50, 0x03, 
    0x16, MP_QSTR_hndl & 0xff, MP_QSTR_hndl >> 8,
    0x54, 
    0x51, 0x02, 
    0x93, 
    0x54, 
    0x17, 0x16, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_link_type & 0xff, MP_QSTR_link_type >> 8,
    0x54, 
    0x51, 0x02, 
    0x9a, 
    0x54, 
    0x17, 0x17, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x30, 
    0x54, 
    0x17, 0x18, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_subevent & 0xff, MP_QSTR_subevent >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x81, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x3e, 
    0x54, 
    0x16, MP_QSTR_VENDOR & 0xff, MP_QSTR_VENDOR >> 8,
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_subevent & 0xff, MP_QSTR_subevent >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x1b, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x81, 
    0xf2, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x51, 0x02, 
    0x14, 0x81, 0x7f, 
    0x54, 
    0x24, MP_QSTR_HCI_EVENTS & 0xff, MP_QSTR_HCI_EVENTS >> 8,
    0x20, 
    0x60, 0x19, 
    0x16, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HCI_EVENT & 0xff, MP_QSTR_HCI_EVENT >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__0 = {{&mp_type_str}, 5407, 13, (const byte*)"\x43\x4f\x4e\x4e\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__1 = {{&mp_type_str}, 25866, 16, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__2 = {{&mp_type_str}, 50221, 11, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__3 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__4 = {{&mp_type_str}, 45548, 21, (const byte*)"\x6d\x61\x73\x74\x65\x72\x5f\x63\x6c\x6f\x63\x6b\x5f\x61\x63\x63\x75\x72\x61\x63\x79"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__5 = {{&mp_type_str}, 22110, 18, (const byte*)"\x41\x44\x56\x45\x52\x54\x49\x53\x49\x4e\x47\x5f\x52\x45\x50\x4f\x52\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__6 = {{&mp_type_str}, 44727, 11, (const byte*)"\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__7 = {{&mp_type_str}, 4022, 11, (const byte*)"\x64\x61\x74\x61\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__8 = {{&mp_type_str}, 46737, 20, (const byte*)"\x43\x4f\x4e\x4e\x5f\x55\x50\x44\x41\x54\x45\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__9 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__10 = {{&mp_type_str}, 33690, 34, (const byte*)"\x52\x45\x41\x44\x5f\x52\x45\x4d\x4f\x54\x45\x5f\x55\x53\x45\x44\x5f\x46\x45\x41\x54\x55\x52\x45\x53\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__11 = {{&mp_type_str}, 20408, 11, (const byte*)"\x4c\x54\x4b\x5f\x52\x45\x51\x55\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__12 = {{&mp_type_str}, 5407, 13, (const byte*)"\x43\x4f\x4e\x4e\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__13 = {{&mp_type_str}, 44737, 16, (const byte*)"\x44\x49\x53\x43\x4f\x4e\x4e\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__14 = {{&mp_type_str}, 22939, 14, (const byte*)"\x45\x4e\x43\x52\x59\x50\x54\x5f\x43\x48\x41\x4e\x47\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__15 = {{&mp_type_str}, 9951, 28, (const byte*)"\x52\x45\x41\x44\x5f\x52\x45\x4d\x4f\x54\x45\x5f\x56\x45\x52\x53\x49\x4f\x4e\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__16 = {{&mp_type_str}, 52422, 17, (const byte*)"\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x5f\x68\x61\x6e\x64\x6c\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__17 = {{&mp_type_str}, 45354, 17, (const byte*)"\x6d\x61\x6e\x75\x66\x61\x63\x74\x75\x72\x65\x72\x5f\x6e\x61\x6d\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__18 = {{&mp_type_str}, 24057, 12, (const byte*)"\x43\x4d\x44\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__19 = {{&mp_type_str}, 22268, 14, (const byte*)"\x48\x41\x52\x44\x57\x41\x52\x45\x5f\x45\x52\x52\x4f\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__20 = {{&mp_type_str}, 49246, 13, (const byte*)"\x4e\x55\x4d\x5f\x43\x4f\x4d\x50\x5f\x50\x4b\x54\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__21 = {{&mp_type_str}, 32510, 13, (const byte*)"\x6e\x75\x6d\x5f\x63\x6f\x6d\x70\x5f\x70\x6b\x74\x73"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__22 = {{&mp_type_str}, 18921, 20, (const byte*)"\x44\x41\x54\x41\x5f\x42\x55\x46\x46\x45\x52\x5f\x4f\x56\x45\x52\x46\x4c\x4f\x57"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__23 = {{&mp_type_str}, 29750, 31, (const byte*)"\x45\x4e\x43\x52\x59\x50\x54\x49\x4f\x4e\x5f\x4b\x45\x59\x5f\x52\x45\x46\x52\x45\x53\x48\x5f\x43\x4f\x4d\x50\x4c\x45\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__24 = {{&mp_type_str}, 37917, 13, (const byte*)"\x4c\x45\x5f\x4d\x45\x54\x41\x5f\x45\x56\x45\x4e\x54"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt_[26] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_event__lt_module_gt__24),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt__HCI_EVENT),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_event__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 1267,
        .n_obj = 25,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack[27] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0a,
    MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x91, 0xde, 0x20, 0x00, 0x00, 0xff,
    0xb1, 
    0x14, 0x87, 0x7f, 
    0xee, 
    0xb0, 
    0x8a, 
    0xef, 
    0xec, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack[2] = {
    MP_ROM_QSTR(MP_QSTR_ogf),
    MP_ROM_QSTR(MP_QSTR_ocf),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 27,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack[28] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x91, 0xe3, 0x20, 0x00, 0x00, 0xff,
    0xb0, 
    0x8a, 
    0xf0, 
    0xb0, 
    0x14, 0x87, 0x7f, 
    0xee, 
    0x50, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack[1] = {
    MP_ROM_QSTR(MP_QSTR_opcode),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 28,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE[53] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c,
    MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x9d, 0xdb, 0x20, 0x6a, 0x40, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x00, 
    0x64, 0x01, 
    0x24, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x01, 
    0x64, 0x01, 
    0x24, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE[2] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_pack),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE_unpack),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 53,
        .n_obj = 0,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__[158] = {
    0x10, 0x00, 0x00, 0x07, 0x00, 0x06, 0x19,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x91, 0xec, 0x28, 0x52, 0x50, 0x29, 0x29, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x00, 0x00, 0xff,
    0xb1, 
    0x37, 0x12, 0x80, 
    0xb2, 
    0x37, 0x0e, 0x80, 
    0x1c, MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb1, 
    0xb2, 
    0x66, 0x02, 
    0xc3, 
    0x35, 0x1d, 0x80, 
    0xb3, 
    0x37, 0x10, 0x80, 
    0x1c, MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0xb3, 
    0x66, 0x01, 
    0x59, 0x02, 
    0xc1, 
    0xc2, 
    0x35, 0x09, 0x80, 
    0x1c, MP_QSTR_ValueError & 0xff, MP_QSTR_ValueError >> 8,
    0x17, 0x07, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x1c, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0xb1, 
    0x21, 
    0x59, 0x02, 
    0xc7, 
    0xc8, 
    0xb8, 
    0xb2, 
    0x21, 
    0x59, 0x03, 
    0xc9, 
    0xca, 
    0xcb, 
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__opcode & 0xff, MP_QSTR__opcode >> 8,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__ogf & 0xff, MP_QSTR__ogf >> 8,
    0xb7, 
    0xb0, 
    0x26, MP_QSTR__ogf_name & 0xff, MP_QSTR__ogf_name >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__ocf & 0xff, MP_QSTR__ocf >> 8,
    0xb9, 
    0xb0, 
    0x26, MP_QSTR__ocf_name & 0xff, MP_QSTR__ocf_name >> 8,
    0xb5, 
    0xb0, 
    0x26, MP_QSTR__evtcode & 0xff, MP_QSTR__evtcode >> 8,
    0xba, 
    0xb0, 
    0x26, MP_QSTR__request_struct & 0xff, MP_QSTR__request_struct >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR__request_data & 0xff, MP_QSTR__request_data >> 8,
    0xbb, 
    0xb0, 
    0x26, MP_QSTR__response_struct & 0xff, MP_QSTR__response_struct >> 8,
    0x17, 0x08, 
    0xb0, 
    0x26, MP_QSTR__response_data & 0xff, MP_QSTR__response_data >> 8,
    0xb6, 
    0xb0, 
    0x26, MP_QSTR__module & 0xff, MP_QSTR__module >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init___0 = {{&mp_type_str}, 49666, 18, (const byte*)"\x6f\x67\x66\x2c\x20\x6f\x63\x66\x20\x6f\x72\x20\x6f\x70\x63\x6f\x64\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init___1 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__[9] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_ogf),
    MP_ROM_QSTR(MP_QSTR_ocf),
    MP_ROM_QSTR(MP_QSTR_opcode),
    MP_ROM_QSTR(MP_QSTR_data),
    MP_ROM_QSTR(MP_QSTR_evtcode),
    MP_ROM_QSTR(MP_QSTR_module),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init___1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 7,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 158,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__[358] = {
    0x09, 0x00, 0x00, 0x02, 0x00, 0x00, 0x2b,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0xa1, 0x02, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x29, 0x22, 0x26, 0x2c, 0x31, 0x49, 0x28, 0x29, 0x22, 0x26, 0x2c, 0x31, 0x49, 0x27, 0x33, 0x28, 0x2d, 0x27, 0x33, 0x28, 0x4d, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__ogf & 0xff, MP_QSTR__ogf >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_ogf_name & 0xff, MP_QSTR_ogf_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__ogf_name & 0xff, MP_QSTR__ogf_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__ocf & 0xff, MP_QSTR__ocf >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_ocf_name & 0xff, MP_QSTR_ocf_name >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__ocf_name & 0xff, MP_QSTR__ocf_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__opcode & 0xff, MP_QSTR__opcode >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_evtcode & 0xff, MP_QSTR_evtcode >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__evtcode & 0xff, MP_QSTR__evtcode >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_request_struct & 0xff, MP_QSTR_request_struct >> 8,
    0xd9, 
    0x37, 0x37, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__request_struct & 0xff, MP_QSTR__request_struct >> 8,
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x1d, MP_QSTR_request_data & 0xff, MP_QSTR_request_data >> 8,
    0x66, 0x01, 
    0xb0, 
    0x1d, MP_QSTR__request_struct & 0xff, MP_QSTR__request_struct >> 8,
    0x1e, MP_QSTR_get & 0xff, MP_QSTR_get >> 8,
    0xb0, 
    0x1d, MP_QSTR__module & 0xff, MP_QSTR__module >> 8,
    0xb0, 
    0x1d, MP_QSTR__request_struct & 0xff, MP_QSTR__request_struct >> 8,
    0x66, 0x02, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_response_struct & 0xff, MP_QSTR_response_struct >> 8,
    0xd9, 
    0x37, 0x37, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__response_struct & 0xff, MP_QSTR__response_struct >> 8,
    0x11, 
    0xde, 
    0x37, 0x02, 0x80, 
    0x11, 
    0x5b, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x1d, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0x66, 0x01, 
    0xb0, 
    0x1d, MP_QSTR__response_struct & 0xff, MP_QSTR__response_struct >> 8,
    0x1e, MP_QSTR_get & 0xff, MP_QSTR_get >> 8,
    0xb0, 
    0x1d, MP_QSTR__module & 0xff, MP_QSTR__module >> 8,
    0xb0, 
    0x1d, MP_QSTR__response_struct & 0xff, MP_QSTR__response_struct >> 8,
    0x66, 0x02, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0x5b, 
    0xb1, 
    0x17, 0x02, 
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__request_data & 0xff, MP_QSTR__request_data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__request_data & 0xff, MP_QSTR__request_data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_request_data & 0xff, MP_QSTR_request_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__request_data & 0xff, MP_QSTR__request_data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_request_length & 0xff, MP_QSTR_request_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0xb1, 
    0x17, 0x03, 
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__response_data & 0xff, MP_QSTR__response_data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__response_data & 0xff, MP_QSTR__response_data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__response_data & 0xff, MP_QSTR__response_data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_response_length & 0xff, MP_QSTR_response_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x1c, MP_QSTR_AttributeError & 0xff, MP_QSTR_AttributeError >> 8,
    0xb1, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr___0 = {{&mp_type_str}, 19575, 14, (const byte*)"\x72\x65\x71\x75\x65\x73\x74\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr___1 = {{&mp_type_str}, 48677, 15, (const byte*)"\x72\x65\x73\x70\x6f\x6e\x73\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr___0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr___1),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 358,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__[78] = {
    0x0d, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0xa1, 0x2a, 0x20, 0x63, 0x20, 0x24, 0x27, 0x34, 0x29, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb0, 
    0x1d, MP_QSTR_ogf_name & 0xff, MP_QSTR_ogf_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_ogf & 0xff, MP_QSTR_ogf >> 8,
    0xb0, 
    0x1d, MP_QSTR_ocf_name & 0xff, MP_QSTR_ocf_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_ocf & 0xff, MP_QSTR_ocf >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_request_data & 0xff, MP_QSTR_request_data >> 8,
    0x64, 0x01, 
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_response_data & 0xff, MP_QSTR_response_data >> 8,
    0x64, 0x01, 
    0x66, 0x08, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str___0 = {{&mp_type_str}, 9433, 97, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x6f\x70\x63\x6f\x64\x65\x3d\x30\x78\x7b\x3a\x30\x34\x78\x7d\x20\x6f\x67\x66\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x6f\x63\x66\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x72\x65\x71\x75\x65\x73\x74\x5f\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x20\x72\x65\x73\x70\x6f\x6e\x73\x65\x5f\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 78,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer[77] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0e,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0xa1, 0x38, 0x80, 0x0b, 0x26, 0x57, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack_from & 0xff, MP_QSTR_unpack_from >> 8,
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x59, 0x02, 
    0xc1, 
    0xc2, 
    0xb0, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x16, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xb0, 
    0x64, 0x84, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 77,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer[65] = {
    0x08, 0x00, 0x00, 0x02, 0x00, 0x01, 0x10,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0xa1, 0x4a, 0x60, 0x20, 0x26, 0x24, 0x24, 0x46, 0x47, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb0, 
    0x1d, MP_QSTR_request_length & 0xff, MP_QSTR_request_length >> 8,
    0x66, 0x03, 
    0xb0, 
    0x1d, MP_QSTR_request_data & 0xff, MP_QSTR_request_data >> 8,
    0x50, 0x02, 
    0xc2, 
    0xb1, 
    0x37, 0x02, 0x80, 
    0xb2, 
    0x5b, 
    0x17, 0x02, 
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0xb2, 
    0x66, 0x01, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_split),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer_0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 65,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND[110] = {
    0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x15,
    MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x9d, 0xe7, 0x20, 0x26, 0x4e, 0x73, 0x80, 0x13, 0x85, 0x28, 0x85, 0x0d, 0x8a, 0x13, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x80, 
    0x80, 
    0x80, 
    0x17, 0x00, 
    0x1b, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x16, MP_QSTR_IDB05A1 & 0xff, MP_QSTR_IDB05A1 >> 8,
    0x50, 0x06, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x10, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 110,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/cmd.py, scope bluetooth_low_energy_protocols_hci_cmd_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_[2741] = {
    0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x53,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_cmd_dot_py >> 8,
    0x21, 0x28, 0x28, 0x39, 0x50, 0x50, 0x80, 0x0d, 0x24, 0x24, 0x24, 0x24, 0x24, 0x45, 0x24, 0x24, 0x24, 0x25, 0x25, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x43, 0x22, 0x20, 0x43, 0x22, 0x2c, 0x4c, 0x22, 0x74, 0x40, 0x43, 0x22, 0x64, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x4c, 0x22, 0x2c, 0x2c, 0x70, 0x20, 0x6d, 0x60, 0x43, 0x22, 0x20, 0x43, 0x22, 0x2c, 0x2b, 0x2b, 0x2b, 0x2b, 0x6f, 0x20, 0x43, 0x22, 0x2c, 0x7e, 0x40, 0x20, 0x22, 0x22, 0x43, 0x22, 0x4c, 0x22, 0x2c, 0x2c, 0x74, 0x40, 0x43, 0x22, 0x20, 0x22, 0x22, 0x56, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x2c, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x7a, 0x20, 0x22, 0x22, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2b, 0x2b, 0x2c, 0x2b, 0x2b, 0x35, 0x2c, 0x4c, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x2c, 0x2b, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x2b, 0x2b, 0x35, 0x2b, 0x2b, 0x2b, 0x2c, 0x2b, 0x2b, 0x4b, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2b, 0x56, 0x22, 0x70, 0x20, 0x43, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2b, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2b, 0x2b, 0x2c, 0x2b, 0x2b, 0x4b, 0x22, 0x70, 0x20, 0x22, 0x22, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x2c, 0x2c, 0x7a, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x43, 0x22, 0x36, 0x56, 0x22, 0x2c, 0x7a, 0x64, 0x22, 0x2c, 0x7a, 0x20, 0x22, 0x22, 0x2c, 0x36, 0x2b, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x56, 0x22, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x2c, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x56, 0x22, 0x70, 0x20, 0x22, 0x22, 0x4c, 0x22, 0x70, 0x20, 0x22, 0x22, 0x2c, 0x2c, 0x4c, 0x22, 0x70, 0x20, 0x43, 0x22, 0x2c, 0x74, 0x40, 0x6c, 0x60, 0x8e, 0x0c, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_event & 0xff, MP_QSTR_bluetooth_low_energy_dot_protocols_dot_hci_dot_event >> 8,
    0x69, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x24, MP_QSTR_EVT_CMD_STATUS & 0xff, MP_QSTR_EVT_CMD_STATUS >> 8,
    0x32, 
    0x81, 
    0x24, MP_QSTR_OGF_LINK_CTL & 0xff, MP_QSTR_OGF_LINK_CTL >> 8,
    0x83, 
    0x24, MP_QSTR_OGF_HOST_CTL & 0xff, MP_QSTR_OGF_HOST_CTL >> 8,
    0x84, 
    0x24, MP_QSTR_OGF_INFO_PARAM & 0xff, MP_QSTR_OGF_INFO_PARAM >> 8,
    0x85, 
    0x24, MP_QSTR_OGF_STATUS_PARAM & 0xff, MP_QSTR_OGF_STATUS_PARAM >> 8,
    0x88, 
    0x24, MP_QSTR_OGF_LE_CTL & 0xff, MP_QSTR_OGF_LE_CTL >> 8,
    0x14, 0x3f, 
    0x24, MP_QSTR_OGF_VENDOR_CMD & 0xff, MP_QSTR_OGF_VENDOR_CMD >> 8,
    0x86, 
    0x24, MP_QSTR_OCF_DISCONNECT & 0xff, MP_QSTR_OCF_DISCONNECT >> 8,
    0x83, 
    0x24, MP_QSTR_OCF_RESET & 0xff, MP_QSTR_OCF_RESET >> 8,
    0xad, 
    0x24, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL & 0xff, MP_QSTR_OCF_READ_TRANSMIT_POWER_LEVEL >> 8,
    0x14, 0x31, 
    0x24, MP_QSTR_OCF_SET_CONTROLLER_TO_HOST_FC & 0xff, MP_QSTR_OCF_SET_CONTROLLER_TO_HOST_FC >> 8,
    0x14, 0x35, 
    0x24, MP_QSTR_OCF_HOST_NUM_COMP_PKTS & 0xff, MP_QSTR_OCF_HOST_NUM_COMP_PKTS >> 8,
    0x81, 
    0x24, MP_QSTR_OCF_READ_LOCAL_VERSION & 0xff, MP_QSTR_OCF_READ_LOCAL_VERSION >> 8,
    0x82, 
    0x24, MP_QSTR_OCF_READ_LOCAL_COMMANDS & 0xff, MP_QSTR_OCF_READ_LOCAL_COMMANDS >> 8,
    0x83, 
    0x24, MP_QSTR_OCF_READ_LOCAL_FEATURES & 0xff, MP_QSTR_OCF_READ_LOCAL_FEATURES >> 8,
    0x89, 
    0x24, MP_QSTR_OCF_READ_BD_ADDR & 0xff, MP_QSTR_OCF_READ_BD_ADDR >> 8,
    0x85, 
    0x24, MP_QSTR_OCF_READ_RSSI & 0xff, MP_QSTR_OCF_READ_RSSI >> 8,
    0x81, 
    0x24, MP_QSTR_OCF_LE_SET_EVENT_MASK & 0xff, MP_QSTR_OCF_LE_SET_EVENT_MASK >> 8,
    0x82, 
    0x24, MP_QSTR_OCF_LE_READ_BUFFER_SIZE & 0xff, MP_QSTR_OCF_LE_READ_BUFFER_SIZE >> 8,
    0x83, 
    0x24, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_LOCAL_SUPPORTED_FEATURES >> 8,
    0x85, 
    0x24, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS & 0xff, MP_QSTR_OCF_LE_SET_RANDOM_ADDRESS >> 8,
    0x86, 
    0x24, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_ADV_PARAMETERS >> 8,
    0x87, 
    0x24, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER & 0xff, MP_QSTR_OCF_LE_READ_ADV_CHANNEL_TX_POWER >> 8,
    0x88, 
    0x24, MP_QSTR_OCF_LE_SET_ADV_DATA & 0xff, MP_QSTR_OCF_LE_SET_ADV_DATA >> 8,
    0x89, 
    0x24, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA & 0xff, MP_QSTR_OCF_LE_SET_SCAN_RESPONSE_DATA >> 8,
    0x8a, 
    0x24, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_ADVERTISE_ENABLE >> 8,
    0x8b, 
    0x24, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS & 0xff, MP_QSTR_OCF_LE_SET_SCAN_PARAMETERS >> 8,
    0x8c, 
    0x24, MP_QSTR_OCF_LE_SET_SCAN_ENABLE & 0xff, MP_QSTR_OCF_LE_SET_SCAN_ENABLE >> 8,
    0x8d, 
    0x24, MP_QSTR_OCF_LE_CREATE_CONN & 0xff, MP_QSTR_OCF_LE_CREATE_CONN >> 8,
    0x8e, 
    0x24, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL & 0xff, MP_QSTR_OCF_LE_CREATE_CONN_CANCEL >> 8,
    0x8f, 
    0x24, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE & 0xff, MP_QSTR_OCF_LE_READ_WHITE_LIST_SIZE >> 8,
    0x91, 
    0x24, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_ADD_DEVICE_TO_WHITE_LIST >> 8,
    0x90, 
    0x24, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_CLEAR_WHITE_LIST >> 8,
    0x92, 
    0x24, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST & 0xff, MP_QSTR_OCF_LE_REMOVE_DEVICE_FROM_WHITE_LIST >> 8,
    0x93, 
    0x24, MP_QSTR_OCF_LE_CONN_UPDATE & 0xff, MP_QSTR_OCF_LE_CONN_UPDATE >> 8,
    0x94, 
    0x24, MP_QSTR_OCF_LE_SET_HOST_CHANNEL_CLASSIFICATION & 0xff, MP_QSTR_OCF_LE_SET_HOST_CHANNEL_CLASSIFICATION >> 8,
    0x95, 
    0x24, MP_QSTR_OCF_LE_READ_CHANNEL_MAP & 0xff, MP_QSTR_OCF_LE_READ_CHANNEL_MAP >> 8,
    0x96, 
    0x24, MP_QSTR_OCF_LE_READ_REMOTE_USED_FEATURES & 0xff, MP_QSTR_OCF_LE_READ_REMOTE_USED_FEATURES >> 8,
    0x97, 
    0x24, MP_QSTR_OCF_LE_ENCRYPT & 0xff, MP_QSTR_OCF_LE_ENCRYPT >> 8,
    0x98, 
    0x24, MP_QSTR_OCF_LE_RAND & 0xff, MP_QSTR_OCF_LE_RAND >> 8,
    0x99, 
    0x24, MP_QSTR_OCF_LE_START_ENCRYPTION & 0xff, MP_QSTR_OCF_LE_START_ENCRYPTION >> 8,
    0x9a, 
    0x24, MP_QSTR_OCF_LE_LTK_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_REPLY >> 8,
    0x9b, 
    0x24, MP_QSTR_OCF_LE_LTK_NEG_REPLY & 0xff, MP_QSTR_OCF_LE_LTK_NEG_REPLY >> 8,
    0x9c, 
    0x24, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES & 0xff, MP_QSTR_OCF_LE_READ_SUPPORTED_STATES >> 8,
    0x9d, 
    0x24, MP_QSTR_OCF_LE_RECEIVER_TEST & 0xff, MP_QSTR_OCF_LE_RECEIVER_TEST >> 8,
    0x9e, 
    0x24, MP_QSTR_OCF_LE_TRANSMITTER_TEST & 0xff, MP_QSTR_OCF_LE_TRANSMITTER_TEST >> 8,
    0x9f, 
    0x24, MP_QSTR_OCF_LE_TEST_END & 0xff, MP_QSTR_OCF_LE_TEST_END >> 8,
    0x53, 0x06, 
    0x16, MP_QSTR_LINK_CTL & 0xff, MP_QSTR_LINK_CTL >> 8,
    0x53, 0x01, 
    0x16, MP_QSTR_DISCONNECT & 0xff, MP_QSTR_DISCONNECT >> 8,
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_reason & 0xff, MP_QSTR_reason >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x86, 
    0x54, 
    0x51, 0x02, 
    0x81, 
    0x54, 
    0x16, MP_QSTR_HOST_CTL & 0xff, MP_QSTR_HOST_CTL >> 8,
    0x53, 0x03, 
    0x16, MP_QSTR_RESET & 0xff, MP_QSTR_RESET >> 8,
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x83, 
    0x54, 
    0x17, 0x00, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_type & 0xff, MP_QSTR_type >> 8,
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_level & 0xff, MP_QSTR_level >> 8,
    0x54, 
    0x51, 0x03, 
    0xad, 
    0x54, 
    0x17, 0x01, 
    0x11, 
    0x11, 
    0x51, 0x03, 
    0x14, 0x31, 
    0x54, 
    0x51, 0x02, 
    0x83, 
    0x54, 
    0x16, MP_QSTR_INFO_PARAM & 0xff, MP_QSTR_INFO_PARAM >> 8,
    0x53, 0x02, 
    0x17, 0x02, 
    0x11, 
    0x53, 0x06, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x17, 0x03, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x04, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x05, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x85, 
    0xec, 
    0x17, 0x06, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x87, 
    0xec, 
    0x17, 0x07, 
    0x54, 
    0x51, 0x03, 
    0x81, 
    0x54, 
    0x17, 0x08, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x51, 0x03, 
    0x89, 
    0x54, 
    0x51, 0x02, 
    0x84, 
    0x54, 
    0x17, 0x09, 
    0x53, 0x01, 
    0x16, MP_QSTR_READ_RSSI & 0xff, MP_QSTR_READ_RSSI >> 8,
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_rssi & 0xff, MP_QSTR_rssi >> 8,
    0x54, 
    0x51, 0x03, 
    0x85, 
    0x54, 
    0x51, 0x02, 
    0x85, 
    0x54, 
    0x16, MP_QSTR_LE_CTL & 0xff, MP_QSTR_LE_CTL >> 8,
    0x53, 0x1e, 
    0x17, 0x0a, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_mask & 0xff, MP_QSTR_mask >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x81, 
    0x54, 
    0x17, 0x0b, 
    0x11, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_pkt_len & 0xff, MP_QSTR_pkt_len >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_max_pkt & 0xff, MP_QSTR_max_pkt >> 8,
    0x54, 
    0x51, 0x03, 
    0x82, 
    0x54, 
    0x17, 0x0c, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_features & 0xff, MP_QSTR_features >> 8,
    0x54, 
    0x51, 0x03, 
    0x83, 
    0x54, 
    0x17, 0x0d, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x85, 
    0x54, 
    0x17, 0x0e, 
    0x53, 0x08, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x17, 0x0f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x10, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x16, MP_QSTR_advtype & 0xff, MP_QSTR_advtype >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x11, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x17, 0x12, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x87, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x13, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8d, 
    0xec, 
    0x16, MP_QSTR_chan_map & 0xff, MP_QSTR_chan_map >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8e, 
    0xec, 
    0x16, MP_QSTR_filter & 0xff, MP_QSTR_filter >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x86, 
    0x54, 
    0x17, 0x14, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_INT8 & 0xff, MP_QSTR_INT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_level & 0xff, MP_QSTR_level >> 8,
    0x54, 
    0x51, 0x03, 
    0x87, 
    0x54, 
    0x17, 0x15, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x9f, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x88, 
    0x54, 
    0x17, 0x16, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x9f, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x89, 
    0x54, 
    0x17, 0x17, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_enable & 0xff, MP_QSTR_enable >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8a, 
    0x54, 
    0x17, 0x18, 
    0x53, 0x05, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_type & 0xff, MP_QSTR_type >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x83, 
    0xec, 
    0x16, MP_QSTR_window & 0xff, MP_QSTR_window >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x19, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_filter & 0xff, MP_QSTR_filter >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8b, 
    0x54, 
    0x17, 0x1a, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_enable & 0xff, MP_QSTR_enable >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_filter_dup & 0xff, MP_QSTR_filter_dup >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8c, 
    0x54, 
    0x17, 0x1b, 
    0x53, 0x0c, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_interval & 0xff, MP_QSTR_interval >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_window & 0xff, MP_QSTR_window >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x84, 
    0xec, 
    0x17, 0x1c, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x17, 0x1d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x86, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x17, 0x1e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x1f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8d, 
    0xec, 
    0x17, 0x20, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8f, 
    0xec, 
    0x17, 0x21, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x91, 
    0xec, 
    0x16, MP_QSTR_latency & 0xff, MP_QSTR_latency >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x93, 
    0xec, 
    0x17, 0x22, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x95, 
    0xec, 
    0x17, 0x23, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x97, 
    0xec, 
    0x17, 0x24, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8d, 
    0x54, 
    0x17, 0x25, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x8e, 
    0x54, 
    0x17, 0x26, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_size & 0xff, MP_QSTR_size >> 8,
    0x54, 
    0x51, 0x03, 
    0x8f, 
    0x54, 
    0x17, 0x27, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x28, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x91, 
    0x54, 
    0x17, 0x29, 
    0x11, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x90, 
    0x54, 
    0x17, 0x2a, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x17, 0x2b, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x86, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_bdaddr & 0xff, MP_QSTR_bdaddr >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x92, 
    0x54, 
    0x17, 0x2c, 
    0x53, 0x07, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x82, 
    0xec, 
    0x17, 0x2d, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x84, 
    0xec, 
    0x17, 0x2e, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x86, 
    0xec, 
    0x16, MP_QSTR_latency & 0xff, MP_QSTR_latency >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x88, 
    0xec, 
    0x17, 0x2f, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x17, 0x30, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8c, 
    0xec, 
    0x17, 0x31, 
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x93, 
    0x54, 
    0x17, 0x32, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_map & 0xff, MP_QSTR_map >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x94, 
    0x54, 
    0x17, 0x33, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x83, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x85, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_map & 0xff, MP_QSTR_map >> 8,
    0x54, 
    0x51, 0x03, 
    0x95, 
    0x54, 
    0x17, 0x34, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x96, 
    0x54, 
    0x16, MP_QSTR_LE_ENCRYPT & 0xff, MP_QSTR_LE_ENCRYPT >> 8,
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x80, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_key & 0xff, MP_QSTR_key >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x90, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_plaintext & 0xff, MP_QSTR_plaintext >> 8,
    0x54, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_encdata & 0xff, MP_QSTR_encdata >> 8,
    0x54, 
    0x51, 0x03, 
    0x97, 
    0x54, 
    0x16, MP_QSTR_LE_RAND & 0xff, MP_QSTR_LE_RAND >> 8,
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_random & 0xff, MP_QSTR_random >> 8,
    0x54, 
    0x51, 0x03, 
    0x98, 
    0x54, 
    0x17, 0x35, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_random & 0xff, MP_QSTR_random >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x8a, 
    0xec, 
    0x17, 0x36, 
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x8c, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_key & 0xff, MP_QSTR_key >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x99, 
    0x54, 
    0x17, 0x37, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x82, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x90, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_key & 0xff, MP_QSTR_key >> 8,
    0x54, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x9a, 
    0x54, 
    0x17, 0x38, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x51, 0x03, 
    0x9b, 
    0x54, 
    0x17, 0x39, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_ARRAY & 0xff, MP_QSTR_ARRAY >> 8,
    0x81, 
    0xec, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x88, 
    0xec, 
    0x50, 0x02, 
    0x16, MP_QSTR_states & 0xff, MP_QSTR_states >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x9c, 
    0x54, 
    0x17, 0x3a, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_frequency & 0xff, MP_QSTR_frequency >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x9d, 
    0x54, 
    0x17, 0x3b, 
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_frequency & 0xff, MP_QSTR_frequency >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_payload & 0xff, MP_QSTR_payload >> 8,
    0x54, 
    0x53, 0x01, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x51, 0x03, 
    0x9e, 
    0x54, 
    0x17, 0x3c, 
    0x11, 
    0x53, 0x02, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x80, 
    0xec, 
    0x16, MP_QSTR_status & 0xff, MP_QSTR_status >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT16 & 0xff, MP_QSTR_UINT16 >> 8,
    0x81, 
    0xec, 
    0x16, MP_QSTR_num_pkts & 0xff, MP_QSTR_num_pkts >> 8,
    0x54, 
    0x51, 0x03, 
    0x9f, 
    0x54, 
    0x51, 0x02, 
    0x88, 
    0x54, 
    0x16, MP_QSTR_VENDOR_CMD & 0xff, MP_QSTR_VENDOR_CMD >> 8,
    0x11, 
    0x51, 0x02, 
    0x14, 0x3f, 
    0x54, 
    0x24, MP_QSTR_HCI_COMMANDS & 0xff, MP_QSTR_HCI_COMMANDS >> 8,
    0x20, 
    0x60, 0x3d, 
    0x16, MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_OPCODE & 0xff, MP_QSTR_OPCODE >> 8,
    0x20, 
    0x60, 0x3e, 
    0x16, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HCI_COMMAND & 0xff, MP_QSTR_HCI_COMMAND >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__0 = {{&mp_type_str}, 49899, 25, (const byte*)"\x52\x45\x41\x44\x5f\x54\x52\x41\x4e\x53\x4d\x49\x54\x5f\x50\x4f\x57\x45\x52\x5f\x4c\x45\x56\x45\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__1 = {{&mp_type_str}, 48933, 25, (const byte*)"\x53\x45\x54\x5f\x43\x4f\x4e\x54\x52\x4f\x4c\x4c\x45\x52\x5f\x54\x4f\x5f\x48\x4f\x53\x54\x5f\x46\x43"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__2 = {{&mp_type_str}, 9664, 18, (const byte*)"\x52\x45\x41\x44\x5f\x4c\x4f\x43\x41\x4c\x5f\x56\x45\x52\x53\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__3 = {{&mp_type_str}, 42434, 11, (const byte*)"\x68\x63\x69\x5f\x76\x65\x72\x73\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__4 = {{&mp_type_str}, 32395, 12, (const byte*)"\x68\x63\x69\x5f\x72\x65\x76\x69\x73\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__5 = {{&mp_type_str}, 28211, 15, (const byte*)"\x6c\x6d\x70\x5f\x70\x61\x6c\x5f\x76\x65\x72\x73\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__6 = {{&mp_type_str}, 45354, 17, (const byte*)"\x6d\x61\x6e\x75\x66\x61\x63\x74\x75\x72\x65\x72\x5f\x6e\x61\x6d\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__7 = {{&mp_type_str}, 24343, 18, (const byte*)"\x6c\x6d\x70\x5f\x70\x61\x6c\x5f\x73\x75\x62\x76\x65\x72\x73\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__8 = {{&mp_type_str}, 57250, 12, (const byte*)"\x52\x45\x41\x44\x5f\x42\x44\x5f\x41\x44\x44\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__9 = {{&mp_type_str}, 27073, 12, (const byte*)"\x53\x54\x41\x54\x55\x53\x5f\x50\x41\x52\x41\x4d"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__10 = {{&mp_type_str}, 15209, 17, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x45\x56\x45\x4e\x54\x5f\x4d\x41\x53\x4b"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__11 = {{&mp_type_str}, 41796, 19, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x42\x55\x46\x46\x45\x52\x5f\x53\x49\x5a\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__12 = {{&mp_type_str}, 29466, 32, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x4c\x4f\x43\x41\x4c\x5f\x53\x55\x50\x50\x4f\x52\x54\x45\x44\x5f\x46\x45\x41\x54\x55\x52\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__13 = {{&mp_type_str}, 2140, 21, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x52\x41\x4e\x44\x4f\x4d\x5f\x41\x44\x44\x52\x45\x53\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__14 = {{&mp_type_str}, 53240, 21, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x41\x44\x56\x5f\x50\x41\x52\x41\x4d\x45\x54\x45\x52\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__15 = {{&mp_type_str}, 55631, 12, (const byte*)"\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__16 = {{&mp_type_str}, 53393, 12, (const byte*)"\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__17 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__18 = {{&mp_type_str}, 36805, 18, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__19 = {{&mp_type_str}, 36034, 13, (const byte*)"\x64\x69\x72\x65\x63\x74\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__20 = {{&mp_type_str}, 39938, 28, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x41\x44\x56\x5f\x43\x48\x41\x4e\x4e\x45\x4c\x5f\x54\x58\x5f\x50\x4f\x57\x45\x52"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__21 = {{&mp_type_str}, 14226, 15, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x41\x44\x56\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__22 = {{&mp_type_str}, 10498, 25, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x53\x43\x41\x4e\x5f\x52\x45\x53\x50\x4f\x4e\x53\x45\x5f\x44\x41\x54\x41"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__23 = {{&mp_type_str}, 18463, 23, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x41\x44\x56\x45\x52\x54\x49\x53\x45\x5f\x45\x4e\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__24 = {{&mp_type_str}, 25780, 22, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x53\x43\x41\x4e\x5f\x50\x41\x52\x41\x4d\x45\x54\x45\x52\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__25 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__26 = {{&mp_type_str}, 40399, 18, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x53\x43\x41\x4e\x5f\x45\x4e\x41\x42\x4c\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__27 = {{&mp_type_str}, 40900, 14, (const byte*)"\x4c\x45\x5f\x43\x52\x45\x41\x54\x45\x5f\x43\x4f\x4e\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__28 = {{&mp_type_str}, 13921, 16, (const byte*)"\x69\x6e\x69\x74\x69\x61\x74\x6f\x72\x5f\x66\x69\x6c\x74\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__29 = {{&mp_type_str}, 25866, 16, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__30 = {{&mp_type_str}, 50221, 11, (const byte*)"\x70\x65\x65\x72\x5f\x62\x64\x61\x64\x64\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__31 = {{&mp_type_str}, 22814, 15, (const byte*)"\x6f\x77\x6e\x5f\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__32 = {{&mp_type_str}, 55631, 12, (const byte*)"\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__33 = {{&mp_type_str}, 53393, 12, (const byte*)"\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__34 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__35 = {{&mp_type_str}, 56501, 13, (const byte*)"\x6d\x69\x6e\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__36 = {{&mp_type_str}, 18859, 13, (const byte*)"\x6d\x61\x78\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__37 = {{&mp_type_str}, 37149, 21, (const byte*)"\x4c\x45\x5f\x43\x52\x45\x41\x54\x45\x5f\x43\x4f\x4e\x4e\x5f\x43\x41\x4e\x43\x45\x4c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__38 = {{&mp_type_str}, 20542, 23, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x57\x48\x49\x54\x45\x5f\x4c\x49\x53\x54\x5f\x53\x49\x5a\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__39 = {{&mp_type_str}, 4308, 27, (const byte*)"\x4c\x45\x5f\x41\x44\x44\x5f\x44\x45\x56\x49\x43\x45\x5f\x54\x4f\x5f\x57\x48\x49\x54\x45\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__40 = {{&mp_type_str}, 44727, 11, (const byte*)"\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__41 = {{&mp_type_str}, 58255, 19, (const byte*)"\x4c\x45\x5f\x43\x4c\x45\x41\x52\x5f\x57\x48\x49\x54\x45\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__42 = {{&mp_type_str}, 6974, 32, (const byte*)"\x4c\x45\x5f\x52\x45\x4d\x4f\x56\x45\x5f\x44\x45\x56\x49\x43\x45\x5f\x46\x52\x4f\x4d\x5f\x57\x48\x49\x54\x45\x5f\x4c\x49\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__43 = {{&mp_type_str}, 44727, 11, (const byte*)"\x62\x64\x61\x64\x64\x72\x5f\x74\x79\x70\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__44 = {{&mp_type_str}, 51313, 14, (const byte*)"\x4c\x45\x5f\x43\x4f\x4e\x4e\x5f\x55\x50\x44\x41\x54\x45"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__45 = {{&mp_type_str}, 55631, 12, (const byte*)"\x6d\x69\x6e\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__46 = {{&mp_type_str}, 53393, 12, (const byte*)"\x6d\x61\x78\x5f\x69\x6e\x74\x65\x72\x76\x61\x6c"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__47 = {{&mp_type_str}, 39524, 19, (const byte*)"\x73\x75\x70\x65\x72\x76\x69\x73\x69\x6f\x6e\x5f\x74\x69\x6d\x65\x6f\x75\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__48 = {{&mp_type_str}, 56501, 13, (const byte*)"\x6d\x69\x6e\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__49 = {{&mp_type_str}, 18859, 13, (const byte*)"\x6d\x61\x78\x5f\x63\x65\x5f\x6c\x65\x6e\x67\x74\x68"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__50 = {{&mp_type_str}, 62523, 34, (const byte*)"\x4c\x45\x5f\x53\x45\x54\x5f\x48\x4f\x53\x54\x5f\x43\x48\x41\x4e\x4e\x45\x4c\x5f\x43\x4c\x41\x53\x53\x49\x46\x49\x43\x41\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__51 = {{&mp_type_str}, 20030, 19, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x43\x48\x41\x4e\x4e\x45\x4c\x5f\x4d\x41\x50"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__52 = {{&mp_type_str}, 18906, 28, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x52\x45\x4d\x4f\x54\x45\x5f\x55\x53\x45\x44\x5f\x46\x45\x41\x54\x55\x52\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__53 = {{&mp_type_str}, 13827, 19, (const byte*)"\x4c\x45\x5f\x53\x54\x41\x52\x54\x5f\x45\x4e\x43\x52\x59\x50\x54\x49\x4f\x4e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__54 = {{&mp_type_str}, 52811, 11, (const byte*)"\x64\x69\x76\x65\x72\x73\x69\x66\x69\x65\x72"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__55 = {{&mp_type_str}, 34925, 12, (const byte*)"\x4c\x45\x5f\x4c\x54\x4b\x5f\x52\x45\x50\x4c\x59"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__56 = {{&mp_type_str}, 31294, 16, (const byte*)"\x4c\x45\x5f\x4c\x54\x4b\x5f\x4e\x45\x47\x5f\x52\x45\x50\x4c\x59"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__57 = {{&mp_type_str}, 55083, 24, (const byte*)"\x4c\x45\x5f\x52\x45\x41\x44\x5f\x53\x55\x50\x50\x4f\x52\x54\x45\x44\x5f\x53\x54\x41\x54\x45\x53"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__58 = {{&mp_type_str}, 38851, 16, (const byte*)"\x4c\x45\x5f\x52\x45\x43\x45\x49\x56\x45\x52\x5f\x54\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__59 = {{&mp_type_str}, 50067, 19, (const byte*)"\x4c\x45\x5f\x54\x52\x41\x4e\x53\x4d\x49\x54\x54\x45\x52\x5f\x54\x45\x53\x54"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__60 = {{&mp_type_str}, 14101, 11, (const byte*)"\x4c\x45\x5f\x54\x45\x53\x54\x5f\x45\x4e\x44"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_[63] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__24),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__25),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__26),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__27),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__28),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__29),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__30),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__31),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__32),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__33),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__34),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__35),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__36),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__37),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__38),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__39),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__40),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__41),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__42),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__43),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__44),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__45),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__46),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__47),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__48),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__49),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__50),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__51),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__52),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__53),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__54),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__55),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__56),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__57),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__58),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__59),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__60),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__OPCODE),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt__HCI_COMMAND),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 2741,
        .n_obj = 61,
        .n_raw_code = 2,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__[39] = {
    0x05, 0x00, 0x00, 0x03, 0x00, 0x01, 0x0b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x81, 0x4a, 0x25, 0x29, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__opcode & 0xff, MP_QSTR__opcode >> 8,
    0x1c, MP_QSTR_ATT_PDUS & 0xff, MP_QSTR_ATT_PDUS >> 8,
    0xb1, 
    0x21, 
    0xb0, 
    0x26, MP_QSTR__opcode_name & 0xff, MP_QSTR__opcode_name >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_opcode),
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__[98] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x10,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x81, 0x4f, 0x28, 0x25, 0x27, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__opcode & 0xff, MP_QSTR__opcode >> 8,
    0x5b, 
    0xb1, 
    0x17, 0x02, 
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__opcode_name & 0xff, MP_QSTR__opcode_name >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr___0 = {{&mp_type_str}, 21647, 11, (const byte*)"\x6f\x70\x63\x6f\x64\x65\x5f\x6e\x61\x6d\x65"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 98,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__[61] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x81, 0x59, 0x20, 0x63, 0x24, 0x27, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_opcode_name & 0xff, MP_QSTR_opcode_name >> 8,
    0xb0, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x05, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str___0 = {{&mp_type_str}, 19132, 50, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x6f\x70\x63\x6f\x64\x65\x3d\x7b\x3a\x73\x7d\x28\x30\x78\x7b\x3a\x30\x32\x78\x7d\x29\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 61,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer[108] = {
    0x0a, 0x00, 0x00, 0x01, 0x00, 0x00, 0x10,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x81, 0x67, 0x80, 0x12, 0x5c, 0x26, 0x56, 0x69, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_unpack & 0xff, MP_QSTR_unpack >> 8,
    0x1c, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x02, 
    0x80, 
    0x21, 
    0xc1, 
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x01, 
    0x1c, MP_QSTR_ATT_STRUCT & 0xff, MP_QSTR_ATT_STRUCT >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0xc2, 
    0xb0, 
    0x1c, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0xb1, 
    0xb0, 
    0x64, 0x02, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 108,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer[39] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x81, 0x85, 0x60, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_opcode & 0xff, MP_QSTR_opcode >> 8,
    0x66, 0x02, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT[96] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x8d, 0x45, 0x20, 0x26, 0x4e, 0x6a, 0x40, 0x85, 0x0a, 0x85, 0x0d, 0x8a, 0x1f, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_B & 0xff, MP_QSTR__lt_B >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x17, 0x00, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 96,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/att.py, scope bluetooth_low_energy_protocols_hci_att_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt_[329] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_att_dot_py >> 8,
    0x21, 0x28, 0x28, 0x59, 0x80, 0x08, 0x22, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x26, 0x26, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x67, 0x80, 0x12, 0x22, 0x3e, 0x3e, 0x1f, 0x62, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x53, 0x1c, 
    0x17, 0x00, 
    0x81, 
    0x54, 
    0x17, 0x01, 
    0x82, 
    0x54, 
    0x17, 0x02, 
    0x83, 
    0x54, 
    0x17, 0x03, 
    0x84, 
    0x54, 
    0x17, 0x04, 
    0x85, 
    0x54, 
    0x17, 0x05, 
    0x86, 
    0x54, 
    0x17, 0x06, 
    0x87, 
    0x54, 
    0x17, 0x07, 
    0x88, 
    0x54, 
    0x17, 0x08, 
    0x89, 
    0x54, 
    0x17, 0x09, 
    0x8a, 
    0x54, 
    0x17, 0x0a, 
    0x8b, 
    0x54, 
    0x17, 0x0b, 
    0x8c, 
    0x54, 
    0x17, 0x0c, 
    0x8d, 
    0x54, 
    0x17, 0x0d, 
    0x8e, 
    0x54, 
    0x17, 0x0e, 
    0x8f, 
    0x54, 
    0x17, 0x0f, 
    0x90, 
    0x54, 
    0x17, 0x10, 
    0x91, 
    0x54, 
    0x17, 0x11, 
    0x92, 
    0x54, 
    0x17, 0x12, 
    0x93, 
    0x54, 
    0x17, 0x13, 
    0x14, 0x80, 0x52, 
    0x54, 
    0x17, 0x14, 
    0x14, 0x81, 0x52, 
    0x54, 
    0x17, 0x15, 
    0x96, 
    0x54, 
    0x17, 0x16, 
    0x97, 
    0x54, 
    0x17, 0x17, 
    0x98, 
    0x54, 
    0x17, 0x18, 
    0x99, 
    0x54, 
    0x17, 0x19, 
    0x9b, 
    0x54, 
    0x17, 0x1a, 
    0x9d, 
    0x54, 
    0x17, 0x1b, 
    0x9e, 
    0x54, 
    0x24, MP_QSTR_ATT_PDUS & 0xff, MP_QSTR_ATT_PDUS >> 8,
    0x53, 0x03, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT8 & 0xff, MP_QSTR_BFUINT8 >> 8,
    0x80, 
    0xec, 
    0x80, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x86, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_a & 0xff, MP_QSTR_a >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT8 & 0xff, MP_QSTR_BFUINT8 >> 8,
    0x80, 
    0xec, 
    0x86, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x81, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_b & 0xff, MP_QSTR_b >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT8 & 0xff, MP_QSTR_BFUINT8 >> 8,
    0x80, 
    0xec, 
    0x87, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x81, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_c & 0xff, MP_QSTR_c >> 8,
    0x54, 
    0x24, MP_QSTR_ATT_STRUCT & 0xff, MP_QSTR_ATT_STRUCT >> 8,
    0x20, 
    0x60, 0x1c, 
    0x16, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_ATT & 0xff, MP_QSTR_ATT >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__0 = {{&mp_type_str}, 57121, 14, (const byte*)"\x45\x72\x72\x6f\x72\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__1 = {{&mp_type_str}, 52995, 20, (const byte*)"\x45\x78\x63\x68\x61\x6e\x67\x65\x5f\x4d\x54\x55\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__2 = {{&mp_type_str}, 40113, 21, (const byte*)"\x45\x78\x63\x68\x61\x6e\x67\x65\x5f\x4d\x54\x55\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__3 = {{&mp_type_str}, 28093, 24, (const byte*)"\x46\x69\x6e\x64\x5f\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__4 = {{&mp_type_str}, 24911, 25, (const byte*)"\x46\x69\x6e\x64\x5f\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__5 = {{&mp_type_str}, 63321, 26, (const byte*)"\x46\x69\x6e\x64\x5f\x42\x79\x5f\x54\x79\x70\x65\x5f\x56\x61\x6c\x75\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__6 = {{&mp_type_str}, 40235, 27, (const byte*)"\x46\x69\x6e\x64\x5f\x42\x79\x5f\x54\x79\x70\x65\x5f\x56\x61\x6c\x75\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__7 = {{&mp_type_str}, 44890, 20, (const byte*)"\x52\x65\x61\x64\x5f\x42\x79\x5f\x54\x79\x70\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__8 = {{&mp_type_str}, 56776, 21, (const byte*)"\x52\x65\x61\x64\x5f\x42\x79\x5f\x54\x79\x70\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__9 = {{&mp_type_str}, 21081, 12, (const byte*)"\x52\x65\x61\x64\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__10 = {{&mp_type_str}, 22571, 13, (const byte*)"\x52\x65\x61\x64\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__11 = {{&mp_type_str}, 6693, 17, (const byte*)"\x52\x65\x61\x64\x5f\x42\x6c\x6f\x62\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__12 = {{&mp_type_str}, 40151, 18, (const byte*)"\x52\x65\x61\x64\x5f\x42\x6c\x6f\x62\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__13 = {{&mp_type_str}, 43734, 21, (const byte*)"\x52\x65\x61\x64\x5f\x4d\x75\x6c\x74\x69\x70\x6c\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__14 = {{&mp_type_str}, 43460, 22, (const byte*)"\x52\x65\x61\x64\x5f\x4d\x75\x6c\x74\x69\x70\x6c\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__15 = {{&mp_type_str}, 33754, 26, (const byte*)"\x52\x65\x61\x64\x5f\x42\x79\x5f\x47\x72\x6f\x75\x70\x5f\x54\x79\x70\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__16 = {{&mp_type_str}, 16968, 27, (const byte*)"\x52\x65\x61\x64\x5f\x42\x79\x5f\x47\x72\x6f\x75\x70\x5f\x54\x79\x70\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__17 = {{&mp_type_str}, 11702, 13, (const byte*)"\x57\x72\x69\x74\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__18 = {{&mp_type_str}, 60132, 14, (const byte*)"\x57\x72\x69\x74\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__19 = {{&mp_type_str}, 21952, 13, (const byte*)"\x57\x72\x69\x74\x65\x5f\x43\x6f\x6d\x6d\x61\x6e\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__20 = {{&mp_type_str}, 33997, 20, (const byte*)"\x53\x69\x67\x6e\x65\x64\x5f\x57\x72\x69\x74\x65\x5f\x43\x6f\x6d\x6d\x61\x6e\x64"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__21 = {{&mp_type_str}, 29320, 21, (const byte*)"\x50\x72\x65\x70\x61\x72\x65\x5f\x57\x72\x69\x74\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__22 = {{&mp_type_str}, 14170, 22, (const byte*)"\x50\x72\x65\x70\x61\x72\x65\x5f\x57\x72\x69\x74\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__23 = {{&mp_type_str}, 10230, 21, (const byte*)"\x45\x78\x65\x63\x75\x74\x65\x5f\x57\x72\x69\x74\x65\x5f\x52\x65\x71\x75\x65\x73\x74"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__24 = {{&mp_type_str}, 43684, 22, (const byte*)"\x45\x78\x65\x63\x75\x74\x65\x5f\x57\x72\x69\x74\x65\x5f\x52\x65\x73\x70\x6f\x6e\x73\x65"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__25 = {{&mp_type_str}, 24841, 25, (const byte*)"\x48\x61\x6e\x64\x6c\x65\x5f\x56\x61\x6c\x75\x65\x5f\x4e\x6f\x74\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__26 = {{&mp_type_str}, 7792, 23, (const byte*)"\x48\x61\x6e\x64\x6c\x65\x5f\x56\x61\x6c\x75\x65\x5f\x49\x6e\x64\x69\x63\x61\x74\x69\x6f\x6e"};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__27 = {{&mp_type_str}, 53387, 25, (const byte*)"\x48\x61\x6e\x64\x6c\x65\x5f\x56\x61\x6c\x75\x65\x5f\x43\x6f\x6e\x66\x69\x72\x6d\x61\x74\x69\x6f\x6e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt_[29] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__0),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__1),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__2),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__3),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__4),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__5),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__6),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__7),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__8),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__9),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__10),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__11),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__12),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__13),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__14),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__15),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__16),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__17),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__18),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__19),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__20),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__21),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__22),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__23),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__24),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__25),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__26),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_att__lt_module_gt__27),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt__ATT),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_att__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 329,
        .n_obj = 28,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__[80] = {
    0x0c, 0x00, 0x00, 0x05, 0x00, 0x03, 0x0f,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x81, 0x1b, 0x25, 0x54, 0x25, 0x25, 0x25, 0x2b, 0x00, 0x00, 0xff,
    0x17, 0x05, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb4, 
    0x37, 0x09, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb4, 
    0x64, 0x01, 
    0x35, 0x01, 0x80, 
    0x80, 
    0xb3, 
    0xb2, 
    0xb1, 
    0x66, 0x04, 
    0xc5, 
    0xb1, 
    0xb0, 
    0x26, MP_QSTR__handle & 0xff, MP_QSTR__handle >> 8,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR__ps & 0xff, MP_QSTR__ps >> 8,
    0xb3, 
    0xb0, 
    0x26, MP_QSTR__xx & 0xff, MP_QSTR__xx >> 8,
    0x1c, MP_QSTR_int & 0xff, MP_QSTR_int >> 8,
    0xb5, 
    0x82, 
    0x64, 0x02, 
    0xb0, 
    0x26, MP_QSTR__tobytes & 0xff, MP_QSTR__tobytes >> 8,
    0xb4, 
    0xb0, 
    0x26, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init___0 = {{&mp_type_str}, 39713, 26, (const byte*)"\x7b\x3a\x30\x31\x36\x62\x7d\x7b\x3a\x30\x32\x62\x7d\x7b\x3a\x30\x32\x62\x7d\x7b\x3a\x30\x31\x32\x62\x7d"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__[6] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_handle),
    MP_ROM_QSTR(MP_QSTR_ps),
    MP_ROM_QSTR(MP_QSTR_xx),
    MP_ROM_QSTR(MP_QSTR_data),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 5,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 80,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__[129] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x14,
    MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x81, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x25, 0x28, 0x33, 0x28, 0x00, 0x00, 0xff,
    0xb1, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__handle & 0xff, MP_QSTR__handle >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_ps & 0xff, MP_QSTR_ps >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__ps & 0xff, MP_QSTR__ps >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_xx & 0xff, MP_QSTR_xx >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__xx & 0xff, MP_QSTR__xx >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_tobytes & 0xff, MP_QSTR_tobytes >> 8,
    0xd9, 
    0x37, 0x05, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__tobytes & 0xff, MP_QSTR__tobytes >> 8,
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0xd9, 
    0x37, 0x13, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x64, 0x01, 
    0x5b, 
    0x80, 
    0x5b, 
    0xb1, 
    0x16, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xd9, 
    0x37, 0x0d, 0x80, 
    0xb0, 
    0x1d, MP_QSTR__data & 0xff, MP_QSTR__data >> 8,
    0x11, 
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x58, 0x02, 
    0x21, 
    0x5b, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 129,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__[67] = {
    0x0b, 0x00, 0x00, 0x01, 0x00, 0x00, 0x12,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x81, 0x33, 0x20, 0x63, 0x20, 0x24, 0x27, 0x24, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0xc1, 
    0xb1, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0x1d, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0xb0, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb0, 
    0x1d, MP_QSTR_ps & 0xff, MP_QSTR_ps >> 8,
    0xb0, 
    0x1d, MP_QSTR_xx & 0xff, MP_QSTR_xx >> 8,
    0xb0, 
    0x1d, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x1c, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0x64, 0x01, 
    0x66, 0x06, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str___0 = {{&mp_type_str}, 9071, 68, (const byte*)"\x3c\x7b\x3a\x73\x7d\x20\x68\x61\x6e\x64\x6c\x65\x3d\x30\x78\x7b\x3a\x30\x34\x78\x7d\x20\x70\x73\x3d\x30\x78\x7b\x3a\x30\x32\x78\x7d\x20\x78\x78\x3d\x30\x78\x7b\x3a\x30\x32\x78\x7d\x20\x6c\x65\x6e\x67\x74\x68\x3d\x7b\x3a\x64\x7d\x20\x64\x61\x74\x61\x3d\x7b\x3a\x73\x7d\x3e"};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str___0),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 67,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer[90] = {
    0x09, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0f,
    MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x81, 0x43, 0x80, 0x09, 0x26, 0x56, 0x49, 0x2c, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_struct & 0xff, MP_QSTR_struct >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1e, MP_QSTR_addressof & 0xff, MP_QSTR_addressof >> 8,
    0xb0, 
    0x11, 
    0x1c, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x58, 0x02, 
    0x21, 
    0x66, 0x01, 
    0x1c, MP_QSTR_HCI_SCO_STRUCT & 0xff, MP_QSTR_HCI_SCO_STRUCT >> 8,
    0x1c, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_LITTLE_ENDIAN & 0xff, MP_QSTR_LITTLE_ENDIAN >> 8,
    0x66, 0x03, 
    0xc1, 
    0xb0, 
    0x1c, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0x1d, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x11, 
    0x58, 0x02, 
    0x21, 
    0xc0, 
    0x1c, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0xb1, 
    0x1d, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0xb1, 
    0x1d, MP_QSTR_ps & 0xff, MP_QSTR_ps >> 8,
    0xb1, 
    0x1d, MP_QSTR_xx & 0xff, MP_QSTR_xx >> 8,
    0xb0, 
    0x64, 0x04, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_data),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 90,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer[39] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0a,
    MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x81, 0x55, 0x60, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_pack & 0xff, MP_QSTR_pack >> 8,
    0xb0, 
    0x1d, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_tobytes & 0xff, MP_QSTR_tobytes >> 8,
    0x66, 0x02, 
    0xb0, 
    0x1d, MP_QSTR_data & 0xff, MP_QSTR_data >> 8,
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 39,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO[98] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14,
    MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x8d, 0x16, 0x20, 0x26, 0x4e, 0x8c, 0x0a, 0x85, 0x0e, 0x85, 0x0f, 0x8a, 0x13, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x16, MP_QSTR__lt_HB & 0xff, MP_QSTR__lt_HB >> 8,
    0x24, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x1b, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x1e, MP_QSTR_calcsize & 0xff, MP_QSTR_calcsize >> 8,
    0x1b, MP_QSTR__struct_format & 0xff, MP_QSTR__struct_format >> 8,
    0x66, 0x01, 
    0x24, MP_QSTR__struct_size & 0xff, MP_QSTR__struct_size >> 8,
    0x80, 
    0x80, 
    0x17, 0x00, 
    0x50, 0x03, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getattr__ & 0xff, MP_QSTR___getattr__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x60, 0x04, 
    0x64, 0x01, 
    0x24, MP_QSTR_from_buffer & 0xff, MP_QSTR_from_buffer >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_to_buffer & 0xff, MP_QSTR_to_buffer >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_0 = {{&mp_type_bytes}, 5381, 0, (const byte*)""};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO[6] = {
    MP_ROM_PTR(&const_obj_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_0),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___init__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___getattr__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO___str__),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_from_buffer),
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO_to_buffer),
};
STATIC const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 98,
        .n_obj = 1,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/sco.py, scope bluetooth_low_energy_protocols_hci_sco_<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_[206] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x13,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash_sco_dot_py >> 8,
    0x21, 0x28, 0x28, 0x39, 0x50, 0x80, 0x08, 0x22, 0x3e, 0x3e, 0x3e, 0x6f, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x16, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ubinascii & 0xff, MP_QSTR_ubinascii >> 8,
    0x69, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x24, MP_QSTR_hexlify & 0xff, MP_QSTR_hexlify >> 8,
    0x69, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x24, MP_QSTR_unhexlify & 0xff, MP_QSTR_unhexlify >> 8,
    0x32, 
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x53, 0x04, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x80, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x8c, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_handle & 0xff, MP_QSTR_handle >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x8c, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x82, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_ps & 0xff, MP_QSTR_ps >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BFUINT16 & 0xff, MP_QSTR_BFUINT16 >> 8,
    0x80, 
    0xec, 
    0x8e, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_POS & 0xff, MP_QSTR_BF_POS >> 8,
    0xef, 
    0xec, 
    0x82, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_BF_LEN & 0xff, MP_QSTR_BF_LEN >> 8,
    0xef, 
    0xec, 
    0x16, MP_QSTR_xx & 0xff, MP_QSTR_xx >> 8,
    0x54, 
    0x1b, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x1d, MP_QSTR_UINT8 & 0xff, MP_QSTR_UINT8 >> 8,
    0x82, 
    0xec, 
    0x16, MP_QSTR_length & 0xff, MP_QSTR_length >> 8,
    0x54, 
    0x24, MP_QSTR_HCI_SCO_STRUCT & 0xff, MP_QSTR_HCI_SCO_STRUCT >> 8,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_HCI_SCO & 0xff, MP_QSTR_HCI_SCO >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt__HCI_SCO),
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 206,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file bluetooth_low_energy/protocols/hci/__init__.py, scope bluetooth_low_energy_protocols_hci___init___<module>
STATIC const byte bytecode_data_bluetooth_low_energy_protocols_hci___init____lt_module_gt_[100] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x15,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash___init___dot_py & 0xff, MP_QSTR_bluetooth_low_energy_slash_protocols_slash_hci_slash___init___dot_py >> 8,
    0x21, 0x28, 0x28, 0x50, 0x60, 0x20, 0x46, 0x46, 0x64, 0x20, 0x24, 0x24, 0x24, 0x24, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x24, MP_QSTR_ustruct & 0xff, MP_QSTR_ustruct >> 8,
    0x80, 
    0x11, 
    0x68, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x24, MP_QSTR_uctypes & 0xff, MP_QSTR_uctypes >> 8,
    0x80, 
    0x16, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_micropython & 0xff, MP_QSTR_micropython >> 8,
    0x69, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x24, MP_QSTR_const & 0xff, MP_QSTR_const >> 8,
    0x32, 
    0x14, 0x81, 0x00, 
    0x24, MP_QSTR_HCI_MAX_PAYLOAD_SIZE & 0xff, MP_QSTR_HCI_MAX_PAYLOAD_SIZE >> 8,
    0x14, 0x81, 0x00, 
    0x24, MP_QSTR_HCI_READ_PACKET_SIZE & 0xff, MP_QSTR_HCI_READ_PACKET_SIZE >> 8,
    0x82, 
    0x24, MP_QSTR_HCI_EVENT_HDR_SIZE & 0xff, MP_QSTR_HCI_EVENT_HDR_SIZE >> 8,
    0x81, 
    0x24, MP_QSTR_HCI_COMMAND_PKT & 0xff, MP_QSTR_HCI_COMMAND_PKT >> 8,
    0x82, 
    0x24, MP_QSTR_HCI_ACLDATA_PKT & 0xff, MP_QSTR_HCI_ACLDATA_PKT >> 8,
    0x83, 
    0x24, MP_QSTR_HCI_SCODATA_PKT & 0xff, MP_QSTR_HCI_SCODATA_PKT >> 8,
    0x84, 
    0x24, MP_QSTR_HCI_EVENT_PKT & 0xff, MP_QSTR_HCI_EVENT_PKT >> 8,
    0x14, 0x81, 0x7f, 
    0x24, MP_QSTR_HCI_VENDOR_PKT & 0xff, MP_QSTR_HCI_VENDOR_PKT >> 8,
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_bluetooth_low_energy_protocols_hci___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_bluetooth_low_energy_protocols_hci___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 100,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger___init__
STATIC const byte bytecode_data_logging__lt_module_gt__Logger___init__[37] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0a,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x16, 0x27, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_NOTSET & 0xff, MP_QSTR_NOTSET >> 8,
    0xb0, 
    0x26, MP_QSTR_level & 0xff, MP_QSTR_level >> 8,
    0xb1, 
    0x38, 0x03, 0x80, 
    0x16, MP_QSTR_root & 0xff, MP_QSTR_root >> 8,
    0xb0, 
    0x26, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger___init__,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 37,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger__level_str
STATIC const byte bytecode_data_logging__lt_module_gt__Logger__level_str[44] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0c,
    MP_QSTR__level_str & 0xff, MP_QSTR__level_str >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x1a, 0x20, 0x28, 0x26, 0x00, 0x00, 0xff,
    0xb1, 
    0x1c, MP_QSTR__level_dict & 0xff, MP_QSTR__level_dict >> 8,
    0xdd, 
    0x37, 0x06, 0x80, 
    0x1c, MP_QSTR__level_dict & 0xff, MP_QSTR__level_dict >> 8,
    0xb1, 
    0x21, 
    0x5b, 
    0x16, MP_QSTR_LVL & 0xff, MP_QSTR_LVL >> 8,
    0x1c, MP_QSTR_str & 0xff, MP_QSTR_str >> 8,
    0xb1, 
    0x64, 0x01, 
    0xf1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger__level_str[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_level),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger__level_str = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger__level_str,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger__level_str,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 44,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_log
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_log[194] = {
    0x11, 0x02, 0x03, 0x03, 0x00, 0x00, 0x16,
    MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x20, 0x20, 0x2f, 0x2e, 0x32, 0x23, 0x1f, 0x42, 0x23, 0x1f, 0x61, 0x40, 0x36, 0x2e, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x1d, MP_QSTR_level & 0xff, MP_QSTR_level >> 8,
    0x38, 0x03, 0x80, 
    0x1c, MP_QSTR__level & 0xff, MP_QSTR__level >> 8,
    0xdb, 
    0x37, 0x94, 0x80, 
    0xb0, 
    0x1e, MP_QSTR__level_str & 0xff, MP_QSTR__level_str >> 8,
    0xb1, 
    0x66, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_name & 0xff, MP_QSTR_name >> 8,
    0x51, 0x02, 
    0xc5, 
    0x16, MP_QSTR__colon_ & 0xff, MP_QSTR__colon_ >> 8,
    0x1e, MP_QSTR_join & 0xff, MP_QSTR_join >> 8,
    0x1c, MP_QSTR_map & 0xff, MP_QSTR_map >> 8,
    0x1c, MP_QSTR_str & 0xff, MP_QSTR_str >> 8,
    0xb5, 
    0x64, 0x02, 
    0x66, 0x01, 
    0xc6, 
    0x3f, 0x15, 0x00, 
    0x1c, MP_QSTR_print & 0xff, MP_QSTR_print >> 8,
    0xb6, 
    0xb2, 
    0xb3, 
    0xf6, 
    0x16, MP_QSTR_file & 0xff, MP_QSTR_file >> 8,
    0x1c, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x64, 0x82, 0x02, 
    0x32, 
    0x44, 
    0x35, 0x2f, 0x80, 
    0x30, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0xdf, 
    0x37, 0x26, 0x80, 
    0xc7, 
    0x40, 0x1a, 0x00, 
    0x1c, MP_QSTR_print & 0xff, MP_QSTR_print >> 8,
    0x17, 0x03, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb7, 
    0xb2, 
    0xb3, 
    0x66, 0x03, 
    0x16, MP_QSTR_file & 0xff, MP_QSTR_file >> 8,
    0x1c, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x64, 0x82, 0x01, 
    0x32, 
    0x44, 
    0x45, 
    0x11, 
    0x11, 
    0xc7, 
    0x28, 0x07, 
    0x41, 
    0x35, 0x01, 0x80, 
    0x41, 
    0x1c, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x1c, MP_QSTR_sys & 0xff, MP_QSTR_sys >> 8,
    0x1d, MP_QSTR_stderr & 0xff, MP_QSTR_stderr >> 8,
    0x1c, MP_QSTR_sys & 0xff, MP_QSTR_sys >> 8,
    0x1d, MP_QSTR_stdout & 0xff, MP_QSTR_stdout >> 8,
    0x50, 0x02, 
    0xdd, 
    0xd3, 
    0x37, 0x17, 0x80, 
    0x1c, MP_QSTR_hasattr & 0xff, MP_QSTR_hasattr >> 8,
    0x1c, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x16, MP_QSTR_flush & 0xff, MP_QSTR_flush >> 8,
    0x64, 0x02, 
    0x37, 0x09, 0x80, 
    0x1c, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x1e, MP_QSTR_flush & 0xff, MP_QSTR_flush >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_logging__lt_module_gt__Logger_log_0 = {{&mp_type_str}, 53642, 56, (const byte*)"\x2d\x2d\x2d\x20\x4c\x6f\x67\x67\x69\x6e\x67\x20\x65\x72\x72\x6f\x72\x20\x2d\x2d\x2d\x0a\x7b\x21\x72\x7d\x0a\x4d\x65\x73\x73\x61\x67\x65\x3a\x20\x7b\x21\x72\x7d\x0a\x41\x72\x67\x75\x6d\x65\x6e\x74\x73\x3a\x20\x7b\x21\x72\x7d"};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_log[4] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_level),
    MP_ROM_QSTR(MP_QSTR_msg),
    MP_ROM_PTR(&const_obj_logging__lt_module_gt__Logger_log_0),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_log = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_log,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_log,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 194,
        .n_obj = 1,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_debug
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_debug[31] = {
    0x0a, 0x00, 0x03, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_debug & 0xff, MP_QSTR_debug >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x32, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x1c, MP_QSTR_DEBUG & 0xff, MP_QSTR_DEBUG >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x67, 0x02, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_debug[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_debug = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_debug,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_debug,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_info
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_info[31] = {
    0x0a, 0x00, 0x03, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_info & 0xff, MP_QSTR_info >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x35, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x1c, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x67, 0x02, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_info[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_info = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_info,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_info,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_warning
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_warning[31] = {
    0x0a, 0x00, 0x03, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_warning & 0xff, MP_QSTR_warning >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x38, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x1c, MP_QSTR_WARNING & 0xff, MP_QSTR_WARNING >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x67, 0x02, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_warning[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_warning = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_warning,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_warning,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_error
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_error[31] = {
    0x0a, 0x00, 0x03, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_error & 0xff, MP_QSTR_error >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x3b, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x1c, MP_QSTR_ERROR & 0xff, MP_QSTR_ERROR >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x67, 0x02, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_error[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_error = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_error,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_error,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger_critical
STATIC const byte bytecode_data_logging__lt_module_gt__Logger_critical[31] = {
    0x0a, 0x00, 0x03, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_critical & 0xff, MP_QSTR_critical >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x3e, 0x00, 0x00, 0xff,
    0xb0, 
    0x1e, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x1c, MP_QSTR_CRITICAL & 0xff, MP_QSTR_CRITICAL >> 8,
    0xb1, 
    0xb2, 
    0xb3, 
    0x67, 0x02, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger_critical[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger_critical = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x03,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger_critical,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger_critical,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 31,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__Logger
STATIC const byte bytecode_data_logging__lt_module_gt__Logger[80] = {
    0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x13,
    MP_QSTR_Logger & 0xff, MP_QSTR_Logger >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x8d, 0x15, 0x65, 0x20, 0x65, 0x60, 0x85, 0x12, 0x65, 0x65, 0x65, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_Logger & 0xff, MP_QSTR_Logger >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x60, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR__level_str & 0xff, MP_QSTR__level_str >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR_log & 0xff, MP_QSTR_log >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR_debug & 0xff, MP_QSTR_debug >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR_info & 0xff, MP_QSTR_info >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_warning & 0xff, MP_QSTR_warning >> 8,
    0x60, 0x06, 
    0x24, MP_QSTR_error & 0xff, MP_QSTR_error >> 8,
    0x60, 0x07, 
    0x24, MP_QSTR_critical & 0xff, MP_QSTR_critical >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__Logger[8] = {
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger___init__),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger__level_str),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_log),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_debug),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_info),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_warning),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_error),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger_critical),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__Logger = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__Logger,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__Logger,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 80,
        .n_obj = 0,
        .n_raw_code = 8,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__getLogger
STATIC const byte bytecode_data_logging__lt_module_gt__getLogger[50] = {
    0x05, 0x00, 0x00, 0x01, 0x00, 0x01, 0x0e,
    MP_QSTR_getLogger & 0xff, MP_QSTR_getLogger >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x45, 0x20, 0x28, 0x26, 0x27, 0x26, 0x00, 0x00, 0xff,
    0xb0, 
    0x1c, MP_QSTR__loggers & 0xff, MP_QSTR__loggers >> 8,
    0xdd, 
    0x37, 0x06, 0x80, 
    0x1c, MP_QSTR__loggers & 0xff, MP_QSTR__loggers >> 8,
    0xb0, 
    0x21, 
    0x5b, 
    0x1c, MP_QSTR_Logger & 0xff, MP_QSTR_Logger >> 8,
    0xb0, 
    0x64, 0x01, 
    0xc1, 
    0xb1, 
    0x1c, MP_QSTR__loggers & 0xff, MP_QSTR__loggers >> 8,
    0xb0, 
    0x27, 
    0xb1, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__getLogger[1] = {
    MP_ROM_QSTR(MP_QSTR_name),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__getLogger = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__getLogger,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__getLogger,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 50,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__info
STATIC const byte bytecode_data_logging__lt_module_gt__info[33] = {
    0x07, 0x00, 0x01, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_info & 0xff, MP_QSTR_info >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x4d, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_getLogger & 0xff, MP_QSTR_getLogger >> 8,
    0x11, 
    0x64, 0x01, 
    0x1e, MP_QSTR_info & 0xff, MP_QSTR_info >> 8,
    0xb0, 
    0xb1, 
    0x18, 
    0x67, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__info[1] = {
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__info = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x01,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__info,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__info,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 33,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__debug
STATIC const byte bytecode_data_logging__lt_module_gt__debug[33] = {
    0x07, 0x00, 0x01, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_debug & 0xff, MP_QSTR_debug >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x50, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_getLogger & 0xff, MP_QSTR_getLogger >> 8,
    0x11, 
    0x64, 0x01, 
    0x1e, MP_QSTR_debug & 0xff, MP_QSTR_debug >> 8,
    0xb0, 
    0xb1, 
    0x18, 
    0x67, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__debug[1] = {
    MP_ROM_QSTR(MP_QSTR_msg),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__debug = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x01,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__debug,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__debug,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 33,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging__lt_module_gt__basicConfig
STATIC const byte bytecode_data_logging__lt_module_gt__basicConfig[71] = {
    0x06, 0x00, 0x00, 0x04, 0x00, 0x04, 0x10,
    MP_QSTR_basicConfig & 0xff, MP_QSTR_basicConfig >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x81, 0x53, 0x20, 0x24, 0x24, 0x24, 0x27, 0x2a, 0x27, 0x00, 0x00, 0xff,
    0xb0, 
    0x25, MP_QSTR__level & 0xff, MP_QSTR__level >> 8,
    0xb2, 
    0x37, 0x04, 0x80, 
    0xb2, 
    0x25, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0xb1, 
    0x11, 
    0xde, 
    0xd3, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_AttributeError & 0xff, MP_QSTR_AttributeError >> 8,
    0x16, MP_QSTR_filename & 0xff, MP_QSTR_filename >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb3, 
    0x11, 
    0xde, 
    0xd3, 
    0x37, 0x0a, 0x80, 
    0x1c, MP_QSTR_AttributeError & 0xff, MP_QSTR_AttributeError >> 8,
    0x16, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0x64, 0x01, 
    0x5c, 0x01, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt__basicConfig[4] = {
    MP_ROM_QSTR(MP_QSTR_level),
    MP_ROM_QSTR(MP_QSTR_filename),
    MP_ROM_QSTR(MP_QSTR_stream),
    MP_ROM_QSTR(MP_QSTR_format),
};
STATIC const mp_raw_code_t raw_code_logging__lt_module_gt__basicConfig = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 4,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt__basicConfig,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt__basicConfig,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 71,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file logging.py, scope logging_<module>
STATIC const byte bytecode_data_logging__lt_module_gt_[180] = {
    0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1d,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_logging_dot_py & 0xff, MP_QSTR_logging_dot_py >> 8,
    0x49, 0x49, 0x25, 0x24, 0x24, 0x24, 0x24, 0x44, 0x22, 0x27, 0x27, 0x27, 0x27, 0x6a, 0x8e, 0x2e, 0x26, 0x45, 0x8b, 0x08, 0x65, 0x65, 0x00, 0x00, 0xff,
    0x80, 
    0x11, 
    0x68, MP_QSTR_sys & 0xff, MP_QSTR_sys >> 8,
    0x24, MP_QSTR_sys & 0xff, MP_QSTR_sys >> 8,
    0x1b, MP_QSTR_sys & 0xff, MP_QSTR_sys >> 8,
    0x1d, MP_QSTR_stderr & 0xff, MP_QSTR_stderr >> 8,
    0x25, MP_QSTR__stream & 0xff, MP_QSTR__stream >> 8,
    0x14, 0x32, 
    0x24, MP_QSTR_CRITICAL & 0xff, MP_QSTR_CRITICAL >> 8,
    0xa8, 
    0x24, MP_QSTR_ERROR & 0xff, MP_QSTR_ERROR >> 8,
    0x9e, 
    0x24, MP_QSTR_WARNING & 0xff, MP_QSTR_WARNING >> 8,
    0x94, 
    0x24, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0x8a, 
    0x24, MP_QSTR_DEBUG & 0xff, MP_QSTR_DEBUG >> 8,
    0x80, 
    0x24, MP_QSTR_NOTSET & 0xff, MP_QSTR_NOTSET >> 8,
    0x53, 0x05, 
    0x16, MP_QSTR_CRIT & 0xff, MP_QSTR_CRIT >> 8,
    0x1b, MP_QSTR_CRITICAL & 0xff, MP_QSTR_CRITICAL >> 8,
    0x54, 
    0x16, MP_QSTR_ERROR & 0xff, MP_QSTR_ERROR >> 8,
    0x1b, MP_QSTR_ERROR & 0xff, MP_QSTR_ERROR >> 8,
    0x54, 
    0x16, MP_QSTR_WARN & 0xff, MP_QSTR_WARN >> 8,
    0x1b, MP_QSTR_WARNING & 0xff, MP_QSTR_WARNING >> 8,
    0x54, 
    0x16, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0x1b, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0x54, 
    0x16, MP_QSTR_DEBUG & 0xff, MP_QSTR_DEBUG >> 8,
    0x1b, MP_QSTR_DEBUG & 0xff, MP_QSTR_DEBUG >> 8,
    0x54, 
    0x25, MP_QSTR__level_dict & 0xff, MP_QSTR__level_dict >> 8,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_Logger & 0xff, MP_QSTR_Logger >> 8,
    0x1b, MP_QSTR_object & 0xff, MP_QSTR_object >> 8,
    0x64, 0x03, 
    0x24, MP_QSTR_Logger & 0xff, MP_QSTR_Logger >> 8,
    0x1b, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0x25, MP_QSTR__level & 0xff, MP_QSTR__level >> 8,
    0x53, 0x00, 
    0x25, MP_QSTR__loggers & 0xff, MP_QSTR__loggers >> 8,
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR_getLogger & 0xff, MP_QSTR_getLogger >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR_info & 0xff, MP_QSTR_info >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR_debug & 0xff, MP_QSTR_debug >> 8,
    0x1b, MP_QSTR_INFO & 0xff, MP_QSTR_INFO >> 8,
    0x11, 
    0x11, 
    0x11, 
    0x50, 0x04, 
    0x18, 
    0x61, 0x04, 
    0x24, MP_QSTR_basicConfig & 0xff, MP_QSTR_basicConfig >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_logging__lt_module_gt_[5] = {
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__Logger),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__getLogger),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__info),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__debug),
    MP_ROM_PTR(&raw_code_logging__lt_module_gt__basicConfig),
};
const mp_raw_code_t raw_code_logging__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_logging__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_logging__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 180,
        .n_obj = 0,
        .n_raw_code = 5,
        #endif
    },
};

// frozen bytecode for file collections/__init__.py, scope collections___init___<module>
STATIC const byte bytecode_data_collections___init____lt_module_gt_[228] = {
    0x09, 0x02, 0x00, 0x00, 0x00, 0x00, 0x11,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_collections_slash___init___dot_py & 0xff, MP_QSTR_collections_slash___init___dot_py >> 8,
    0x24, 0x1f, 0x59, 0x23, 0x1f, 0x50, 0x39, 0x2d, 0x3a, 0x2d, 0x00, 0x00, 0xff,
    0x3f, 0x2f, 0x00, 
    0x80, 
    0x16, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x16, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x16, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x50, 0x04, 
    0x68, MP_QSTR_collections & 0xff, MP_QSTR_collections >> 8,
    0x69, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x24, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x69, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x24, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x69, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x24, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x69, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x24, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x32, 
    0x44, 
    0x35, 0x7b, 0x80, 
    0x30, 
    0x1b, MP_QSTR_ImportError & 0xff, MP_QSTR_ImportError >> 8,
    0xdf, 
    0x37, 0x72, 0x80, 
    0x32, 
    0x3f, 0x26, 0x00, 
    0x80, 
    0x16, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x16, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x50, 0x03, 
    0x68, MP_QSTR_ucollections & 0xff, MP_QSTR_ucollections >> 8,
    0x69, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x24, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x69, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x24, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x69, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x24, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x32, 
    0x44, 
    0x35, 0x44, 0x80, 
    0x30, 
    0x1b, MP_QSTR_ImportError & 0xff, MP_QSTR_ImportError >> 8,
    0xdf, 
    0x37, 0x3b, 0x80, 
    0x32, 
    0x80, 
    0x16, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x16, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x50, 0x02, 
    0x68, MP_QSTR_ucollections & 0xff, MP_QSTR_ucollections >> 8,
    0x69, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x24, MP_QSTR_namedtuple & 0xff, MP_QSTR_namedtuple >> 8,
    0x69, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x24, MP_QSTR_OrderedDict & 0xff, MP_QSTR_OrderedDict >> 8,
    0x32, 
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x1b, MP_QSTR_globals & 0xff, MP_QSTR_globals >> 8,
    0x64, 0x00, 
    0xdd, 
    0xd3, 
    0x37, 0x10, 0x80, 
    0x81, 
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x69, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x24, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x32, 
    0x45, 
    0x35, 0x01, 0x80, 
    0x41, 
    0x45, 
    0x35, 0x01, 0x80, 
    0x41, 
    0x16, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x1b, MP_QSTR_globals & 0xff, MP_QSTR_globals >> 8,
    0x64, 0x00, 
    0xdd, 
    0xd3, 
    0x37, 0x10, 0x80, 
    0x81, 
    0x16, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x50, 0x01, 
    0x68, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x69, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x24, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x32, 
    0x11, 
    0x5b, 
};
const mp_raw_code_t raw_code_collections___init____lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_collections___init____lt_module_gt_,
        .const_table = NULL,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 228,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___new__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___new__[42] = {
    0x07, 0x00, 0x02, 0x02, 0x00, 0x01, 0x0b,
    MP_QSTR___new__ & 0xff, MP_QSTR___new__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x07, 0x30, 0x26, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_super & 0xff, MP_QSTR_super >> 8,
    0x1c, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0xb0, 
    0x64, 0x02, 
    0x1e, MP_QSTR___new__ & 0xff, MP_QSTR___new__ >> 8,
    0xb0, 
    0x66, 0x01, 
    0xc3, 
    0x53, 0x00, 
    0xb3, 
    0x26, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb3, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___new__[2] = {
    MP_ROM_QSTR(MP_QSTR_cls),
    MP_ROM_QSTR(MP_QSTR_default_factory),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___new__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x02,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___new__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___new__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 42,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___init__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___init__[29] = {
    0x05, 0x00, 0x02, 0x02, 0x00, 0x01, 0x0a,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x0c, 0x25, 0x00, 0x00, 0xff,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb1, 
    0xb0, 
    0x26, MP_QSTR_default_factory & 0xff, MP_QSTR_default_factory >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___init__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_default_factory),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x02,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___init__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 29,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___getitem__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___getitem__[114] = {
    0x0d, 0x03, 0x00, 0x02, 0x00, 0x00, 0x10,
    MP_QSTR___getitem__ & 0xff, MP_QSTR___getitem__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x10, 0x23, 0x57, 0x23, 0x55, 0x2a, 0x28, 0x27, 0x00, 0x00, 0xff,
    0x3f, 0x0b, 0x00, 
    0xb0, 
    0x1d, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb1, 
    0x21, 
    0x5b, 
    0x44, 
    0x35, 0x4b, 0x80, 
    0x30, 
    0x1c, MP_QSTR_KeyError & 0xff, MP_QSTR_KeyError >> 8,
    0xdf, 
    0x37, 0x42, 0x80, 
    0xc2, 
    0x40, 0x36, 0x00, 
    0x3f, 0x0c, 0x00, 
    0xb1, 
    0x1e, MP_QSTR___class__ & 0xff, MP_QSTR___class__ >> 8,
    0xb2, 
    0x66, 0x01, 
    0x32, 
    0x44, 
    0x35, 0x13, 0x80, 
    0x30, 
    0x1c, MP_QSTR_TypeError & 0xff, MP_QSTR_TypeError >> 8,
    0xdf, 
    0x37, 0x0a, 0x80, 
    0x32, 
    0x1c, MP_QSTR_StopIteration & 0xff, MP_QSTR_StopIteration >> 8,
    0x5c, 0x01, 
    0x45, 
    0x35, 0x01, 0x80, 
    0x41, 
    0xb0, 
    0x1e, MP_QSTR___missing__ & 0xff, MP_QSTR___missing__ >> 8,
    0xb1, 
    0x66, 0x01, 
    0xc3, 
    0xb3, 
    0xb0, 
    0x1d, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb1, 
    0x27, 
    0xb3, 
    0x5b, 
    0x44, 
    0x45, 
    0x11, 
    0x11, 
    0xc2, 
    0x28, 0x02, 
    0x41, 
    0x35, 0x01, 0x80, 
    0x41, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___getitem__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___getitem__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___getitem__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___getitem__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 114,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___setitem__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___setitem__[25] = {
    0x06, 0x00, 0x00, 0x03, 0x00, 0x00, 0x09,
    MP_QSTR___setitem__ & 0xff, MP_QSTR___setitem__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x1c, 0x00, 0x00, 0xff,
    0xb2, 
    0xb0, 
    0x1d, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb1, 
    0x27, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___setitem__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
    MP_ROM_QSTR(MP_QSTR_v),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___setitem__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___setitem__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___setitem__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 25,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___delitem__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___delitem__[26] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___delitem__ & 0xff, MP_QSTR___delitem__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x1f, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xb1, 
    0x18, 
    0x34, 
    0x27, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___delitem__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___delitem__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___delitem__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___delitem__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___contains__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___contains__[23] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR___contains__ & 0xff, MP_QSTR___contains__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x22, 0x00, 0x00, 0xff,
    0xb1, 
    0xb0, 
    0x1d, MP_QSTR_d & 0xff, MP_QSTR_d >> 8,
    0xdd, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___contains__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___contains__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___contains__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___contains__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 23,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict___missing__
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___missing__[42] = {
    0x04, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0b,
    MP_QSTR___missing__ & 0xff, MP_QSTR___missing__ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x81, 0x25, 0x29, 0x28, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_default_factory & 0xff, MP_QSTR_default_factory >> 8,
    0x11, 
    0xde, 
    0x37, 0x08, 0x80, 
    0x1c, MP_QSTR_KeyError & 0xff, MP_QSTR_KeyError >> 8,
    0xb1, 
    0x64, 0x01, 
    0x5c, 0x01, 
    0xb0, 
    0x1e, MP_QSTR_default_factory & 0xff, MP_QSTR_default_factory >> 8,
    0x66, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict___missing__[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_key),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict___missing__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict___missing__,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict___missing__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 42,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict__lt_module_gt__defaultdict
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt__defaultdict[86] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11,
    MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x4d, 0x8e, 0x09, 0x69, 0x20, 0x85, 0x0c, 0x65, 0x65, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x1b, MP_QSTR_staticmethod & 0xff, MP_QSTR_staticmethod >> 8,
    0x11, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x00, 
    0x64, 0x01, 
    0x24, MP_QSTR___new__ & 0xff, MP_QSTR___new__ >> 8,
    0x11, 
    0x50, 0x01, 
    0x18, 
    0x61, 0x01, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR___getitem__ & 0xff, MP_QSTR___getitem__ >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR___setitem__ & 0xff, MP_QSTR___setitem__ >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR___delitem__ & 0xff, MP_QSTR___delitem__ >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR___contains__ & 0xff, MP_QSTR___contains__ >> 8,
    0x60, 0x06, 
    0x24, MP_QSTR___missing__ & 0xff, MP_QSTR___missing__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt__defaultdict[7] = {
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___new__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___init__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___getitem__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___setitem__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___delitem__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___contains__),
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict___missing__),
};
STATIC const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt__defaultdict = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt__defaultdict,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt__defaultdict,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 86,
        .n_obj = 0,
        .n_raw_code = 7,
        #endif
    },
};

// frozen bytecode for file collections/defaultdict.py, scope collections_defaultdict_<module>
STATIC const byte bytecode_data_collections_defaultdict__lt_module_gt_[27] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_collections_slash_defaultdict_dot_py & 0xff, MP_QSTR_collections_slash_defaultdict_dot_py >> 8,
    0x00, 0x00, 0xff,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x64, 0x02, 
    0x24, MP_QSTR_defaultdict & 0xff, MP_QSTR_defaultdict >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_defaultdict__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_collections_defaultdict__lt_module_gt__defaultdict),
};
const mp_raw_code_t raw_code_collections_defaultdict__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_defaultdict__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_collections_defaultdict__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 27,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque___init__
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque___init__[50] = {
    0x05, 0x00, 0x00, 0x03, 0x00, 0x02, 0x0b,
    MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x61, 0x25, 0x26, 0x49, 0x00, 0x00, 0xff,
    0xb2, 
    0xb0, 
    0x26, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0xb1, 
    0x11, 
    0xde, 
    0x37, 0x09, 0x80, 
    0x51, 0x00, 
    0xb0, 
    0x26, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x35, 0x0a, 0x80, 
    0x1c, MP_QSTR_list & 0xff, MP_QSTR_list >> 8,
    0xb1, 
    0x64, 0x01, 
    0xb0, 
    0x26, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque___init__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_iterable),
    MP_ROM_QSTR(MP_QSTR_maxlen),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque___init__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 3,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque___init__,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque___init__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 50,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_popleft
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_popleft[27] = {
    0x04, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_popleft & 0xff, MP_QSTR_popleft >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x0a, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x80, 
    0x66, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_popleft[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_popleft = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_popleft,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_popleft,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 27,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_popright
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_popright[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_popright & 0xff, MP_QSTR_popright >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x0d, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x66, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_popright[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_popright = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_popright,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_popright,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_pop
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_pop[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x10, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x66, 0x00, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_pop[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_pop = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_pop,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_pop,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_append
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_append[65] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0b,
    MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x13, 0x2b, 0x3b, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0x11, 
    0xde, 
    0xd3, 
    0x37, 0x18, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x64, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0xd8, 
    0x37, 0x07, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_popleft & 0xff, MP_QSTR_popleft >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_append[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_a),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_append = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_append,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_append,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 65,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_appendleft
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_appendleft[66] = {
    0x06, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0b,
    MP_QSTR_appendleft & 0xff, MP_QSTR_appendleft >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x18, 0x2c, 0x3b, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_insert & 0xff, MP_QSTR_insert >> 8,
    0x80, 
    0xb1, 
    0x66, 0x02, 
    0x32, 
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0x11, 
    0xde, 
    0xd3, 
    0x37, 0x18, 0x80, 
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x64, 0x01, 
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0xd8, 
    0x37, 0x07, 0x80, 
    0xb0, 
    0x1e, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_appendleft[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_a),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_appendleft = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_appendleft,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_appendleft,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 66,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_extend
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_extend[29] = {
    0x05, 0x00, 0x00, 0x02, 0x00, 0x00, 0x09,
    MP_QSTR_extend & 0xff, MP_QSTR_extend >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x1d, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_extend & 0xff, MP_QSTR_extend >> 8,
    0xb1, 
    0x66, 0x01, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_extend[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_iterable),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_extend = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_extend,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_extend,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 29,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_extendleft
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_extendleft[36] = {
    0x0a, 0x00, 0x00, 0x02, 0x00, 0x00, 0x0a,
    MP_QSTR_extendleft & 0xff, MP_QSTR_extendleft >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x20, 0x26, 0x00, 0x00, 0xff,
    0xb1, 
    0x47, 
    0x43, 0x0c, 0x00, 
    0xc2, 
    0xb0, 
    0x1e, MP_QSTR_appendleft & 0xff, MP_QSTR_appendleft >> 8,
    0xb2, 
    0x66, 0x01, 
    0x32, 
    0x35, 0xf1, 0x7f, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_extendleft[2] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_QSTR(MP_QSTR_iterable),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_extendleft = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 2,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_extendleft,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_extendleft,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 36,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque_clear
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque_clear[28] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR_clear & 0xff, MP_QSTR_clear >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x24, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x1e, MP_QSTR_clear & 0xff, MP_QSTR_clear >> 8,
    0x66, 0x00, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque_clear[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque_clear = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque_clear,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque_clear,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 28,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque___len__
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque___len__[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___len__ & 0xff, MP_QSTR___len__ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x27, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_len & 0xff, MP_QSTR_len >> 8,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque___len__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque___len__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque___len__,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque___len__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque___bool__
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque___bool__[26] = {
    0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___bool__ & 0xff, MP_QSTR___bool__ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x2a, 0x00, 0x00, 0xff,
    0x1c, MP_QSTR_bool & 0xff, MP_QSTR_bool >> 8,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x64, 0x01, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque___bool__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque___bool__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque___bool__,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque___bool__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque___iter__
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque___iter__[26] = {
    0x03, 0x00, 0x04, 0x01, 0x00, 0x00, 0x09,
    MP_QSTR___iter__ & 0xff, MP_QSTR___iter__ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x2d, 0x00, 0x00, 0xff,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0x42, 
    0x11, 
    0x5e, 
    0x32, 
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque___iter__[1] = {
    MP_ROM_QSTR(MP_QSTR_self),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque___iter__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x04,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque___iter__,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque___iter__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 26,
        .n_obj = 0,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque___str__
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque___str__[56] = {
    0x07, 0x00, 0x00, 0x01, 0x00, 0x00, 0x0b,
    MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x81, 0x30, 0x25, 0x24, 0x00, 0x00, 0xff,
    0x17, 0x01, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_q & 0xff, MP_QSTR_q >> 8,
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0x11, 
    0xde, 
    0x37, 0x06, 0x80, 
    0x16, MP_QSTR_ & 0xff, MP_QSTR_ >> 8,
    0x35, 0x0b, 0x80, 
    0x17, 0x02, 
    0x1e, MP_QSTR_format & 0xff, MP_QSTR_format >> 8,
    0xb0, 
    0x1d, MP_QSTR_maxlen & 0xff, MP_QSTR_maxlen >> 8,
    0x66, 0x01, 
    0x66, 0x02, 
    0x5b, 
};
STATIC const mp_obj_str_t const_obj_collections_deque__lt_module_gt__deque___str___0 = {{&mp_type_str}, 18693, 13, (const byte*)"\x64\x65\x71\x75\x65\x28\x7b\x30\x7d\x7b\x31\x7d\x29"};
STATIC const mp_obj_str_t const_obj_collections_deque__lt_module_gt__deque___str___1 = {{&mp_type_str}, 33329, 12, (const byte*)"\x2c\x20\x6d\x61\x78\x6c\x65\x6e\x3d\x7b\x30\x7d"};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque___str__[3] = {
    MP_ROM_QSTR(MP_QSTR_self),
    MP_ROM_PTR(&const_obj_collections_deque__lt_module_gt__deque___str___0),
    MP_ROM_PTR(&const_obj_collections_deque__lt_module_gt__deque___str___1),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque___str__ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 1,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque___str__,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque___str__,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 56,
        .n_obj = 2,
        .n_raw_code = 0,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque__lt_module_gt__deque
STATIC const byte bytecode_data_collections_deque__lt_module_gt__deque[115] = {
    0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18,
    MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x4d, 0x8a, 0x07, 0x65, 0x65, 0x65, 0x65, 0x40, 0x65, 0x40, 0x65, 0x65, 0x20, 0x65, 0x65, 0x65, 0x65, 0x00, 0x00, 0xff,
    0x1b, MP_QSTR___name__ & 0xff, MP_QSTR___name__ >> 8,
    0x24, MP_QSTR___module__ & 0xff, MP_QSTR___module__ >> 8,
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x24, MP_QSTR___qualname__ & 0xff, MP_QSTR___qualname__ >> 8,
    0x11, 
    0x11, 
    0x50, 0x02, 
    0x18, 
    0x61, 0x00, 
    0x24, MP_QSTR___init__ & 0xff, MP_QSTR___init__ >> 8,
    0x60, 0x01, 
    0x24, MP_QSTR_popleft & 0xff, MP_QSTR_popleft >> 8,
    0x60, 0x02, 
    0x24, MP_QSTR_popright & 0xff, MP_QSTR_popright >> 8,
    0x60, 0x03, 
    0x24, MP_QSTR_pop & 0xff, MP_QSTR_pop >> 8,
    0x60, 0x04, 
    0x24, MP_QSTR_append & 0xff, MP_QSTR_append >> 8,
    0x60, 0x05, 
    0x24, MP_QSTR_appendleft & 0xff, MP_QSTR_appendleft >> 8,
    0x60, 0x06, 
    0x24, MP_QSTR_extend & 0xff, MP_QSTR_extend >> 8,
    0x60, 0x07, 
    0x24, MP_QSTR_extendleft & 0xff, MP_QSTR_extendleft >> 8,
    0x60, 0x08, 
    0x24, MP_QSTR_clear & 0xff, MP_QSTR_clear >> 8,
    0x60, 0x09, 
    0x24, MP_QSTR___len__ & 0xff, MP_QSTR___len__ >> 8,
    0x60, 0x0a, 
    0x24, MP_QSTR___bool__ & 0xff, MP_QSTR___bool__ >> 8,
    0x60, 0x0b, 
    0x24, MP_QSTR___iter__ & 0xff, MP_QSTR___iter__ >> 8,
    0x60, 0x0c, 
    0x24, MP_QSTR___str__ & 0xff, MP_QSTR___str__ >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt__deque[13] = {
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque___init__),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_popleft),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_popright),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_pop),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_append),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_appendleft),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_extend),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_extendleft),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque_clear),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque___len__),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque___bool__),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque___iter__),
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque___str__),
};
STATIC const mp_raw_code_t raw_code_collections_deque__lt_module_gt__deque = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt__deque,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt__deque,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 115,
        .n_obj = 0,
        .n_raw_code = 13,
        #endif
    },
};

// frozen bytecode for file collections/deque.py, scope collections_deque_<module>
STATIC const byte bytecode_data_collections_deque__lt_module_gt_[27] = {
    0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
    MP_QSTR__lt_module_gt_ & 0xff, MP_QSTR__lt_module_gt_ >> 8,
    MP_QSTR_collections_slash_deque_dot_py & 0xff, MP_QSTR_collections_slash_deque_dot_py >> 8,
    0x00, 0x00, 0xff,
    0x20, 
    0x60, 0x00, 
    0x16, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x64, 0x02, 
    0x24, MP_QSTR_deque & 0xff, MP_QSTR_deque >> 8,
    0x11, 
    0x5b, 
};
STATIC const mp_rom_obj_t const_table_data_collections_deque__lt_module_gt_[1] = {
    MP_ROM_PTR(&raw_code_collections_deque__lt_module_gt__deque),
};
const mp_raw_code_t raw_code_collections_deque__lt_module_gt_ = {
    .kind = MP_CODE_BYTECODE,
    .scope_flags = 0x00,
    .n_pos_args = 0,
    .data.u_byte = {
        .bytecode = bytecode_data_collections_deque__lt_module_gt_,
        .const_table = (mp_uint_t*)const_table_data_collections_deque__lt_module_gt_,
        #if MICROPY_PERSISTENT_CODE_SAVE
        .bc_len = 27,
        .n_obj = 0,
        .n_raw_code = 1,
        #endif
    },
};

const char mp_frozen_mpy_names[] = {
"bluetooth_low_energy/modules/base_hci.py\0"
"bluetooth_low_energy/modules/st_microelectronics/bluenrg_ms.py\0"
"bluetooth_low_energy/modules/st_microelectronics/__init__.py\0"
"bluetooth_low_energy/modules/st_microelectronics/spbtle_rf.py\0"
"bluetooth_low_energy/modules/__init__.py\0"
"bluetooth_low_energy/api/central.py\0"
"bluetooth_low_energy/api/delegate.py\0"
"bluetooth_low_energy/api/uuid.py\0"
"bluetooth_low_energy/api/characteristic.py\0"
"bluetooth_low_energy/api/service.py\0"
"bluetooth_low_energy/api/constants.py\0"
"bluetooth_low_energy/api/scanner.py\0"
"bluetooth_low_energy/api/peripheral.py\0"
"bluetooth_low_energy/api/__init__.py\0"
"bluetooth_low_energy/api/descriptor.py\0"
"bluetooth_low_energy/api/util.py\0"
"bluetooth_low_energy/api/scan_entry.py\0"
"bluetooth_low_energy/__init__.py\0"
"bluetooth_low_energy/protocols/__init__.py\0"
"bluetooth_low_energy/protocols/at/__init__.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/__init__.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/status.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/event.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/cmd.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/__init__.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/st_microelectronics/bluenrg_ms/constant.py\0"
"bluetooth_low_energy/protocols/hci/vendor_specifics/__init__.py\0"
"bluetooth_low_energy/protocols/hci/acl.py\0"
"bluetooth_low_energy/protocols/hci/smp.py\0"
"bluetooth_low_energy/protocols/hci/uart.py\0"
"bluetooth_low_energy/protocols/hci/status.py\0"
"bluetooth_low_energy/protocols/hci/l2cap.py\0"
"bluetooth_low_energy/protocols/hci/event.py\0"
"bluetooth_low_energy/protocols/hci/cmd.py\0"
"bluetooth_low_energy/protocols/hci/att.py\0"
"bluetooth_low_energy/protocols/hci/sco.py\0"
"bluetooth_low_energy/protocols/hci/__init__.py\0"
"logging.py\0"
"collections/__init__.py\0"
"collections/defaultdict.py\0"
"collections/deque.py\0"
"\0"};
const mp_raw_code_t *const mp_frozen_mpy_content[] = {
    &raw_code_bluetooth_low_energy_modules_base_hci__lt_module_gt_,
    &raw_code_bluetooth_low_energy_modules_st_microelectronics_bluenrg_ms__lt_module_gt_,
    &raw_code_bluetooth_low_energy_modules_st_microelectronics___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_modules_st_microelectronics_spbtle_rf__lt_module_gt_,
    &raw_code_bluetooth_low_energy_modules___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_central__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_delegate__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_uuid__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_characteristic__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_service__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_constants__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_scanner__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_peripheral__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_descriptor__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_util__lt_module_gt_,
    &raw_code_bluetooth_low_energy_api_scan_entry__lt_module_gt_,
    &raw_code_bluetooth_low_energy___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_at___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_status__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_event__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_cmd__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics_st_microelectronics_bluenrg_ms_constant__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_vendor_specifics___init____lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_acl__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_smp__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_uart__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_status__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_l2cap__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_event__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_cmd__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_att__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci_sco__lt_module_gt_,
    &raw_code_bluetooth_low_energy_protocols_hci___init____lt_module_gt_,
    &raw_code_logging__lt_module_gt_,
    &raw_code_collections___init____lt_module_gt_,
    &raw_code_collections_defaultdict__lt_module_gt_,
    &raw_code_collections_deque__lt_module_gt_,
};
